/****************************************************************************
 *
 *  Rohde & Schwarz RTO Digital Oscilloscope instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSSCOPE_HEADER
#define __RSSCOPE_HEADER

#include "rscore.h"
#include "rsscope_attributes.h"
#include "rsscope_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#define RSSCOPE_VAL_MEASUREMENT_RUNNING_MASK 0x1D
#define RSSCOPE_VAL_WAIT_FOR_TRIGGER_MASK 0x08

    /*****************************************************************************
     *- Useful Macros & Constants -----------------------------------------------*
     *****************************************************************************/
#define RSSCOPE_SIMULATION_ID_QUERY      "Rohde&Schwarz,RTO,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSSCOPE_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSSCOPE_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSSCOPE_OPC_TIMEOUT              50000L   /* Maximum time to wait for OPC in milliseconds */

     /****************************************************************************
      *----------------- Instrument Driver Revision Information -----------------*
      ****************************************************************************/

      /* Class Driver Identification */

#define RSSCOPE_CLASS_DRIVER_DESCRIPTION           ""
#define RSSCOPE_CLASS_DRIVER_PREFIX                ""
#define RSSCOPE_CLASS_DRIVER_VENDOR                ""
#define RSSCOPE_CLASS_DRIVER_REVISION              ""
#define RSSCOPE_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSSCOPE_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSSCOPE_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSSCOPE_SPECIFIC_DRIVER_PREFIX             "RSSCOPE"
#define RSSCOPE_SPECIFIC_DRIVER_LOCATOR            ""
#define RSSCOPE_SPECIFIC_DRIVER_VENDOR             ""
#define RSSCOPE_MAJOR_VERSION                      5L    /* Instrument driver major version          */
#define RSSCOPE_MINOR_VERSION                      35L    /* Instrument driver minor version          */
#define RSSCOPE_MINOR_MINOR_VERSION                1L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSSCOPE_SUPPORTED_INSTRUMENT_MODELS        "RTO,RTE,RTP"    /* Instrument driver supported model(s)     */
#define RSSCOPE_GROUP_CAPABILITIES                 ""
#define RSSCOPE_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

 /*- Inherent Instrument Specific Attributes ----------------------------*/

     /* User Options */

#define RSSCOPE_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSSCOPE_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSSCOPE_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSSCOPE_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSSCOPE_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSSCOPE_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSSCOPE_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSSCOPE_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSSCOPE_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSSCOPE_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSSCOPE_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSSCOPE_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSSCOPE_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSSCOPE_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSSCOPE_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSSCOPE_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSSCOPE_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSSCOPE_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSSCOPE_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */

        /* Driver Setup */

#define RSSCOPE_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSSCOPE_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSSCOPE_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSSCOPE_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSSCOPE_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSSCOPE_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSSCOPE_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSSCOPE_ATTR_INTERPOLATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSSCOPE_ATTR_NUM_AVERAGES                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSSCOPE_ATTR_SAMPLE_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSSCOPE_ATTR_HORZ_RECORD_SELECTION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSSCOPE_ATTR_ACQUISITION_AUTO_ADJUSTMENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1743
#define RSSCOPE_ATTR_HORZ_TIME_PER_RECORD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSSCOPE_ATTR_HORZ_RECORD_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSSCOPE_ATTR_HORZ_RECORD_LENGTH_LIMIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSSCOPE_ATTR_HORZ_SCALE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSSCOPE_ATTR_ZVC_RECORD_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3247
#define RSSCOPE_ATTR_ZVC_CURRENT_RESOLUTION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3248
#define RSSCOPE_ATTR_ACQUSITION_START_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSSCOPE_ATTR_NUMBER_OF_ACQUISITIONS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2608
#define RSSCOPE_ATTR_ACQUISITION_RESTRICT_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSSCOPE_ATTR_ACQUISITION_SAMPLE_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3244
#define RSSCOPE_ATTR_ACQUISITION_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSSCOPE_ATTR_HORZ_SAMPLE_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSSCOPE_ATTR_HORZ_ADC_SAMPLE_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSSCOPE_ATTR_AUTOSCALE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSSCOPE_ATTR_HORZ_DIVISIONS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSSCOPE_ATTR_HORZ_REFERENCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSSCOPE_ATTR_HORZ_RESOLUTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSSCOPE_ATTR_ROLL_MODE_AUTO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSSCOPE_ATTR_ROLL_STATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1647
#define RSSCOPE_ATTR_ROLL_MODE_THRESHOLD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSSCOPE_ATTR_ULTRA_SEGMENTATION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSSCOPE_ATTR_ULTRA_SEGMENTATION_DEPENDENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSSCOPE_ATTR_ULTRA_SEGMENTATION_AUTO_REPLAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSSCOPE_ATTR_CALIBRATION_SOURCE_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3304
#define RSSCOPE_ATTR_CALIBRATION_SOURCE_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSSCOPE_ATTR_CALIBRATION_OPERATING_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSSCOPE_ATTR_CALIBRATION_DESTINATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSSCOPE_ATTR_CALIBRATION_RESULT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3858
#define RSSCOPE_ATTR_CALIBRATION_DATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4093
#define RSSCOPE_ATTR_CALIBRATION_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4094
#define RSSCOPE_ATTR_REF_OSCILLATOR_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 470
#define RSSCOPE_ATTR_REF_OSCILLATOR_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSSCOPE_ATTR_PROBE_STATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSSCOPE_ATTR_PROBE_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSSCOPE_ATTR_PROBE_NAME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSSCOPE_ATTR_PROBE_INPUT_IMPEDANCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSSCOPE_ATTR_PROBE_INPUT_CAPACITANCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSSCOPE_ATTR_PROBE_ATTENUATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSSCOPE_ATTR_PROBE_BANDWIDTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSSCOPE_ATTR_PROBE_SET_OFFSET_TO_MEAN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSSCOPE_ATTR_PROBE_DEGAUSS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2446
#define RSSCOPE_ATTR_PROBE_AUTO_ZERO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSSCOPE_ATTR_PROBE_USE_AUTO_ZERO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2447
#define RSSCOPE_ATTR_PROBE_ZERO_ADJUST_VALUE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2448
#define RSSCOPE_ATTR_PROBE_SAVE_TO_PROBE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2449
#define RSSCOPE_ATTR_PROBE_MICRO_BUTTON_ACTION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSSCOPE_ATTR_PROBE_SOFTWARE_VERSION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSSCOPE_ATTR_PROBE_PRODUCTION_DATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSSCOPE_ATTR_PROBE_PART_NUMBER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSSCOPE_ATTR_PROBE_SERIAL_NUMBER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSSCOPE_ATTR_PROBE_FIRMWARE_PATH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSSCOPE_ATTR_PROBE_FIRMWARE_UPDATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSSCOPE_ATTR_PROBE_FIRMWARE_UPDATE_STATUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 326
#define RSSCOPE_ATTR_PROBE_SELFTEST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 327
#define RSSCOPE_ATTR_PROBE_SELFTEST_STATUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSSCOPE_ATTR_PROBE_DETECTION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSSCOPE_ATTR_PROBE_ATTENUATION_MANUAL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSSCOPE_ATTR_PROBE_VERTICAL_UNIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 474
#define RSSCOPE_ATTR_PROBE_GAIN_MANUAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSSCOPE_ATTR_DETECTED_PROBE_GAIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSSCOPE_ATTR_PROBE_PREDEFINED_CURRENT_PROBE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSSCOPE_ATTR_PROBE_PREDEFINED_TEKTRONICS_PROBE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3859
#define RSSCOPE_ATTR_PROBE_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3215
#define RSSCOPE_ATTR_PROBE_DM_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3216
#define RSSCOPE_ATTR_PROBE_CM_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1480
#define RSSCOPE_ATTR_PROBE_POSITIVE_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3217
#define RSSCOPE_ATTR_PROBE_NEGATIVE_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3218
#define RSSCOPE_ATTR_PROBE_ATTENUATOR_ZA15                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1481
#define RSSCOPE_ATTR_PROBE_TERMINATION_VOLTAGE_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3219
#define RSSCOPE_ATTR_PROBE_TERMINATION_VOLTAGE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3220
#define RSSCOPE_ATTR_PROBE_TERMINATION_VOLTAGE_ADJUSTMENT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3221
#define RSSCOPE_ATTR_PROBE_TERMINATION_VOLTAGE_MEASURE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3222
#define RSSCOPE_ATTR_PROBE_COUPLING_AC                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3249
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3860
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_SELECT_TIP_MODULE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3305
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_CUSTOM_TIP_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3861
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_ZMA30_SELECT_TIP_SUBMODULE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3306
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_ZMA40_SELECT_TIP_SUBMODULE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3307
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_BANDWIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3308
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_PROBING_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3309
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_REMOVE_PROBE_LOADING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3310
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_IMPEDANCE_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3311
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_IMPEDANCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3312
#define RSSCOPE_ATTR_PROBE_DEEMBEDDING_LOAD_S_PARAMETER_FILE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3851
#define RSSCOPE_ATTR_PROBE_PROBEMETER_COPY_TO_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3314
#define RSSCOPE_ATTR_PROBE_RT_ZHD_VOLTAGE_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3315
#define RSSCOPE_ATTR_PROBE_RT_ZHD_BANDWIDTH_LIMIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3316
#define RSSCOPE_ATTR_PROBE_RT_ZHD_OVERRANGE_BUZZER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3317
#define RSSCOPE_ATTR_PROBE_ADAPTER_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3862
#define RSSCOPE_ATTR_PROBE_CONVERTER_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3863
#define RSSCOPE_ATTR_PROBE_RTZ1M_BANDWIDTH_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3864
#define RSSCOPE_ATTR_PROBE_RTZ1M_SELF_ALIGN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3865
#define RSSCOPE_ATTR_PMETER_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1482
#define RSSCOPE_ATTR_PMETER_VISIBILITY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1483
#define RSSCOPE_ATTR_PMETER_DISPLAY_DIFF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1484
#define RSSCOPE_ATTR_PMETER_MEASUREMENT_COMMON_RESULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1485
#define RSSCOPE_ATTR_PMATER_MEASUREMENT_DIFFERENTIAL_RESULT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1486
#define RSSCOPE_ATTR_PMETER_MEASUREMENT_POSITIVE_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1487
#define RSSCOPE_ATTR_PMETER_MEASUREMENT_NEGATIVE_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1488
#define RSSCOPE_ATTR_PMETER_MEASUREMENT_SINGLE_RESULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1489
#define RSSCOPE_ATTR_ZVC_BANDWIDTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3250
#define RSSCOPE_ATTR_ZVC_DECIMATION_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3251
#define RSSCOPE_ATTR_ZVC_RESOLUTION_COUPLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3866
#define RSSCOPE_ATTR_ZVC_NAME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3252
#define RSSCOPE_ATTR_ZVC_PART_NUMBER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3253
#define RSSCOPE_ATTR_ZVC_SERIAL_NUMBER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3254
#define RSSCOPE_ATTR_ZVC_FIRMWARE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3255
#define RSSCOPE_ATTR_ZVC_I_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3256
#define RSSCOPE_ATTR_ZVC_I_BANDWIDTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3257
#define RSSCOPE_ATTR_ZVC_I_IMPEDANCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3258
#define RSSCOPE_ATTR_ZVC_I_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3259
#define RSSCOPE_ATTR_ZVC_I_DESKEW_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3260
#define RSSCOPE_ATTR_ZVC_I_RESET_OVERLOAD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3261
#define RSSCOPE_ATTR_ZVC_I_OVERLOAD_DETECTED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3262
#define RSSCOPE_ATTR_ZVC_I_VERTICAL_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3263
#define RSSCOPE_ATTR_ZVC_I_VERTICAL_SCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3264
#define RSSCOPE_ATTR_ZVC_I_SHUNT_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3265
#define RSSCOPE_ATTR_ZVC_I_SHUNT_EXTERNAL_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3266
#define RSSCOPE_ATTR_ZVC_I_SHUNT_INTERNAL_MAXIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3267
#define RSSCOPE_ATTR_ZVC_I_SHUNT_MAXIMUM_CURRENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3268
#define RSSCOPE_ATTR_ZVC_I_SHUNT_EXTERNAL_MAXIMUM_VOLTAGE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3269
#define RSSCOPE_ATTR_ZVC_I_ZERO_OFFSET_DETECT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4095
#define RSSCOPE_ATTR_ZVC_I_ZERO_OFFSET_USE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4096
#define RSSCOPE_ATTR_ZVC_I_ZERO_OFFSET_STATUS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4097
#define RSSCOPE_ATTR_ZVC_V_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3270
#define RSSCOPE_ATTR_ZVC_V_BANDWIDTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3271
#define RSSCOPE_ATTR_ZVC_V_IMPEDANCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3272
#define RSSCOPE_ATTR_ZVC_V_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3273
#define RSSCOPE_ATTR_ZVC_V_DESKEW_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3274
#define RSSCOPE_ATTR_ZVC_V_RESET_OVERLOAD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3275
#define RSSCOPE_ATTR_ZVC_V_OVERLOAD_DETECTED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3276
#define RSSCOPE_ATTR_ZVC_V_VERTICAL_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3277
#define RSSCOPE_ATTR_ZVC_V_VERTICAL_SCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3278
#define RSSCOPE_ATTR_TRIGGER_PROBE_STATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1490
#define RSSCOPE_ATTR_TRIGGER_PROBE_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1491
#define RSSCOPE_ATTR_TRIGGER_PROBE_NAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1492
#define RSSCOPE_ATTR_TRIGGER_PROBE_INPUT_IMPEDANCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1493
#define RSSCOPE_ATTR_TRIGGER_PROBE_INPUT_CAPACITANCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1494
#define RSSCOPE_ATTR_TRIGGER_PROBE_ATTENUATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1495
#define RSSCOPE_ATTR_TRIGGER_PROBE_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1496
#define RSSCOPE_ATTR_TRIGGER_PROBE_SET_OFFSET_TO_MEAN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1497
#define RSSCOPE_ATTR_TRIGGER_PROBE_AUTO_ZERO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1498
#define RSSCOPE_ATTR_TRIGGER_PROBE_CM_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1499
#define RSSCOPE_ATTR_TRIGGER_PROBE_ATTENUATOR_ZA15                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1500
#define RSSCOPE_ATTR_TRIGGER_PROBE_MICRO_BUTTON_ACTION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1501
#define RSSCOPE_ATTR_TRIGGER_PROBE_SOFTWARE_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1502
#define RSSCOPE_ATTR_TRIGGER_PROBE_PRODUCTION_DATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1503
#define RSSCOPE_ATTR_TRIGGER_PROBE_PART_NUMBER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1504
#define RSSCOPE_ATTR_TRIGGER_PROBE_SERIAL_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1505
#define RSSCOPE_ATTR_TRIGGER_PROBE_FIRMWARE_PATH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1506
#define RSSCOPE_ATTR_TRIGGER_PROBE_FIRMWARE_UPDATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1507
#define RSSCOPE_ATTR_TRIGGER_PROBE_FIRMWARE_UPDATE_STATUS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1508
#define RSSCOPE_ATTR_TRIGGER_PROBE_SELFTEST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1509
#define RSSCOPE_ATTR_TRIGGER_PROBE_SELFTEST_STATUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1510
#define RSSCOPE_ATTR_TRIGGER_PROBE_SELFTEST_RESULT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1511
#define RSSCOPE_ATTR_TRIGGER_PROBE_DETECTION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1512
#define RSSCOPE_ATTR_TRIGGER_PROBE_ATTENUATION_MANUAL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1513
#define RSSCOPE_ATTR_TRIGGER_PROBE_VERTICAL_UNIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1514
#define RSSCOPE_ATTR_TRIGGER_PROBE_GAIN_MANUAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1515
#define RSSCOPE_ATTR_TRIGGER_DETECTED_PROBE_GAIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1516
#define RSSCOPE_ATTR_TRIGGER_PROBE_PREDEFINED_CURRENT_PROBE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1517
#define RSSCOPE_ATTR_TRIGGER_INPUT_PROBE_COUPLING_AC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3318
#define RSSCOPE_ATTR_TRIGGER_INPUT_PROBE_RT_ZHD_OVERRANGE_BUZZER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3319
#define RSSCOPE_ATTR_TRIGGER_INPUT_PROBE_RT_ZHD_BANDWIDTH_LIMIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3320
#define RSSCOPE_ATTR_TRIGGER_INPUT_PROBE_DEGAUSS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3321
#define RSSCOPE_ATTR_TRIGGER_INPUT_PROBE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3322
#define RSSCOPE_ATTR_TRIGGER_PMETER_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1518
#define RSSCOPE_ATTR_TRIGGER_PMETER_DISPLAY_DIFF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1519
#define RSSCOPE_ATTR_TRIGGER_PMETER_VISIBILITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1520
#define RSSCOPE_ATTR_TRIGGER_PMETER_MEASUREMENT_COMMON_RESULT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1521
#define RSSCOPE_ATTR_TRIGGER_PMATER_MEASUREMENT_DIFFERENTIAL_RESULT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1522
#define RSSCOPE_ATTR_TRIGGER_PMETER_MEASUREMENT_POSITIVE_RESULT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1523
#define RSSCOPE_ATTR_TRIGGER_PMETER_MEASUREMENT_NEGATIVE_RESULT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1524
#define RSSCOPE_ATTR_TRIGGER_PMETER_MEASUREMENT_SINGLE_RESULT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1525
#define RSSCOPE_ATTR_CHANNEL_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSSCOPE_ATTR_VERTICAL_RANGE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSSCOPE_ATTR_VERTICAL_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSSCOPE_ATTR_CHANNEL_INVERT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2810
#define RSSCOPE_ATTR_VERTICAL_COUPLING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSSCOPE_ATTR_VERTICAL_SCALE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSSCOPE_ATTR_CHANNEL_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSSCOPE_ATTR_CHANNEL_BANDWIDTH_LIMIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSSCOPE_ATTR_CHANNEL_OVERLOAD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSSCOPE_ATTR_CHANNEL_ANTIALIASING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3323
#define RSSCOPE_ATTR_INPUT_IMPEDANCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSSCOPE_ATTR_GROUND_CONNECTION_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSSCOPE_ATTR_DIGITAL_FILTER_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSSCOPE_ATTR_DIGITAL_FILTER_CUT_OFF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSSCOPE_ATTR_EXTERNAL_ATTENUATION_SCALE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define RSSCOPE_ATTR_EXTERNAL_ATTENUATION_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSSCOPE_ATTR_WAVEFORM_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSSCOPE_ATTR_WAVEFORM_HEADER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSSCOPE_ATTR_ACQUISITION_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSSCOPE_ATTR_WAVEFORM_ACQUISITION_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSSCOPE_ATTR_WAVEFORM_ACQUISITION_COUPLE_CHANNELS_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2658
#define RSSCOPE_ATTR_MULTIWAVEFORM_ACQUISITION_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2659
#define RSSCOPE_ATTR_SKEW_OFFSET_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSSCOPE_ATTR_SKEW_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSSCOPE_ATTR_SKEW_EXTENSION_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3324
#define RSSCOPE_ATTR_PROBE_SKEW_STATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3325
#define RSSCOPE_ATTR_COUPLE_VERTICAL_CHANNEL_SETTINGS_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3869
#define RSSCOPE_ATTR_QUERY_VERTICAL_CHANNEL_SETTINGS_COUPLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3870
#define RSSCOPE_ATTR_DIFFERENTIAL_SIGNAL_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3871
#define RSSCOPE_ATTR_DIFFERENTIAL_SIGNAL_POSITIVE_INPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3872
#define RSSCOPE_ATTR_DIFFERENTIAL_SIGNAL_NEGATIVE_INPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3873
#define RSSCOPE_ATTR_DIFFERENTIAL_SIGNAL_OUTPUT_A                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3874
#define RSSCOPE_ATTR_DIFFERENTIAL_SIGNAL_OUTPUT_B                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3875
#define RSSCOPE_ATTR_DIFFERENTIAL_COMMON_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4098
#define RSSCOPE_ATTR_DIFFERENTIAL_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4099
#define RSSCOPE_ATTR_DIFFERENTIAL_COMMON_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4100
#define RSSCOPE_ATTR_DIFFERENTIAL_POSITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4101
#define RSSCOPE_ATTR_DIFFERENTIAL_COMMON_SCALE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4102
#define RSSCOPE_ATTR_DIFFERENTIAL_SCALE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4103
#define RSSCOPE_ATTR_DIFFERENTIAL_COMMON_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4104
#define RSSCOPE_ATTR_DIFFERENTIAL_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4105
#define RSSCOPE_ATTR_DIFFERENTIAL_NEGATIVE_SIGNAL_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4106
#define RSSCOPE_ATTR_DIFFERENTIAL_POSITIVE_SIGNAL_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4107
#define RSSCOPE_ATTR_DIFFERENTIAL_COUPLING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4108
#define RSSCOPE_ATTR_HIGH_DEFINITION_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1744
#define RSSCOPE_ATTR_HIGH_DEFINITION_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1745
#define RSSCOPE_ATTR_HIGH_DEFINITION_RESOLUTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1746
#define RSSCOPE_ATTR_TRIGGER_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSSCOPE_ATTR_TRIGGER_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSSCOPE_ATTR_TRIGGER_SERIAL_BUS_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2295
#define RSSCOPE_ATTR_TRIGGER_MODIFIER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSSCOPE_ATTR_TRIGGER_LEVEL_AUTO_FIND                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSSCOPE_ATTR_TRIGGER_EVENT_COUPLING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSSCOPE_ATTR_TRIGGER_SOURCE_COUPLING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSSCOPE_ATTR_TRIGGER_LINES_DISPLAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSSCOPE_ATTR_TRIGGER_OUT_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSSCOPE_ATTR_TRIGGER_OUT_ACTION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4463
#define RSSCOPE_ATTR_TRIGGER_OUT_POLARITY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define RSSCOPE_ATTR_TRIGGER_OUT_PULSE_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define RSSCOPE_ATTR_TRIGGER_OUT_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSSCOPE_ATTR_TRIGGER_EVENT_BEEP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2296
#define RSSCOPE_ATTR_TRIGGER_EVENT_PRINT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2297
#define RSSCOPE_ATTR_TRIGGER_EVENT_SAVE_WAVEFORM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2298
#define RSSCOPE_ATTR_TRIGGER_EVENT_RUN_EXTERNAL_APPLICATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3326
#define RSSCOPE_ATTR_TRIGGER_EVENT_TRIGGER_OUT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4465
#define RSSCOPE_ATTR_TRIGGER_EXTERNAL_OVERLOAD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1526
#define RSSCOPE_ATTR_DIGITAL_FILTER_TRIGGER_COUPLING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSSCOPE_ATTR_HIGH_FREQUENCY_REJECT_TRIGGER_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3327
#define RSSCOPE_ATTR_TRIGGER_AC_POWER_INPUT_SLOPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3328
#define RSSCOPE_ATTR_TRIGGER_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSSCOPE_ATTR_DIGITAL_FILTER_TRIGGER_RF_REJECT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_COUPLING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSSCOPE_ATTR_TRIGGER_SLOPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQUENCY_HIGHPASS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 758
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQUENCY_LOWPASS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 759
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_GROUND_CONNECTION_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_NOISE_REJECT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1527
#define RSSCOPE_ATTR_RUNT_CONDITION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSSCOPE_ATTR_RUNT_WIDTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSSCOPE_ATTR_RUNT_DELTA                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSSCOPE_ATTR_RUNT_POLARITY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSSCOPE_ATTR_RUNT_HIGH_THRESHOLD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSSCOPE_ATTR_RUNT_LOW_THRESHOLD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSSCOPE_ATTR_GLITCH_WIDTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSSCOPE_ATTR_GLITCH_POLARITY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSSCOPE_ATTR_GLITCH_CONDITION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSSCOPE_ATTR_WIDTH_CONDITION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSSCOPE_ATTR_WIDTH                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSSCOPE_ATTR_WIDTH_DELTA                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSSCOPE_ATTR_WIDTH_POLARITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSSCOPE_ATTR_WINDOW_CONDITION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSSCOPE_ATTR_WINDOW_WIDTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSSCOPE_ATTR_WINDOW_DELTA                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSSCOPE_ATTR_WINDOW_TIME_CONDITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 752
#define RSSCOPE_ATTR_WINDOW_UPPER_LIMIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSSCOPE_ATTR_WINDOW_LOWER_LIMIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSSCOPE_ATTR_TIMEOUT_CONDITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSSCOPE_ATTR_TIMEOUT_VALUE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSSCOPE_ATTR_INTERVAL_CONDITION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSSCOPE_ATTR_INTERVAL_WIDTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSSCOPE_ATTR_INTERVAL_DELTA                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSSCOPE_ATTR_INTERVAL_POLARITY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSSCOPE_ATTR_SLEW_CONDITION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSSCOPE_ATTR_SLEW_RATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSSCOPE_ATTR_SLEW_DELTA                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSSCOPE_ATTR_SLEW_POLARITY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSSCOPE_ATTR_SLEW_UPPER_LIMIT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSSCOPE_ATTR_SLEW_LOWER_LIMIT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSSCOPE_ATTR_DATA2CLOCK_SIGNAL_EDGE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4466
#define RSSCOPE_ATTR_DATA2CLOCK_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSSCOPE_ATTR_DATA2CLOCK_LEVEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSSCOPE_ATTR_DATA2CLOCK_HOLD_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSSCOPE_ATTR_DATA2CLOCK_SETUP_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSSCOPE_ATTR_DATA2CLOCK_POLARITY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSSCOPE_ATTR_PATTERN_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSSCOPE_ATTR_PATTERN_TIMEOUT_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSSCOPE_ATTR_PATTERN_TIMEOUT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSSCOPE_ATTR_PATTERN_CONDITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSSCOPE_ATTR_PATTERN_WIDTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSSCOPE_ATTR_PATTERN_DELTA                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSSCOPE_ATTR_SERIAL_PATTERN_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSSCOPE_ATTR_SERIAL_PATTERN_LEVEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSSCOPE_ATTR_SERIAL_PATTERN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSSCOPE_ATTR_SERIAL_PATTERN_POLARITY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSSCOPE_ATTR_SERIAL_PATTERN_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3876
#define RSSCOPE_ATTR_SERIAL_PATTERN_REFERENCE_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4467
#define RSSCOPE_ATTR_SERIAL_PATTERN_BIT_PATTERN_A                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3877
#define RSSCOPE_ATTR_SERIAL_PATTERN_BIT_PATTERN_B                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3878
#define RSSCOPE_ATTR_SERIAL_PATTERN_BIT_PATTERN_LENGTH_A                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3879
#define RSSCOPE_ATTR_SERIAL_PATTERN_BIT_PATTERN_LENGTH_B                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3880
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_ALIGNMENT_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3882
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_ALIGNMENT_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3883
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_ALIGNMENT_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3884
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_ALIGNMENT_TIMEOUT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3885
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_IDLE_RANGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3886
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_LOGIC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3887
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_BIT_ORDER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3888
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_CONDITION_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3881
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_BIT_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3889
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_PATTERN_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3890
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_SEARCH_RANGE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3891
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_PATTERN_CONDITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3892
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3893
#define RSSCOPE_ATTR_SERIAL_PATTERN_COMPLEX_WORD_PATTERN_RANGE_END                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3894
#define RSSCOPE_ATTR_SERIAL_PATTERN_PRBS_ERROR_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3895
#define RSSCOPE_ATTR_SERIAL_PATTERN_PRBS_NOMINAL_BIT_RATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3896
#define RSSCOPE_ATTR_SERIAL_PATTERN_PRBS_SEQUENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3897
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_ALIGNMENT_SYMBOL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3898
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_SCRAMBLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3899
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_KD_SYMBOL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3900
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_EIGHT_BIT_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3901
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_TEN_BIT_D_PLUS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3903
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_TEN_BIT_D_MINUS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3902
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_APPEND_ROW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3904
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_ROW_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3905
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_CLEAR_TABLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3906
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_DISPARITY_ERROR_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3907
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_SYMBOL_ERROR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3908
#define RSSCOPE_ATTR_SERIAL_PATTERN_EBTB_FRAME_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3909
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_ALIGNMENT_PATTERN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3910
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_SKIP_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3911
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_SKIP_END                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3912
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_SKIP_BYTES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3913
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3914
#define RSSCOPE_ATTR_SERIAL_PATTERN_I32B_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3915
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_ALIGNMENT_PATTERN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4361
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_SKIP_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4362
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_SKIP_END                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4363
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_SKIP_BYTES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4364
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4365
#define RSSCOPE_ATTR_SERIAL_PATTERN_I30B_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4366
#define RSSCOPE_ATTR_NFC_TRIGGER_TECHNOLOGY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define RSSCOPE_ATTR_NFC_TRIGGER_BIT_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSSCOPE_ATTR_NFC_TRIGGER_EVENT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_ALGORITHM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4468
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_BIT_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4469
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_BIT_RATE_ESTIMATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4470
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_CONTINUOUS_BIT_RATE_ESTIMATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4471
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4472
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_LEVEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4473
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_RELATIVE_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4474
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_SAMPLING_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4475
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_SERIAL_STANDARD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4476
#define RSSCOPE_ATTR_CDR_TRIGGER_EYE_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4477
#define RSSCOPE_ATTR_TV_TRIGGER_STANDARD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSSCOPE_ATTR_TV_TRIGGER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSSCOPE_ATTR_TV_TRIGGER_LINE_NUMBER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSSCOPE_ATTR_TV_TRIGGER_FIELD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSSCOPE_ATTR_TV_TRIGGER_POLARITY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSSCOPE_ATTR_TV_TRIGGER_PULSE_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSSCOPE_ATTR_TV_TRIGGER_LINE_PERIOD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSSCOPE_ATTR_TV_TRIGGER_PULSE_WIDTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSSCOPE_ATTR_TV_TRIGGER_SCAN_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_1                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3916
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_2                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3917
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_3                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3918
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_4                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3919
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3920
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3921
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_3                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3922
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_4                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3923
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_1_2                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3924
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_3_4                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3925
#define RSSCOPE_ATTR_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_ALL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3926
#define RSSCOPE_ATTR_NOISE_REJECT_HYSTERESIS_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSSCOPE_ATTR_NOISE_REJECT_HYSTERESIS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSSCOPE_ATTR_NOISE_REJECT_HYSTERESIS_RELATIVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1528
#define RSSCOPE_ATTR_NOISE_REJECT_HYSTERESIS_SCALE_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1529
#define RSSCOPE_ATTR_NOISE_REJECT_HYSTERESIS_RANGE_IN_DIVISIONS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3329
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_EVENTS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_RANDOM_MINIMUM_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_RANDOM_MAXIMUM_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_AUTO_TIME_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_HOLDOFF_AUTO_SCALE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_B_EVENTS_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_RESET_BY_TIMEOUT_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_RESET_TIMEOUT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_RESET_EVENT_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSSCOPE_ATTR_TRIGGER_SEQUENCE_EVENT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4464
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_NACK                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 760
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_DATA_WRITE_NACK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 761
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_DATA_READ_NACK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 762
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS_BIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_POSITION_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 583
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_POSITION_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 763
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_POSITION_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 764
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_DATA_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_PATTERN_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 765
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_PATTERN_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 766
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_OR_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_OR_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_OR_ACCESS_BIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_OR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_POSITION_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 586
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_DATA_ALIGNMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_DATA_INDEX_MIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_DATA_INDEX_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 587
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_MOSI_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 767
#define RSSCOPE_ATTR_PROTOCOL_SPI_TRIGGER_MISO_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 768
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 411
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 414
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 415
#define RSSCOPE_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 416
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_DATA_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 588
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_DATA_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 589
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_DATA_TRANSFER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 590
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_CONDITION_DATA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 769
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_DATA_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 770
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_DATA_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 771
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 772
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_IDENTIFIER_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 773
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_PATTERN_IDENTIFIER_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 774
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_ADDRESS_OR_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_ADDRESS_OR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_CHECKSUM_ERROR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 775
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_CRC_ERROR_PATTERN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_CRC_ERROR_DATA_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_CRC_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER_PARITY_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 776
#define RSSCOPE_ATTR_PROTOCOL_LIN_TRIGGER_SYNC_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 777
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_STANDARD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1747
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_ID_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_FDF                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1748
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_BRS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1749
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FD_BITS_ESI                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1750
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_ENDIANNESS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_DATA_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 778
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_DATA_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 779
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_DATA_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 780
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_DLC_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1648
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_DLC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1649
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_NUMBER_OF_DATA_BYTES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3211
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_POSITION_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1751
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_POSITION_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1752
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_POSITION_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1753
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 781
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_IDENTIFIER_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 782
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_PATTERN_IDENTIFIER_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 783
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_CHECKSUM_ERROR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 784
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_BIT_STUFFING_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 785
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_FORM_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 786
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_ACK_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 787
#define RSSCOPE_ATTR_PROTOCOL_CAN_TRIGGER_STUFF_COUNT_ERROR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3212
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_MESSAGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1754
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_ON_SIGNAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1755
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_SIGNAL_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1756
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_SIGNAL_MIN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1757
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_SIGNAL_MAX                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1758
#define RSSCOPE_ATTR_PROTOCOL_CAN_SYMBOLIC_TRIGGER_SIGNAL_ENUM_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1759
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 602
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_CYCLE_STEP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_SYMBOL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PAYLOAD_PREAMBLE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 788
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_NULL_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 789
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_SYNC_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 790
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_STARTUP_FRAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 791
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_FRAME_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 792
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PATTERN_FRAME_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 793
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PATTERN_FRAME_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 794
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_DATA_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 795
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PATTERN_DATA_MIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 796
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PATTERN_DATA_MAX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 797
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PAYLOAD_LENGTH_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 798
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PAYLOAD_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 799
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PAYLOAD_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 800
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_CYCLE_COUNT_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 801
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_CYCLE_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 802
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_CYCLE_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 803
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_DATA_POSITION_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 804
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_DATA_POSITION_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 805
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_DATA_POSITION_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 806
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_FRAME_START_SEQUENCE_ERROR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 807
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_BYTE_START_SEQUENCE_ERROR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 808
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_FRAME_END_SEQUENCE_ERROR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 809
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_HEADER_CRC_ERROR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 810
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_TRIGGER_PAYLOAD_CRC_ERROR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 811
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_WINDOW_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_WORD_SELECT_SLOPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_CHANNEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_PATTERN_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 812
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRIGGER_PATTERN_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 813
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1530
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_SYNC_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1531
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_PATTERN_CONDITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1532
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_PATTERN_MIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1533
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_PATTERN_MAX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1534
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_INDEX_CONDITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1535
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_INDEX_MIN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1536
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_DATA_INDEX_MAX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1537
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_DATA_PATTERN_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1760
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_DATA_PATTERN_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1761
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_DATA_PATTERN_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1762
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_PATTERN_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1538
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_PATTERN_MIN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1539
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_RTA_PATTERN_MAX                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1540
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_INFO_PATTERN_CONDITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1541
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_INFO_PATTERN_MIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1542
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_INFO_PATTERN_MAX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1543
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_COMMAND_TRANSMIT_RECEIVE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1544
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_SUBADDRESS_PATTERN_CONDITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1545
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_SUBADDRESS_PATTERN_MIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1546
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_SUBADDRESS_PATTERN_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1547
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_COMMAND_RTA_PATTERN_CONDITION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1763
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_COMMAND_RTA_PATTERN_MIN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1764
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_COMMAND_RTA_PATTERN_MAX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1765
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_WORD_COUNT_PATTERN_CONDITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1548
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_WORD_COUNT_PATTERN_MIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1549
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_WORD_COUNT_PATTERN_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1550
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_MESSAGE_ERROR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1551
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_BUSY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1552
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_INSTRUMENTATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1553
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_SUBSYSTEM                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1554
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_SERVICE_REQUEST                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1555
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_DYNAMIC_BUS_CONTROL              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1556
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_BROADCAST_COMMAND                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1557
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_STATUS_FLAG_TERMINAL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1558
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_SYNCHRONIZATION_ERROR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1559
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_PARITY_ERROR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1560
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_MANCHESTER_CODING_ERROR                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1561
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_TIMING_MIN_GAP_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1562
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_TIMING_MIN_GAP_TIME                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1563
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_TIMING_MAX_RESPONSE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1564
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_TRIGGER_ERROR_TIMING_MAX_RESPONSE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1565
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1566
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_LABEL_DATA_SDI                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1567
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_LABEL_DATA_SSM                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1568
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_LABEL_PATTERN_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1569
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_LABEL_PATTERN_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1570
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_LABEL_PATTERN_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1571
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_DATA_PATTERN_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1572
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_DATA_PATTERN_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1573
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_DATA_PATTERN_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1574
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_CODING_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1575
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_PARITY_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1576
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_TIMING_MIN_GAP_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1577
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_TIMING_MIN_GAP_BITS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1578
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_TIMING_MAX_GAP_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1579
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_TRIGGER_ERROR_TIMING_MAX_GAP_BITS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1580
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1786
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_INTERRUPT_PATTERN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4109
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_SLAVE_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1787
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_SLAVE_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1788
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_SLAVE_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1789
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ADDRESS_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1790
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ADDRESS_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1791
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ADDRESS_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1792
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_BYTE_COUNT_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1793
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_BYTE_COUNT_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1794
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_BYTE_COUNT_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1795
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_DATA_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1796
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_DATA_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1797
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_DATA_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1798
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_INDEX_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1799
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_INDEX_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1800
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_INDEX_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1801
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_MASK_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4110
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_MASK_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4111
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_MASK_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4112
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_SCC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1802
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_LENGTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1803
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_BUS_PARK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1804
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_PARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1805
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_NO_RESPONSE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1806
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_UNKNOWN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1807
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_GAP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4113
#define RSSCOPE_ATTR_PROTOCOL_RFFE_TRIGGER_ERROR_VERSION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4114
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1946
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_START_CODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1947
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_OPERATION_CODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1948
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_PHYSICAL_PORT_ADDRESS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1949
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_REGISTER_DEVICE_ADDRESS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1950
#define RSSCOPE_ATTR_PROTOCOL_MDIO_TRIGGER_DATA_ADDRESS_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1951
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3330
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3331
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_ERROR_CRC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4115
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_ERROR_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4116
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_ERROR_PREAMBLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4117
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_CRC_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4118
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_CRC_PATTERN_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4119
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_CRC_PATTERN_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4120
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_DESTINATION_ADDRESS_CONDITION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4121
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_DESTINATION_ADDRESS_PATTERN_MIN                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4122
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_DESTINATION_ADDRESS_PATTERN_MAX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4123
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_SOURCE_ADDRESS_CONDITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4124
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_SOURCE_ADDRESS_PATTERN_MIN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4125
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_SOURCE_ADDRESS_PATTERN_MAX                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4126
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_TYPE_OPERATOR_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4127
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_TYPE_OPERATOR_PATTERN_MIN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4128
#define RSSCOPE_ATTR_ETHERNET_TRIGGER_FRAME_TYPE_OPERATOR_PATTERN_MAX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4129
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2050
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_TOKEN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2051
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_DATA_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2052
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_HANDSHAKE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2053
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SPECIAL_PID                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2054
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ERROR_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2055
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PID_ERROR_CHECK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2056
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_END_POINT_CHECK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2057
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_END_POINT_CHECK_CONDITION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2058
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_END_POINT_CHECK_MIN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2059
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_END_POINT_CHECK_MAX                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2060
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ADDRESS_CHECK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2061
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ADDRESS_CHECK_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2062
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ADDRESS_CHECK_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2063
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ADDRESS_CHECK_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2064
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PAYLOAD_CHECK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2065
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PAYLOAD_CHECK_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2066
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PAYLOAD_CHECK_POSITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2067
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PAYLOAD_CHECK_DATA_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2068
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PAYLOAD_CHECK_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2069
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_FRAME_CHECK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2070
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_FRAME_CHECK_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2071
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_FRAME_CHECK_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2072
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_FRAME_CHECK_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2073
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SC_CHECK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2074
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SC_CHECK_START_COMPLETE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2075
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PORT_CHECK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2076
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PORT_CHECK_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2077
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PORT_CHECK_MIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2078
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_PORT_CHECK_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2079
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SEU_CHECK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2080
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SEU_CHECK_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2081
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SEU_CHECK_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2082
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_SEU_CHECK_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2083
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ET_CHECK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2084
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ET_CHECK_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2085
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ET_CHECK_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2086
#define RSSCOPE_ATTR_PROTOCOL_USB_TRIGGER_ET_CHECK_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2087
#define RSSCOPE_ATTR_USB_PD_TRIGGER_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3030
#define RSSCOPE_ATTR_USB_PD_TRIGGER_PACKET_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3032
#define RSSCOPE_ATTR_USB_PD_TRIGGER_DATA_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3034
#define RSSCOPE_ATTR_USB_PD_TRIGGER_DATA_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3035
#define RSSCOPE_ATTR_USB_PD_TRIGGER_DATA_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3036
#define RSSCOPE_ATTR_USB_PD_TRIGGER_INDEX_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3037
#define RSSCOPE_ATTR_USB_PD_TRIGGER_INDEX_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3038
#define RSSCOPE_ATTR_USB_PD_TRIGGER_INDEX_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3039
#define RSSCOPE_ATTR_USB_PD_TRIGGER_BIT_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3040
#define RSSCOPE_ATTR_MANCHESTER_NRZ_TRIGGER_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2253
#define RSSCOPE_ATTR_MANCHESTER_NRZ_TRIGGER_DATA_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2254
#define RSSCOPE_ATTR_MANCHESTER_NRZ_TRIGGER_INDEX_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2255
#define RSSCOPE_ATTR_MANCHESTER_NRZ_TRIGGER_INDEX_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2256
#define RSSCOPE_ATTR_MANCHESTER_NRZ_TRIGGER_INDEX_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2257
#define RSSCOPE_ATTR_NRZ_TRIGGER_WORD_LENGTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2258
#define RSSCOPE_ATTR_SENT_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2259
#define RSSCOPE_ATTR_SENT_TRIGGER_TRANSMISSION_SEQUENCE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2260
#define RSSCOPE_ATTR_SENT_TRIGGER_TRANSMISSION_SEQUENCE_STATUS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2261
#define RSSCOPE_ATTR_SENT_TRIGGER_TRANSMISSION_SEQUENCE_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2262
#define RSSCOPE_ATTR_SENT_TRIGGER_TRANSMISSION_SEQUENCE_DATA_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2263
#define RSSCOPE_ATTR_SENT_TRIGGER_TRANSMISSION_SEQUENCE_DATA_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2264
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2265
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_ID_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2266
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_ID_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2268
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_ID_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2269
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_ID_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2270
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_DATA_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2271
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_DATA_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2272
#define RSSCOPE_ATTR_SENT_TRIGGER_SERIAL_MESSAGE_DATA_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2273
#define RSSCOPE_ATTR_PROTOCOL_SENT_TRIGGER_FORM_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2274
#define RSSCOPE_ATTR_PROTOCOL_SENT_TRIGGER_CALIBRATION_PULSE_ERROR                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2275
#define RSSCOPE_ATTR_PROTOCOL_SENT_TRIGGER_PULSE_PERIOD_ERROR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2276
#define RSSCOPE_ATTR_PROTOCOL_SENT_TRIGGER_CRC_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2277
#define RSSCOPE_ATTR_PROTOCOL_SENT_TRIGGER_IRREGULAR_FRAME_LENGTH_ERROR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2278
#define RSSCOPE_ATTR_DPHY_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2468
#define RSSCOPE_ATTR_DPHY_TRIGGER_VIRTUAL_CHANNEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2469
#define RSSCOPE_ATTR_DPHY_TRIGGER_DATA_TYPE_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2470
#define RSSCOPE_ATTR_DPHY_TRIGGER_DATA_TYPE_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2471
#define RSSCOPE_ATTR_DPHY_TRIGGER_DATA_TYPE_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2472
#define RSSCOPE_ATTR_DPHY_TRIGGER_WORD_COUNT_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2473
#define RSSCOPE_ATTR_DPHY_TRIGGER_WORD_COUNT_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2474
#define RSSCOPE_ATTR_DPHY_TRIGGER_WORD_COUNT_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2475
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2476
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2477
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2478
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_CONDITION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2479
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2480
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2481
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_INDEX_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2482
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_INDEX_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2483
#define RSSCOPE_ATTR_DPHY_TRIGGER_HIGH_SPEED_DATA_INDEX_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2484
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_INDEX_CONDITION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2485
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_INDEX_MIN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2486
#define RSSCOPE_ATTR_DPHY_TRIGGER_LOW_POWER_ESCAPE_MODE_DATA_INDEX_MAX                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2487
#define RSSCOPE_ATTR_DPHY_TRIGGER_ESCAPE_MODE_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2513
#define RSSCOPE_ATTR_DPHY_TRIGGER_ESCAPE_MODE_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2514
#define RSSCOPE_ATTR_DPHY_TRIGGER_ESCAPE_MODE_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2515
#define RSSCOPE_ATTR_MPHY_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2660
#define RSSCOPE_ATTR_MPHY_TRIGGER_LCC_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2661
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_ONE_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2662
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_ONE_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2663
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_ONE_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2664
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_TWO_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2665
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_TWO_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2666
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_TWO_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2667
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_THREE_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2668
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_THREE_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2669
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_THREE_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2670
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_FOUR_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2671
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_FOUR_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2672
#define RSSCOPE_ATTR_MPHY_TRIGGER_WORD_FOUR_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2673
#define RSSCOPE_ATTR_MPHY_TRIGGER_TC_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2674
#define RSSCOPE_ATTR_MPHY_TRIGGER_DATA_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2675
#define RSSCOPE_ATTR_MPHY_TRIGGER_DATA_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2676
#define RSSCOPE_ATTR_MPHY_TRIGGER_DATA_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2677
#define RSSCOPE_ATTR_MPHY_TRIGGER_INDEX_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2678
#define RSSCOPE_ATTR_MPHY_TRIGGER_INDEX_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2679
#define RSSCOPE_ATTR_MPHY_TRIGGER_INDEX_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2680
#define RSSCOPE_ATTR_MPHY_TRIGGER_FSN_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2681
#define RSSCOPE_ATTR_MPHY_TRIGGER_FSN_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2682
#define RSSCOPE_ATTR_MPHY_TRIGGER_FSN_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2683
#define RSSCOPE_ATTR_MPHY_TRIGGER_CRC_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2684
#define RSSCOPE_ATTR_MPHY_TRIGGER_CRC_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2685
#define RSSCOPE_ATTR_MPHY_TRIGGER_CRC_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2686
#define RSSCOPE_ATTR_MPHY_TRIGGER_CREQ_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2687
#define RSSCOPE_ATTR_MPHY_TRIGGER_RREQ_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2688
#define RSSCOPE_ATTR_MPHY_TRIGGER_CREDIT_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2689
#define RSSCOPE_ATTR_MPHY_TRIGGER_CREDIT_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2690
#define RSSCOPE_ATTR_MPHY_TRIGGER_CREDIT_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2691
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_BEGIN_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2692
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_BEGIN_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2693
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_BEGIN_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2694
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_ID_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2695
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_ID_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2696
#define RSSCOPE_ATTR_MPHY_TRIGGER_PACP_ID_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2697
#define RSSCOPE_ATTR_MPHY_TRIGGER_PRP_WIDTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3392
#define RSSCOPE_ATTR_MPHY_TRIGGER_LCC_ERROR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2698
#define RSSCOPE_ATTR_MPHY_TRIGGER_ERROR_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2699
#define RSSCOPE_ATTR_MPHY_TRIGGER_ERROR_RESERVED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2700
#define RSSCOPE_ATTR_MPHY_TRIGGER_ERROR_SYMBOL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2701
#define RSSCOPE_ATTR_MPHY_TRIGGER_ERROR_UNIDENTIFIED_UNIPRO_FRAME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2702
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2576
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_CONTROL_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2580
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_TIME_CODE_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2577
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_TIME_CODE_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2578
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_TIME_CODE_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2579
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_DATA_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2581
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_DATA_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2582
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_DATA_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2583
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_PARITY_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2584
#define RSSCOPE_ATTR_SPACE_WIRE_TRIGGER_ESCAPE_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2585
#define RSSCOPE_ATTR_ZONE_LOGICAL_EXPRESSION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2703
#define RSSCOPE_ATTR_APPLY_ZONE_TRIGGER_HISTORY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3413
#define RSSCOPE_ATTR_CXPI_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2888
#define RSSCOPE_ATTR_CXPI_TRIGGER_NM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2889
#define RSSCOPE_ATTR_CXPI_TRIGGER_CT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2890
#define RSSCOPE_ATTR_CXPI_TRIGGER_FRAME_ID_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2891
#define RSSCOPE_ATTR_CXPI_TRIGGER_FRAME_ID_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2892
#define RSSCOPE_ATTR_CXPI_TRIGGER_FRAME_ID_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2893
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2894
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2895
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2896
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_EXTEND_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2897
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_EXTEND_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2898
#define RSSCOPE_ATTR_CXPI_TRIGGER_DLC_EXTEND_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2899
#define RSSCOPE_ATTR_CXPI_TRIGGER_DATA_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2900
#define RSSCOPE_ATTR_CXPI_TRIGGER_DATA_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2901
#define RSSCOPE_ATTR_CXPI_TRIGGER_DATA_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2902
#define RSSCOPE_ATTR_CXPI_TRIGGER_INDEX_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2903
#define RSSCOPE_ATTR_CXPI_TRIGGER_INDEX_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2904
#define RSSCOPE_ATTR_CXPI_TRIGGER_INDEX_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2905
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_CRC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2906
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_DLC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2907
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_IBS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2908
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_IFS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2909
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2910
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_PARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2911
#define RSSCOPE_ATTR_CXPI_TRIGGER_ERROR_UART                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2912
#define RSSCOPE_ATTR_PCIE_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3064
#define RSSCOPE_ATTR_PCIE_TRIGGER_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4367
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3065
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_SEQUENCE_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3066
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_TC                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3067
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_ORDERING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3068
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_SNOOP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3069
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_REQUESTER_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3070
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_DEVICE_ID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3071
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_READ_WRITE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3072
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_ADDRESS_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3073
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3074
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_AT_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4368
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_ROUTING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3075
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_MESSAGE_CODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3076
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_STATUS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3077
#define RSSCOPE_ATTR_PCIE_TRIGGER_TLP_COMPLETER_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3078
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3089
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3090
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_INIT_PHASE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3091
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_INIT_VH_FC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3092
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_INIT_MIXED_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3093
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_INIT_AUTHORIZED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3094
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_INIT_DEVICE_PORT_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3095
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_VL_NUMBER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3096
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_VH_ABSENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3097
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_TLP_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3098
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_CREDIT_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3099
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_A                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3100
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_MR_VH_GROUP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3101
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_SEQUENCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3102
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_FC_CREDIT_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3103
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_FC_VC_ID                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3104
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_PM_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3105
#define RSSCOPE_ATTR_PCIE_TRIGGER_DLLP_VENDOR_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3106
#define RSSCOPE_ATTR_PCIE_TRIGGER_OSET_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3110
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_CRC16                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3111
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_LCRC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3112
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_ECRC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3113
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_INVALID_SYMBOL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3114
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_DISP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3115
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4369
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_MALFORM_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4370
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_MAX_END_PREFIX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4371
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_PREFIX_ORDER_ERROR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4372
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_SYNC_BIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4373
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_VALUE_OUT_OF_RANGE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4374
#define RSSCOPE_ATTR_PCIE_TRIGGER_ERRC_UNKNOWN_PACKET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4375
#define RSSCOPE_ATTR_EBTB_TRIGGER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3301
#define RSSCOPE_ATTR_EBTB_TRIGGER_CONDITION_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4376
#define RSSCOPE_ATTR_EBTB_TRIGGER_DISPARITY_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3279
#define RSSCOPE_ATTR_EBTB_TRIGGER_DATA_CHARACTER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3280
#define RSSCOPE_ATTR_EBTB_TRIGGER_DX_SYMBOL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3281
#define RSSCOPE_ATTR_EBTB_TRIGGER_DY_SYMBOL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3282
#define RSSCOPE_ATTR_EBTB_TRIGGER_SYMBOL_FORMAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3283
#define RSSCOPE_ATTR_EBTB_TRIGGER_EB_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3284
#define RSSCOPE_ATTR_EBTB_TRIGGER_TB_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3285
#define RSSCOPE_ATTR_EBTB_TRIGGER_GLITCH_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3286
#define RSSCOPE_ATTR_EBTB_TRIGGER_SYMBOL_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3287
#define RSSCOPE_ATTR_EBTB_TRIGGER_SYMBOL_EXPRESSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3288
#define RSSCOPE_ATTR_EBTB_TRIGGER_UNKNOWN_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3289
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3414
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DESTINATION_ADDRESS_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3415
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DESTINATION_ADDRESS_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3416
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DESTINATION_ADDRESS_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3417
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_SOURCE_ADDRESS_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3418
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_SOURCE_ADDRESS_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3419
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_SOURCE_ADDRESS_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3420
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_TYPE_LENGTH_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3421
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_TYPE_LENGTH_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3422
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_TYPE_LENGTH_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3423
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_CRC_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3424
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_CRC_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3425
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_CRC_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3426
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DATA_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3427
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DATA_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3428
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_DATA_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3429
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_INDEX_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3430
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_INDEX_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3431
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_INDEX_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3432
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_ERROR_PREAMBLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3433
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_ERROR_CRC                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3434
#define RSSCOPE_ATTR_100BASE_T1_TRIGGER_ERROR_SFD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3435
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4217
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4377
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DESTINATION_ADDRESS_CONDITION            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4218
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DESTINATION_ADDRESS_MIN                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4219
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DESTINATION_ADDRESS_MAX                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4220
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_SOURCE_ADDRESS_CONDITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4221
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_SOURCE_ADDRESS_MIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4222
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_SOURCE_ADDRESS_MAX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4223
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_LENGTH_TYPE_CONDITION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4224
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_LENGTH_TYPE_MIN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4225
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_LENGTH_TYPE_MAX                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4226
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_FRAME_CHECK_CRC_CONDITION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4227
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_FRAME_CHECK_CRC_MIN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4228
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_FRAME_CHECK_CRC_MAX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4229
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DATA_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4230
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DATA_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4231
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_DATA_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4232
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_INDEX_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4233
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_INDEX_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4234
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_INDEX_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4235
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_ERROR_RS_FEC                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4236
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_ERROR_CRC                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4237
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_ERROR_OUT_OF_RANGE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4238
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_TRIGGER_ERROR_ZERO_TERNARY_SYMBOL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4239
#define RSSCOPE_ATTR_RUN_SINGLE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSSCOPE_ATTR_RUN_SINGLE_WITHOUT_WAIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2162
#define RSSCOPE_ATTR_RUN_CONTINUOUS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSSCOPE_ATTR_STOP                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSSCOPE_ATTR_FORCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSSCOPE_ATTR_SEND_SW_TRIGGER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSSCOPE_ATTR_SEND_SW_TRIGGER_AND_WAIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSSCOPE_ATTR_CURSOR_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSSCOPE_ATTR_ALL_CURSORS_OFF                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSSCOPE_ATTR_CURSOR_MEASUREMENT_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSSCOPE_ATTR_CURSOR_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSSCOPE_ATTR_CURSOR_TRACKING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSSCOPE_ATTR_CURSOR_RESULT_TABLE_POSITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3927
#define RSSCOPE_ATTR_CURSOR_X_POSITION_COUPLING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSSCOPE_ATTR_CURSOR_Y_POSITION_COUPLING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSSCOPE_ATTR_CURSOR_ENVELOPE_CURVE_1                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 814
#define RSSCOPE_ATTR_CURSOR_ENVELOPE_CURVE_2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 815
#define RSSCOPE_ATTR_CURSOR_HORIZONTAL_DISTANCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 816
#define RSSCOPE_ATTR_CURSOR_HORIZONTAL_DELTA_SLOPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3436
#define RSSCOPE_ATTR_CURSOR_VERTICAL_DISTANCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 817
#define RSSCOPE_ATTR_CURSOR_INVERSE_DISTANCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSSCOPE_ATTR_CURSOR_SEARCH_PEAK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4055
#define RSSCOPE_ATTR_CURSOR_SEARCH_NEXT_LEFT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4056
#define RSSCOPE_ATTR_CURSOR_SEARCH_NEXT_RIGHT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4057
#define RSSCOPE_ATTR_CURSOR_SEARCH_NEXT_ABSOLUTE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4058
#define RSSCOPE_ATTR_CURSOR_PEAK_EXCURSION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSSCOPE_ATTR_CURSOR_THRESHOLD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2441
#define RSSCOPE_ATTR_CURSOR_SOURCE_2                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3290
#define RSSCOPE_ATTR_CURSOR_SOURCE_2_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3291
#define RSSCOPE_ATTR_CURSOR_LABEL_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3292
#define RSSCOPE_ATTR_CURSOR_STYLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3293
#define RSSCOPE_ATTR_CURSOR_SHOW_IN_ALL_DIAGRAMS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3928
#define RSSCOPE_ATTR_CURSOR_VERTICAL_LABEL_LEFT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4480
#define RSSCOPE_ATTR_CURSOR_VERTICAL_LABEL_RIGHT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4481
#define RSSCOPE_ATTR_CURSOR_HORIZONTAL_LABEL_LOWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4482
#define RSSCOPE_ATTR_CURSOR_HORIZONTAL_LABEL_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4483
#define RSSCOPE_ATTR_CURSOR_SPECTRUM_WAVEFORMS_C1_TO_CENTER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3229
#define RSSCOPE_ATTR_CURSOR_SPECTRUM_WAVEFORMS_CENTER_TO_C1                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3230
#define RSSCOPE_ATTR_CURSOR_X_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSSCOPE_ATTR_CURSOR_Y_POSITION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSSCOPE_ATTR_MEASUREMENT_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSSCOPE_ATTR_MULTIPLE_MEASUREMENT_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSSCOPE_ATTR_MULTIPLE_MEASUREMENT_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define RSSCOPE_ATTR_MEASUREMENT_CATEGORY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSSCOPE_ATTR_ADDITIONAL_MEASUREMENTS_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSSCOPE_ATTR_ADDITIONAL_MEASUREMENTS_DISABLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSSCOPE_ATTR_CLEAR_MEASUREMENT_STATISTIC_DATA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSSCOPE_ATTR_MEASUREMENT_LIMIT_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSSCOPE_ATTR_MEASUREMENT_DISPLAY_STYLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSSCOPE_ATTR_GENERATE_BEEP_ON_MEASUREMENT_EVENT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSSCOPE_ATTR_STOP_ACQUISITION_ON_MEASUREMENT_EVENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSSCOPE_ATTR_PRINT_ON_MEASUREMENT_EVENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSSCOPE_ATTR_SAVE_WAVEFORM_DATA_ON_MEASUREMENT_EVENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSSCOPE_ATTR_CREATE_TRIGGER_OUT_PULSE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3231
#define RSSCOPE_ATTR_SAVE_REPORT_ON_MEASUREMENT_EVENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3437
#define RSSCOPE_ATTR_START_EXTERNAL_APPLICATION_ON_MEASUREMENT_EVENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3438
#define RSSCOPE_ATTR_MEASUREMENT_PREFIX_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1581
#define RSSCOPE_ATTR_DEFINE_FIRST_MEASUREMENT_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3929
#define RSSCOPE_ATTR_DEFINE_SECOND_MEASUREMENT_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3930
#define RSSCOPE_ATTR_AMPT_MAIN_MEASUREMENT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSSCOPE_ATTR_AMPT_AREA_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSSCOPE_ATTR_AMPT_SIGNAL_DETECTION_THRESHOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSSCOPE_ATTR_AMPLITUDE_PULSES_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 821
#define RSSCOPE_ATTR_AMPLITUDE_MEASURED_SLOPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2609
#define RSSCOPE_ATTR_AMPLITUDE_EDGES_SLOPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 822
#define RSSCOPE_ATTR_AMPLITUDE_CLOCK_SLOPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 823
#define RSSCOPE_ATTR_AMPLITUDE_TIME_DATA_REFERENCE_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 824
#define RSSCOPE_ATTR_AMPLITUDE_TIME_CLOCK_REFERENCE_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 825
#define RSSCOPE_ATTR_AMPT_PULSE_TRAIN_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSSCOPE_ATTR_ENVELOPE_SELECTION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSSCOPE_ATTR_AMPLITUDE_DELAY_TO_TRIGGER_SLOPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1304
#define RSSCOPE_ATTR_AMPLITUDE_DELAY_TO_TRIGGER_REFERENCE_LEVEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1305
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_PARAMETER_MEASUREMENT_TYPE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4378
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_PARAMETER_AMPTIME_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4379
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_PARAMETER_GROUP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4380
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_PARAMETER_MEASUREMENT_SPECTRUM              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4381
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_OPERATOR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4382
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_CONSTANT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4383
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_CONSTANT_UNIT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4384
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_CUSTOM_NAME_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4385
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_CUSTOM_UNIT_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4386
#define RSSCOPE_ATTR_AMPLITUDE_TIME_ARITHMETIC_CUSTOM_UNIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4387
#define RSSCOPE_ATTR_AMPT_DELAY_LEVEL_SELECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSSCOPE_ATTR_AMPT_DELAY_SLOPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSSCOPE_ATTR_AMPT_DELAY_DIRECTION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSSCOPE_ATTR_AMPT_DELAY_EDGE_NUMBER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSSCOPE_ATTR_AMPT_LIMIT_CHECK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSSCOPE_ATTR_AMPLITUDE_TIME_LOWER_LIMIT_VALUE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 826
#define RSSCOPE_ATTR_AMPLITUDE_TIME_UPPER_LIMIT_VALUE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 827
#define RSSCOPE_ATTR_AMPLITUDE_TIME_LOWER_LIMIT_MARGIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 828
#define RSSCOPE_ATTR_AMPLITUDE_TIME_UPPER_LIMIT_MARGIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 829
#define RSSCOPE_ATTR_JITTER_MAIN_MEASUREMENT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 830
#define RSSCOPE_ATTR_JITTER_CLOCK_MEASUREMENT_CYCLE_BEGIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 832
#define RSSCOPE_ATTR_JITTER_CLOCK_MEASUREMENT_CYCLE_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 833
#define RSSCOPE_ATTR_JITTER_CLOCK_MEASUREMENT_PULSE_POLARITY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 834
#define RSSCOPE_ATTR_JITTER_DATA_MEASUREMENT_CLOCK_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 835
#define RSSCOPE_ATTR_JITTER_DATA_MEASUREMENT_DATA_SLOPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 836
#define RSSCOPE_ATTR_JITTER_DATA_MEASUREMENT_CLOCK_SLOPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 837
#define RSSCOPE_ATTR_JITTER_DATA_MEASUREMENT_UNIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4388
#define RSSCOPE_ATTR_JITTER_DELAY_MEASUREMENT_EDGE_POLARITY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 838
#define RSSCOPE_ATTR_JITTER_DELAY_MEASUREMENT_RELATIVE_POLARITY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 839
#define RSSCOPE_ATTR_JITTER_LIMIT_CHECK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 840
#define RSSCOPE_ATTR_JITTER_LIMIT_LOWER_VALUE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 841
#define RSSCOPE_ATTR_JITTER_LIMIT_UPPER_VALUE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 842
#define RSSCOPE_ATTR_JITTER_LIMIT_LOWER_MARGIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 843
#define RSSCOPE_ATTR_JITTER_LIMIT_UPPER_MARGIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 844
#define RSSCOPE_ATTR_ADVANCED_JITTER_ANALYZED_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4130
#define RSSCOPE_ATTR_ADVANCED_JITTER_SERIAL_STANDARD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4240
#define RSSCOPE_ATTR_ADVANCED_JITTER_SIGNAL_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4131
#define RSSCOPE_ATTR_ADVANCED_JITTER_QUICK_START_ANALYSIS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4132
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4133
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4134
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CDR_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4135
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_NOMINAL_BITRATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4136
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_EDGE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4137
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_SAMPLING_TIME                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4389
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_MULTIPLIER_FACTOR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4390
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4391
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_OFFSET_ESTIMATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4392
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4393
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_FREQ_ESTIMATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4394
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_CLOCK_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4395
#define RSSCOPE_ATTR_ADVANCED_JITTER_REFERENCE_UI_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4138
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4139
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_COUPLING_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4140
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_COUPLED_CURSOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4141
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_COUPLED_ZOOM_DIAGRAM                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4142
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4144
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_ABSOLUTE_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4145
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_ABSOLUTE_STOP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4146
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_RELATIVE_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4147
#define RSSCOPE_ATTR_ADVANCED_JITTER_GATING_RELATIVE_STOP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4148
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_STEP_RESPONSE_LENGTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4149
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_ESTIMATE_STEP_RESPONSE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4150
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_STEP_RESPONSE_ESTIMATED_MAX             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4151
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_STEP_POSITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4241
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_TARGET_BER_EXPONENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4152
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_DISPLAY_INTERLEAVED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4396
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_DISPLAY_PERIODIC_JITTER_LABELS          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4397
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_DISPLAY_PERIODIC_NOISE_LABELS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4398
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_SELECT_ALL_BASIC_JITTER_COMPONENTS      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4153
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_SELECT_ALL_JITTER_COMPONENTS            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4154
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_CLEAR_SELECTED_BASIC_JITTER_COMPONENTS  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4155
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_CLEAR_SELECTED_JITTER_COMPONENTS        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4156
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_COMPONENT_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4157
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_SELECT_ALL_NOISE_COMPONENTS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4242
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_CLEAR_SELECTED_NOISE_COMPONENTS         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4243
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_PERIODIC_COMPONENTS_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4244
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_MAX_PERIODIC_VERTICAL_COMPONENTS        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4158
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_MAX_PERIODIC_HORIZONTAL_COMPONENTS      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4159
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_OTHER_BOUNDED_UNCORRELATED_ENABLED      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4245
#define RSSCOPE_ATTR_ADVANCED_JITTER_DECOMPOSITION_PERIODIC_JITTER_TABLE_ENABLED           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4160
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4161
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_STATISTICS_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4162
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_STEP_RESPONSE_DIAGRAM_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4163
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_BATHTUB_PLOT_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4164
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_BATHTUB_PLOT_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4165
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_BATHTUB_PERIODIC_COMPONENTS_ENABLED           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4246
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_BATHTUB_OBUJ_COMPONENTS_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4247
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_NOISE_BATHTUB_PLOT_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4248
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_NOISE_BATHTUB_PERIODIC_COMPONENTS_ENABLED     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4249
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_NOISE_BATHTUB_OBUN_COMPONENTS_ENABLED         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4250
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SYNTHETIC_EYE_PLOT_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4166
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SYNTHETIC_EYE_PLOT_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4167
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SYNTHETIC_EYE_HORIZONTAL_COMPONENTS_ENABLED   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4251
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SYNTHETIC_EYE_VERTICAL_COMPONENTS_ENABLED     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4252
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_DIAGRAM_TRANSITIONS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4168
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_DIAGRAM_LEVELS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4253
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_UNIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4169
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_HISTOGRAM_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4170
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_TRACK_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4171
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_SPECTRUM_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4172
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_SCALE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4173
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4174
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_PEAK_TO_PEAK                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4175
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STANDARD_DEVIATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4176
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STATISTICS_WAVEFORM_COUNT           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4177
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STATISTICS_MAX_PEAK_TO_PEAK         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4180
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STATISTICS_MAX_STANDARD_DEVIATION   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4181
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STATISTICS_MIN_PEAK_TO_PEAK         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4182
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_COMPONENT_STATISTICS_MIN_STANDARD_DEVIATION   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4183
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SCALING_MAX_NUM_OF_BINS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4184
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_CONTINUOUS_AUTO_SCALE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4185
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_BASIC_JITTER_CONTINUOUS_AUTO_SCALE_ENABLED    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4254
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_NOISE_CONTINUOUS_AUTO_SCALE_ENABLED           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4255
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_JITTER_SPECTRUM_CONTINUOUS_AUTO_SCALE_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 4256
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_NOISE_SPECTRUM_CONTINUOUS_AUTO_SCALE_ENABLED  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4257
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_SCALING_MEASUREMENT_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4186
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_PERIODIC_COMPONENT_COUNT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4187
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_PERIODIC_COMPONENT_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4188
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_PERIODIC_COMPONENT_VALUE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4189
#define RSSCOPE_ATTR_ADVANCED_JITTER_RESULTS_PERIODIC_COMPONENT_DIRECTION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4190
#define RSSCOPE_ATTR_EYE_MAIN_MEASUREMENT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSSCOPE_ATTR_EYE_JITTER_AUTOSCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3294
#define RSSCOPE_ATTR_EYE_LIMIT_CHECK                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSSCOPE_ATTR_EYE_JITTER_LOWER_LIMIT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 846
#define RSSCOPE_ATTR_EYE_JITTER_UPPER_LIMIT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 847
#define RSSCOPE_ATTR_EYE_JITTER_LOWER_LIMIT_MARGIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 848
#define RSSCOPE_ATTR_EYE_JITTER_UPPER_LIMIT_MARGIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 849
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_START                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4486
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_STOP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4487
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_ALGORITHM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4488
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_THRESHOLD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4489
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_HEIGHT_ALGORITHM                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4490
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_HEIGHT_START                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4491
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_HEIGHT_STOP                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4492
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_WIDTH_ALGORITHM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4493
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_WIDTH_WINDOW_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4494
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_WIDTH_START                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4495
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_WIDTH_STOP                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4496
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_DUTY_CYCLE_DISTORTION_LEVEL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4497
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_USE_MEAS_LEVEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4498
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4499
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_RTFT_START_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4500
#define RSSCOPE_ATTR_EYE_JITTER_MEASUREMENT_RTFT_STOP_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4501
#define RSSCOPE_ATTR_HISTOGRAM_MAIN_MEASUREMENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSSCOPE_ATTR_HISTOGRAM_SELECT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSSCOPE_ATTR_HISTOGRAM_PROBABILITY_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSSCOPE_ATTR_HISTOGRAM_PROBABILITY_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSSCOPE_ATTR_REMOVE_HISTOGRAM                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSSCOPE_ATTR_RESET_HISTOGRAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSSCOPE_ATTR_HISTOGRAM_DISPLAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSSCOPE_ATTR_HISTOGRAM_LIMIT_CHECK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSSCOPE_ATTR_HISTOGRAM_LOWER_LIMIT_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 867
#define RSSCOPE_ATTR_HISTOGRAM_UPPER_LIMIT_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 868
#define RSSCOPE_ATTR_HISTOGRAM_LOWER_LIMIT_MARGIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 869
#define RSSCOPE_ATTR_HISTOGRAM_UPPER_LIMIT_MARGIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 870
#define RSSCOPE_ATTR_SPECTRUM_MAIN_MEASUREMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSSCOPE_ATTR_SPECTRUM_CHANNEL_POWER_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSSCOPE_ATTR_SPECTRUM_OCCUPIED_BANDWIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSSCOPE_ATTR_SPECTRUM_CHANNEL_POWER_CENTER_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSSCOPE_ATTR_SPECTRUM_N_DB_DOWN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSSCOPE_ATTR_SPECTRUM_PEAK_EXCURSION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2442
#define RSSCOPE_ATTR_SPECTRUM_ABSOLUTE_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2704
#define RSSCOPE_ATTR_SPECTRUM_LIMIT_CHECK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSSCOPE_ATTR_SPECTRUM_LOWER_LIMIT_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 872
#define RSSCOPE_ATTR_SPECTRUM_UPPER_LIMIT_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 873
#define RSSCOPE_ATTR_SPECTRUM_LOWER_LIMIT_MARGIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 874
#define RSSCOPE_ATTR_SPECTRUM_UPPER_LIMIT_MARGIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 875
#define RSSCOPE_ATTR_SPECTRUM_MAX_NUMBER_OF_RESULTS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3439
#define RSSCOPE_ATTR_SPECTRUM_RESULT_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3931
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_PARAMETER_MEASUEREMENT_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4399
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_PARAMETER_AMPLITUDE_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4400
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_PARAMETER_GROUP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4401
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_PARAMETER_MEASUREMENT_SPECTRUM                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4402
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_OPERATOR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4403
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_CONSTANT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4404
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_CONSTANT_UNIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4405
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_CUSTOM_NAME_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4406
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_CUSTOM_UNIT_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4407
#define RSSCOPE_ATTR_SPECTRUM_ARITHMETIC_CUSTOM_UNIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4408
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_UNIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4503
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_MODULATION_AMPLITUDE_START                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4504
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_MODULATION_AMPLITUDE_STOP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4505
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_VALID_RANGE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4506
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_LOWER_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4507
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_UPPER_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4508
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_LOWER_MARGIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4509
#define RSSCOPE_ATTR_OPTICAL_MEASUREMENT_UPPER_MARGIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4510
#define RSSCOPE_ATTR_STATISTICS_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSSCOPE_ATTR_STATISTICS_HISTOGRAM_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSSCOPE_ATTR_STATISTICS_RESET_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSSCOPE_ATTR_STATISTICS_RESET_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSSCOPE_ATTR_STATISTICS_RESET_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSSCOPE_ATTR_STATISTICS_RESET_MEASUREMENTS_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define RSSCOPE_ATTR_STATISTICS_RESET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSSCOPE_ATTR_STATISTICS_NUMBER_OF_BINS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2450
#define RSSCOPE_ATTR_TRACK_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 876
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 737
#define RSSCOPE_ATTR_TRACK_WAVEFORM_HEADER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 877
#define RSSCOPE_ATTR_TRACK_WAVEFORM_DATA_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 878
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_WAVEFORM_DATA_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 739
#define RSSCOPE_ATTR_LONG_TERM_MEASUREMENT_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSSCOPE_ATTR_LONG_TERM_COUNT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSSCOPE_ATTR_LONG_TERM_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSSCOPE_ATTR_LONG_TERM_VERTICAL_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSSCOPE_ATTR_LONG_TERM_VERTICAL_SCALING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSSCOPE_ATTR_LONG_TERM_VERTICAL_CONTINUOUS_AUTO_SCALING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define RSSCOPE_ATTR_LONG_TERM_VERTICAL_AUTOSCALE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSSCOPE_ATTR_LONG_TERM_ENVIRONMENT_SENSOR_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSSCOPE_ATTR_PROTOCOL_MAIN_MEASUREMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4191
#define RSSCOPE_ATTR_PROTOCOL_ADDITIONAL_MEASUREMENT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4193
#define RSSCOPE_ATTR_FRAME_TO_FRAME_FROM_FRAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3932
#define RSSCOPE_ATTR_FRAME_TO_FRAME_FROM_FIELD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3933
#define RSSCOPE_ATTR_FRAME_TO_FRAME_FROM_VALUE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3934
#define RSSCOPE_ATTR_FRAME_TO_FRAME_TO_FRAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3935
#define RSSCOPE_ATTR_FRAME_TO_FRAME_TO_FIELD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3936
#define RSSCOPE_ATTR_FRAME_TO_FRAME_TO_VALUE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3937
#define RSSCOPE_ATTR_TRIGGER_TO_FRAME_DIRECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3938
#define RSSCOPE_ATTR_TRIGGER_TO_FRAME_FRAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3939
#define RSSCOPE_ATTR_TRIGGER_TO_FRAME_FIELD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3940
#define RSSCOPE_ATTR_TRIGGER_TO_FRAME_VALUE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3941
#define RSSCOPE_ATTR_FIELD_VALUE_FRAME_IDENTIFICATION_FRAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3942
#define RSSCOPE_ATTR_FIELD_VALUE_FRAME_IDENTIFICATION_FIELD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3943
#define RSSCOPE_ATTR_FIELD_VALUE_FRAME_IDENTIFICATION_VALUE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3944
#define RSSCOPE_ATTR_FIELD_VALUE_FIELD_TO_BE_TRACKED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3945
#define RSSCOPE_ATTR_MAIN_BIT_RATE_FRAME_NAME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4194
#define RSSCOPE_ATTR_MAIN_BIT_RATE_FIELD_NAME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4195
#define RSSCOPE_ATTR_MAIN_BIT_RATE_ID_VALUE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4196
#define RSSCOPE_ATTR_SECONDARY_BIT_RATE_FRAME_NAME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4197
#define RSSCOPE_ATTR_SECONDARY_BIT_RATE_FIELD_NAME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4198
#define RSSCOPE_ATTR_SECONDARY_BIT_RATE_ID_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4199
#define RSSCOPE_ATTR_GATING_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSSCOPE_ATTR_GATING_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSSCOPE_ATTR_GATING_ABSOLUTE_START                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 879
#define RSSCOPE_ATTR_GATING_RELATIVE_START                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 880
#define RSSCOPE_ATTR_GATING_ABSOLUTE_STOP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 881
#define RSSCOPE_ATTR_GATING_RELATIVE_STOP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 882
#define RSSCOPE_ATTR_GATING_NOISE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSSCOPE_ATTR_GATING_SHOW_GATE_AREA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSSCOPE_ATTR_GATING_ZOOM_COUPLING_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSSCOPE_ATTR_GATING_CURSOR_COUPLING_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2610
#define RSSCOPE_ATTR_GATING_COUPLING_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3441
#define RSSCOPE_ATTR_GATING_CURSOR_SET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2611
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_ACTUAL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4059
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_AVERAGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4060
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_EVENT_COUNT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4061
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_NEGATIVE_PEAK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4062
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_POSITIVE_PEAK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4063
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_RELIABILITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4064
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_RMS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4065
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_WAVEFORM_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4066
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_STANDARD_DEVIATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4067
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_TOP_OUTER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4068
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_TOP_INNER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4069
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_BOTTOM_INNER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4070
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_BOTTOM_OUTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4071
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_LOWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4072
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_MIDDLE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4073
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_UPPER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4074
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_SIGNAL_LOW                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4075
#define RSSCOPE_ATTR_READ_REFERENCE_LEVEL_SIGNAL_HIGH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4076
#define RSSCOPE_ATTR_SPECTRUM_MEASUREMENT_HARMONICS_RESULTS_NUMBER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2443
#define RSSCOPE_ATTR_DISPLAY_RESULT_LINES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSSCOPE_ATTR_DISPLAY_REFERENCE_LEVELS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 898
#define RSSCOPE_ATTR_DISPLAY_RESULT_TABLE_DEFAULT_POSITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3442
#define RSSCOPE_ATTR_DISPLAY_GROUP_RESULT_DIALOGS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3443
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_ACTUAL_STRING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4352
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_AVERAGE_STRING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4353
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_EVENT_COUNT_STRING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4354
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_NEGATIVE_PEAK_STRING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4355
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_POSITIVE_PEAK_STRING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4356
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_RELIABILITY_STRING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4357
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_RMS_STRING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4358
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_WAVEFORM_COUNT_STRING                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4359
#define RSSCOPE_ATTR_READ_MAIN_MEASUREMENT_STANDARD_DEVIATION_STRING                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4360
#define RSSCOPE_ATTR_REFERENCE_LEVEL_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSSCOPE_ATTR_REFERENCE_LEVEL_RELATIVE_LEVELS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSSCOPE_ATTR_REFERENCE_LEVEL_USER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSSCOPE_ATTR_REFERENCE_LEVEL_DEFINITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSSCOPE_ATTR_REFERENCE_LEVEL_AUTO_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSSCOPE_ATTR_REFERENCE_LEVEL_AVERAGING_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSSCOPE_ATTR_REFERENCE_LEVEL_AVERAGING_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSSCOPE_ATTR_REFERENCE_USER_SIGNAL_HIGH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSSCOPE_ATTR_REFERENCE_USER_SIGNAL_LOW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSSCOPE_ATTR_REFERENCE_USER_TOP_DISTANCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSSCOPE_ATTR_REFERENCE_USER_BOTTOM_DISTANCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSSCOPE_ATTR_USER_REFERENCE_UPPER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSSCOPE_ATTR_USER_REFERENCE_LOWER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSSCOPE_ATTR_USER_REFERENCE_MIDDLE_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSSCOPE_ATTR_USER_REFERENCE_RELATIVE_UPPER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define RSSCOPE_ATTR_USER_REFERENCE_RELATIVE_MIDDLE_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define RSSCOPE_ATTR_USER_REFERENCE_RELATIVE_LOWER_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSSCOPE_ATTR_USER_REFERENCE_HYSTERESIS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSSCOPE_ATTR_TUBE_RELATIVE_OUTER_DISTANCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSSCOPE_ATTR_TUBE_RELATIVE_INNER_DISTANCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSSCOPE_ATTR_TUBE_ABSOLUTE_TOP_OUTER_DISTANCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 899
#define RSSCOPE_ATTR_TUBE_ABSOLUTE_TOP_INNER_DISTANCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 900
#define RSSCOPE_ATTR_TUBE_ABSOLUTE_BOTTOM_INNER_DISTANCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 901
#define RSSCOPE_ATTR_TUBE_ABSOLUTE_BOTTOM_OUTER_DISTANCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 902
#define RSSCOPE_ATTR_MATH_WAVEFORM_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSSCOPE_ATTR_MATH_WAVEFORM_ENVELOPE_SELECTION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1587
#define RSSCOPE_ATTR_MATH_ACQUISITION_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSSCOPE_ATTR_MATH_EXPRESSION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSSCOPE_ATTR_MATH_VERTICAL_RANGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSSCOPE_ATTR_MATH_VERTICAL_SCALE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSSCOPE_ATTR_MATH_VERTICAL_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSSCOPE_ATTR_MATH_RESET                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSSCOPE_ATTR_MATH_RESET_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 669
#define RSSCOPE_ATTR_MATH_ENVELOPE_TIMEOUT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSSCOPE_ATTR_MATH_ACQUIRED_WAVEFORMS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSSCOPE_ATTR_FFT_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4409
#define RSSCOPE_ATTR_FFT_FREQUENCY_AXIS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3237
#define RSSCOPE_ATTR_FFT_CENTER_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSSCOPE_ATTR_FFT_FREQUENCY_SPAN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSSCOPE_ATTR_FFT_FULL_SPAN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSSCOPE_ATTR_FFT_START_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSSCOPE_ATTR_FFT_STOP_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSSCOPE_ATTR_FFT_WINDOW_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSSCOPE_ATTR_FFT_USE_COLOR_TABLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3238
#define RSSCOPE_ATTR_FFT_REFERENCE_LEVEL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSSCOPE_ATTR_FFT_MAGNITUDE_RANGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSSCOPE_ATTR_FFT_MAGNITUDE_UNIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSSCOPE_ATTR_FFT_PHASE_UNIT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSSCOPE_ATTR_FFT_PHASE_UNWRAP_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 903
#define RSSCOPE_ATTR_FFT_NOISE_SUPPRESSION_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSSCOPE_ATTR_FFT_NOISE_SUPPRESSION_THRESHOLD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSSCOPE_ATTR_FFT_VERTICAL_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4410
#define RSSCOPE_ATTR_FFT_RESOLUTION_BANDWIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSSCOPE_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSSCOPE_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSSCOPE_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSSCOPE_ATTR_FFT_RESOLUTION_BANDWIDTH_GATE_COUPLING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSSCOPE_ATTR_FFT_FRAME_ARITHMETIC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSSCOPE_ATTR_FFT_FRAME_MAX_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSSCOPE_ATTR_FFT_FRAME_COVERAGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSSCOPE_ATTR_FFT_FRAME_OVERLAP_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSSCOPE_ATTR_FFT_GATE_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSSCOPE_ATTR_FFT_GATE_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSSCOPE_ATTR_FFT_GATE_ABSOLUTE_START                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 904
#define RSSCOPE_ATTR_FFT_GATE_RELATIVE_START                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 905
#define RSSCOPE_ATTR_FFT_GATE_ABSOLUTE_STOP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 906
#define RSSCOPE_ATTR_FFT_GATE_RELATIVE_STOP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 907
#define RSSCOPE_ATTR_FFT_GATE_DISPLAY_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSSCOPE_ATTR_FFT_GATE_ZOOM_COUPLING_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSSCOPE_ATTR_FFT_COUPLED_SPECTRUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3239
#define RSSCOPE_ATTR_FFT_SPECTRUM_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3240
#define RSSCOPE_ATTR_FFT_SPECTRUM_COLOR_TABLE_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3241
#define RSSCOPE_ATTR_FFT_SPECTRUM_TIME_LINE_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3242
#define RSSCOPE_ATTR_FFT_SPECTRUM_TIME_LINE_POSITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3243
#define RSSCOPE_ATTR_MATH_WAVEFORM_HEADER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HEADER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_SIGNAL_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3444
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_LOAD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_SAVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_DELETE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_UPDATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_CLEAR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_RESTORE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_MULTICHANNEL_FILE_NAME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2705
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_MULTICHANNEL_IMPORT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2706
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_MULTICHANNEL_OPEN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2707
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_COUPLING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_STRETCHING_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_FACTOR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_VERTICAL_RESET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3946
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HORZ_COUPLING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HORZ_STRETCHING_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HORZ_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HORZ_FACTOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSSCOPE_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4411
#define RSSCOPE_ATTR_SELECTED_MASK_NAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 910
#define RSSCOPE_ATTR_MASK_TEST_RESULT_ACQUISITION_COMPLETE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 911
#define RSSCOPE_ATTR_MASK_TEST_RESULT_ACQUISITION_REMAINING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 912
#define RSSCOPE_ATTR_MASK_TEST_RESULT_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 913
#define RSSCOPE_ATTR_MASK_TEST_RESULT_SAMPLE_HITS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 914
#define RSSCOPE_ATTR_MASK_TEST_RESULT_ACQUISITION_HITS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 915
#define RSSCOPE_ATTR_MASK_TEST_RESULT_FAIL_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 916
#define RSSCOPE_ATTR_MASK_TEST_RESULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 917
#define RSSCOPE_ATTR_MASK_TEST_EVENT_BEEP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 918
#define RSSCOPE_ATTR_MASK_TEST_EVENT_STOP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 919
#define RSSCOPE_ATTR_MASK_TEST_EVENT_PRINT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 920
#define RSSCOPE_ATTR_MASK_TEST_EVENT_SAVE_WAVEFORM                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 921
#define RSSCOPE_ATTR_MASK_TEST_EVENT_SAVE_REPORT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3445
#define RSSCOPE_ATTR_MASK_TEST_EVENT_START_EXTERNAL_APPLICATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3446
#define RSSCOPE_ATTR_MASK_TEST_EVENT_CREATE_TRIGGER_OUT_PULSE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3447
#define RSSCOPE_ATTR_MASK_CREATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSSCOPE_ATTR_MASK_DELETE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSSCOPE_ATTR_MASK_CONVERT_TO_USER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3947
#define RSSCOPE_ATTR_MASK_TEST_ENABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 924
#define RSSCOPE_ATTR_MASK_TEST_CLEAR_ALL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3448
#define RSSCOPE_ATTR_MASK_TEST_DEFINITION_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 925
#define RSSCOPE_ATTR_MASK_TEST_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 926
#define RSSCOPE_ATTR_MASK_TEST_FAIL_CONDITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 927
#define RSSCOPE_ATTR_MASK_TEST_VIOLATION_TOLERANCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 928
#define RSSCOPE_ATTR_MASK_TEST_SAVE_PATH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 929
#define RSSCOPE_ATTR_MASK_TEST_SAVE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 704
#define RSSCOPE_ATTR_MASK_TEST_OPEN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define RSSCOPE_ATTR_MASK_TEST_DELETE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSSCOPE_ATTR_MASK_TEST_SEGMENT_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4200
#define RSSCOPE_ATTR_MASK_SELECTED_SEGMENT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 933
#define RSSCOPE_ATTR_MASK_SEGMENT_COUNT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 934
#define RSSCOPE_ATTR_MASK_SEGMENT_ADD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSSCOPE_ATTR_MASK_SELECTED_POINT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 948
#define RSSCOPE_ATTR_MASK_COPY_WAVEFORM                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSSCOPE_ATTR_MASK_WAVEFORM_USED_REFERENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 959
#define RSSCOPE_ATTR_MASK_WAVEFORM_HORIZONTAL_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 960
#define RSSCOPE_ATTR_MASK_WAVEFORM_VERTICAL_WIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 961
#define RSSCOPE_ATTR_MASK_WAVEFORM_VERTICAL_STRETCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 962
#define RSSCOPE_ATTR_MASK_WAVEFORM_VERTICAL_POSITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 963
#define RSSCOPE_ATTR_MASK_TEST_EYE_SHAPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 964
#define RSSCOPE_ATTR_MASK_TEST_EYE_MAIN_WIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 965
#define RSSCOPE_ATTR_MASK_TEST_EYE_MINOR_WIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 966
#define RSSCOPE_ATTR_MASK_TEST_EYE_MAIN_HEIGHT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 967
#define RSSCOPE_ATTR_MASK_TEST_EYE_MINOR_HEIGHT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 968
#define RSSCOPE_ATTR_MASK_TEST_EYE_COPY_LEFT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 969
#define RSSCOPE_ATTR_MASK_TEST_EYE_COPY_RIGHT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 970
#define RSSCOPE_ATTR_MASK_TEST_EYE_INTERPATTERN_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 971
#define RSSCOPE_ATTR_MASK_TEST_EYE_TOP_ENABLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 972
#define RSSCOPE_ATTR_MASK_TEST_EYE_BOTTOM_ENABLE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 973
#define RSSCOPE_ATTR_MASK_TEST_EYE_OFFSET_TOP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 974
#define RSSCOPE_ATTR_MASK_TEST_EYE_OFFSET_BOTTOM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 975
#define RSSCOPE_ATTR_MASK_TEST_EYE_TIME_WIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 976
#define RSSCOPE_ATTR_MASK_TEST_EYE_SYMETRIC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 977
#define RSSCOPE_ATTR_MASK_TEST_EYE_HORIZONTAL_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 978
#define RSSCOPE_ATTR_MASK_TEST_EYE_VERTICAL_POSITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 979
#define RSSCOPE_ATTR_MASK_TEST_SHOW_LABEL_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4512
#define RSSCOPE_ATTR_MASK_TEST_LABEL_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3449
#define RSSCOPE_ATTR_MASK_TEST_RENAME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3450
#define RSSCOPE_ATTR_MASK_TEST_HIGHLIGHT_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3948
#define RSSCOPE_ATTR_MASK_TEST_HIGHLIGHT_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3949
#define RSSCOPE_ATTR_MASK_TEST_HIGHLIGHT_ENDLESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3950
#define RSSCOPE_ATTR_MASK_TEST_COLOR_UNMATCHED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3951
#define RSSCOPE_ATTR_MASK_TEST_COLOR_MATCHED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3952
#define RSSCOPE_ATTR_MASK_TEST_COLOR_BORDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3953
#define RSSCOPE_ATTR_MASK_TEST_COLOR_INTERIOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3954
#define RSSCOPE_ATTR_SELECTED_SEARCH_NAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 987
#define RSSCOPE_ATTR_SELECTED_SEARCH_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 988
#define RSSCOPE_ATTR_NEW_SEARCH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSSCOPE_ATTR_DELETE_SEARCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSSCOPE_ATTR_SEARCH_NEXT_RESULT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSSCOPE_ATTR_SEARCH_ALL_RESULTS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSSCOPE_ATTR_CLEAR_SEARCH_RESULTS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSSCOPE_ATTR_SEARCH_TRIGGER_LEVEL_AUTO_FIND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSSCOPE_ATTR_SEARCH_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 989
#define RSSCOPE_ATTR_SEARCH_ONLINE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 990
#define RSSCOPE_ATTR_SEARCH_TRIGGER_LEVEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 993
#define RSSCOPE_ATTR_SEARCH_TRIGGER_CONDITIONS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 994
#define RSSCOPE_ATTR_SEARCH_TRIGGER_EDGE_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 995
#define RSSCOPE_ATTR_SEARCH_TRIGGER_EDGE_SLOPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 996
#define RSSCOPE_ATTR_SEARCH_TRIGGER_EDGE_COPY_FROM_A                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4077
#define RSSCOPE_ATTR_SEARCH_TRIGGER_EDGE_COPY_FROM_B                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4078
#define RSSCOPE_ATTR_SEARCH_TRIGGER_GLITCH_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 997
#define RSSCOPE_ATTR_SEARCH_TRIGGER_GLITCH_WIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 998
#define RSSCOPE_ATTR_SEARCH_TRIGGER_GLITCH_POLARITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 999
#define RSSCOPE_ATTR_SEARCH_TRIGGER_GLITCH_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1000
#define RSSCOPE_ATTR_SEARCH_TRIGGER_GLITCH_COPY_FROM_A                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4079
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1001
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1002
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH_DELTA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1003
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1004
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1005
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WIDTH_COPY_FROM_A                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4080
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1006
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_UPPER_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1007
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_LOWER_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1008
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1009
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_WIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1010
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_DELTA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1011
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_RANGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1012
#define RSSCOPE_ATTR_SEARCH_TRIGGER_RUNT_COPY_FROM_A                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4081
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1013
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_UPPER_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1014
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_LOWER_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1015
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_VERTICAL_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1016
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_TIME_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1017
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_WIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1018
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_DELTA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1019
#define RSSCOPE_ATTR_SEARCH_TRIGGER_WINDOW_COPY_FROM_A                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4082
#define RSSCOPE_ATTR_SEARCH_TRIGGER_TIMEOUT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1020
#define RSSCOPE_ATTR_SEARCH_TRIGGER_TIMEOUT_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1021
#define RSSCOPE_ATTR_SEARCH_TRIGGER_TIMEOUT_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1022
#define RSSCOPE_ATTR_SEARCH_TRIGGER_TIMEOUT_COPY_FROM_A                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4083
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1023
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_WIDTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1024
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_DELTA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1025
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1026
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1027
#define RSSCOPE_ATTR_SEARCH_TRIGGER_INTERVAL_COPY_FROM_A                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4084
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1028
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_UPPER_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1029
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_LOWER_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1030
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1031
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_DELTA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1032
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_POLARITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1033
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1034
#define RSSCOPE_ATTR_SEARCH_TRIGGER_SLEW_RATE_COPY_FROM_A                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4085
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1035
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1036
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1037
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_HOLD_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1038
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_SETUP_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1039
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_EDGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1040
#define RSSCOPE_ATTR_SEARCH_TRIGGER_DATA2CLOCK_COPY_FROM_A                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4086
#define RSSCOPE_ATTR_SEARCH_TRIGGER_STATE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1041
#define RSSCOPE_ATTR_SEARCH_TRIGGER_STATE_CLOCK_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1042
#define RSSCOPE_ATTR_SEARCH_TRIGGER_STATE_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1043
#define RSSCOPE_ATTR_SEARCH_TRIGGER_STATE_CLOCK_EDGE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1044
#define RSSCOPE_ATTR_SEARCH_TRIGGER_STATE_COPY_FROM_A                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4087
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3955
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_2                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3956
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_3                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3957
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_4                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3958
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_1                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3959
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_2                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3960
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_3                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3961
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_4                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3962
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_1_2                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3963
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_3_4                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3964
#define RSSCOPE_ATTR_SEARCH_STATE_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_ALL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3965
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1048
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1049
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_TIMEOUT_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1050
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_TIMEOUT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1051
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1052
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH_DELTA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1053
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_WIDTH_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1054
#define RSSCOPE_ATTR_SEARCH_TRIGGER_PATTERN_COPY_FROM_A                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4088
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_1                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3966
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_2                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3967
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_3                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3968
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_ENABLED_CHANNEL_4                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3969
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3970
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_2                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3971
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_3                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3972
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNEL_4                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3973
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_1_2               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3974
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_3_4               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3975
#define RSSCOPE_ATTR_SEARCH_PATTERN_TRIGGER_QUALIFICATION_LOGIC_CHANNELS_ALL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3976
#define RSSCOPE_ATTR_SEARCH_GATE_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1058
#define RSSCOPE_ATTR_SEARCH_GATE_SHOW                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1059
#define RSSCOPE_ATTR_ZOOM_COUPLING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1060
#define RSSCOPE_ATTR_SEARCH_GATE_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1061
#define RSSCOPE_ATTR_SEARCH_GATE_ABSOLUTE_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1062
#define RSSCOPE_ATTR_SEARCH_GATE_RELATIVE_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1063
#define RSSCOPE_ATTR_SEARCH_GATE_ABSOLUTE_STOP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1064
#define RSSCOPE_ATTR_SEARCH_GATE_RELATIVE_STOP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1065
#define RSSCOPE_ATTR_SEARCH_RESULT_TABLE_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1066
#define RSSCOPE_ATTR_SEARCH_RESULT_SORT_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1067
#define RSSCOPE_ATTR_SEARCH_RESULT_SORT_ASCENDING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1068
#define RSSCOPE_ATTR_SEARCH_RESULT_MAX_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1069
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_WINDOW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1070
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_HORIZONTAL_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1071
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_ABSOLUTE_HORIZONTAL_POSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1072
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_ABSOLUTE_HORIZONTAL_RANGE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1073
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_RELATIVE_HORIZONTAL_POSITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1074
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_RELATIVE_HORIZONTAL_RANGE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1075
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_VERTICAL_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1076
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_ABSOLUTE_VERTICAL_POSITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1077
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_ABSOLUTE_VERTICAL_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1078
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_RELATIVE_VERTICAL_POSITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1079
#define RSSCOPE_ATTR_SEARCH_RESULT_ZOOM_RELATIVE_VERTICAL_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1080
#define RSSCOPE_ATTR_SEARCH_NOISE_REJECT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1081
#define RSSCOPE_ATTR_SEARCH_NOISE_REJECT_HYSTERESIS_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1082
#define RSSCOPE_ATTR_SEARCH_NOISE_REJECT_ABSOLUTE_HYSTERESIS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1083
#define RSSCOPE_ATTR_SEARCH_NOISE_REJECT_RELATIVE_HYSTERESIS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1084
#define RSSCOPE_ATTR_SEARCH_I2C_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2338
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_START                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2357
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_REPEATED_START                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2358
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_STOP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2359
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_NACK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2360
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_ADDRESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2361
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_ADDRESS_OR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2362
#define RSSCOPE_ATTR_SEARCH_I2C_CRITERIA_ADDRESS_DATA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2363
#define RSSCOPE_ATTR_SEARCH_I2C_ADRESS_NACK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2339
#define RSSCOPE_ATTR_SEARCH_I2C_DATA_WRITE_NACK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2340
#define RSSCOPE_ATTR_SEARCH_I2C_DATA_READ_NACK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2341
#define RSSCOPE_ATTR_SEARCH_I2C_ACCESS_BIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2342
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2343
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2344
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2345
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2346
#define RSSCOPE_ATTR_SEARCH_I2C_POSITION_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2347
#define RSSCOPE_ATTR_SEARCH_I2C_POSITION_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2348
#define RSSCOPE_ATTR_SEARCH_I2C_POSITION_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2349
#define RSSCOPE_ATTR_SEARCH_I2C_DATA_CONDITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2350
#define RSSCOPE_ATTR_SEARCH_I2C_PATTERN_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2351
#define RSSCOPE_ATTR_SEARCH_I2C_PATTERN_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2352
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_OR_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2353
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_OR_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2354
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_OR_ACCESS_BIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2355
#define RSSCOPE_ATTR_SEARCH_I2C_ADDRESS_OR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2356
#define RSSCOPE_ATTR_SEARCH_I2C_FRAME_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2364
#define RSSCOPE_ATTR_SEARCH_LIN_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2299
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_START_OF_FRAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2317
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_IDENTIFIER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2318
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_IDENTIFIER_OR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2319
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_IDENTIFIER_DATA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2320
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_WAKEUP_FRAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2321
#define RSSCOPE_ATTR_SEARCH_LIN_CRITERIA_ERROR_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2322
#define RSSCOPE_ATTR_SEARCH_LIN_CONDITION_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2303
#define RSSCOPE_ATTR_SEARCH_LIN_PATTERN_DATA_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2304
#define RSSCOPE_ATTR_SEARCH_LIN_PATTERN_DATA_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2305
#define RSSCOPE_ATTR_SEARCH_LIN_DATA_LENGTH_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2451
#define RSSCOPE_ATTR_SEARCH_LIN_DATA_LENGTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2452
#define RSSCOPE_ATTR_SEARCH_LIN_DATA_TRANSFER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2453
#define RSSCOPE_ATTR_SEARCH_LIN_IDENTIFIER_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2306
#define RSSCOPE_ATTR_SEARCH_LIN_PATTERN_IDENTIFIER_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2307
#define RSSCOPE_ATTR_SEARCH_LIN_PATTERN_IDENTIFIER_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2308
#define RSSCOPE_ATTR_SEARCH_LIN_ADDRESS_OR_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2309
#define RSSCOPE_ATTR_SEARCH_LIN_ADDRESS_OR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2310
#define RSSCOPE_ATTR_SEARCH_LIN_CHECKSUM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2311
#define RSSCOPE_ATTR_SEARCH_LIN_CRC_ERROR_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2312
#define RSSCOPE_ATTR_SEARCH_LIN_CRC_ERROR_DATA_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2313
#define RSSCOPE_ATTR_SEARCH_LIN_CRC_STANDARD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2314
#define RSSCOPE_ATTR_SEARCH_LIN_IDENTIFIER_PARITY_ERROR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2315
#define RSSCOPE_ATTR_SEARCH_LIN_SYNC_ERROR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2316
#define RSSCOPE_ATTR_SEARCH_LIN_SELECTED_FRAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4412
#define RSSCOPE_ATTR_SEARCH_LIN_FRAME_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2323
#define RSSCOPE_ATTR_SEARCH_LIN_FRAME_SYMBOLIC_DATA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4413
#define RSSCOPE_ATTR_SEARCH_LIN_FRAME_SYMBOLIC_DATA_EXPORT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4414
#define RSSCOPE_ATTR_SEARCH_CAN_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1650
#define RSSCOPE_ATTR_SEARCH_CAN_COPY_FROM_A                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1652
#define RSSCOPE_ATTR_SEARCH_CAN_START_OF_FRAME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1653
#define RSSCOPE_ATTR_SEARCH_CAN_FRAME_TYPE_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1654
#define RSSCOPE_ATTR_SEARCH_CAN_FRAME_IDENTIFIER_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1655
#define RSSCOPE_ATTR_SEARCH_CAN_IDENTIFIER_DATA_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1656
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1766
#define RSSCOPE_ATTR_SEARCH_CAN_FRAME_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1658
#define RSSCOPE_ATTR_SEARCH_CAN_STANDARD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1767
#define RSSCOPE_ATTR_SEARCH_CAN_ID_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1659
#define RSSCOPE_ATTR_SEARCH_CAN_IDENTIFIER_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1660
#define RSSCOPE_ATTR_SEARCH_CAN_IDENTIFIER_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1661
#define RSSCOPE_ATTR_SEARCH_CAN_IDENTIFIER_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1662
#define RSSCOPE_ATTR_SEARCH_CAN_FD_BITS_FDF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1768
#define RSSCOPE_ATTR_SEARCH_CAN_FD_BITS_BRS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1769
#define RSSCOPE_ATTR_SEARCH_CAN_FD_BITS_ESI                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1770
#define RSSCOPE_ATTR_SEARCH_CAN_DLC_CONDITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1663
#define RSSCOPE_ATTR_SEARCH_CAN_DLC                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1664
#define RSSCOPE_ATTR_SEARCH_CAN_POSITION_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1771
#define RSSCOPE_ATTR_SEARCH_CAN_POSITION_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1772
#define RSSCOPE_ATTR_SEARCH_CAN_POSITION_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1773
#define RSSCOPE_ATTR_SEARCH_CAN_DATA_CONDITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1666
#define RSSCOPE_ATTR_SEARCH_CAN_DATA_MIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1667
#define RSSCOPE_ATTR_SEARCH_CAN_DATA_MAX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1668
#define RSSCOPE_ATTR_SEARCH_CAN_CRC_ERROR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1669
#define RSSCOPE_ATTR_SEARCH_CAN_BIT_STUFFING_ERROR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1671
#define RSSCOPE_ATTR_SEARCH_CAN_ACK_ERROR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1672
#define RSSCOPE_ATTR_SEARCH_CAN_STUFF_COUNT_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3223
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_MESSAGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1774
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_SEARCH_FOR_SIGNAL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1775
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_SIGNAL_VALUE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1776
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_SIGNAL_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1777
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_SIGNAL_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1778
#define RSSCOPE_ATTR_SEARCH_CAN_SYMBOLIC_SIGNAL_ENUM_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1779
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1692
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_COPY_FROM_A                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1694
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_START_OF_FRAME_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1695
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_SYMBOL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1696
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_IDENTIFIER_DATA_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1697
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_ERROR_CONDITION_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1698
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_PAYLOAD_PREAMBLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1699
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_NULL_FRAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1700
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_SYNC_FRAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1701
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_STARTUP_FRAME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1702
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_FRAME_ID_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1703
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_FRAME_ID_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1704
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_FRAME_ID_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1705
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_PAYLOAD_LENGTH_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1706
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_PAYLOAD_LENGTH_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1707
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_PAYLOAD_LENGTH_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1708
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_CYCLE_COUNT_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1709
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_CYCLE_COUNT_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1710
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_CYCLE_COUNT_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1711
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_CYCLE_COUNT_STEP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1712
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_POSITION_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1713
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_POSITION_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1714
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_POSITION_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1715
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1716
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1717
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_DATA_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1718
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_IDENTIFIER_MIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1719
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_IDENTIFIER_MAX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1720
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_SYMBOL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1721
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_FRAME_START_SEQUENCE_ERROR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1722
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_BYTE_START_SEQUENCE_ERROR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1723
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_FRAME_END_SEQUENCE_ERROR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1724
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_HEADER_CRC_ERROR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1725
#define RSSCOPE_ATTR_SEARCH_FLEXRAY_PAYLOAD_CRC_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1726
#define RSSCOPE_ATTR_SEARCH_MIL1553_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1808
#define RSSCOPE_ATTR_SEARCH_MIL1553_SYNC_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1809
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_PATTERN_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1810
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_PATTERN_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1811
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_PATTERN_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1812
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_INDEX_CONDITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1813
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_INDEX_MIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1814
#define RSSCOPE_ATTR_SEARCH_MIL1553_DATA_INDEX_MAX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1815
#define RSSCOPE_ATTR_SEARCH_MIL1553_RTA_DATA_PATTERN_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1816
#define RSSCOPE_ATTR_SEARCH_MIL1553_RTA_DATA_PATTERN_MIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1817
#define RSSCOPE_ATTR_SEARCH_MIL1553_RTA_DATA_PATTERN_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1818
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_STATUS_RTA_PATTERN_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1819
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_STATUS_RTA_PATTERN_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1820
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_STATUS_RTA_PATTERN_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1821
#define RSSCOPE_ATTR_SEARCH_MIL1553_INFO_PATTERN_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1822
#define RSSCOPE_ATTR_SEARCH_MIL1553_INFO_PATTERN_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1823
#define RSSCOPE_ATTR_SEARCH_MIL1553_INFO_PATTERN_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1824
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_TRANSMIT_RECEIVE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1825
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_SUBADDRESS_PATTERN_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1826
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_SUBADDRESS_PATTERN_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1827
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_SUBADDRESS_PATTERN_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1828
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_RTA_PATTERN_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1829
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_RTA_PATTERN_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1830
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_RTA_PATTERN_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1831
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_WORD_COUNT_PATTERN_CONDITION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1832
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_WORD_COUNT_PATTERN_MIN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1833
#define RSSCOPE_ATTR_SEARCH_MIL1553_COMMAND_WORD_COUNT_PATTERN_MAX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1834
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_MESSAGE_ERROR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1835
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_BUSY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1836
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_INSTRUMENTATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1837
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_SUBSYSTEM                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1838
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_SERVICE_REQUEST                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1839
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_DYNAMIC_BUS_CONTROL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1840
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_BROADCAST_COMMAND                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1841
#define RSSCOPE_ATTR_SEARCH_MIL1553_STATUS_FLAG_TERMINAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1842
#define RSSCOPE_ATTR_SEARCH_MIL1553_ERROR_SYNCHRONIZATION_ERROR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1843
#define RSSCOPE_ATTR_SEARCH_MIL1553_ERROR_PARITY_ERROR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1844
#define RSSCOPE_ATTR_SEARCH_MIL1553_ERROR_MANCHESTER_CODING_ERROR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1845
#define RSSCOPE_ATTR_SEARCH_MIL1553_ERROR_TIMING_ERROR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1846
#define RSSCOPE_ATTR_SEARCH_MIL1553_WORDS_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1847
#define RSSCOPE_ATTR_SEARCH_ARINC429_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1856
#define RSSCOPE_ATTR_SEARCH_ARINC429_LABEL_DATA_SDI                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1857
#define RSSCOPE_ATTR_SEARCH_ARINC429_LABEL_DATA_SSM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1858
#define RSSCOPE_ATTR_SEARCH_ARINC429_LABEL_PATTERN_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1859
#define RSSCOPE_ATTR_SEARCH_ARINC429_LABEL_PATTERN_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1860
#define RSSCOPE_ATTR_SEARCH_ARINC429_LABEL_PATTERN_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1861
#define RSSCOPE_ATTR_SEARCH_ARINC429_DATA_PATTERN_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1862
#define RSSCOPE_ATTR_SEARCH_ARINC429_DATA_PATTERN_MIN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1863
#define RSSCOPE_ATTR_SEARCH_ARINC429_DATA_PATTERN_MAX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1864
#define RSSCOPE_ATTR_SEARCH_ARINC429_ERROR_CODING_ERROR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1865
#define RSSCOPE_ATTR_SEARCH_ARINC429_ERROR_PARITY_ERROR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1866
#define RSSCOPE_ATTR_SEARCH_ARINC429_ERROR_TIMING_ERROR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1867
#define RSSCOPE_ATTR_SEARCH_ARINC429_WORDS_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1868
#define RSSCOPE_ATTR_SEARCH_RFFE_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1905
#define RSSCOPE_ATTR_SEARCH_RFFE_INTERRUPT_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2759
#define RSSCOPE_ATTR_SEARCH_RFFE_SLAVE_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1906
#define RSSCOPE_ATTR_SEARCH_RFFE_SLAVE_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1907
#define RSSCOPE_ATTR_SEARCH_RFFE_SLAVE_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1908
#define RSSCOPE_ATTR_SEARCH_RFFE_ADDRESS_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1909
#define RSSCOPE_ATTR_SEARCH_RFFE_ADDRESS_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1910
#define RSSCOPE_ATTR_SEARCH_RFFE_ADDRESS_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1911
#define RSSCOPE_ATTR_SEARCH_RFFE_BYTE_COUNT_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1912
#define RSSCOPE_ATTR_SEARCH_RFFE_BYTE_COUNT_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1913
#define RSSCOPE_ATTR_SEARCH_RFFE_BYTE_COUNT_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1914
#define RSSCOPE_ATTR_SEARCH_RFFE_DATA_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1915
#define RSSCOPE_ATTR_SEARCH_RFFE_DATA_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1916
#define RSSCOPE_ATTR_SEARCH_RFFE_DATA_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1917
#define RSSCOPE_ATTR_SEARCH_RFFE_INDEX_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1918
#define RSSCOPE_ATTR_SEARCH_RFFE_INDEX_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1919
#define RSSCOPE_ATTR_SEARCH_RFFE_INDEX_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1920
#define RSSCOPE_ATTR_SEARCH_RFFE_ERROR_SCC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1921
#define RSSCOPE_ATTR_SEARCH_RFFE_ERROR_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1922
#define RSSCOPE_ATTR_SEARCH_RFFE_ERROR_PARITY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1924
#define RSSCOPE_ATTR_SEARCH_RFFE_ERROR_GAP_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4201
#define RSSCOPE_ATTR_SEARCH_RFFE_ERROR_VERSION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4202
#define RSSCOPE_ATTR_SEARCH_RFFE_SEQUENCE_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1927
#define RSSCOPE_ATTR_SEARCH_MDIO_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1962
#define RSSCOPE_ATTR_SEARCH_MDIO_START_CODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1963
#define RSSCOPE_ATTR_SEARCH_MDIO_OPERATION_CODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1964
#define RSSCOPE_ATTR_SEARCH_MDIO_PHYSICAL_PORT_ADDRESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1965
#define RSSCOPE_ATTR_SEARCH_MDIO_REGISTER_DEVICE_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1966
#define RSSCOPE_ATTR_SEARCH_MDIO_DATA_ADDRESS_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1967
#define RSSCOPE_ATTR_SEARCH_MDIO_WORD_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1968
#define RSSCOPE_ATTR_SEARCH_ETHERNET_FRAME_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1978
#define RSSCOPE_ATTR_SEARCH_ETHERNET_ERROR_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1979
#define RSSCOPE_ATTR_SEARCH_ETHERNET_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4513
#define RSSCOPE_ATTR_SEARCH_ETHERNET_DESTINATION_ADDRESS_CONDITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1980
#define RSSCOPE_ATTR_SEARCH_ETHERNET_DESTINATION_ADDRESS_MIN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1981
#define RSSCOPE_ATTR_SEARCH_ETHERNET_DESTINATION_ADDRESS_MAX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1982
#define RSSCOPE_ATTR_SEARCH_ETHERNET_SOURCE_ADDRESS_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1983
#define RSSCOPE_ATTR_SEARCH_ETHERNET_SOURCE_ADDRESS_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1984
#define RSSCOPE_ATTR_SEARCH_ETHERNET_SOURCE_ADDRESS_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1985
#define RSSCOPE_ATTR_SEARCH_ETHERNET_TYPE_LENGTH_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1986
#define RSSCOPE_ATTR_SEARCH_ETHERNET_TYPE_LENGTH_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1987
#define RSSCOPE_ATTR_SEARCH_ETHERNET_TYPE_LENGTH_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1988
#define RSSCOPE_ATTR_SEARCH_ETHERNET_FRAME_CHECK_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1989
#define RSSCOPE_ATTR_SEARCH_ETHERNET_FRAME_CHECK_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1990
#define RSSCOPE_ATTR_SEARCH_ETHERNET_FRAME_CHECK_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1991
#define RSSCOPE_ATTR_SEARCH_ETHERNET_ERROR_PREAMBLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1992
#define RSSCOPE_ATTR_SEARCH_ETHERNET_ERROR_LENGTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1993
#define RSSCOPE_ATTR_SEARCH_ETHERNET_WORD_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1994
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_START_OF_PACKET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2088
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_TOKEN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2089
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2090
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_HANDSHAKE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2091
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_SPECIAL_PID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2092
#define RSSCOPE_ATTR_SEARCH_USB_CRITERIA_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2093
#define RSSCOPE_ATTR_SEARCH_USB_TOKEN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2094
#define RSSCOPE_ATTR_SEARCH_USB_DATA_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2095
#define RSSCOPE_ATTR_SEARCH_USB_HANDSHAKE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2096
#define RSSCOPE_ATTR_SEARCH_USB_SPECIAL_PID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2097
#define RSSCOPE_ATTR_SEARCH_USB_PID_ERROR_CHECK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2098
#define RSSCOPE_ATTR_SEARCH_USB_ERROR_PID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2099
#define RSSCOPE_ATTR_SEARCH_USB_ERROR_CRC5                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2100
#define RSSCOPE_ATTR_SEARCH_USB_ERROR_CRC16                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2101
#define RSSCOPE_ATTR_SEARCH_USB_ERROR_BITSTUFF                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2102
#define RSSCOPE_ATTR_SEARCH_USB_ERROR_GLITCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2103
#define RSSCOPE_ATTR_SEARCH_USB_END_POINT_CHECK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2104
#define RSSCOPE_ATTR_SEARCH_USB_END_POINT_CHECK_CONDITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2105
#define RSSCOPE_ATTR_SEARCH_USB_END_POINT_CHECK_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2106
#define RSSCOPE_ATTR_SEARCH_USB_END_POINT_CHECK_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2107
#define RSSCOPE_ATTR_SEARCH_USB_ADDRESS_CHECK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2108
#define RSSCOPE_ATTR_SEARCH_USB_ADDRESS_CHECK_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2109
#define RSSCOPE_ATTR_SEARCH_USB_ADDRESS_CHECK_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2110
#define RSSCOPE_ATTR_SEARCH_USB_ADDRESS_CHECK_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2111
#define RSSCOPE_ATTR_SEARCH_USB_PAYLOAD_CHECK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2112
#define RSSCOPE_ATTR_SEARCH_USB_PAYLOAD_CHECK_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2113
#define RSSCOPE_ATTR_SEARCH_USB_PAYLOAD_CHECK_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2114
#define RSSCOPE_ATTR_SEARCH_USB_PAYLOAD_CHECK_DATA_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2115
#define RSSCOPE_ATTR_SEARCH_USB_PAYLOAD_CHECK_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2116
#define RSSCOPE_ATTR_SEARCH_USB_FRAME_CHECK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2117
#define RSSCOPE_ATTR_SEARCH_USB_FRAME_CHECK_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2118
#define RSSCOPE_ATTR_SEARCH_USB_FRAME_CHECK_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2119
#define RSSCOPE_ATTR_SEARCH_USB_FRAME_CHECK_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2120
#define RSSCOPE_ATTR_SEARCH_USB_SC_CHECK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2121
#define RSSCOPE_ATTR_SEARCH_USB_SC_CHECK_START_COMPLETE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2122
#define RSSCOPE_ATTR_SEARCH_USB_PORT_CHECK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2123
#define RSSCOPE_ATTR_SEARCH_USB_PORT_CHECK_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2124
#define RSSCOPE_ATTR_SEARCH_USB_PORT_CHECK_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2125
#define RSSCOPE_ATTR_SEARCH_USB_PORT_CHECK_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2126
#define RSSCOPE_ATTR_SEARCH_USB_SEU_CHECK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2127
#define RSSCOPE_ATTR_SEARCH_USB_SEU_CHECK_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2128
#define RSSCOPE_ATTR_SEARCH_USB_SEU_CHECK_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2129
#define RSSCOPE_ATTR_SEARCH_USB_SEU_CHECK_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2130
#define RSSCOPE_ATTR_SEARCH_USB_ET_CHECK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2131
#define RSSCOPE_ATTR_SEARCH_USB_ET_CHECK_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2132
#define RSSCOPE_ATTR_SEARCH_USB_ET_CHECK_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2133
#define RSSCOPE_ATTR_SEARCH_USB_ET_CHECK_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2134
#define RSSCOPE_ATTR_SEARCH_USB_PACKET_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2135
#define RSSCOPE_ATTR_SEARCH_USB31_GEN1_FRAME_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2993
#define RSSCOPE_ATTR_USB_PD_SEARCH_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3041
#define RSSCOPE_ATTR_USB_PD_SEARCH_PACKET_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3043
#define RSSCOPE_ATTR_USB_PD_SEARCH_NUMBER_OF_FRAMES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3299
#define RSSCOPE_ATTR_USB_PD_SEARCH_DATA_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3045
#define RSSCOPE_ATTR_USB_PD_SEARCH_DATA_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3046
#define RSSCOPE_ATTR_USB_PD_SEARCH_DATA_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3047
#define RSSCOPE_ATTR_USB_PD_SEARCH_INDEX_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3048
#define RSSCOPE_ATTR_USB_PD_SEARCH_INDEX_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3049
#define RSSCOPE_ATTR_USB_PD_SEARCH_INDEX_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3050
#define RSSCOPE_ATTR_USB_PD_SEARCH_BIT_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3051
#define RSSCOPE_ATTR_SEARCH_USB_PD_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3052
#define RSSCOPE_ATTR_SEARCH_EBTB_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2429
#define RSSCOPE_ATTR_SEARCH_EBTB_DISPARITY_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2430
#define RSSCOPE_ATTR_SEARCH_EBTB_GLITCHING_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2431
#define RSSCOPE_ATTR_SEARCH_EBTB_UNKNOWN_SYMBOL_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2432
#define RSSCOPE_ATTR_SEARCH_EBTB_SEARCH_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4415
#define RSSCOPE_ATTR_SEARCH_EBTB_SYMBOL_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2433
#define RSSCOPE_ATTR_SEARCH_EBTB_SYMBOL_FORMAT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2434
#define RSSCOPE_ATTR_SEARCH_EBTB_KD_CODE_SYMBOL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2435
#define RSSCOPE_ATTR_SEARCH_EBTB_DX                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2436
#define RSSCOPE_ATTR_SEARCH_EBTB_DY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2437
#define RSSCOPE_ATTR_SEARCH_EBTB_EIGHT_BIT_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2438
#define RSSCOPE_ATTR_SEARCH_EBTB_TEN_BIT_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2439
#define RSSCOPE_ATTR_SEARCH_EBTB_EXPRESSION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2440
#define RSSCOPE_ATTR_SEARCH_EBTB_SYMBOL_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2424
#define RSSCOPE_ATTR_SEARCH_SENT_CALIBRATION_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2420
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2421
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_TYPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2386
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_STATUS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2387
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2388
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_DATA_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2389
#define RSSCOPE_ATTR_SEARCH_SENT_TRANSMISSION_SEQUENCE_DATA_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2390
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2422
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2391
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_ID_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2392
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_ID_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2393
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_ID_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2394
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_ID_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2395
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_DATA_CONDITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2396
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_DATA_MIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2397
#define RSSCOPE_ATTR_SEARCH_SENT_SERIAL_MESSAGE_DATA_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2398
#define RSSCOPE_ATTR_SEARCH_SENT_ERROR_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2423
#define RSSCOPE_ATTR_SEARCH_SENT_FORM_ERROR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2399
#define RSSCOPE_ATTR_SEARCH_SENT_CALIBRATION_PULSE_ERROR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2400
#define RSSCOPE_ATTR_SEARCH_SENT_PULSE_PERIOD_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2401
#define RSSCOPE_ATTR_SEARCH_SENT_CRC_ERROR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2402
#define RSSCOPE_ATTR_SEARCH_SENT_IRREGULAR_FRAME_LENGTH_ERROR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2403
#define RSSCOPE_ATTR_SEARCH_SENT_FRAME_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2404
#define RSSCOPE_ATTR_DPHY_SEARCH_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2529
#define RSSCOPE_ATTR_DPHY_SEARCH_VIRTUAL_CHANNEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2530
#define RSSCOPE_ATTR_DPHY_SEARCH_DATA_TYPE_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2531
#define RSSCOPE_ATTR_DPHY_SEARCH_DATA_TYPE_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2532
#define RSSCOPE_ATTR_DPHY_SEARCH_DATA_TYPE_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2533
#define RSSCOPE_ATTR_DPHY_SEARCH_WORD_COUNT_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2534
#define RSSCOPE_ATTR_DPHY_SEARCH_WORD_COUNT_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2535
#define RSSCOPE_ATTR_DPHY_SEARCH_WORD_COUNT_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2536
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2537
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2538
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2539
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2540
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2541
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2542
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_INDEX_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2543
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_INDEX_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2544
#define RSSCOPE_ATTR_DPHY_SEARCH_HIGH_SPEED_DATA_INDEX_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2545
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_INDEX_CONDITION                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2546
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_INDEX_MIN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2547
#define RSSCOPE_ATTR_DPHY_SEARCH_LOW_POWER_ESCAPE_MODE_DATA_INDEX_MAX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2548
#define RSSCOPE_ATTR_DPHY_SEARCH_ESCAPE_MODE_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2549
#define RSSCOPE_ATTR_DPHY_SEARCH_ESCAPE_MODE_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2550
#define RSSCOPE_ATTR_DPHY_SEARCH_ESCAPE_MODE_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2551
#define RSSCOPE_ATTR_SEARCH_DPHY_FRAME_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2552
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2592
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_CONTROL_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2593
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_TIME_CODE_CONDITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2594
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_TIME_CODE_MIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2595
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_TIME_CODE_MAX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2596
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_DATA_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2597
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_DATA_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2598
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_DATA_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2599
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_PARITY_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2600
#define RSSCOPE_ATTR_SPACE_WIRE_SEARCH_ESCAPE_ERROR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2601
#define RSSCOPE_ATTR_SEARCH_SPACE_WIRE_FRAME_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2602
#define RSSCOPE_ATTR_SEARCH_SPI_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2708
#define RSSCOPE_ATTR_SEARCH_SPI_DATA_OPERATOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2709
#define RSSCOPE_ATTR_SEARCH_SPI_MISO_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2710
#define RSSCOPE_ATTR_SEARCH_SPI_MOSI_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2711
#define RSSCOPE_ATTR_SEARCH_SPI_DATA_POSITION_OPERATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2712
#define RSSCOPE_ATTR_SEARCH_SPI_DATA_POSITION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2713
#define RSSCOPE_ATTR_SEARCH_SPI_DATA_ALIGNMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2714
#define RSSCOPE_ATTR_SEARCH_SPI_DATA_POSITION_TO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2715
#define RSSCOPE_ATTR_SEARCH_MPHY_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2716
#define RSSCOPE_ATTR_SEARCH_MPHY_LCC_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2717
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_ONE_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2718
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_ONE_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2719
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_ONE_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2720
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_TWO_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2721
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_TWO_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2722
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_TWO_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2723
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_THREE_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2724
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_THREE_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2725
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_THREE_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2726
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_FOUR_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2727
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_FOUR_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2728
#define RSSCOPE_ATTR_SEARCH_MPHY_WORD_FOUR_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2729
#define RSSCOPE_ATTR_SEARCH_MPHY_TC_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2730
#define RSSCOPE_ATTR_SEARCH_MPHY_DATA_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2731
#define RSSCOPE_ATTR_SEARCH_MPHY_DATA_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2732
#define RSSCOPE_ATTR_SEARCH_MPHY_DATA_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2733
#define RSSCOPE_ATTR_SEARCH_MPHY_INDEX_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2734
#define RSSCOPE_ATTR_SEARCH_MPHY_INDEX_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2735
#define RSSCOPE_ATTR_SEARCH_MPHY_INDEX_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2736
#define RSSCOPE_ATTR_SEARCH_MPHY_FSN_CONDITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2737
#define RSSCOPE_ATTR_SEARCH_MPHY_FSN_MIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2738
#define RSSCOPE_ATTR_SEARCH_MPHY_FSN_MAX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2739
#define RSSCOPE_ATTR_SEARCH_MPHY_CRC_CONDITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2740
#define RSSCOPE_ATTR_SEARCH_MPHY_CRC_MIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2741
#define RSSCOPE_ATTR_SEARCH_MPHY_CRC_MAX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2742
#define RSSCOPE_ATTR_SEARCH_MPHY_CREQ_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2743
#define RSSCOPE_ATTR_SEARCH_MPHY_RREQ_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2744
#define RSSCOPE_ATTR_SEARCH_MPHY_CREDIT_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2745
#define RSSCOPE_ATTR_SEARCH_MPHY_CREDIT_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2746
#define RSSCOPE_ATTR_SEARCH_MPHY_CREDIT_MAX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2747
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_BEGIN_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2748
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_BEGIN_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2749
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_BEGIN_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2750
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_ID_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2751
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_ID_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2752
#define RSSCOPE_ATTR_SEARCH_MPHY_PACP_ID_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2753
#define RSSCOPE_ATTR_SEARCH_MPHY_LCC_ERROR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2754
#define RSSCOPE_ATTR_SEARCH_MPHY_ERROR_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2755
#define RSSCOPE_ATTR_SEARCH_MPHY_ERROR_RESERVED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2756
#define RSSCOPE_ATTR_SEARCH_MPHY_ERROR_SYMBOL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2757
#define RSSCOPE_ATTR_SEARCH_MPHY_ERROR_UNIDENTIFIED_UNIPRO_FRAME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2758
#define RSSCOPE_ATTR_CXPI_SEARCH_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2913
#define RSSCOPE_ATTR_CXPI_SEARCH_NM                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2914
#define RSSCOPE_ATTR_CXPI_SEARCH_CT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2915
#define RSSCOPE_ATTR_CXPI_SEARCH_FRAME_ID_CONDITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2916
#define RSSCOPE_ATTR_CXPI_SEARCH_FRAME_ID_MIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2917
#define RSSCOPE_ATTR_CXPI_SEARCH_FRAME_ID_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2918
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_CONDITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2919
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_MIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2920
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_MAX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2921
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_EXTEND_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2922
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_EXTEND_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2923
#define RSSCOPE_ATTR_CXPI_SEARCH_DLC_EXTEND_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2924
#define RSSCOPE_ATTR_CXPI_SEARCH_DATA_CONDITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2925
#define RSSCOPE_ATTR_CXPI_SEARCH_DATA_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2926
#define RSSCOPE_ATTR_CXPI_SEARCH_DATA_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2927
#define RSSCOPE_ATTR_CXPI_SEARCH_INDEX_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2928
#define RSSCOPE_ATTR_CXPI_SEARCH_INDEX_MIN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2929
#define RSSCOPE_ATTR_CXPI_SEARCH_INDEX_MAX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2930
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_CRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2931
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_DLC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2932
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_IBS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2933
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_IFS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2934
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2935
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_PARITY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2936
#define RSSCOPE_ATTR_CXPI_SEARCH_ERROR_UART                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2937
#define RSSCOPE_ATTR_SEARCH_CXPI_FRAME_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3003
#define RSSCOPE_ATTR_PCIE_SEARCH_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3116
#define RSSCOPE_ATTR_PCIE_PACKET_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3300
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3117
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_SEQUENCE_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3118
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_TC                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3119
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_ORDERING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3120
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_SNOOP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3121
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_REQUESTER_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3122
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_DEVICE_ID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3123
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_READ_WRITE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3124
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_ADDRESS_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3125
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3126
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_ROUTING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3127
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_MESSAGE_CODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3128
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_STATUS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3129
#define RSSCOPE_ATTR_PCIE_SEARCH_TLP_COMPLETER_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3130
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3131
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3132
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_INIT_PHASE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3133
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_INIT_VH_FC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3134
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_INIT_MIXED_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3135
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_INIT_AUTHORIZED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3136
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_INIT_DEVICE_PORT_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3137
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_VL_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3138
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_VH_ABSENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3139
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_TLP_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3140
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_CREDIT_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3141
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_A                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3142
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_MR_VH_GROUP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3143
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_SEQUENCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3144
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_FC_CREDIT_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3145
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_FC_VC_ID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3146
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_PM_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3147
#define RSSCOPE_ATTR_PCIE_SEARCH_DLLP_VENDOR_PATTERN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3148
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_TRAINING_SEQUENCE_1                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3149
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_TRAINING_SEQUENCE_2                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3150
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_FAST_TRAINING_SEQUENCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3151
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_EIDL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3152
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_EIDE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3153
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_SKP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3154
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_COMP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3155
#define RSSCOPE_ATTR_PCIE_SEARCH_OSET_START_OF_DATA_SEQUENCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4416
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_CRC16                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3156
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_LCRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3157
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_ECRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3158
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_INVALID_SYMBOL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3159
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_DISP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3160
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_LENGTH_ERROR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4417
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_MALFORMED_ERROR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4418
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_MAX_END_PREFIX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4419
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_PREFIX_ORDER_ERROR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4420
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_SYNC_BIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4421
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_UNKNOWN_PACKET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4422
#define RSSCOPE_ATTR_PCIE_SEARCH_ERRC_VALUE_OUT_OF_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4423
#define RSSCOPE_ATTR_SEARCH_PCIE_PACKET_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3161
#define RSSCOPE_ATTR_SEARCH_DDR_FRAME_COUNT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3571
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3582
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DESTINATION_ADDRESS_CONDITION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3583
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DESTINATION_ADDRESS_MAX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3584
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DESTINATION_ADDRESS_MIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3585
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_SOURCE_ADDRESS_CONDITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3586
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_SOURCE_ADDRESS_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3587
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_SOURCE_ADDRESS_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3588
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_TYPE_LENGTH_CONDITION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3589
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_TYPE_LENGTH_MAX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3590
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_TYPE_LENGTH_MIN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3591
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_CRC_CONDITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3592
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_CRC_MAX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3593
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_CRC_MIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3594
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DATA_CONDITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3595
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DATA_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3596
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_DATA_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3597
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_INDEX_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3598
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_INDEX_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3599
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_INDEX_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3600
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_ERROR_PREAMBLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3601
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_ERROR_CRC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3602
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_ERROR_SFD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3603
#define RSSCOPE_ATTR_SEARCH_100BASE_T1_FRAME_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3604
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4258
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DESTINATION_ADDRESS_CONDITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4259
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DESTINATION_ADDRESS_MIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4260
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DESTINATION_ADDRESS_MAX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4261
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_SOURCE_ADDRESS_CONDITION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4262
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_SOURCE_ADDRESS_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4263
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_SOURCE_ADDRESS_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4264
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_LENGTH_TYPE_CONDITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4265
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_LENGTH_TYPE_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4266
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_LENGTH_TYPE_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4267
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_CHECK_CRC_CONDITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4268
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_CHECK_CRC_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4269
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_CHECK_CRC_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4270
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DATA_CONDITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4271
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DATA_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4272
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_DATA_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4273
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_INDEX_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4274
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_INDEX_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4275
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_INDEX_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4276
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_ERROR_RS_FEC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4277
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_ERROR_CRC                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4278
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_ERROR_OUT_OF_RANGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4279
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_ERROR_ZERO_TERNARY_SYMBOL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4280
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4281
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_SELECTED_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4282
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_STATUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4283
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_START_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4285
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_STOP_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4287
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_DESTINATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4289
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_DESTINATION_SYMBOLS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4291
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4293
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_SOURCE_SYMBOLS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4295
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_DATA_STRING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4297
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_CRC                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4299
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_LENGTH_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4301
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4303
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_NUMBER_OF_WORDS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4305
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_SELECTED_WORD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4306
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_WORD_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4307
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_WORD_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4309
#define RSSCOPE_ATTR_SEARCH_1000BASE_T1_FRAME_WORD_VALUE_STRING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4311
#define RSSCOPE_ATTR_PROTOCOL_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSSCOPE_ATTR_PROTOCOL_TYPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347
#define RSSCOPE_ATTR_PROTOCOL_LABEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348
#define RSSCOPE_ATTR_PROTOCOL_DISPLAY_RESULT_TABLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSSCOPE_ATTR_PROTOCOL_RESULT_TABLE_ZOOM_COUPLING_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3978
#define RSSCOPE_ATTR_PROTOCOL_RESULT_TABLE_POSITION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3979
#define RSSCOPE_ATTR_PROTOCOL_SHOW_THRESHOLD_LINES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3213
#define RSSCOPE_ATTR_PROTOCOL_DATA_FORMAT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSSCOPE_ATTR_PROTOCOL_SHOW_DETAILS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3214
#define RSSCOPE_ATTR_PROTOCOL_BUS_DATA_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1781
#define RSSCOPE_ATTR_PROTOCOL_LABEL_LIST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSSCOPE_ATTR_PROTOCOL_LABEL_LIST_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1782
#define RSSCOPE_ATTR_PROTOCOL_REFERENCE_LEVELS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSSCOPE_ATTR_PROTOCOL_AUTOSET_THRESHOLD_AND_BITRATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3980
#define RSSCOPE_ATTR_PROTOCOL_EXPORT_INCLUDE_FRAME_TIMING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4424
#define RSSCOPE_ATTR_PROTOCOL_EXPORT_INCLUDE_DETAILS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4425
#define RSSCOPE_ATTR_PROTOCOL_EXPORT_SAVE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4426
#define RSSCOPE_ATTR_PROTOCOL_I2C_TECHNOLOGY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352
#define RSSCOPE_ATTR_PROTOCOL_I2C_RW_BIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSSCOPE_ATTR_PROTOCOL_I2C_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1085
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1086
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1087
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_STOP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1088
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ADDRESS_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1089
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ADDRESS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1090
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_RW_BIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1091
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ACK_BIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1092
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ACCESS_BIT_START                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1093
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_SLAVE_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1094
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ADDRESS_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1095
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ADDRESS_ACK_BIT_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1096
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_ADDRESS_COMPLETE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1097
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BIT_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3981
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1098
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_LABEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1099
#define RSSCOPE_ATTR_PROTOCOL_I2C_SELECTED_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1100
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BYTE_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1101
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BYTE_ACK_BIT_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1102
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BYTE_START                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1103
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BYTE_ACK_BIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3619
#define RSSCOPE_ATTR_PROTOCOL_I2C_FRAME_BYTE_COMPLETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3620
#define RSSCOPE_ATTR_PROTOCOL_I2C_SCL_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1105
#define RSSCOPE_ATTR_PROTOCOL_I2C_SCL_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1106
#define RSSCOPE_ATTR_PROTOCOL_I2C_SDA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1107
#define RSSCOPE_ATTR_PROTOCOL_I2C_SDA_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1108
#define RSSCOPE_ATTR_PROTOCOL_SPI_BIT_ORDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSSCOPE_ATTR_PROTOCOL_SPI_WORD_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSSCOPE_ATTR_PROTOCOL_SPI_TECHNOLOGY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 385
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_START_CONDITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 484
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_START_TIMEOUT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 485
#define RSSCOPE_ATTR_PROTOCOL_SPI_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1109
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1110
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1111
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_STOP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1112
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_BIT_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3982
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1113
#define RSSCOPE_ATTR_PROTOCOL_SPI_SELECTED_WORD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1114
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_START                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1115
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_STOP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1116
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_MISO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1117
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_MISO_FORMATTED_VALUE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3621
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_MOSI                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1118
#define RSSCOPE_ATTR_PROTOCOL_SPI_FRAME_WORD_MOSI_FORMATTED_VALUE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3622
#define RSSCOPE_ATTR_PROTOCOL_SPI_CLOCK_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1120
#define RSSCOPE_ATTR_PROTOCOL_SPI_CLOCK_THRESHOLD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1121
#define RSSCOPE_ATTR_PROTOCOL_SPI_MOSI_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1122
#define RSSCOPE_ATTR_PROTOCOL_SPI_MOSI_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1123
#define RSSCOPE_ATTR_PROTOCOL_SPI_MOSI_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1124
#define RSSCOPE_ATTR_PROTOCOL_SPI_MISO_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1125
#define RSSCOPE_ATTR_PROTOCOL_SPI_MISO_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1126
#define RSSCOPE_ATTR_PROTOCOL_SPI_MISO_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1127
#define RSSCOPE_ATTR_PROTOCOL_SPI_SLAVE_SELECT_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1128
#define RSSCOPE_ATTR_PROTOCOL_SPI_SLAVE_SELECT_POLARITY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1129
#define RSSCOPE_ATTR_PROTOCOL_SPI_SLAVE_SELECT_THRESHOLD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1130
#define RSSCOPE_ATTR_PROTOCOL_UART_TECHNOLOGY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSSCOPE_ATTR_PROTOCOL_UART_BIT_RATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSSCOPE_ATTR_PROTOCOL_UART_PARITY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSSCOPE_ATTR_PROTOCOL_UART_POLARITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 407
#define RSSCOPE_ATTR_PROTOCOL_UART_STOP_BITS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 408
#define RSSCOPE_ATTR_PROTOCOL_UART_DATA_BITS_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 409
#define RSSCOPE_ATTR_PROTOCOL_UART_WORD_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 418
#define RSSCOPE_ATTR_PROTOCOL_UART_PRIMARY_BIT_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3983
#define RSSCOPE_ATTR_PROTOCOL_UART_PACKETS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1588
#define RSSCOPE_ATTR_PROTOCOL_UART_TOUT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1589
#define RSSCOPE_ATTR_PROTOCOL_UART_END_OF_FRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1590
#define RSSCOPE_ATTR_PROTOCOL_UART_RX_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1137
#define RSSCOPE_ATTR_PROTOCOL_UART_RX_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1138
#define RSSCOPE_ATTR_PROTOCOL_UART_TX_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1139
#define RSSCOPE_ATTR_PROTOCOL_UART_TX_THRESHOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1140
#define RSSCOPE_ATTR_PROTOCOL_LIN_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 486
#define RSSCOPE_ATTR_PROTOCOL_LIN_THRESHOLD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 487
#define RSSCOPE_ATTR_PROTOCOL_LIN_TECHNOLOGY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define RSSCOPE_ATTR_PROTOCOL_LIN_STANDARD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define RSSCOPE_ATTR_PROTOCOL_LIN_BIT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSSCOPE_ATTR_PROTOCOL_LIN_POLARITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSSCOPE_ATTR_PROTOCOL_LIN_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1141
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1142
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1143
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_STOP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1144
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_VERSION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1145
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_ID_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1146
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_ID_PARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1147
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_ID_STATUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1148
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_SYNC_STATUS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1149
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_CHECKSUM_STATUS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1150
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_CHECKSUM_VALUE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1151
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_BIT_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3984
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_LABEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1152
#define RSSCOPE_ATTR_PROTOCOL_LIN_SELECTED_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1153
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_BYTE_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1154
#define RSSCOPE_ATTR_PROTOCOL_LIN_FRAME_BYTE_STATUS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1155
#define RSSCOPE_ATTR_PROTOCOL_CAN_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define RSSCOPE_ATTR_PROTOCOL_CAN_LINE_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define RSSCOPE_ATTR_PROTOCOL_CAN_THRESHOLD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define RSSCOPE_ATTR_PROTOCOL_CAN_TECHNOLOGY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 510
#define RSSCOPE_ATTR_PROTOCOL_CAN_BIT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1783
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_BIT_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1784
#define RSSCOPE_ATTR_PROTOCOL_CAN_JUMP_WIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define RSSCOPE_ATTR_PROTOCOL_CAN_SAMPLE_POINT_REL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_JUMP_WIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3181
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_SAMPLE_POINT_REL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3182
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_STANDARD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3207
#define RSSCOPE_ATTR_PROTOCOL_CAN_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1157
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_STANDARD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2149
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1158
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1159
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_STOP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1160
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1161
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ID_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1162
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ID_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1163
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ID_STATUS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1164
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_DLC_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1165
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_DLC_STATUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1166
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ACK_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1167
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ACK_STATUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1168
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_BIT_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3987
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_CRC_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1169
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_CRC_STATUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1170
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_ERROR_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1171
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_LABEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1172
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_NUMBER_OF_BYTES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3183
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_FORM_ERROR_CAUSE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3184
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_FRAME_STUFF_COUNT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3208
#define RSSCOPE_ATTR_PROTOCOL_CAN_SELECTED_BYTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1173
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_BYTE_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1174
#define RSSCOPE_ATTR_PROTOCOL_CAN_FRAME_BYTE_STATUS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1175
#define RSSCOPE_ATTR_PROTOCOL_CAN_SAMPLE_POINT_ABS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 513
#define RSSCOPE_ATTR_PROTOCOL_CAN_FD_SAMPLE_POINT_ABS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3185
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SOURCE_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 592
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SINGLE_POLARITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 593
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SINGLE_PRESET_TRESHOLD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_DIFF_PRESET_TRESHOLD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 595
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_THRESHOLD_HIGH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1177
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_THRESHOLD_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1178
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_LOGIC_PRESET_TRESHOLD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_THRESHOLD_DATA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1179
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_THRESHOLD_ENABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1180
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_BIT_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_CHANNEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SEPARATE_HEADER_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SELECTED_FRAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1181
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_COUNT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_STATUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_START                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1182
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_STOP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1183
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_FLAGS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1184
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_PAYLOAD_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1185
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_IDENTIFIER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1186
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_HEADER_CRC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1187
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_CRC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1188
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_HEADER_CRC_STATUS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1189
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_CRC_STATUS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1190
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_FRAME_LABEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1191
#define RSSCOPE_ATTR_PROTOCOL_FLEXRAY_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 591
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_VARIANT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRESHOLDS_COUPLING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_WORD_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CHANNEL_ORDER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_BIT_ORDER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CHANNEL_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CHANNEL_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_FRAME_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TDM_CHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_SELECTED_FRAME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1193
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_FRAME_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CLOCK_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1203
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CLOCK_THRESHOLD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1204
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_CLOCK_POLARITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_WS_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1205
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_WS_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1206
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_WS_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_DATA_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1207
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_DATA_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1208
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_DATA_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_LEFT_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3989
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_RIGHT_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3990
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_TDM_CHANNEL_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3991
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1591
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_POLARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1592
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_THRESHOLD_HIGH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1593
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_THRESHOLD_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1594
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_THRESHOLD_PRESET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1595
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_MIN_GAP_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1596
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_MIN_GAP_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1597
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_MAX_RESPONSE_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1598
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_MAX_RESPONSE_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1599
#define RSSCOPE_ATTR_PROTOCOL_MIL1553_DECODING_RESULTS_WORDS_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1600
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1609
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1610
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_BIT_RATE_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1611
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_BIT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1612
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_THRESHOLD_HIGH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1613
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_THRESHOLD_LOW                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1614
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_THRESHOLD_PRESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1615
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_MIN_GAP_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1616
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_MIN_GAP_BITS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1617
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_MAX_GAP_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1618
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_MAX_GAP_BITS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1619
#define RSSCOPE_ATTR_PROTOCOL_ARINC429_DECODING_RESULTS_WORDS_COUNT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1620
#define RSSCOPE_ATTR_PROTOCOL_RFFE_CLOCK_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1878
#define RSSCOPE_ATTR_PROTOCOL_RFFE_DATA_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1879
#define RSSCOPE_ATTR_PROTOCOL_RFFE_PRESET_THRESHOLD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1880
#define RSSCOPE_ATTR_PROTOCOL_RFFE_CLOCK_THRESHOLD_HIGH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1881
#define RSSCOPE_ATTR_PROTOCOL_RFFE_CLOCK_THRESHOLD_LOW                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1882
#define RSSCOPE_ATTR_PROTOCOL_RFFE_CLOCK_THRESHOLD_HYSTERESIS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1883
#define RSSCOPE_ATTR_PROTOCOL_RFFE_DATA_THRESHOLD_HIGH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1884
#define RSSCOPE_ATTR_PROTOCOL_RFFE_DATA_THRESHOLD_LOW                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1885
#define RSSCOPE_ATTR_PROTOCOL_RFFE_DATA_THRESHOLD_HYSTERESIS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1886
#define RSSCOPE_ATTR_PROTOCOL_RFFE_THRESHOLDS_COUPLING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1887
#define RSSCOPE_ATTR_PROTOCOL_RFFE_GLITCH_FILTER_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1888
#define RSSCOPE_ATTR_PROTOCOL_RFFE_GLITCH_FILTER_WIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1889
#define RSSCOPE_ATTR_PROTOCOL_RFFE_MIN_GAP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1890
#define RSSCOPE_ATTR_PROTOCOL_RFFE_MIN_GAP_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1891
#define RSSCOPE_ATTR_PROTOCOL_RFFE_MAX_GAP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1892
#define RSSCOPE_ATTR_PROTOCOL_RFFE_MAX_GAP_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1893
#define RSSCOPE_ATTR_PROTOCOL_RFFE_READ_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4203
#define RSSCOPE_ATTR_PROTOCOL_RFFE_VERSION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4204
#define RSSCOPE_ATTR_PROTOCOL_RFFE_DECODING_RESULTS_SEQUENCE_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1894
#define RSSCOPE_ATTR_PROTOCOL_MDIO_THRESHOLD_PRESET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1938
#define RSSCOPE_ATTR_PROTOCOL_MDIO_CLOCK_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1939
#define RSSCOPE_ATTR_PROTOCOL_MDIO_CLOCK_THRESHOLD_HIGH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1940
#define RSSCOPE_ATTR_PROTOCOL_MDIO_CLOCK_THRESHOLD_LOW                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1941
#define RSSCOPE_ATTR_PROTOCOL_MDIO_DATA_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1942
#define RSSCOPE_ATTR_PROTOCOL_MDIO_DATA_THRESHOLD_HIGH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1943
#define RSSCOPE_ATTR_PROTOCOL_MDIO_DATA_THRESHOLD_LOW                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1944
#define RSSCOPE_ATTR_PROTOCOL_MDIO_THRESHOLDS_COUPLING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1945
#define RSSCOPE_ATTR_PROTOCOL_MDIO_MAX_GAP_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2771
#define RSSCOPE_ATTR_PROTOCOL_MDIO_DECODING_RESULTS_WORD_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1952
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_VARIANT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2006
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2007
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2008
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_THRESHOLD_PRESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2009
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_THRESHOLD_LOW                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2010
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_THRESHOLD_HIGH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2011
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_BIT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2012
#define RSSCOPE_ATTR_PROTOCOL_ETHERNET_DECODING_RESULTS_WORD_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2013
#define RSSCOPE_ATTR_PROTOCOL_USB_D_PLUS_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2025
#define RSSCOPE_ATTR_PROTOCOL_USB_D_MINUS_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2026
#define RSSCOPE_ATTR_PROTOCOL_USB_DIFFERENTIAL_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2027
#define RSSCOPE_ATTR_PROTOCOL_USB_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2028
#define RSSCOPE_ATTR_PROTOCOL_USB_STROBE_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2029
#define RSSCOPE_ATTR_PROTOCOL_USB_TECHNOLOGY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2030
#define RSSCOPE_ATTR_PROTOCOL_USB_D_PLUS_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2031
#define RSSCOPE_ATTR_PROTOCOL_USB_D_MINUS_THRESHOLD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2032
#define RSSCOPE_ATTR_PROTOCOL_USB_DIFFERENTIAL_THRESHOLD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2033
#define RSSCOPE_ATTR_PROTOCOL_USB_DATA_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2034
#define RSSCOPE_ATTR_PROTOCOL_USB_STROBE_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2035
#define RSSCOPE_ATTR_PROTOCOL_USB_DECODING_RESULTS_PACKET_COUNT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2036
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2956
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2957
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_THRESHOLD_LOW                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2958
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_THRESHOLD_HIGH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2959
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_SCRAMBLE_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2960
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3626
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_FRAME_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2961
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_HIGH_SPEED_BITRATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4427
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4428
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_ZERO_FREQUENCY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4429
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_POLE_FREQUENCY_FP1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4430
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_POLE_FREQUENCY_FP2                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4431
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_DC_GAIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4432
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_CTLE_CHANNEL_LENGTH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4433
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_DFE_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4434
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_DFE_ESTIMATE_COEFFICIENTS_ENABLED        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4435
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_DFE_COEFFICIENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4436
#define RSSCOPE_ATTR_PROTOCOL_USB31_GEN1_TYPE_DSP_DFE_NUMBER_OF_TAPS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4437
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_DATA_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3013
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_DATA_THRESHOLD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3014
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_DATA_HYSTERESIS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3015
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_THRESHOLD_VRD15                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3016
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_THRESHOLD_VRD_USB                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3017
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_THRESHOLD_VRA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3018
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_SHOW_DECODE_DETAIL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3019
#define RSSCOPE_ATTR_PROTOCOL_USB_PD_FRAME_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3020
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CODING_STANDARD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2168
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_BITRATE_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2169
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_BITRATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2170
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_GAP_TIME_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2171
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_GAP_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2172
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_DATA_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2173
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2174
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_CLOCK_PHASE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2175
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_THRESHOLD_LOW                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2176
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_THRESHOLD_HIGH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2177
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_THRESHOLD_PRESET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2178
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_THRESHOLD_COUPLING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2179
#define RSSCOPE_ATTR_PROTOCOL_NRZ_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2180
#define RSSCOPE_ATTR_PROTOCOL_NRZ_ENABLE_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2772
#define RSSCOPE_ATTR_PROTOCOL_NRZ_CLOCK_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2181
#define RSSCOPE_ATTR_PROTOCOL_NRZ_POLARITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2182
#define RSSCOPE_ATTR_PROTOCOL_NRZ_ENA_POLARITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2773
#define RSSCOPE_ATTR_PROTOCOL_NRZ_IDLE_POLARITY_UNCLOCKED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2183
#define RSSCOPE_ATTR_PROTOCOL_NRZ_IDLE_POLARITY_CLOCKED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2184
#define RSSCOPE_ATTR_PROTOCOL_NRZ_CLOCK_PHASE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2185
#define RSSCOPE_ATTR_PROTOCOL_NRZ_THRESHOLD_CLOCK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2186
#define RSSCOPE_ATTR_PROTOCOL_NRZ_THRESHOLD_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2187
#define RSSCOPE_ATTR_PROTOCOL_NRZ_THRESHOLD_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2188
#define RSSCOPE_ATTR_PROTOCOL_NRZ_THRESHOLD_COUPLING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2189
#define RSSCOPE_ATTR_PROTOCOL_NRZ_THRESHOLD_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2774
#define RSSCOPE_ATTR_PROTOCOL_NRZ_HYSTERESIS_CLOCK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3631
#define RSSCOPE_ATTR_PROTOCOL_NRZ_HYSTERESIS_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3632
#define RSSCOPE_ATTR_PROTOCOL_NRZ_HYSTERESIS_ENABLE_VALUE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3633
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_SELECTED_FRAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2190
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FRAME_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2191
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FRAME_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2192
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_ADD_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2193
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FRAME_CLEAR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2194
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FRAME_OPEN_DESCRIPTION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2195
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FRAME_SAVE_DESCRIPTION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2196
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_EXPORT_FRAMES_AS_RAW_BITS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3634
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_SELECTED_CELL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2197
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_COUNT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2198
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_ADD_CELL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2199
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_NAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2200
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_BIT_COUNT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2201
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_CONDITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2202
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_FORMAT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2203
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_BIT_ORDER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2204
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_COLOR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2205
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_COLOR_CRGB                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3245
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_CELL_RESULT_COLUMN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2206
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_SELECTED_FIELD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4438
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3635
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_NUMERIC_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4439
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_BIT_STATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4440
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_DATA_PATTERN_CONDITION     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4441
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_DATA_PATTERN_MIN           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4442
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_DATA_PATTERN_MAX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4443
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_INDEX_PATTERN_CONDITION    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4444
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_INDEX_PATTERN_MIN          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4445
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_FILTER_FRAME_FIELD_INDEX_PATTERN_MAX          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4446
#define RSSCOPE_ATTR_PROTOCOL_MANCHESTER_NRZ_RESULT_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2207
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_SIGNAL_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2219
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_DIFFERENTIAL_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2220
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_D_PLUS_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2221
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_D_MINUS_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2222
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_FULL_AUTOSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2223
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_DIFFERENTIAL_THRESHOLD_HIGH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2224
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_DIFFERENTIAL_THRESHOLD_LOW                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2225
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_THRESHOLD_D_PLUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2226
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_THRESHOLD_D_MINUS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2227
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_BITRATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2228
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_BITRATE_DETERMINATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2229
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_ESTIMATED_BITRATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3650
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_SW_CDR_BITRATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2230
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_SYNC_SYMBOL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2231
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2232
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_SECOND_PATTERN_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2233
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_SECOND_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2234
#define RSSCOPE_ATTR_PROTOCOLS_EBTB_DISPLAY_FORMAT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2235
#define RSSCOPE_ATTR_PROTOCOL_EBTB_SYMBOL_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2236
#define RSSCOPE_ATTR_PROTOCOL_SENT_DATA_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2241
#define RSSCOPE_ATTR_PROTOCOL_SENT_THRESHOLD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2242
#define RSSCOPE_ATTR_PROTOCOL_SENT_TECHNOLOGY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2243
#define RSSCOPE_ATTR_PROTOCOL_SENT_CLOCK_PERIOD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2244
#define RSSCOPE_ATTR_PROTOCOL_SENT_CLOCK_TOLERANCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2245
#define RSSCOPE_ATTR_PROTOCOL_SENT_DATA_NIBBLES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2246
#define RSSCOPE_ATTR_PROTOCOL_SENT_SERIAL_FORMAT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2247
#define RSSCOPE_ATTR_PROTOCOL_SENT_CRC_VERSION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2248
#define RSSCOPE_ATTR_PROTOCOL_SENT_CRC_CALCULATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2249
#define RSSCOPE_ATTR_PROTOCOL_SENT_PAUSE_PULSE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2250
#define RSSCOPE_ATTR_PROTOCOL_SENT_FRAME_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2251
#define RSSCOPE_ATTR_PROTOCOL_SENT_RESULT_DISPLAY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2252
#define RSSCOPE_ATTR_PROTOCOL_SENT_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2279
#define RSSCOPE_ATTR_PROTOCOL_DPHY_VARIANT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2461
#define RSSCOPE_ATTR_PROTOCOL_DPHY_PHYSICAL_CONFIGURATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3654
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DATA_LANES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2462
#define RSSCOPE_ATTR_PROTOCOL_DPHY_CP_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2463
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DN_ZERO_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2488
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_ZERO_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2464
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_ONE_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2465
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_TWO_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2466
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_THREE_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2467
#define RSSCOPE_ATTR_PROTOCOL_DPHY_CP_PROBE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2489
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DN_ZERO_PROBE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2490
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_ZERO_PROBE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2491
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_ONE_PROBE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2492
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_TWO_PROBE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2493
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DP_THREE_PROBE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2494
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DATA_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2495
#define RSSCOPE_ATTR_PROTOCOL_DPHY_DISPALY_DATA_VECTOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2496
#define RSSCOPE_ATTR_PROTOCOL_DPHY_THRESHOLD_PRESET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2497
#define RSSCOPE_ATTR_PROTOCOL_DPHY_THRESHOLD_COUPLING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2498
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_CP_THRESHOLD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2499
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_ZERO_THRESHOLD                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2500
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_ONE_THRESHOLD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2501
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_TWO_THRESHOLD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2502
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_THREE_THRESHOLD                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2503
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_CP_HYSTERESIS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2504
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_ZERO_HYSTERESIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2505
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_ONE_HYSTERESIS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2506
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_TWO_HYSTERESIS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2507
#define RSSCOPE_ATTR_PROTOCOL_DPHY_HIGH_SPEED_DP_THREE_HYSTERESIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2508
#define RSSCOPE_ATTR_PROTOCOL_DPHY_LOW_POWER_DN_ZERO_THRESHOLD_UPPER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2509
#define RSSCOPE_ATTR_PROTOCOL_DPHY_LOW_POWER_DP_ZERO_THRESHOLD_UPPER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2510
#define RSSCOPE_ATTR_PROTOCOL_DPHY_LOW_POWER_DN_ZERO_THRESHOLD_LOWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2511
#define RSSCOPE_ATTR_PROTOCOL_DPHY_LOW_POWER_DP_ZERO_THRESHOLD_LOWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2512
#define RSSCOPE_ATTR_PROTOCOL_DPHY_SHOW_MULTIPLE_LANES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4447
#define RSSCOPE_ATTR_PROTOCOL_DPHY_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2516
#define RSSCOPE_ATTR_PROTOCOL_MPHY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2775
#define RSSCOPE_ATTR_PROTOCOL_MPHY_DATA_LANES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2776
#define RSSCOPE_ATTR_PROTOCOL_MPHY_DATA_SOURCE_ZERO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2777
#define RSSCOPE_ATTR_PROTOCOL_MPHY_DATA_SOURCE_ONE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2778
#define RSSCOPE_ATTR_PROTOCOL_MPHY_DATA_SOURCE_TWO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2779
#define RSSCOPE_ATTR_PROTOCOL_MPHY_DATA_SOURCE_THREE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2780
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_ZERO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2781
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_ONE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2782
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_TWO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2783
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_THREE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2784
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_COUPLING_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2785
#define RSSCOPE_ATTR_PROTOCOL_MPHY_THRESHOLD_PRESET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2786
#define RSSCOPE_ATTR_PROTOCOL_MPHY_SCRAMBLED_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3655
#define RSSCOPE_ATTR_PROTOCOL_MPHY_SHOW_MULTIPLE_LANES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4448
#define RSSCOPE_ATTR_PROTOCOL_MPHY_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2787
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_STROBE_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2565
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_DATA_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2566
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_THRESHOLD_PRESET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2567
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_THRESHOLD_COUPLING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2568
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_STROBE_THRESHOLD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2569
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_DATA_THRESHOLD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2570
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_STROBE_HYSTERESIS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2571
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_DATA_HYSTERESIS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2572
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_SYNC_SETTINGS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2573
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_SYNC_BIT_POSITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2574
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_MIN_GAP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2575
#define RSSCOPE_ATTR_PROTOCOL_SPACE_WIRE_FRAME_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2586
#define RSSCOPE_ATTR_PROTOCOL_CXPI_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2938
#define RSSCOPE_ATTR_PROTOCOL_CXPI_POLARITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2939
#define RSSCOPE_ATTR_PROTOCOL_CXPI_THRESHOLD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2940
#define RSSCOPE_ATTR_PROTOCOL_CXPI_HYSTERESIS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2941
#define RSSCOPE_ATTR_PROTOCOL_CXPI_DISPLAY_ORDER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2942
#define RSSCOPE_ATTR_PROTOCOL_CXPI_AVERAGE_BIT_RATE_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2943
#define RSSCOPE_ATTR_PROTOCOL_CXPI_BIT_RATE_VALUE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2944
#define RSSCOPE_ATTR_PROTOCOL_CXPI_MEASURED_BIT_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2945
#define RSSCOPE_ATTR_PROTOCOL_CXPI_EXPECTED_IBS_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3666
#define RSSCOPE_ATTR_PROTOCOL_CXPI_EXPECTED_IBS_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3667
#define RSSCOPE_ATTR_PROTOCOL_CXPI_EXPECTED_IFS_MIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3668
#define RSSCOPE_ATTR_PROTOCOL_CXPI_EXPECTED_IFS_MAX                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3669
#define RSSCOPE_ATTR_PROTOCOL_CXPI_FRAME_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2946
#define RSSCOPE_ATTR_PROTOCOL_PCIE_GENERATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3079
#define RSSCOPE_ATTR_PROTOCOL_PCIE_LINK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3080
#define RSSCOPE_ATTR_PROTOCOL_PCIE_DESCRAMBLING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3081
#define RSSCOPE_ATTR_PROTOCOL_PCIE_FILTER_IDLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3994
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SHOW_MULTIPLE_LANES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4449
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SOURCE_LANE_ZERO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3995
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SOURCE_LANE_ONE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3996
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SOURCE_LANE_TWO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3997
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SOURCE_LANE_THREE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3998
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_LOW_LANE_ZERO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3999
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_LOW_LANE_ONE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4000
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_LOW_LANE_TWO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4001
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_LOW_LANE_THREE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4002
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_HIGH_LANE_ZERO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4003
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_HIGH_LANE_ONE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4004
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_HIGH_LANE_TWO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4005
#define RSSCOPE_ATTR_PROTOCOL_PCIE_THRESHOLD_HIGH_LANE_THREE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4006
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_NOMINAL_BITRATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3082
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_PLL_ORDER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3083
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_PLL_BANDWIDTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3084
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_PLL_RELATIVE_BANDWIDTH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3085
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_PLL_DAMPING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3086
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_INITIAL_PHASE_SYNC                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3087
#define RSSCOPE_ATTR_PROTOCOL_PCIE_CDR_SELECTED_RESULTS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3088
#define RSSCOPE_ATTR_PROTOCOL_PCIE_DSP_DFE_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4450
#define RSSCOPE_ATTR_PROTOCOL_PCIE_DSP_DFE_ESTIMATE_COEFFICIENTS_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4451
#define RSSCOPE_ATTR_PROTOCOL_PCIE_DSP_DFE_COEFFICIENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4452
#define RSSCOPE_ATTR_PROTOCOL_PCIE_DSP_DFE_NUMBER_OF_TAPS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4453
#define RSSCOPE_ATTR_PROTOCOL_PCIE_PACKET_COUNT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3187
#define RSSCOPE_ATTR_PROTOCOL_PCIE_SELECTED_PACKET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4454
#define RSSCOPE_ATTR_PROTOCOL_PCIE_PACKET_BIT_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4455
#define RSSCOPE_ATTR_PROTOCOL_DDR_STANDARD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4007
#define RSSCOPE_ATTR_PROTOCOL_DDR_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3670
#define RSSCOPE_ATTR_PROTOCOL_DDR_DATA_THRESHOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3671
#define RSSCOPE_ATTR_PROTOCOL_DDR_DATA_HYSTERESIS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3672
#define RSSCOPE_ATTR_PROTOCOL_DDR_STROBE_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3673
#define RSSCOPE_ATTR_PROTOCOL_DDR_STROBE_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3674
#define RSSCOPE_ATTR_PROTOCOL_DDR_STROBE_HYSTERESIS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3675
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3676
#define RSSCOPE_ATTR_PROTOCOL_DDR_SELECTED_FRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3677
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3678
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_START_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3679
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_STOP_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3680
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3681
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_NUMBER_OF_WORDS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3682
#define RSSCOPE_ATTR_PROTOCOL_DDR_SELECTED_FIELD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3683
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_FIELD_STATUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3684
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_FIELD_START_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3685
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_FIELD_STOP_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3686
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_FIELD_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3687
#define RSSCOPE_ATTR_PROTOCOL_DDR_FRAME_FIELD_FORMATTED_VALUE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3688
#define RSSCOPE_ATTR_EYE_DIAGRAM_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3689
#define RSSCOPE_ATTR_EYE_DIAGRAM_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3690
#define RSSCOPE_ATTR_EYE_DIAGRAM_BIT_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4008
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3691
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_SIGNAL_SOURCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4515
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_SLOPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3692
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CDR_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4516
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_ALGORITHM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4517
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4518
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_RELATIVE_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4519
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_BIT_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4520
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_SAMPLING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4521
#define RSSCOPE_ATTR_EYE_DIAGRAM_CDR_ANALOG_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4522
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_SOFTWARE_CDR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4523
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_EDGE_TYPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4524
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_FACTOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4525
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4526
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_FREQUENCY_ESTIMATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4527
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4528
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_OFFSET_ESTIMATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4529
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4530
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_SAMPLING_TIME                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4531
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_CLOCK_SOURCE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4532
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIMING_REFERENCE_PROTOCOL_SERIAL_BUS_INDEX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4533
#define RSSCOPE_ATTR_EYE_DIAGRAM_TIME_REFERENCE_VERTICAL_REFERENCE_LEVEL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3693
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_TIME_UNITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3694
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_TIME_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3695
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_TIME_POSITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3696
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_BIT_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3697
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_RANGE_UI                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3698
#define RSSCOPE_ATTR_EYE_DIAGRAM_HORIZONTAL_SETTINGS_POSITION_UI                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3699
#define RSSCOPE_ATTR_EYE_DIAGRAM_VERTICAL_SETTINGS_SCALE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4534
#define RSSCOPE_ATTR_EYE_DIAGRAM_VERTICAL_SETTINGS_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4535
#define RSSCOPE_ATTR_EYE_DIAGRAM_VERTICAL_SETTINGS_POSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4536
#define RSSCOPE_ATTR_EYE_DIAGRAM_MAX_SLICES_PER_ACQUISITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3700
#define RSSCOPE_ATTR_EYE_DIAGRAM_EYE_STRIPE_DISPLAY_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3701
#define RSSCOPE_ATTR_EYE_DIAGRAM_INFINITE_PERSISTENCE_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4537
#define RSSCOPE_ATTR_EYE_DIAGRAM_PERSISTENCE_RESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4538
#define RSSCOPE_ATTR_EYE_DIAGRAM_DISPLAY_PERSISTENCE_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4539
#define RSSCOPE_ATTR_EYE_DIAGRAM_DISPLAY_PERSISTENCE_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4540
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3702
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_COUPLING_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3703
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3704
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_ABSOLUTE_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3705
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_ABSOLUTE_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3706
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_RELATIVE_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3707
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_RELATIVE_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3708
#define RSSCOPE_ATTR_EYE_DIAGRAM_GATE_CURSOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3709
#define RSSCOPE_ATTR_EYE_DIAGRAM_SIGNAL_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3711
#define RSSCOPE_ATTR_EYE_DIAGRAM_SIGNAL_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3712
#define RSSCOPE_ATTR_EYE_DIAGRAM_SIGNAL_CONDITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3713
#define RSSCOPE_ATTR_EYE_DIAGRAM_SIGNAL_VERTICAL_REFERENCE_LEVEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3714
#define RSSCOPE_ATTR_EYE_DIAGRAM_SIGNAL_VERTICAL_REFERENCE_LEVEL_STOP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4610
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3715
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_BIT_SEQUENCE_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3716
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_PATTERN_CENTER_BIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3718
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_PATTERN_SHIFT_BIT_LEFT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3720
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_PATTERN_SHIFT_BIT_RIGHT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3721
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_FRAME_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4009
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_LENGTH_ERRORS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4010
#define RSSCOPE_ATTR_EYE_DIAGRAM_FILTER_RESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3722
#define RSSCOPE_ATTR_EYE_DIAGRAM_RESULTS_BITS_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4541
#define RSSCOPE_ATTR_EYE_DIAGRAM_RESULTS_LAST_POSITION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4542
#define RSSCOPE_ATTR_EYE_DIAGRAM_RESULTS_BIT_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4543
#define RSSCOPE_ATTR_EYE_DIAGRAM_RESULTS_TOTAL_NUMBER_OF_ACQUISITIONS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4544
#define RSSCOPE_ATTR_EYE_DIAGRAM_RESULTS_TOTAL_NUMBER_OF_SLICES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4545
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_SLICES_COMPLETED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3723
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_SLICE_HITS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3724
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_VIOLATION_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3725
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_VIOLATION_COUNT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3726
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_VIOLATION_START_TIME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3727
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_VIOLATION_STOP_TIME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3728
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_VIOLATION_SLICE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3729
#define RSSCOPE_ATTR_EYE_DIAGRAM_MASK_TESTS_ZOOM_COUPLING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4546
#define RSSCOPE_ATTR_EYE_DIAGRAM_MEASUREMENT_MAX_PRECISION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4548
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_ATTENUATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3730
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FORWARD_POSITIVE_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3731
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FORWARD_NEGATIVE_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3732
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FORWARD_DIFFERENTIAL_SOURCE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3733
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FORWARD_SIGNAL_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3734
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_REVERSE_POSITIVE_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3735
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_REVERSE_NEGATIVE_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3736
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_REVERSE_DIFFERENTIAL_SOURCE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3737
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_REVERSE_SIGNAL_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3738
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_POLARITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3739
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_THRESHOLD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3740
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3741
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_SYMBOL_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3742
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3743
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_SELECTED_FRAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3744
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_STATUS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3745
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_START_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3746
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_STOP_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3747
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3748
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_CRC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3749
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_DESTINATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3751
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3752
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_DESTINATION_LABEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3753
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_SOURCE_LABEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3754
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_BIT_RATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4011
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3755
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_NUMBER_OF_WORDS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3756
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_SELECTED_WORD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3757
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_WORD_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3758
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_WORD_VALUE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3759
#define RSSCOPE_ATTR_PROTOCOL_100BASE_T1_FRAME_WORD_STRING_VALUE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3760
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_REVERSE_SIGNAL_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4313
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_REVERSE_DIFFERENTIAL_SOURCE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4314
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_REVERSE_POSITIVE_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4315
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_REVERSE_NEGATIVE_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4316
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FORWARD_SIGNAL_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4317
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FORWARD_DIFFERENTIAL_SOURCE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4318
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FORWARD_POSITIVE_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4319
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FORWARD_NEGATIVE_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4320
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_ATTENUATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4321
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_POLARITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4322
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4323
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_SYMBOL_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4324
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_COUNT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4325
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_SELECTED_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4326
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_STATUS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4327
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_START_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4328
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_STOP_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4329
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4330
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_CRC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4331
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_DATA_BYTES_RAWSTRING                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4332
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_DESTINATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4334
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_DESTINATION_SYMBOLS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4335
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4336
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_SOURCE_SYMBOLS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4337
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_BIT_RATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4338
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4339
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_NUMBER_OF_WORDS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4340
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_SELECTED_WORD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4341
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_WORD_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4342
#define RSSCOPE_ATTR_PROTOCOL_1000BASE_T1_FRAME_WORD_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4343
#define RSSCOPE_ATTR_POWER_ANALYSIS_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1306
#define RSSCOPE_ATTR_POWER_ANALYSIS_VOLTAGE_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1307
#define RSSCOPE_ATTR_POWER_ANALYSIS_CURRENT_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1308
#define RSSCOPE_ATTR_POWER_ANALYSIS_START_DESKEW                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1309
#define RSSCOPE_ATTR_POWER_ANALYSIS_DESKEW_RESET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1310
#define RSSCOPE_ATTR_POWER_ANALYSIS_DESKEW_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1630
#define RSSCOPE_ATTR_POWER_ANALYSIS_DESKEW_CURRENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1631
#define RSSCOPE_ATTR_POWER_ANALYSIS_DESKEW_USER_DEFINED_RESET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1311
#define RSSCOPE_ATTR_POWER_ANALYSE_PROBE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1312
#define RSSCOPE_ATTR_POWER_ANALYSIS_DUT_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1313
#define RSSCOPE_ATTR_POWER_ANALYSIS_USER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1314
#define RSSCOPE_ATTR_POWER_ANALYSIS_SITE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1315
#define RSSCOPE_ATTR_POWER_ANALYSIS_TEMPERATURE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1316
#define RSSCOPE_ATTR_POWER_ANALYSIS_DESCRIPTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1317
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_ADD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1318
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_SEL_ALL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1319
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_SEL_NONE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1320
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_SEL_REMOVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1321
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_SEL_INVERT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1322
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FILE_NEW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1329
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FILE_NAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1330
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FILE_SAVE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1331
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FILE_DELETE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1332
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_PAPER_SIZE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1333
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FONT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1334
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FONT_SIZE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1335
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_FONT_COLOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1336
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_LOGO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1337
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_INV_COLOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1338
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_TITLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1339
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_MSETUP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1340
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_SETTINGS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1341
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_VSETUP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1342
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_HSETUP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1343
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_TSETUP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1344
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_MEAS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1345
#define RSSCOPE_ATTR_POWER_ANALYSIS_REPORT_CONTENT_RESULTS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1346
#define RSSCOPE_ATTR_START_POWER_QUALITY_MEASUREMENT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1347
#define RSSCOPE_ATTR_POWER_QUALITY_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1348
#define RSSCOPE_ATTR_POWER_QUALITY_CUSTOM_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2622
#define RSSCOPE_ATTR_POWER_QUALITY_SCALING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1349
#define RSSCOPE_ATTR_POWER_QUALITY_ADD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1350
#define RSSCOPE_ATTR_START_POWER_CURRENT_HARMONICS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1354
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_STANDARD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1355
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_EN_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1356
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_MI_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1357
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_DO_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1358
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_EVALUATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1359
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_EVALUATION_VOLT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1360
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_SCALING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1361
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_ADD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1362
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_USED_STANDARD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1363
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_RESULT_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1364
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_RESULT_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1365
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_RESULT_STD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1366
#define RSSCOPE_ATTR_POWER_CURRENT_HARMONICS_RESULT_VALUE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1367
#define RSSCOPE_ATTR_START_POWER_INRUSH_CURRENT_MEASUREMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1368
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_MAX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1369
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_TRIGGER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1370
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_ADD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1371
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_ADD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1372
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_INS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1373
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_REMOVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1374
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_COUNT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1375
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_VALUE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1376
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1377
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_GATE_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1378
#define RSSCOPE_ATTR_POWER_INRUSH_CURRENT_RESULT_VALUE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1379
#define RSSCOPE_ATTR_START_POWER_RIPPLE_MEASUREMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1380
#define RSSCOPE_ATTR_POWER_RIPPLE_CURRENT_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2160
#define RSSCOPE_ATTR_POWER_RIPPLE_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1381
#define RSSCOPE_ATTR_POWER_RIPPLE_SCALING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1382
#define RSSCOPE_ATTR_POWER_RIPPLE_ADD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1383
#define RSSCOPE_ATTR_START_POWER_SPECTRUM_MEASUREMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1385
#define RSSCOPE_ATTR_POWER_SPECTRUM_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1386
#define RSSCOPE_ATTR_POWER_SPECTRUM_SCALING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1387
#define RSSCOPE_ATTR_POWER_SPECTRUM_ADD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1388
#define RSSCOPE_ATTR_POWER_SPECTRUM_MEASUREMENT_RESULT_COUNT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1633
#define RSSCOPE_ATTR_POWER_SPECTRUM_MEASUREMENT_FREQUENCY_RESULT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1389
#define RSSCOPE_ATTR_POWER_SPECTRUM_MEASUREMENT_LEVEL_RESULT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1390
#define RSSCOPE_ATTR_START_POWER_SLEW_RATE_MEASUREMENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1391
#define RSSCOPE_ATTR_POWER_SLEW_RATE_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1392
#define RSSCOPE_ATTR_POWER_SLEW_RATE_AVERAGE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1393
#define RSSCOPE_ATTR_POWER_SLEW_RATE_SCALING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1394
#define RSSCOPE_ATTR_POWER_SLEW_RATE_ADD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1395
#define RSSCOPE_ATTR_POWER_SLEW_RATE_GATE_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1396
#define RSSCOPE_ATTR_POWER_SLEW_RATE_GATE_STOP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1397
#define RSSCOPE_ATTR_START_POWER_SAFE_OPERATING_AREA_MEASUREMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1399
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_MASK_TEST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1400
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_SCALE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1401
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_SWITCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2157
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LIN_ADD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1402
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LIN_INS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1403
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LIN_REMOVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1404
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LIN_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1405
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LOG_ADD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1406
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LOG_INS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1407
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LOG_REMOVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1408
#define RSSCOPE_ATTR_SAFE_OPERATING_AREA_LOG_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1409
#define RSSCOPE_ATTR_POWER_SAFE_OPERATING_AREA_ADD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1412
#define RSSCOPE_ATTR_START_POWER_MODULATION_MEASUREMENT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1413
#define RSSCOPE_ATTR_POWER_MODULATION_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1414
#define RSSCOPE_ATTR_POWER_MODULATION_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1415
#define RSSCOPE_ATTR_POWER_MODULATION_SCALING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1416
#define RSSCOPE_ATTR_POWER_MODULATION_HISTOGRAM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1417
#define RSSCOPE_ATTR_POWER_MODULATION_ADD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1418
#define RSSCOPE_ATTR_START_POWER_DYNAMIC_ON_RESISTANCE_MEASUREMENT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1420
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_AVERAGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1421
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_SCALING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1422
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_ADD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1423
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_GATE_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1424
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_GATE_STOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1425
#define RSSCOPE_ATTR_POWER_DYNAMIC_ON_RESISTANCE_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1426
#define RSSCOPE_ATTR_START_POWER_EFFICIENCY_MEASUREMENT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1427
#define RSSCOPE_ATTR_POWER_EFFICIENCY_SCALING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1428
#define RSSCOPE_ATTR_POWER_EFFICIENCY_ADD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1429
#define RSSCOPE_ATTR_START_POWER_SWITCHINGLOSS_MEASUREMENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1431
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_TON_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1432
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_TOF_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1433
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_CONDUCTION_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1434
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_NON_CONDUCTION_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1435
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_TOTAL_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1436
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_SWITCHING_FREQUENCY_STATE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1437
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_SWITCHING_FREQUENCY_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1438
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_SCALING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1439
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_ADD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1440
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_CONDUCTION_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1441
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_CONDUCTION_STOP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1442
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_NO_CONDUCTION_START                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1443
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_NO_CONDUCTION_STOP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1634
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_TURN_ON_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1444
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_TURN_ON_STOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1445
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_TURN_OFF_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1446
#define RSSCOPE_ATTR_POWER_SWITCHINGLOSS_GATE_TURN_OFF_STOP                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1447
#define RSSCOPE_ATTR_START_POWER_ON_OFF_MEASUREMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1450
#define RSSCOPE_ATTR_POWER_ON_OFF_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1451
#define RSSCOPE_ATTR_POWER_ON_OFF_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1453
#define RSSCOPE_ATTR_POWER_ON_STEADY_STATE_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1454
#define RSSCOPE_ATTR_POWER_OFF_STEADY_STATE_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1455
#define RSSCOPE_ATTR_POWER_ON_TRIGGER_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1456
#define RSSCOPE_ATTR_POWER_ON_TRIGGER_LEVEL_DC                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 1635
#define RSSCOPE_ATTR_POWER_OFF_TRIGGER_LEVEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1457
#define RSSCOPE_ATTR_POWER_OFF_TRIGGER_LEVEL_DC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1636
#define RSSCOPE_ATTR_POWER_ON_OFF_ADD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1458
#define RSSCOPE_ATTR_POWER_ON_OFF_INPUT_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1637
#define RSSCOPE_ATTR_POWER_ON_RESULT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1459
#define RSSCOPE_ATTR_POWER_OFF_RESULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1460
#define RSSCOPE_ATTR_START_POWER_TRANSIENT_RESPONSE_MEASUREMENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1461
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_INPUT_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1462
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_TRIGGER_SOURCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1463
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_TRIGGER_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1464
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_TRIGGER_SLOPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1465
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_TUBE_TOLERANCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1466
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_SIGNAL_HIGH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1467
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_SIGNAL_LOW                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1468
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 1469
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_SCALING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1470
#define RSSCOPE_ATTR_POWER_TRANSIENT_RESPONSE_ADD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1471
#define RSSCOPE_ATTR_DEEMBEDDING_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3761
#define RSSCOPE_ATTR_DEEMBEDDING_EFFECTIVE_BANDWIDTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3762
#define RSSCOPE_ATTR_DEEMBEDDING_DELAY_COMPENSATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3763
#define RSSCOPE_ATTR_DEEMBEDDING_REALTIME_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4344
#define RSSCOPE_ATTR_DEEMBEDDING_REMOVE_COMPONENT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3765
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3767
#define RSSCOPE_ATTR_DEEMBEDDING_SETTINGS_FILE_NAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3768
#define RSSCOPE_ATTR_DEEMBEDDING_SAVE_SETTINGS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3769
#define RSSCOPE_ATTR_DEEMBEDDING_LOAD_SETTINGS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3770
#define RSSCOPE_ATTR_DEEMBEDDING_DELETE_SETTINGS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3771
#define RSSCOPE_ATTR_DEEMBEDDING_PRESET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3772
#define RSSCOPE_ATTR_DEEMBEDDING_SELECTED_COMPONENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3773
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3774
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3775
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_NAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3776
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_PORT_COUNT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3777
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3778
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_REMOVE_PROBE_LOADING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3779
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_IMPEDANCE_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3780
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_IMPEDANCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3781
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_IDENTICAL_PATHS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3783
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_INPUT_PORT_1                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3784
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_INPUT_PORT_2                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3785
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_OUTPUT_PORT_1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3786
#define RSSCOPE_ATTR_DEEMBEDDING_COMPONENT_OUTPUT_PORT_2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3787
#define RSSCOPE_ATTR_DEEMBEDDING_ATTENUATION_DC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3790
#define RSSCOPE_ATTR_DEEMBEDDING_ATTENUATION_MAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3791
#define RSSCOPE_ATTR_DEEMBEDDING_GAIN_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3792
#define RSSCOPE_ATTR_MSO_TRIGGER_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 631
#define RSSCOPE_ATTR_MSO_TRIGGER_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSSCOPE_ATTR_MSO_EDGE_TRIGGER_EXPRESSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1210
#define RSSCOPE_ATTR_MSO_EDGE_TRIGGER_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSSCOPE_ATTR_MSO_WIDTH_TRIGGER_EXPRESSION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1211
#define RSSCOPE_ATTR_MSO_WIDTH_TRIGGER_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSSCOPE_ATTR_MSO_WIDTH_TRIGGER_CONDITION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSSCOPE_ATTR_MSO_WIDTH_TRIGGER_WIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSSCOPE_ATTR_MSO_WIDTH_TRIGGER_DELTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSSCOPE_ATTR_MSO_TIMEOUT_TRIGGER_EXPRESSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1212
#define RSSCOPE_ATTR_MSO_TIMEOUT_TRIGGER_VALUE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSSCOPE_ATTR_MSO_TIMEOUT_TRIGGER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSSCOPE_ATTR_MSO_DATA2CLOCK_TRIGGER_CLOCK_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1213
#define RSSCOPE_ATTR_MSO_DATA2CLOCK_TRIGGER_CLOCK_EDGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 1214
#define RSSCOPE_ATTR_MSO_DATA2CLOCK_TRIGGER_HOLD_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSSCOPE_ATTR_MSO_DATA2CLOCK_TRIGGER_SETUP_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSSCOPE_ATTR_MSO_STATE_TRIGGER_EXPRESSION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1215
#define RSSCOPE_ATTR_MSO_STATE_TRIGGER_CLOCK_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1216
#define RSSCOPE_ATTR_MSO_STATE_TRIGGER_CLOCK_EDGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1217
#define RSSCOPE_ATTR_MSO_STATE_TRIGGER_CHANNEL_STATUS_BIT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1218
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_EXPRESSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1219
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_TIMEOUT_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_TIMEOUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_WIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_DELTA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_CONDITION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSSCOPE_ATTR_MSO_PATTERN_TRIGGER_CHANNEL_STATUS_BIT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1220
#define RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_EXPRESSION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1221
#define RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_CLOCK_SOURCE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1222
#define RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_CLOCK_EDGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1223
#define RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_PATTERN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSSCOPE_ATTR_MSO_SIGNAL_LABEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define RSSCOPE_ATTR_MSO_DIGITAL_CHANNEL_DISPLAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4345
#define RSSCOPE_ATTR_MSO_SIGNAL_DESKEW                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 626
#define RSSCOPE_ATTR_MSO_TECHNOLOGY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define RSSCOPE_ATTR_MSO_TRESHOLD                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 627
#define RSSCOPE_ATTR_MSO_HYSTERESIS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 628
#define RSSCOPE_ATTR_MSO_DIGITAL_CHANNEL_COUPLING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4012
#define RSSCOPE_ATTR_MSO_BUS_STATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSSCOPE_ATTR_MSO_DISPLAY_SHOW_DIGITAL_SIGNALS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 1224
#define RSSCOPE_ATTR_MSO_DISPLAY_SHOW_BUS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1225
#define RSSCOPE_ATTR_MSO_DISPLAY_REPRESENTATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 622
#define RSSCOPE_ATTR_MSO_CLOCKED_BUS_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define RSSCOPE_ATTR_MSO_CLOCKED_BUS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define RSSCOPE_ATTR_MSO_CLOCKED_BUS_SLOPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define RSSCOPE_ATTR_MSO_SIGNAL_DESKEW_ALL_CHANNELS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSSCOPE_ATTR_MSO_CHANNEL_COUPLING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 629
#define RSSCOPE_ATTR_MSO_DIGITAL_RESOLUTION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2150
#define RSSCOPE_ATTR_MSO_DIGITAL_RECORD_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2151
#define RSSCOPE_ATTR_MSO_TECHNOLOGY_ALL_CHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define RSSCOPE_ATTR_MSO_REMOVE_ALL_ASSIGNED_CHANNELS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 630
#define RSSCOPE_ATTR_MSO_DATA_FORMAT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4208
#define RSSCOPE_ATTR_MSO_SIGNAL_ASSIGN_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSSCOPE_ATTR_MSO_INDIVIDUAL_SIGNAL_DESKEW                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3793
#define RSSCOPE_ATTR_MSO_INDIVIDUAL_SIGNAL_LABEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3794
#define RSSCOPE_ATTR_MSO_TRESHOLD_ALL_CHANNELS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define RSSCOPE_ATTR_MSO_HYSTERESIS_ALL_CHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define RSSCOPE_ATTR_MSO_DECODE_TABLE_SHOW                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4013
#define RSSCOPE_ATTR_MSO_DECODE_TABLE_EDGE_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4014
#define RSSCOPE_ATTR_MSO_DECODE_TABLE_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4015
#define RSSCOPE_ATTR_PULSE_SOURCE_STATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4016
#define RSSCOPE_ATTR_PULSE_SOURCE_LOW_OUTPUT_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4017
#define RSSCOPE_ATTR_PULSE_SOURCE_REPETITION_RATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4018
#define RSSCOPE_ATTR_PULSE_SOURCE_DUTY_CYCLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4019
#define RSSCOPE_ATTR_PULSE_SOURCE_CLOCK_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4020
#define RSSCOPE_ATTR_PULSE_SOURCE_RESET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4021
#define RSSCOPE_ATTR_TDR_TDT_START_DEFAULT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4022
#define RSSCOPE_ATTR_TDR_TDT_CALIBRATION_LOAD_FILENAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4023
#define RSSCOPE_ATTR_TDR_TDT_CALIBRATION_LOAD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4024
#define RSSCOPE_ATTR_TDR_TDT_CALIBRATION_SAVE_FILENAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4025
#define RSSCOPE_ATTR_TDR_TDT_CALIBRATION_SAVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4026
#define RSSCOPE_ATTR_TDR_TDT_ANALYSIS_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4027
#define RSSCOPE_ATTR_TDR_TDT_CONNECTION_CONFIGURATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4089
#define RSSCOPE_ATTR_TDR_TDT_PULSE_REFERENCE_CHANNEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4028
#define RSSCOPE_ATTR_TDR_TDT_PULSE_OUT_CHANNEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4029
#define RSSCOPE_ATTR_TDR_TDT_PULSE_DIFF_OUT_CHANNEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4090
#define RSSCOPE_ATTR_TDR_TDT_PULSE_DIFF_REFERENCE_CHANNEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4091
#define RSSCOPE_ATTR_TDR_TDT_SHORT_LENGTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4030
#define RSSCOPE_ATTR_TDR_TDT_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4549
#define RSSCOPE_ATTR_TDR_TDT_USE_CALIBRATION_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4031
#define RSSCOPE_ATTR_TDR_TDT_BANDWIDTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4032
#define RSSCOPE_ATTR_TDR_TDT_DOMAIN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4033
#define RSSCOPE_ATTR_TDR_TDT_DUT_PERMITTIVITY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4034
#define RSSCOPE_ATTR_TDR_TDT_SIGNAL_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4035
#define RSSCOPE_ATTR_TDR_TDT_SIGNAL_VERTICAL_SCALE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4038
#define RSSCOPE_ATTR_TDR_TDT_SIGNAL_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4036
#define RSSCOPE_ATTR_TDR_TDT_SIGNAL_VERTICAL_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4037
#define RSSCOPE_ATTR_TDR_TDT_SIGNAL_WAVEFORM_HEADER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4092
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ENABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2815
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PRESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2816
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OPERATION_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2817
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COPY_SETTINGS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2818
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FUNCTION_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2819
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2820
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PERIOD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2821
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_DUTY_CYCLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2822
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_SYMMETRY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2823
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PULSE_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2824
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_MODULATION_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2825
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_CARRIER_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2826
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_CARRIER_PERIOD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2827
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_AM_MODULATION_SIGNAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2828
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_AM_MODULATION_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2829
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_AM_MODULATION_DEPTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2830
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_AM_MODULATION_DUTY_CYCLE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2831
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_AM_MODULATION_SYMMETRY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2832
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FM_MODULATION_SIGNAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2833
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FM_MODULATION_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2834
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FM_MODULATION_FREQUENCY_DEVIATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2835
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FM_MODULATION_DUTY_CYCLE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2836
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FM_MODULATION_SYMMETRY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2837
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PWM_MODULATION_SIGNAL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2838
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PWM_MODULATION_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2839
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PWM_MODULATION_DEPTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2840
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PWM_MODULATION_DUTY_CYCLE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2841
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_PWM_MODULATION_SYMMETRY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2842
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FSK_MODULATION_FREQUENCY_1                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2843
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FSK_MODULATION_FREQUENCY_2                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2844
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_FSK_MODULATION_HOP_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2845
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_SWEEP_START_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2846
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_SWEEP_STOP_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2847
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_SWEEP_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2848
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2849
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_RUN_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2850
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_RUN_SINGLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4456
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_SAMPLE_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2851
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_SAMPLES                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2852
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_FILE_NAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2853
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_OPEN_FILE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2854
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_MULTICHANNEL_FILE_NAME                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2855
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_MULTICHANNEL_OPEN_FILE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2856
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_MULTICHANNEL_WAVEFORM                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2857
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_SCOPE_SOURCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2858
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ARBITRARY_SCOPE_OPEN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2859
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_AMPLITUDE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2860
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2861
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_HIGH_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2862
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_LOW_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2863
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_INVERSION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2864
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_USER_LOAD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2865
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_OUTPUT_DC_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2866
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_ADD_NOISE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2867
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_NOISE_LEVEL_PERCENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2868
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_NOISE_ABSOLUTE_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2869
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_NOISE_DC_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2870
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4457
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_ALL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2871
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_OUTPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4346
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_NOISE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4458
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_ARBITRARY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4459
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_AMPLITUDE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2872
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_PHASE_SHIFT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2873
#define RSSCOPE_ATTR_WAVEFORM_GENERATOR_COUPLING_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2874
#define RSSCOPE_ATTR_PATTERN_GENERATOR_ENABLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2875
#define RSSCOPE_ATTR_PATTERN_GENERATOR_PRESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2876
#define RSSCOPE_ATTR_PATTERN_GENERATOR_RUN_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2877
#define RSSCOPE_ATTR_PATTERN_GENERATOR_RUN_SINGLE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4460
#define RSSCOPE_ATTR_PATTERN_GENERATOR_BIT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2878
#define RSSCOPE_ATTR_PATTERN_GENERATOR_HIGH_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2879
#define RSSCOPE_ATTR_PATTERN_GENERATOR_FILE_NAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2880
#define RSSCOPE_ATTR_PATTERN_GENERATOR_LOAD_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2881
#define RSSCOPE_ATTR_GENERATOR_SYNCHRONIZATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2882
#define RSSCOPE_ATTR_GENERATOR_START_ALIGNMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2883
#define RSSCOPE_ATTR_GENERATOR_START_ALIGNMENT_WITH_OPC                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3246
#define RSSCOPE_ATTR_GENERATOR_ABORT_ALIGNMENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2884
#define RSSCOPE_ATTR_GENERATOR_ALIGNMENT_DATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2885
#define RSSCOPE_ATTR_GENERATOR_ALIGNMENT_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2886
#define RSSCOPE_ATTR_GENERATOR_ALIGNMENT_OVERALL_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2887
#define RSSCOPE_ATTR_NUMBER_OF_FRONTENDS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4550
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_PRESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4551
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_MEASUREMENT_SETUP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4552
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_CHANNEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4553
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FILE_PATH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4554
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_CABLE_ALIGNMENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4555
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_CONNECTION_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4556
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_CONNECTION_CURRENT_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4557
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4558
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_IDENTIFIER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4560
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_INPUT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4561
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4562
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_REFERENCE_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4563
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_IF_OUTPUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4564
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_BANDWIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4565
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_LO_IN_FREQUENCY_CABLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4566
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_GAIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4567
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_LO_INPUT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4568
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_LO_OUTPUT_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4569
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_ATTENUATION_AUTO_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4570
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_AMPLITUDE_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4571
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_ATTENUATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4572
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_ATTENUATION_STEP_VALUES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4573
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_CONNECTION_ERROR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4574
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_CONFIG_AUTO_MODE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4575
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_CONFIG_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 4576
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_CONFIG_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4578
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_CONFIG_SELECTION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4580
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_MAX_IF_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4581
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_MIN_IF_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4582
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_IF_FREQUENCY_SIDEBAND                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4583
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_LO_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4584
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_LO_OUTPUT_FREQUENCY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4585
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_MAX_RF_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4586
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_MIN_RF_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4587
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_REFERENCE_FREQUENCY_LIST                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4588
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_IF_ATTENUATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4589
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_RF_CONNECTOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4590
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_UPDATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4591
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_SELECTED_MULTI_BAND                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4592
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_NUMBER_OF_FREQUENCY_BANDS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4593
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_LIST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4594
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_START                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4595
#define RSSCOPE_ATTR_EXTERNAL_FRONTEND_FREQUENCY_BAND_END                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4596
#define RSSCOPE_ATTR_IQ_MODE_STATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define RSSCOPE_ATTR_IQ_INPUT_SAMPLE_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 4209
#define RSSCOPE_ATTR_IQ_RELATIVE_BANDWIDTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define RSSCOPE_ATTR_IQ_SAMPLE_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define RSSCOPE_ATTR_IQ_RECORD_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define RSSCOPE_ATTR_IQ_FILTER_BANDWIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define RSSCOPE_ATTR_IQ_INPUT_TYPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define RSSCOPE_ATTR_IQ_INPUT_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSSCOPE_ATTR_IQ_CARRIER_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 685
#define RSSCOPE_ATTR_IQ_REAL_SIDEBAND                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 686
#define RSSCOPE_ATTR_IQ_COMPLEX_SIDEBAND                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define RSSCOPE_ATTR_IQ_WARNING_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4210
#define RSSCOPE_ATTR_IQ_WARNING_MESSAGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 4211
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_X_SCALING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2650
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_WAVEFORM_DATA_SIGNAL_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2652
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_COLOR_TABLE_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2653
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_USE_COLOR_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2654
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_SPECTROGRAM_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2655
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_COUPLED_SPECTRUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2651
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_TIMELINE_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 2657
#define RSSCOPE_ATTR_SPECTRUM_ANALYSIS_TIMELINE_POSITION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 2656
#define RSSCOPE_ATTR_CDR_SOFTWARE_SERIAL_STANDARD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4042
#define RSSCOPE_ATTR_CDR_SOFTWARE_BIT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1226
#define RSSCOPE_ATTR_CDR_SOFTWARE_BIT_RATE_CORRECTION_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4044
#define RSSCOPE_ATTR_CDR_SOFTWARE_BIT_RATE_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4045
#define RSSCOPE_ATTR_CDR_SOFTWARE_ESTIMATE_BIT_RATE_ONCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4043
#define RSSCOPE_ATTR_CDR_SOFTWARE_DATA_EDGES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1227
#define RSSCOPE_ATTR_CDR_SOFTWARE_INITIAL_PHASE_SYNC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 1228
#define RSSCOPE_ATTR_CDR_SOFTWARE_SELECTED_RESULTS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 1229
#define RSSCOPE_ATTR_CDR_SOFTWARE_ALGORITHM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1230
#define RSSCOPE_ATTR_CDR_SOFTWARE_SAMPLING_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4461
#define RSSCOPE_ATTR_CDR_SOFTWARE_PLL_ORDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1231
#define RSSCOPE_ATTR_CDR_SOFTWARE_PLL_DAMPING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1232
#define RSSCOPE_ATTR_CDR_SOFTWARE_PLL_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1233
#define RSSCOPE_ATTR_CDR_SOFTWARE_PLL_REL_BANDWIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1234
#define RSSCOPE_ATTR_CDR_SOFTWARE_PLL_REVERSE_LOCK_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4347
#define RSSCOPE_ATTR_CDR_HARDWARE_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1235
#define RSSCOPE_ATTR_CDR_HARDWARE_SERIAL_STANDARD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 4046
#define RSSCOPE_ATTR_CDR_HARDWARE_ESTIMATE_BIT_RATE_ONCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 4047
#define RSSCOPE_ATTR_CDR_HARDWARE_BIT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1236
#define RSSCOPE_ATTR_CDR_HARDWARE_DATA_EDGES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1237
#define RSSCOPE_ATTR_CDR_HARDWARE_PLL_ORDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 1238
#define RSSCOPE_ATTR_CDR_HARDWARE_PLL_DAMPING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 1239
#define RSSCOPE_ATTR_CDR_HARDWARE_PLL_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1240
#define RSSCOPE_ATTR_CDR_HARDWARE_PLL_REL_BANDWIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1241
#define RSSCOPE_ATTR_USE_CDR                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 1742
#define RSSCOPE_ATTR_CDR_HARDWARE_TRIGGER_UI_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 1242
#define RSSCOPE_ATTR_DISPLAY_UPDATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 753
#define RSSCOPE_ATTR_DISPLAY_MESSAGE_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2444
#define RSSCOPE_ATTR_DISPLAY_MESSAGE_TEXT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2445
#define RSSCOPE_ATTR_DISPLAY_GATE_TRANSPARENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2797
#define RSSCOPE_ATTR_DISPLAY_CLEAR_RESULTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 4048
#define RSSCOPE_ATTR_DISPLAY_RESULTS_ON_EXTERNAL_MONITOR_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4348
#define RSSCOPE_ATTR_DISPLAY_DIALOGS_ON_EXTERNAL_MONITOR_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4349
#define RSSCOPE_ATTR_PERSISTENCE_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSSCOPE_ATTR_INFINITE_PERSISTENCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSSCOPE_ATTR_PERSISTENCE_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSSCOPE_ATTR_PERSISTENCE_RESET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 425
#define RSSCOPE_ATTR_SIGNAL_STYLE_INTENSITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 426
#define RSSCOPE_ATTR_SIGNAL_STYLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define RSSCOPE_ATTR_USE_COLOR_TABLE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 428
#define RSSCOPE_ATTR_ASSIGN_COLOR_TABLE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 429
#define RSSCOPE_ATTR_SIGNAL_COLOR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3298
#define RSSCOPE_ATTR_ADD_COLOR_TABLE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 430
#define RSSCOPE_ATTR_REMOVE_COLOR_TABLE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 431
#define RSSCOPE_ATTR_COLOR_TABLE_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 432
#define RSSCOPE_ATTR_COLOR_TABLE_APPEND_NEW_ROW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 433
#define RSSCOPE_ATTR_DIAGRAM_SHOW_GRID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 434
#define RSSCOPE_ATTR_DIAGRAM_SHOW_CROSSHAIR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 435
#define RSSCOPE_ATTR_DIAGRAM_SHOW_LABELS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 436
#define RSSCOPE_ATTR_DIAGRAM_SHOW_TAB_TITLES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 437
#define RSSCOPE_ATTR_DIAGRAM_KEEP_Y_GRID_FIXED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 438
#define RSSCOPE_ATTR_DIAGRAM_KEEP_X_GRID_FIXED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4212
#define RSSCOPE_ATTR_DIAGRAM_SHOW_FINE_GRID_SCALE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 1257
#define RSSCOPE_ATTR_SIGNAL_BAR_STATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSSCOPE_ATTR_SIGNAL_BAR_POSITION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSSCOPE_ATTR_SIGNAL_BAR_AUTO_HIDE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 441
#define RSSCOPE_ATTR_SIGNAL_BAR_HIDE_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 442
#define RSSCOPE_ATTR_SIGNAL_BAR_HIDE_HEAD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 443
#define RSSCOPE_ATTR_SIGNAL_BAR_HIDING_TRANSPARENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSSCOPE_ATTR_SIGNAL_BAR_BORDER_COLOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSSCOPE_ATTR_SIGNAL_BAR_FILL_COLOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSSCOPE_ATTR_RESULT_BOX_POSITION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 698
#define RSSCOPE_ATTR_REMOVE_DIAGRAM                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSSCOPE_ATTR_DISPLAY_DIAGRAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSSCOPE_ATTR_REMOVE_WAVEFORM_FROM_DIAGRAM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSSCOPE_ATTR_SELECTED_LABEL_NAME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1260
#define RSSCOPE_ATTR_SELECTED_LABEL_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1261
#define RSSCOPE_ATTR_LABEL_SHOW                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 4462
#define RSSCOPE_ATTR_WAVEFORM_LABEL_FONT_SIZE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4213
#define RSSCOPE_ATTR_DIAGRAM_ZOOM_OVERLAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 740
#define RSSCOPE_ATTR_XY_DIAGRAM_STATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSSCOPE_ATTR_XY_DIAGRAM_RATIO                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSSCOPE_ATTR_SWAP_XY_DIAGRAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSSCOPE_ATTR_XY_DIAGRAM_X_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1276
#define RSSCOPE_ATTR_XY_DIAGRAM_Y_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 1277
#define RSSCOPE_ATTR_HISTORY_GET_ACQUISITIONS_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSSCOPE_ATTR_HISTORY_STATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSSCOPE_ATTR_HISTORY_START_INDEX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSSCOPE_ATTR_HISTORY_STOP_INDEX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSSCOPE_ATTR_HISTORY_ACQUISITION_VIEW                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSSCOPE_ATTR_HISTORY_ACQUISITION_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 538
#define RSSCOPE_ATTR_HISTORY_AUTO_REPEAT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSSCOPE_ATTR_HISTORY_PLAYBACK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSSCOPE_ATTR_HISTORY_ABSOLUTE_TIME_STAMP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1278
#define RSSCOPE_ATTR_HISTORY_RELATIVE_TIME_STAMP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 1279
#define RSSCOPE_ATTR_HISTORY_TIME_REFERENCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 2612
#define RSSCOPE_ATTR_HISTORY_DATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSSCOPE_ATTR_SAVE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSSCOPE_ATTR_RECALL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSSCOPE_ATTR_DRIVES                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSSCOPE_ATTR_CHANGE_DRIVE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSSCOPE_ATTR_CURRENT_DIRECTORY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSSCOPE_ATTR_CREATE_DIRECTORY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSSCOPE_ATTR_REMOVE_DIRECTORY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSSCOPE_ATTR_DELETE_FILE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSSCOPE_ATTR_SAVESET_PREVIEW_IMAGE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2152
#define RSSCOPE_ATTR_SAVESET_ONE_FILE_NAME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3799
#define RSSCOPE_ATTR_SAVESET_ONE_FILE_OPEN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3800
#define RSSCOPE_ATTR_SAVESET_ONE_FILE_SAVE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3801
#define RSSCOPE_ATTR_SAVESET_ONE_FILE_USER_PREFERENCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4599
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_MULTICHANNEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 742
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SCOPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SCOPE_CURSOR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SCOPE_GATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 566
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SCOPE_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_SCOPE_STOP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_DATA_LOGGING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 569
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_TIMESTAMPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2613
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_FAST_EXPORT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 743
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define RSSCOPE_ATTR_WAVEFORM_EXPORT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_INTERLEAVED_XY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_RAW_VALUES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_DISPLAY_OFF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4350
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_CDR_INFO                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4600
#define RSSCOPE_ATTR_WAVEFORM_EXPORT_CHANNEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 741
#define RSSCOPE_ATTR_HISTOGRAM_EXPORT_NAME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 744
#define RSSCOPE_ATTR_HISTOGRAM_EXPORT_INCIDENCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 745
#define RSSCOPE_ATTR_HISTOGRAM_EXPORT_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 746
#define RSSCOPE_ATTR_HISTOGRAM_EXPORT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 747
#define RSSCOPE_ATTR_NUMERIC_RESULTS_DECIMAL_SYMBOL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4214
#define RSSCOPE_ATTR_NUMERIC_RESULTS_DELIMITER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4215
#define RSSCOPE_ATTR_NUMERIC_RESULTS_OMIT_UNITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3804
#define RSSCOPE_ATTR_NUMERIC_RESULTS_EXPORT_FILE_NAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 3805
#define RSSCOPE_ATTR_NUMERIC_RESULTS_SAVE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3806
#define RSSCOPE_ATTR_LONG_TERM_EXPORT_RESULT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 748
#define RSSCOPE_ATTR_LONG_TERM_EXPORT_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 749
#define RSSCOPE_ATTR_LONG_TERM_EXPORT_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 750
#define RSSCOPE_ATTR_LONG_TERM_EXPORT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 751
#define RSSCOPE_ATTR_REPORT_LANGUAGE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2614
#define RSSCOPE_ATTR_REPORT_PAPER_SIZE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2615
#define RSSCOPE_ATTR_REPORT_USER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2616
#define RSSCOPE_ATTR_REPORT_COMMENT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 2617
#define RSSCOPE_ATTR_REPORT_LOGO_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2618
#define RSSCOPE_ATTR_REPORT_LOGO_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2619
#define RSSCOPE_ATTR_REPORT_FILE_NAME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2620
#define RSSCOPE_ATTR_SAVE_REPORT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2621
#define RSSCOPE_ATTR_EXPORT_EYE_SELECT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4601
#define RSSCOPE_ATTR_EXPORT_EYE_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4602
#define RSSCOPE_ATTR_EXPORT_EYE_PATH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4603
#define RSSCOPE_ATTR_EXPORT_EYE_SAVE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4604
#define RSSCOPE_ATTR_AUTONAMING_PREFIX                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 2623
#define RSSCOPE_ATTR_AUTONAMING_TEXT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2624
#define RSSCOPE_ATTR_AUTONAMING_USER_TEXT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 2625
#define RSSCOPE_ATTR_AUTONAMING_DATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2626
#define RSSCOPE_ATTR_AUTONAMING_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2627
#define RSSCOPE_ATTR_AUTONAMING_TIME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 2628
#define RSSCOPE_ATTR_AUTONAMING_DEFAULT_PATH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2629
#define RSSCOPE_ATTR_AUTONAMING_RESET_PATH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2630
#define RSSCOPE_ATTR_AUTONAMING_RESET_ALL_SETTINGS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2631
#define RSSCOPE_ATTR_HARDCOPY_FILE_NAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSSCOPE_ATTR_HARDCOPY_PRINT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSSCOPE_ATTR_HARDCOPY_PRINT_NEXT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3807
#define RSSCOPE_ATTR_HARDCOPY_GET_FIRST_PRINTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSSCOPE_ATTR_HARDCOPY_GET_NEXT_PRINTER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSSCOPE_ATTR_HARDCOPY_COLOR                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSSCOPE_ATTR_HARDCOPY_DEVICE_DESTINATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSSCOPE_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSSCOPE_ATTR_HARDCOPY_DEVICE_ORIENTATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSSCOPE_ATTR_HARDCOPY_WHITE_BACKGROUND                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 2153
#define RSSCOPE_ATTR_HARDCOPY_SELECT_PRINTER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSSCOPE_ATTR_HARDCOPY_PRINT_COLOR_SET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 2158
#define RSSCOPE_ATTR_HARDCOPY_INVERSE_COLORS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2159
#define RSSCOPE_ATTR_HARDCOPY_INCLUDE_SIGNAL_BAR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3808
#define RSSCOPE_ATTR_HARDCOPY_SHOW_SETUP_DIALOG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3809
#define RSSCOPE_ATTR_EXTERNAL_APPLICATION_NAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3810
#define RSSCOPE_ATTR_EXTERNAL_APPLICATION_PARAMETER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3811
#define RSSCOPE_ATTR_EXTERNAL_APPLICATION_WORKING_DIRECTORY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3812
#define RSSCOPE_ATTR_QUICK_ACTION_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3813
#define RSSCOPE_ATTR_QUICK_ACTION_APPLICATION_PATH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3814
#define RSSCOPE_ATTR_QUICK_ACTION_PARAMETER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3815
#define RSSCOPE_ATTR_QUICK_ACTION_WORKING_DIRECTORY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3816
#define RSSCOPE_ATTR_QUICK_ACTION_EXECUTE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3817
#define RSSCOPE_ATTR_CHANNEL_COUNT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2161
#define RSSCOPE_ATTR_FIRMWARE_SHUTDOWN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 462
#define RSSCOPE_ATTR_FIRMWARE_VERSION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 463
#define RSSCOPE_ATTR_COMPUTER_NAME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 464
#define RSSCOPE_ATTR_MATERIAL_NUMBER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSSCOPE_ATTR_SERIAL_NUMBER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSSCOPE_ATTR_START_SELFTEST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSSCOPE_ATTR_SELFTEST_STATUS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 468
#define RSSCOPE_ATTR_SET_QUERY_PATTERN_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSSCOPE_ATTR_SERVICE_MODE_PASSWORD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3818
#define RSSCOPE_ATTR_SCOPE_MODEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 2798
#define RSSCOPE_ATTR_SCOPE_SERIES                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2799
#define RSSCOPE_ATTR_SCOPE_FAMILY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2800
#define RSSCOPE_ATTR_USER_DEFINED_PRESET_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 4606
#define RSSCOPE_ATTR_USER_DEFINED_PRESET_PATH_AND_FILE_NAME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 4607
#define RSSCOPE_ATTR_USER_DEFINED_PRESET_OPEN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4608
#define RSSCOPE_ATTR_USER_DEFINED_PRESET_SAVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 4609
#define RSSCOPE_ATTR_ID_QUERY_RESPONSE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSSCOPE_ATTR_LOGGING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 2648
#define RSSCOPE_ATTR_CALIBRATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSSCOPE_ATTR_SELF_TEST_QUERY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSSCOPE_ATTR_BYTE_ORDER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 2154
#define RSSCOPE_ATTR_SYSTEM_ERROR_ALL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4050
#define RSSCOPE_ATTR_SYSTEM_ERROR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSSCOPE_ATTR_SYSTEM_ERROR_CODE_ALL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 3838
#define RSSCOPE_ATTR_SYSTEM_ERROR_CODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3839
#define RSSCOPE_ATTR_SYSTEM_ERROR_COUNT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 3840
#define RSSCOPE_ATTR_OPERATION_REGISTER_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3841
#define RSSCOPE_ATTR_OPERATION_REGISTER_EVENT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3842
#define RSSCOPE_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 2167
#define RSSCOPE_ATTR_GPIB_ADDRESS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3819
#define RSSCOPE_ATTR_GPIB_TERMINATOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3820
#define RSSCOPE_ATTR_SYSTEM_SHUTDOWN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3821
#define RSSCOPE_ATTR_SYSTEM_VERSION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3822
#define RSSCOPE_ATTR_SYSTEM_PRESET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 3823
#define RSSCOPE_ATTR_SYSTEM_DEVICE_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 4051
#define RSSCOPE_ATTR_LOCK_LOCAL_KEYS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3824
#define RSSCOPE_ATTR_SYSTEM_INFO_DEVICE_FOOTPRINT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 3825
#define RSSCOPE_ATTR_SYSTEM_REMOTE_CONTROL_COMMAND_SET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 3826
#define RSSCOPE_ATTR_QUERY_SYSTEM_DATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4053
#define RSSCOPE_ATTR_QUERY_SYSTEM_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 4054
#define RSSCOPE_ATTR_REMOTE_TRACE_FILE_NAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3827
#define RSSCOPE_ATTR_REMOTE_TRACE_FILE_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 3828
#define RSSCOPE_ATTR_REMOTE_TRACE_FILE_SIZE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3829
#define RSSCOPE_ATTR_REMOTE_TRACE_START_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 3830
#define RSSCOPE_ATTR_REMOTE_TRACE_STOP_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 3831
#define RSSCOPE_ATTR_REMOTE_TRACE_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 3832
#define RSSCOPE_ATTR_REMOTE_TRACE_COMMAND_EXECUTION_DURATION_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3834
#define RSSCOPE_ATTR_REMOTE_TRACE_RPC_OUTPUT_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 3835
#define RSSCOPE_ATTR_REMOTE_TRACE_PARSER_TRANSITIONS_OUTPUT_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 3836
#define RSSCOPE_ATTR_REMOTE_TRACE_FUNCTION_NAMES_OUTPUT_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3837

// rsscope_rngSampleMode
#define RSSCOPE_VAL_REAL_TIME                                               0
#define RSSCOPE_VAL_EQUIVALENT_TIME                                         1
#define RSSCOPE_VAL_INTERPOLATED_TIME                                       2

// rsscope_rngWaveformArithmetics
#define RSSCOPE_VAL_OFF                                                     0
#define RSSCOPE_VAL_ENVELOPE                                                1
#define RSSCOPE_VAL_AVERAGE                                                 2
#define RSSCOPE_VAL_RMS                                                     3
#define RSSCOPE_VAL_MINH                                                    4
#define RSSCOPE_VAL_MAXH                                                    5

// rsscope_rngVerticalCoupling
#define RSSCOPE_VAL_AC                                                      0
#define RSSCOPE_VAL_DC                                                      1
#define RSSCOPE_VAL_DC_LIMIT                                                2

// rsscope_rngChannelBWLimit
#define RSSCOPE_VAL_BW_FULL                                                 0
#define RSSCOPE_VAL_BW_800                                                  1
#define RSSCOPE_VAL_BW_200                                                  2
#define RSSCOPE_VAL_BW_20                                                   3

// rsscope_rngTriggerMode
#define RSSCOPE_VAL_NORMAL                                                  0
#define RSSCOPE_VAL_AUTO                                                    1
#define RSSCOPE_VAL_FREERUN                                                 2

// rsscope_rngTriggerSource
#define RSSCOPE_VAL_CHANNEL1                                                1
#define RSSCOPE_VAL_CHANNEL2                                                2
#define RSSCOPE_VAL_CHANNEL3                                                3
#define RSSCOPE_VAL_CHANNEL4                                                4
#define RSSCOPE_VAL_EXTERNAL                                                5
#define RSSCOPE_VAL_SBUS                                                    6
#define RSSCOPE_VAL_LINE                                                    7
#define RSSCOPE_VAL_D0                                                      8
#define RSSCOPE_VAL_D1                                                      9
#define RSSCOPE_VAL_D2                                                      10
#define RSSCOPE_VAL_D3                                                      11
#define RSSCOPE_VAL_D4                                                      12
#define RSSCOPE_VAL_D5                                                      13
#define RSSCOPE_VAL_D6                                                      14
#define RSSCOPE_VAL_D7                                                      15
#define RSSCOPE_VAL_D8                                                      16
#define RSSCOPE_VAL_D9                                                      17
#define RSSCOPE_VAL_D10                                                     18
#define RSSCOPE_VAL_D11                                                     19
#define RSSCOPE_VAL_D12                                                     20
#define RSSCOPE_VAL_D13                                                     21
#define RSSCOPE_VAL_D14                                                     22
#define RSSCOPE_VAL_D15                                                     23
#define RSSCOPE_VAL_LOGIC                                                   24
#define RSSCOPE_VAL_MSOB1                                                   25
#define RSSCOPE_VAL_MSOB2                                                   26
#define RSSCOPE_VAL_MSOB3                                                   27
#define RSSCOPE_VAL_MSOB4                                                   28
#define RSSCOPE_VAL_Z1V1                                                    29
#define RSSCOPE_VAL_Z1V2                                                    30
#define RSSCOPE_VAL_Z1V3                                                    31
#define RSSCOPE_VAL_Z1V4                                                    32
#define RSSCOPE_VAL_Z1I1                                                    33
#define RSSCOPE_VAL_Z1I2                                                    34
#define RSSCOPE_VAL_Z1I3                                                    35
#define RSSCOPE_VAL_Z1I4                                                    36
#define RSSCOPE_VAL_Z2V1                                                    37
#define RSSCOPE_VAL_Z2V2                                                    38
#define RSSCOPE_VAL_Z2V3                                                    39
#define RSSCOPE_VAL_Z2V4                                                    40
#define RSSCOPE_VAL_Z2I1                                                    41
#define RSSCOPE_VAL_Z2I2                                                    42
#define RSSCOPE_VAL_Z2I3                                                    43
#define RSSCOPE_VAL_Z2I4                                                    44
#define RSSCOPE_VAL_DIFF1                                                   45
#define RSSCOPE_VAL_DIFF2                                                   46
#define RSSCOPE_VAL_COMMON1                                                 47
#define RSSCOPE_VAL_COMMON2                                                 48

// rsscope_rngTriggerType
#define RSSCOPE_VAL_EDGE_TRIGGER                                            0
#define RSSCOPE_VAL_WIDTH_TRIGGER                                           1
#define RSSCOPE_VAL_RUNT_TRIGGER                                            2
#define RSSCOPE_VAL_GLITCH_TRIGGER                                          3
#define RSSCOPE_VAL_WINDOW_TRIGGER                                          4
#define RSSCOPE_VAL_TIMEOUT_TRIGGER                                         5
#define RSSCOPE_VAL_INTERVAL_TRIGGER                                        6
#define RSSCOPE_VAL_SLEW_RATE_TRIGGER                                       7
#define RSSCOPE_VAL_DATA_TO_CLOCK_TRIGGER                                   8
#define RSSCOPE_VAL_PATTERN_TRIGGER                                         9
#define RSSCOPE_VAL_ANALOG_EDGE_TRIGGER                                     10
#define RSSCOPE_VAL_SERIAL_PATTERN_TRIGGER                                  11
#define RSSCOPE_VAL_STATE_TRIGGER                                           12
#define RSSCOPE_VAL_NFC_TRIGGER                                             13
#define RSSCOPE_VAL_TV_TRIGGER                                              14
#define RSSCOPE_VAL_CDR_TRIGGER                                             15
#define RSSCOPE_VAL_SETHOLD_TRIGGER                                         16

// rsscope_rngTriggerSlope
#define RSSCOPE_VAL_POSITIVE                                                0
#define RSSCOPE_VAL_NEGATIVE                                                1
#define RSSCOPE_VAL_EITHER                                                  2

// rsscope_rngTriggerCoupling
#define RSSCOPE_VAL_DCL                                                     2

// rsscope_rngWidthCondition
#define RSSCOPE_VAL_SHORTER                                                 0
#define RSSCOPE_VAL_LONGER                                                  1
#define RSSCOPE_VAL_WITHIN                                                  2
#define RSSCOPE_VAL_OUTSIDE                                                 3

// rsscope_rngCursorFunction
#define RSSCOPE_VAL_CURSOR_HORIZONTAL                                       0
#define RSSCOPE_VAL_CURSOR_VERTICAL                                         1
#define RSSCOPE_VAL_CURSOR_PAIRED                                           2

// rsscope_rngWaveformParameter
#define RSSCOPE_VAL_WAV_NONE                                                0
#define RSSCOPE_VAL_WAV_C1W1                                                1
#define RSSCOPE_VAL_WAV_C1W2                                                2
#define RSSCOPE_VAL_WAV_C1W3                                                3
#define RSSCOPE_VAL_WAV_C2W1                                                4
#define RSSCOPE_VAL_WAV_C2W2                                                5
#define RSSCOPE_VAL_WAV_C2W3                                                6
#define RSSCOPE_VAL_WAV_C3W1                                                7
#define RSSCOPE_VAL_WAV_C3W2                                                8
#define RSSCOPE_VAL_WAV_C3W3                                                9
#define RSSCOPE_VAL_WAV_C4W1                                                10
#define RSSCOPE_VAL_WAV_C4W2                                                11
#define RSSCOPE_VAL_WAV_C4W3                                                12
#define RSSCOPE_VAL_WAV_M1                                                  13
#define RSSCOPE_VAL_WAV_M2                                                  14
#define RSSCOPE_VAL_WAV_M3                                                  15
#define RSSCOPE_VAL_WAV_M4                                                  16
#define RSSCOPE_VAL_WAV_M5                                                  17
#define RSSCOPE_VAL_WAV_R1                                                  18
#define RSSCOPE_VAL_WAV_R2                                                  19
#define RSSCOPE_VAL_WAV_R3                                                  20
#define RSSCOPE_VAL_WAV_R4                                                  21
#define RSSCOPE_VAL_WAV_XY1                                                 22
#define RSSCOPE_VAL_WAV_XY2                                                 23
#define RSSCOPE_VAL_WAV_XY3                                                 24
#define RSSCOPE_VAL_WAV_XY4                                                 25
#define RSSCOPE_VAL_WAV_MRES1                                               26
#define RSSCOPE_VAL_WAV_MRES2                                               27
#define RSSCOPE_VAL_WAV_MRES3                                               28
#define RSSCOPE_VAL_WAV_MRES4                                               29
#define RSSCOPE_VAL_WAV_MRES5                                               30
#define RSSCOPE_VAL_WAV_MRES6                                               31
#define RSSCOPE_VAL_WAV_MRES7                                               32
#define RSSCOPE_VAL_WAV_MRES8                                               33
#define RSSCOPE_VAL_WAV_SBUS1                                               34
#define RSSCOPE_VAL_WAV_SBUS2                                               35
#define RSSCOPE_VAL_WAV_SBUS3                                               36
#define RSSCOPE_VAL_WAV_SBUS4                                               37
#define RSSCOPE_VAL_WAV_D0                                                  38
#define RSSCOPE_VAL_WAV_D1                                                  39
#define RSSCOPE_VAL_WAV_D2                                                  40
#define RSSCOPE_VAL_WAV_D3                                                  41
#define RSSCOPE_VAL_WAV_D4                                                  42
#define RSSCOPE_VAL_WAV_D5                                                  43
#define RSSCOPE_VAL_WAV_D6                                                  44
#define RSSCOPE_VAL_WAV_D7                                                  45
#define RSSCOPE_VAL_WAV_D8                                                  46
#define RSSCOPE_VAL_WAV_D9                                                  47
#define RSSCOPE_VAL_WAV_D10                                                 48
#define RSSCOPE_VAL_WAV_D11                                                 49
#define RSSCOPE_VAL_WAV_D12                                                 50
#define RSSCOPE_VAL_WAV_D13                                                 51
#define RSSCOPE_VAL_WAV_D14                                                 52
#define RSSCOPE_VAL_WAV_D15                                                 53
#define RSSCOPE_VAL_WAV_MSOB1                                               54
#define RSSCOPE_VAL_WAV_MSOB2                                               55
#define RSSCOPE_VAL_WAV_MSOB3                                               56
#define RSSCOPE_VAL_WAV_MSOB4                                               57
#define RSSCOPE_VAL_WAV_TRK1                                                58
#define RSSCOPE_VAL_WAV_TRK2                                                59
#define RSSCOPE_VAL_WAV_TRK3                                                60
#define RSSCOPE_VAL_WAV_TRK4                                                61
#define RSSCOPE_VAL_WAV_TRK5                                                62
#define RSSCOPE_VAL_WAV_TRK6                                                63
#define RSSCOPE_VAL_WAV_TRK7                                                64
#define RSSCOPE_VAL_WAV_TRK8                                                65
#define RSSCOPE_VAL_WAV_IMR                                                 66
#define RSSCOPE_VAL_WAV_CDRSW1                                              67
#define RSSCOPE_VAL_WAV_CDRSW2                                              68
#define RSSCOPE_VAL_WAV_CDRHW                                               69
#define RSSCOPE_VAL_WAV_QUICK                                               70
#define RSSCOPE_VAL_WAV_SG1TL1                                              71
#define RSSCOPE_VAL_WAV_SG1TL2                                              72
#define RSSCOPE_VAL_WAV_SG2TL1                                              73
#define RSSCOPE_VAL_WAV_SG2TL2                                              74
#define RSSCOPE_VAL_WAV_SG3TL1                                              75
#define RSSCOPE_VAL_WAV_SG3TL2                                              76
#define RSSCOPE_VAL_WAV_SG4TL1                                              77
#define RSSCOPE_VAL_WAV_SG4TL2                                              78
#define RSSCOPE_VAL_WAV_SG1                                                 79
#define RSSCOPE_VAL_WAV_SG2                                                 80
#define RSSCOPE_VAL_WAV_SG3                                                 81
#define RSSCOPE_VAL_WAV_SG4                                                 82
#define RSSCOPE_VAL_WAV_AEYE1                                               83
#define RSSCOPE_VAL_WAV_AEYE2                                               84
#define RSSCOPE_VAL_WAV_AEYE3                                               85
#define RSSCOPE_VAL_WAV_AEYE4                                               86
#define RSSCOPE_VAL_WAV_Z1V1                                                87
#define RSSCOPE_VAL_WAV_Z1V2                                                88
#define RSSCOPE_VAL_WAV_Z1V3                                                89
#define RSSCOPE_VAL_WAV_Z1V4                                                90
#define RSSCOPE_VAL_WAV_Z1I1                                                91
#define RSSCOPE_VAL_WAV_Z1I2                                                92
#define RSSCOPE_VAL_WAV_Z1I3                                                93
#define RSSCOPE_VAL_WAV_Z1I4                                                94
#define RSSCOPE_VAL_WAV_Z2V1                                                95
#define RSSCOPE_VAL_WAV_Z2V2                                                96
#define RSSCOPE_VAL_WAV_Z2V3                                                97
#define RSSCOPE_VAL_WAV_Z2V4                                                98
#define RSSCOPE_VAL_WAV_Z2I1                                                99
#define RSSCOPE_VAL_WAV_Z2I2                                                100
#define RSSCOPE_VAL_WAV_Z2I3                                                101
#define RSSCOPE_VAL_WAV_Z2I4                                                102
#define RSSCOPE_VAL_WAV_DIFF1                                               103
#define RSSCOPE_VAL_WAV_DIFF2                                               104
#define RSSCOPE_VAL_WAV_COMMON1                                             105
#define RSSCOPE_VAL_WAV_COMMON2                                             106
#define RSSCOPE_VAL_WAV_TDRZ                                                107
#define RSSCOPE_VAL_WAV_TDRH                                                108
#define RSSCOPE_VAL_WAV_TDRR                                                109
#define RSSCOPE_VAL_WAV_M6                                                  110
#define RSSCOPE_VAL_WAV_M7                                                  111
#define RSSCOPE_VAL_WAV_M8                                                  112
#define RSSCOPE_VAL_WAV_SEYE1                                               113
#define RSSCOPE_VAL_WAV_SEYE2                                               114
#define RSSCOPE_VAL_WAV_TJSP1                                               115
#define RSSCOPE_VAL_WAV_TJSP2                                               116
#define RSSCOPE_VAL_WAV_DDJS1                                               117
#define RSSCOPE_VAL_WAV_DDJS2                                               118
#define RSSCOPE_VAL_WAV_PJSP1                                               119
#define RSSCOPE_VAL_WAV_PJSP2                                               120
#define RSSCOPE_VAL_WAV_RJSP1                                               121
#define RSSCOPE_VAL_WAV_RJSP2                                               122
#define RSSCOPE_VAL_WAV_BATH1                                               123
#define RSSCOPE_VAL_WAV_BATH2                                               124
#define RSSCOPE_VAL_WAV_BME1                                                125
#define RSSCOPE_VAL_WAV_BME2                                                126
#define RSSCOPE_VAL_WAV_SRTR1                                               127
#define RSSCOPE_VAL_WAV_SRTR2                                               128
#define RSSCOPE_VAL_WAV_SDTR1                                               129
#define RSSCOPE_VAL_WAV_SDTR2                                               130
#define RSSCOPE_VAL_WAV_TJTR1                                               131
#define RSSCOPE_VAL_WAV_TJTR2                                               132
#define RSSCOPE_VAL_WAV_DJTR1                                               133
#define RSSCOPE_VAL_WAV_DJTR2                                               134
#define RSSCOPE_VAL_WAV_DDJTR1                                              135
#define RSSCOPE_VAL_WAV_DDJTR2                                              136
#define RSSCOPE_VAL_WAV_PJTR1                                               137
#define RSSCOPE_VAL_WAV_PJTR2                                               138
#define RSSCOPE_VAL_WAV_RJTR1                                               139
#define RSSCOPE_VAL_WAV_RJTR2                                               140
#define RSSCOPE_VAL_WAV_SRES1                                               141
#define RSSCOPE_VAL_WAV_SRES2                                               142
#define RSSCOPE_VAL_WAV_SRHIST1                                             143
#define RSSCOPE_VAL_WAV_SRHIST2                                             144
#define RSSCOPE_VAL_WAV_SDHIST1                                             145
#define RSSCOPE_VAL_WAV_SDHIST2                                             146
#define RSSCOPE_VAL_WAV_TJHIST1                                             147
#define RSSCOPE_VAL_WAV_TJHIST2                                             148
#define RSSCOPE_VAL_WAV_DJHIST1                                             149
#define RSSCOPE_VAL_WAV_DJHIST2                                             150
#define RSSCOPE_VAL_WAV_DDJHIST1                                            151
#define RSSCOPE_VAL_WAV_DDJHIST2                                            152
#define RSSCOPE_VAL_WAV_PJHIST1                                             153
#define RSSCOPE_VAL_WAV_PJHIST2                                             154
#define RSSCOPE_VAL_WAV_RJOHIST1                                            155
#define RSSCOPE_VAL_WAV_RJOHIST2                                            156
#define RSSCOPE_VAL_WAV_SG5TL1                                              157
#define RSSCOPE_VAL_WAV_SG5TL2                                              158
#define RSSCOPE_VAL_WAV_SG6TL1                                              159
#define RSSCOPE_VAL_WAV_SG6TL2                                              160
#define RSSCOPE_VAL_WAV_SG7TL1                                              161
#define RSSCOPE_VAL_WAV_SG7TL2                                              162
#define RSSCOPE_VAL_WAV_SG8TL1                                              163
#define RSSCOPE_VAL_WAV_SG8TL2                                              164
#define RSSCOPE_VAL_WAV_SG5                                                 165
#define RSSCOPE_VAL_WAV_SG6                                                 166
#define RSSCOPE_VAL_WAV_SG7                                                 167
#define RSSCOPE_VAL_WAV_SG8                                                 168
#define RSSCOPE_VAL_WAV_NBATHTUB1                                           169
#define RSSCOPE_VAL_WAV_NBATHTUB2                                           170
#define RSSCOPE_VAL_WAV_NBMEAS1                                             171
#define RSSCOPE_VAL_WAV_NBMEAS2                                             172
#define RSSCOPE_VAL_WAV_TNHIST1                                             173
#define RSSCOPE_VAL_WAV_TNHIST2                                             174
#define RSSCOPE_VAL_WAV_DNHIST1                                             175
#define RSSCOPE_VAL_WAV_DNHIST2                                             176
#define RSSCOPE_VAL_WAV_DDNHIST1                                            177
#define RSSCOPE_VAL_WAV_DDNHIST2                                            178
#define RSSCOPE_VAL_WAV_PNHIST1                                             179
#define RSSCOPE_VAL_WAV_PNHIST2                                             180
#define RSSCOPE_VAL_WAV_RNOHIST1                                            181
#define RSSCOPE_VAL_WAV_RNOHIST2                                            182
#define RSSCOPE_VAL_WAV_TNTRACK1                                            183
#define RSSCOPE_VAL_WAV_TNTRACK2                                            184
#define RSSCOPE_VAL_WAV_DNTRACK1                                            185
#define RSSCOPE_VAL_WAV_DNTRACK2                                            186
#define RSSCOPE_VAL_WAV_DDNTRACK1                                           187
#define RSSCOPE_VAL_WAV_DDNTRACK2                                           188
#define RSSCOPE_VAL_WAV_PNTRACK1                                            189
#define RSSCOPE_VAL_WAV_PNTRACK2                                            190
#define RSSCOPE_VAL_WAV_RNOTRACK1                                           191
#define RSSCOPE_VAL_WAV_RNOTRACK2                                           192
#define RSSCOPE_VAL_WAV_TNSPECTRUM1                                         193
#define RSSCOPE_VAL_WAV_TNSPECTRUM2                                         194
#define RSSCOPE_VAL_WAV_DDNSPECTRUM1                                        195
#define RSSCOPE_VAL_WAV_DDNSPECTRUM2                                        196
#define RSSCOPE_VAL_WAV_PNSPECTRUM1                                         197
#define RSSCOPE_VAL_WAV_PNSPECTRUM2                                         198
#define RSSCOPE_VAL_WAV_RNOSPECTRUM1                                        199
#define RSSCOPE_VAL_WAV_RNOSPECTRUM2                                        200
#define RSSCOPE_VAL_WAV_PJDHIST1                                            201
#define RSSCOPE_VAL_WAV_PJDHIST2                                            202
#define RSSCOPE_VAL_WAV_BUJHIST1                                            203
#define RSSCOPE_VAL_WAV_BUJHIST2                                            204
#define RSSCOPE_VAL_WAV_RJHIST1                                             205
#define RSSCOPE_VAL_WAV_RJHIST2                                             206
#define RSSCOPE_VAL_WAV_PJDTRACK1                                           207
#define RSSCOPE_VAL_WAV_PJDTRACK2                                           208
#define RSSCOPE_VAL_WAV_PJDSPECTRUM1                                        209
#define RSSCOPE_VAL_WAV_PJDSPECTRUM2                                        210
#define RSSCOPE_VAL_WAV_PNDHIST1                                            211
#define RSSCOPE_VAL_WAV_PNDHIST2                                            212
#define RSSCOPE_VAL_WAV_BUNHIST1                                            213
#define RSSCOPE_VAL_WAV_BUNHIST2                                            214
#define RSSCOPE_VAL_WAV_PNDTRACK1                                           215
#define RSSCOPE_VAL_WAV_PNDTRACK2                                           216
#define RSSCOPE_VAL_WAV_PNDSPECTRUM1                                        217
#define RSSCOPE_VAL_WAV_PNDSPECTRUM2                                        218

// rsscope_rngMinMax
#define RSSCOPE_VAL_MIN                                                     0
#define RSSCOPE_VAL_MAX                                                     1

// rsscope_rngAcquisitionType
#define RSSCOPE_VAL_SAMPLE                                                  0
#define RSSCOPE_VAL_PEAK_DETECT                                             1
#define RSSCOPE_VAL_HI_RES                                                  2

// rsscope_rngHorzRecordSelection
#define RSSCOPE_VAL_RESOLUTION                                              0
#define RSSCOPE_VAL_RECORD_TIME                                             1

// rsscope_rngInterpolation
#define RSSCOPE_VAL_SINE_X                                                  0
#define RSSCOPE_VAL_LINEAR                                                  1
#define RSSCOPE_VAL_SAMPLE_HOLD                                             2

// rsscope_rngCutOffFrequency
#define RSSCOPE_VAL_CUTOFF_KHZ5                                             0
#define RSSCOPE_VAL_CUTOFF_KHZ50                                            1
#define RSSCOPE_VAL_CUTOFF_MHZ50                                            2

// rsscope_rngFilterType
#define RSSCOPE_VAL_FILTER_OFF                                              0
#define RSSCOPE_VAL_FILTER_LOW_PASS                                         1
#define RSSCOPE_VAL_FILTER_HIGH_PASS                                        2

// rsscope_rngRuntCondition
#define RSSCOPE_VAL_ANY                                                     4

// rsscope_rngWindowCondition
#define RSSCOPE_VAL_ENTER                                                   0
#define RSSCOPE_VAL_EXIT                                                    1

// rsscope_rngTimeoutCondition
#define RSSCOPE_VAL_TIMEOUT_LOW                                             0
#define RSSCOPE_VAL_TIMEOUT_HIGH                                            1
#define RSSCOPE_VAL_TIMEOUT_EITHER                                          2

// rsscope_rngPatternMode
#define RSSCOPE_VAL_PATTERN_OFF                                             0
#define RSSCOPE_VAL_PATTERN_TIMEOUT                                         1
#define RSSCOPE_VAL_PATTERN_WIDTH                                           2

// rsscope_rngPatternTimeoutMode
#define RSSCOPE_VAL_PATTERN_TIMEOUT_LOW                                     0
#define RSSCOPE_VAL_PATTERN_TIMEOUT_HIGH                                    1

// rsscope_rngTriggerQualificationLogic
#define RSSCOPE_VAL_LOGIC_DIRECT                                            0
#define RSSCOPE_VAL_LOGIC_NEGATE                                            1
#define RSSCOPE_VAL_LOGIC_LOW                                               2
#define RSSCOPE_VAL_LOGIC_HIGH                                              3

// rsscope_rngLogic
#define RSSCOPE_VAL_AND                                                     0
#define RSSCOPE_VAL_OR                                                      1
#define RSSCOPE_VAL_NAND                                                    2
#define RSSCOPE_VAL_NOR                                                     3

// rsscope_rngAutoManual
#define RSSCOPE_VAL_MANUAL                                                  0

// rsscope_rngTriggerSequence
#define RSSCOPE_VAL_SEQ_AONLY                                               0
#define RSSCOPE_VAL_SEQ_ABR                                                 1
#define RSSCOPE_VAL_SEQ_AZ                                                  2
#define RSSCOPE_VAL_SEQ_ABRZ                                                3
#define RSSCOPE_VAL_SEQ_AB                                                  4
#define RSSCOPE_VAL_SEQ_AORB                                                5
#define RSSCOPE_VAL_SEQ_AORBZ                                               6

// rsscope_rngHoldoffMode
#define RSSCOPE_VAL_HOLDOFF_OFF                                             0
#define RSSCOPE_VAL_HOLDOFF_AUTO                                            1
#define RSSCOPE_VAL_HOLDOFF_TIME                                            2
#define RSSCOPE_VAL_HOLDOFF_EVENTS                                          3
#define RSSCOPE_VAL_HOLDOFF_RANDOM                                          4

// rsscope_rngMeasurementCategory
#define RSSCOPE_VAL_AMPTIME                                                 0
#define RSSCOPE_VAL_EYE                                                     1
#define RSSCOPE_VAL_SPECTRUM                                                2
#define RSSCOPE_VAL_HISTOGRAM                                               3
#define RSSCOPE_VAL_PROTOCOL                                                4
#define RSSCOPE_VAL_JITTER                                                  5
#define RSSCOPE_VAL_OPTICAL                                                 6

// rsscope_rngAmplitudeTimeMeasurementType
#define RSSCOPE_VAL_MEAS_HIGH                                               1
#define RSSCOPE_VAL_MEAS_LOW                                                2
#define RSSCOPE_VAL_MEAS_AMPLITUDE                                          3
#define RSSCOPE_VAL_MEAS_MAXIMUM                                            4
#define RSSCOPE_VAL_MEAS_MINIMUM                                            5
#define RSSCOPE_VAL_MEAS_PEAK_TO_PEAK                                       6
#define RSSCOPE_VAL_MEAS_MEAN                                               7
#define RSSCOPE_VAL_MEAS_RMS                                                8
#define RSSCOPE_VAL_MEAS_STD_DEVIATION                                      9
#define RSSCOPE_VAL_MEAS_POS_OVERSHOOT                                      10
#define RSSCOPE_VAL_MEAS_NEG_OVERSHOOT                                      11
#define RSSCOPE_VAL_MEAS_AREA                                               12
#define RSSCOPE_VAL_MEAS_RISE_TIME                                          13
#define RSSCOPE_VAL_MEAS_FALL_TIME                                          14
#define RSSCOPE_VAL_MEAS_POS_PULSE                                          15
#define RSSCOPE_VAL_MEAS_NEG_PULSE                                          16
#define RSSCOPE_VAL_MEAS_PERIOD                                             17
#define RSSCOPE_VAL_MEAS_FREQUENCY                                          18
#define RSSCOPE_VAL_MEAS_POS_DUTY_CYCLE                                     19
#define RSSCOPE_VAL_MEAS_NEG_DUTY_CYCLE                                     20
#define RSSCOPE_VAL_MEAS_CYCLE_AREA                                         21
#define RSSCOPE_VAL_MEAS_CYCLE_MEAN                                         22
#define RSSCOPE_VAL_MEAS_CYCLE_RMS                                          23
#define RSSCOPE_VAL_MEAS_CYCLE_STD_DEV                                      24
#define RSSCOPE_VAL_MEAS_PULSE_COUNT                                        25
#define RSSCOPE_VAL_MEAS_DELAY                                              26
#define RSSCOPE_VAL_MEAS_PHASE                                              27
#define RSSCOPE_VAL_MEAS_BURST_WIDTH                                        28
#define RSSCOPE_VAL_MEAS_POS_SWITCHING                                      29
#define RSSCOPE_VAL_MEAS_NEG_SWITCHING                                      30
#define RSSCOPE_VAL_MEAS_PROBEMETER                                         31
#define RSSCOPE_VAL_MEAS_PULSE_TRAIN                                        32
#define RSSCOPE_VAL_MEAS_EDGE_COUNT                                         33
#define RSSCOPE_VAL_MEAS_SHT                                                34
#define RSSCOPE_VAL_MEAS_SHR                                                35
#define RSSCOPE_VAL_MEAS_SETUP                                              36
#define RSSCOPE_VAL_MEAS_HOLD                                               37
#define RSSCOPE_VAL_MEAS_DTOT                                               38
#define RSSCOPE_VAL_MEAS_SLER                                               39
#define RSSCOPE_VAL_MEAS_SLEF                                               40
#define RSSCOPE_VAL_MEAS_ATAR                                               41

// rsscope_rngEyeJitterMeasurementType
#define RSSCOPE_VAL_MEAS_EXTINCTION_RATIO_PCT                               2
#define RSSCOPE_VAL_MEAS_EXTINCTION_RATIO_DBM                               3
#define RSSCOPE_VAL_MEAS_EYE_HEIGHT                                         4
#define RSSCOPE_VAL_MEAS_EYE_WIDTH                                          5
#define RSSCOPE_VAL_MEAS_EYE_TOP                                            6
#define RSSCOPE_VAL_MEAS_EYE_BASE                                           7
#define RSSCOPE_VAL_MEAS_Q_FACTOR                                           10
#define RSSCOPE_VAL_MEAS_RMS_NOISE                                          14
#define RSSCOPE_VAL_MEAS_SNR                                                15
#define RSSCOPE_VAL_MEAS_DUTY_CYCLE_DISTORTION                              16
#define RSSCOPE_VAL_MEAS_EYE_RISE_TIME                                      17
#define RSSCOPE_VAL_MEAS_EYE_FALL_TIME                                      18
#define RSSCOPE_VAL_MEAS_EYE_BIT_RATE                                       19
#define RSSCOPE_VAL_MEAS_EYE_AMPLITUDE                                      20
#define RSSCOPE_VAL_MEAS_PEAK_TO_PEAK_JITTER                                28
#define RSSCOPE_VAL_MEAS_STD_DEVIATION_JITTER                               29
#define RSSCOPE_VAL_MEAS_RMS_JITTER                                         30

// rsscope_rngSpectrumMeasurementType
#define RSSCOPE_VAL_MEAS_CHANNEL_POWER                                      1
#define RSSCOPE_VAL_MEAS_OCCUPIED_BANDWIDTH                                 2
#define RSSCOPE_VAL_MEAS_N_DB_DOWN                                          3
#define RSSCOPE_VAL_MEAS_THD                                                4
#define RSSCOPE_VAL_MEAS_HAR                                                5
#define RSSCOPE_VAL_MEAS_THDPCT                                             6
#define RSSCOPE_VAL_MEAS_THDA                                               7
#define RSSCOPE_VAL_MEAS_THDU                                               8
#define RSSCOPE_VAL_MEAS_THDR                                               9
#define RSSCOPE_VAL_MEAS_PLIST                                              10
#define RSSCOPE_VAL_MEAS_THDF                                               11
#define RSSCOPE_VAL_MEAS_SPAR                                               12

// rsscope_rngHistogramMeasurementType
#define RSSCOPE_VAL_MEAS_WAVEFORM_COUNT                                     1
#define RSSCOPE_VAL_MEAS_WAVEFORM_SAMPLES                                   2
#define RSSCOPE_VAL_MEAS_HISTOGRAM_SAMPLES                                  3
#define RSSCOPE_VAL_MEAS_HISTOGRAM_PEAK                                     4
#define RSSCOPE_VAL_MEAS_PEAK                                               5
#define RSSCOPE_VAL_MEAS_UPPER_PEAK                                         6
#define RSSCOPE_VAL_MEAS_LOWER_PEAK                                         7
#define RSSCOPE_VAL_MEAS_HISTOGRAM_MAXIMUM                                  8
#define RSSCOPE_VAL_MEAS_HISTOGRAM_MINIMUM                                  9
#define RSSCOPE_VAL_MEAS_MEDIAN                                             10
#define RSSCOPE_VAL_MEAS_MAXIMUM_MINIMUM                                    11
#define RSSCOPE_VAL_MEAS_HISTOGRAM_MEAN                                     12
#define RSSCOPE_VAL_MEAS_HISTOGRAM_STD_DEVIATION                            13
#define RSSCOPE_VAL_MEAS_M1ST                                               14
#define RSSCOPE_VAL_MEAS_M2ST                                               15
#define RSSCOPE_VAL_MEAS_M3ST                                               16
#define RSSCOPE_VAL_MEAS_MKP                                                17
#define RSSCOPE_VAL_MEAS_MKN                                                18

// rsscope_rngLimitCheck
#define RSSCOPE_VAL_INSIDE_LIMIT                                            0
#define RSSCOPE_VAL_UPPER_LIMIT                                             1
#define RSSCOPE_VAL_LOWER_LIMIT                                             2
#define RSSCOPE_VAL_OUTSIDE_LIMIT                                           3

// rsscope_rngProbabilityType
#define RSSCOPE_VAL_PROBABILITY_PEAK                                        0
#define RSSCOPE_VAL_PROBABILITY_UPPK                                        1
#define RSSCOPE_VAL_PROBABILITY_LWPK                                        2
#define RSSCOPE_VAL_PROBABILITY_MAX                                         3
#define RSSCOPE_VAL_PROBABILITY_MIN                                         4
#define RSSCOPE_VAL_PROBABILITY_MEDIAN                                      5
#define RSSCOPE_VAL_PROBABILITY_MEAN                                        6

// rsscope_rngLimitType
#define RSSCOPE_VAL_LIMIT_OFF                                               0
#define RSSCOPE_VAL_LIMIT_ONLY                                              1
#define RSSCOPE_VAL_LIMIT_MARGIN                                            2

// rsscope_rngMeasurementEvent
#define RSSCOPE_VAL_EVENT_NO_ACTION                                         0
#define RSSCOPE_VAL_EVENT_SUCCESS                                           1
#define RSSCOPE_VAL_EVENT_VIOLATION                                         2

// rsscope_rngAbsRel
#define RSSCOPE_VAL_ABS                                                     0
#define RSSCOPE_VAL_REL                                                     1

// rsscope_rngLowUpp
#define RSSCOPE_VAL_LOW                                                     0
#define RSSCOPE_VAL_UPP                                                     1

// rsscope_rngStatisticsMode
#define RSSCOPE_VAL_STAT_MODE_TIME                                          1
#define RSSCOPE_VAL_STAT_MODE_WAVEFORMS                                     2
#define RSSCOPE_VAL_STAT_MODE_MEAS                                          3

// rsscope_rngFFTWindowType
#define RSSCOPE_VAL_RECTANGULAR                                             0
#define RSSCOPE_VAL_HAMMING                                                 1
#define RSSCOPE_VAL_HANN                                                    2
#define RSSCOPE_VAL_BLACKMAN                                                3
#define RSSCOPE_VAL_GAUSSIAN                                                4
#define RSSCOPE_VAL_FLATTOP                                                 5
#define RSSCOPE_VAL_KAISER                                                  6

// rsscope_rngRBWGateCoupling
#define RSSCOPE_VAL_COUPLING_LENGTH                                         0
#define RSSCOPE_VAL_COUPLING_RBW                                            1

// rsscope_rngFFTMagnitudeUnit
#define RSSCOPE_VAL_SCALE_LINEAR                                            0
#define RSSCOPE_VAL_SCALE_DBM                                               1
#define RSSCOPE_VAL_SCALE_DB                                                2
#define RSSCOPE_VAL_SCALE_DBUV                                              3
#define RSSCOPE_VAL_SCALE_DBMV                                              4
#define RSSCOPE_VAL_SCALE_DBV                                               5
#define RSSCOPE_VAL_SCALE_DBPS                                              6
#define RSSCOPE_VAL_SCALE_DBNS                                              7
#define RSSCOPE_VAL_SCALE_DBUS                                              8
#define RSSCOPE_VAL_SCALE_DBMS                                              9
#define RSSCOPE_VAL_SCALE_DBS                                               10
#define RSSCOPE_VAL_SCALE_DBHZ                                              11
#define RSSCOPE_VAL_SCALE_DBKHZ                                             12
#define RSSCOPE_VAL_SCALE_DBMHZ                                             13
#define RSSCOPE_VAL_SCALE_DBGHZ                                             14
#define RSSCOPE_VAL_SCALE_DBA                                               15
#define RSSCOPE_VAL_SCALE_DBMA                                              16
#define RSSCOPE_VAL_SCALE_DBUA                                              17

// rsscope_rngFFTPhaseUnit
#define RSSCOPE_VAL_SCALE_DEG                                               0
#define RSSCOPE_VAL_SCALE_RAD                                               1

// rsscope_rngRefLevelRelative
#define RSSCOPE_VAL_FIVE                                                    0
#define RSSCOPE_VAL_TEN                                                     1
#define RSSCOPE_VAL_TWENTY                                                  2
#define RSSCOPE_VAL_USER_LEVEL                                              3

// rsscope_rngUserLevel
#define RSSCOPE_VAL_HIGH_LOW                                                0
#define RSSCOPE_VAL_LEVEL                                                   1

// rsscope_rngRefLevelAutoMode
#define RSSCOPE_VAL_REF_AUTO                                                0
#define RSSCOPE_VAL_REF_PPR                                                 1
#define RSSCOPE_VAL_REF_MPR                                                 2
#define RSSCOPE_VAL_REF_ABS_PEAK                                            3
#define RSSCOPE_VAL_REF_UPML                                                4
#define RSSCOPE_VAL_REF_UMLP                                                5
#define RSSCOPE_VAL_REF_UALM                                                6
#define RSSCOPE_VAL_REF_UMLA                                                7

// rsscope_rngRefWfmCoupling
#define RSSCOPE_VAL_COUPLED                                                 0
#define RSSCOPE_VAL_INDEPENDENT                                             1

// rsscope_rngRefWfmHorzCoupling
#define RSSCOPE_VAL_ORIGINAL                                                1

// rsscope_rngProbeButtonAction
#define RSSCOPE_VAL_PROBE_BUTTON_NO_ACTION                                  0
#define RSSCOPE_VAL_PROBE_BUTTON_RUN_CONTINUOUS                             1
#define RSSCOPE_VAL_PROBE_BUTTON_RUN_SINGLE                                 2
#define RSSCOPE_VAL_PROBE_BUTTON_AUTOSET                                    3
#define RSSCOPE_VAL_PROBE_BUTTON_AUTO_ZERO                                  4
#define RSSCOPE_VAL_PROBE_BUTTON_SET_OFFSET_TO_MEAN                         5
#define RSSCOPE_VAL_PROBE_BUTTON_FIND_TRIG_LEVEL                            6
#define RSSCOPE_VAL_PROBE_BUTTON_PRINT                                      7
#define RSSCOPE_VAL_PROBE_BUTTON_SAVE_TO_FILE                               8
#define RSSCOPE_VAL_PROBE_BUTTON_REPORT                                     9
#define RSSCOPE_VAL_PROBE_BUTTON_PROBEMODE                                  10
#define RSSCOPE_VAL_PROBE_BUTTON_PROBESETUP                                 11

// rsscope_rngProbeState
#define RSSCOPE_VAL_PROBE_STATE_NDET                                        0
#define RSSCOPE_VAL_PROBE_STATE_DET                                         1

// rsscope_rngProbeFirmwareUpdateStatus
#define RSSCOPE_VAL_PROBE_FIRMWARE_UPDATE_STATUS_UNKNOWN                    0
#define RSSCOPE_VAL_PROBE_FIRMWARE_UPDATE_STATUS_MEASURING                  1
#define RSSCOPE_VAL_PROBE_FIRMWARE_UPDATE_STATUS_UPDATE                     2
#define RSSCOPE_VAL_PROBE_FIRMWARE_UPDATE_STATUS_FAILED                     3

// rsscope_rngProbeSelftestStatus
#define RSSCOPE_VAL_PROBE_SELFTEST_STATUS_FAILED                            0
#define RSSCOPE_VAL_PROBE_SELFTEST_STATUS_PASSED                            1
#define RSSCOPE_VAL_PROBE_SELFTEST_STATUS_UNDEFINED                         2

// rsscope_rngProtocolWaveformSource
#define RSSCOPE_VAL_PROTOCOL_WAV_NONE                                       0
#define RSSCOPE_VAL_PROTOCOL_WAV_C1W1                                       1
#define RSSCOPE_VAL_PROTOCOL_WAV_C2W1                                       2
#define RSSCOPE_VAL_PROTOCOL_WAV_C3W1                                       3
#define RSSCOPE_VAL_PROTOCOL_WAV_C4W1                                       4
#define RSSCOPE_VAL_PROTOCOL_WAV_M1                                         5
#define RSSCOPE_VAL_PROTOCOL_WAV_M2                                         6
#define RSSCOPE_VAL_PROTOCOL_WAV_M3                                         7
#define RSSCOPE_VAL_PROTOCOL_WAV_M4                                         8
#define RSSCOPE_VAL_PROTOCOL_WAV_R1                                         9
#define RSSCOPE_VAL_PROTOCOL_WAV_R2                                         10
#define RSSCOPE_VAL_PROTOCOL_WAV_R3                                         11
#define RSSCOPE_VAL_PROTOCOL_WAV_R4                                         12
#define RSSCOPE_VAL_PROTOCOL_WAV_D0                                         13
#define RSSCOPE_VAL_PROTOCOL_WAV_D1                                         14
#define RSSCOPE_VAL_PROTOCOL_WAV_D2                                         15
#define RSSCOPE_VAL_PROTOCOL_WAV_D3                                         16
#define RSSCOPE_VAL_PROTOCOL_WAV_D4                                         17
#define RSSCOPE_VAL_PROTOCOL_WAV_D5                                         18
#define RSSCOPE_VAL_PROTOCOL_WAV_D6                                         19
#define RSSCOPE_VAL_PROTOCOL_WAV_D7                                         20
#define RSSCOPE_VAL_PROTOCOL_WAV_D8                                         21
#define RSSCOPE_VAL_PROTOCOL_WAV_D9                                         22
#define RSSCOPE_VAL_PROTOCOL_WAV_D10                                        23
#define RSSCOPE_VAL_PROTOCOL_WAV_D11                                        24
#define RSSCOPE_VAL_PROTOCOL_WAV_D12                                        25
#define RSSCOPE_VAL_PROTOCOL_WAV_D13                                        26
#define RSSCOPE_VAL_PROTOCOL_WAV_D14                                        27
#define RSSCOPE_VAL_PROTOCOL_WAV_D15                                        28
#define RSSCOPE_VAL_PROTOCOL_WAV_M5                                         29
#define RSSCOPE_VAL_PROTOCOL_WAV_M6                                         30
#define RSSCOPE_VAL_PROTOCOL_WAV_M7                                         31
#define RSSCOPE_VAL_PROTOCOL_WAV_M8                                         32

// rsscope_rngProtocolType
#define RSSCOPE_VAL_I2C                                                     0
#define RSSCOPE_VAL_SPI                                                     1
#define RSSCOPE_VAL_UART                                                    2
#define RSSCOPE_VAL_CAN                                                     3
#define RSSCOPE_VAL_LIN                                                     4
#define RSSCOPE_VAL_FLEX                                                    5
#define RSSCOPE_VAL_AUDIO                                                   6
#define RSSCOPE_VAL_MILS                                                    7
#define RSSCOPE_VAL_ARIN                                                    8
#define RSSCOPE_VAL_MDIO                                                    9
#define RSSCOPE_VAL_ETH                                                     10
#define RSSCOPE_VAL_RFFE                                                    11
#define RSSCOPE_VAL_USB                                                     12
#define RSSCOPE_VAL_CMSB                                                    13
#define RSSCOPE_VAL_EBTB                                                    14
#define RSSCOPE_VAL_SENT                                                    15
#define RSSCOPE_VAL_DPHY                                                    16
#define RSSCOPE_VAL_SWIRE                                                   17
#define RSSCOPE_VAL_MPHY                                                    18
#define RSSCOPE_VAL_CXPI                                                    19
#define RSSCOPE_VAL_USB3                                                    20
#define RSSCOPE_VAL_USBPD                                                   21
#define RSSCOPE_VAL_PCIE                                                    22
#define RSSCOPE_VAL_HBTO                                                    23
#define RSSCOPE_VAL_DDR                                                     24
#define RSSCOPE_VAL_TBTO                                                    25

// rsscope_rngProtocolTechnology
#define RSSCOPE_VAL_V38                                                     0
#define RSSCOPE_VAL_V25                                                     1
#define RSSCOPE_VAL_V20                                                     2
#define RSSCOPE_VAL_V165                                                    3
#define RSSCOPE_VAL_V15                                                     4
#define RSSCOPE_VAL_V125                                                    5
#define RSSCOPE_VAL_V09                                                     6
#define RSSCOPE_VAL_V0                                                      7
#define RSSCOPE_VAL_VM13                                                    8
#define RSSCOPE_VAL_MAN                                                     9

// rsscope_rngProtocolPolarity
#define RSSCOPE_VAL_IDLE_LOW                                                0
#define RSSCOPE_VAL_IDLE_HIGH                                               1

// rsscope_rngProtocolTriggerCondition
#define RSSCOPE_VAL_COND_NQ                                                 0
#define RSSCOPE_VAL_COND_EQ                                                 1
#define RSSCOPE_VAL_COND_LT                                                 2
#define RSSCOPE_VAL_COND_LE                                                 3
#define RSSCOPE_VAL_COND_GT                                                 4
#define RSSCOPE_VAL_COND_GE                                                 5
#define RSSCOPE_VAL_COND_IN                                                 6
#define RSSCOPE_VAL_COND_OUT                                                7
#define RSSCOPE_VAL_COND_ANY                                                8
#define RSSCOPE_VAL_CONDITION_OFF                                           9

// rsscope_rngProtocolI2CAddressType
#define RSSCOPE_VAL_I2C_BIT7                                                1
#define RSSCOPE_VAL_I2C_BIT7_RW                                             2
#define RSSCOPE_VAL_I2C_BIT10                                               3
#define RSSCOPE_VAL_I2C_ANY                                                 4

// rsscope_rngProtocolI2CTriggerType
#define RSSCOPE_VAL_I2C_TRIGGER_START                                       0
#define RSSCOPE_VAL_I2C_TRIGGER_REPSTART                                    1
#define RSSCOPE_VAL_I2C_TRIGGER_STOP                                        2
#define RSSCOPE_VAL_I2C_TRIGGER_NACK                                        3
#define RSSCOPE_VAL_I2C_TRIGGER_ADDRESS                                     4
#define RSSCOPE_VAL_I2C_TRIGGER_ADOR                                        5
#define RSSCOPE_VAL_I2C_TRIGGER_ADAT                                        6

// rsscope_rngProtocolI2CAccessBit
#define RSSCOPE_VAL_I2C_ACCESS_BIT_UNDEF                                    -1
#define RSSCOPE_VAL_I2C_ACCESS_BIT_EITHER                                   0
#define RSSCOPE_VAL_I2C_ACCESS_BIT_READ                                     1
#define RSSCOPE_VAL_I2C_ACCESS_BIT_WRITE                                    2

// rsscope_rngProtocolSPIBitOrder
#define RSSCOPE_VAL_SPI_MSBF                                                0
#define RSSCOPE_VAL_SPI_LSBF                                                1

// rsscope_rngProtocolSPIPolarity
#define RSSCOPE_VAL_ACTLOW                                                  0
#define RSSCOPE_VAL_ACTHIGH                                                 1

// rsscope_rngProtocolSPITriggerType
#define RSSCOPE_VAL_SPI_TRIGGER_SSACTIVE                                    0
#define RSSCOPE_VAL_SPI_TRIGGER_TIMEOUT                                     1
#define RSSCOPE_VAL_SPI_TRIGGER_MOSI                                        2
#define RSSCOPE_VAL_SPI_TRIGGER_MISO                                        3
#define RSSCOPE_VAL_SPI_TRIGGER_MOMI                                        4

// rsscope_rngProtocolSPIDataAlignment
#define RSSCOPE_VAL_SPI_TRIGGER_BIT                                         0
#define RSSCOPE_VAL_SPI_TRIGGER_WORD                                        1

// rsscope_rngProtocolSPIFrameStartCond
#define RSSCOPE_VAL_SPI_FRAME_START_SS                                      0
#define RSSCOPE_VAL_SPI_FRAME_START_CLK                                     1

// rsscope_rngProtocolUARTParity
#define RSSCOPE_VAL_UART_NONE                                               0
#define RSSCOPE_VAL_UART_ODD                                                1
#define RSSCOPE_VAL_UART_EVEN                                               2
#define RSSCOPE_VAL_UART_MARK                                               3
#define RSSCOPE_VAL_UART_SPACE                                              4
#define RSSCOPE_VAL_UART_DC                                                 5

// rsscope_rngProtocolUARTStopBits
#define RSSCOPE_VAL_UART_B1                                                 0
#define RSSCOPE_VAL_UART_B1_5                                               1
#define RSSCOPE_VAL_UART_B2                                                 2

// rsscope_rngProtocolUARTTriggerType
#define RSSCOPE_VAL_UART_TRIGGER_STBT                                       0
#define RSSCOPE_VAL_UART_TRIGGER_PCKS                                       1
#define RSSCOPE_VAL_UART_TRIGGER_DATA                                       2
#define RSSCOPE_VAL_UART_TRIGGER_PRER                                       3
#define RSSCOPE_VAL_UART_TRIGGER_BRKC                                       4
#define RSSCOPE_VAL_UART_TRIGGER_FERR                                       5

// rsscope_rngProtocolUARTLine
#define RSSCOPE_VAL_UART_RX                                                 0
#define RSSCOPE_VAL_UART_TX                                                 1

// rsscope_rngProtocolUARTDataPosition
#define RSSCOPE_VAL_UART_TRIGGER_EQUAL                                      0
#define RSSCOPE_VAL_UART_TRIGGER_NEQUAL                                     1
#define RSSCOPE_VAL_UART_TRIGGER_GREATER                                    2
#define RSSCOPE_VAL_UART_TRIGGER_INRANGE                                    3

// rsscope_rngProtocolLINTechnology
#define RSSCOPE_VAL_LIN_V9                                                  0
#define RSSCOPE_VAL_LIN_V6                                                  1
#define RSSCOPE_VAL_LIN_V35                                                 2
#define RSSCOPE_VAL_LIN_V25                                                 3
#define RSSCOPE_VAL_LIN_V15                                                 4
#define RSSCOPE_VAL_LIN_MAN                                                 5

// rsscope_rngProtocolLINStandard
#define RSSCOPE_VAL_LIN_STANDARD_AUTO                                       0
#define RSSCOPE_VAL_LIN_STANDARD_1X                                         1
#define RSSCOPE_VAL_LIN_STANDARD_2X                                         2
#define RSSCOPE_VAL_LIN_STANDARD_J2602                                      3

// rsscope_rngProtocolLINTrigger
#define RSSCOPE_VAL_LIN_FRAME_START                                         0
#define RSSCOPE_VAL_LIN_FRAME_ID                                            1
#define RSSCOPE_VAL_LIN_FRAME_ID_OR                                         2
#define RSSCOPE_VAL_LIN_FRMAE_ID_DATA                                       3
#define RSSCOPE_VAL_LIN_FRAME_WAKEUP                                        4
#define RSSCOPE_VAL_LIN_ERR_COND                                            5

// rsscope_rngProtocolCANLineType
#define RSSCOPE_VAL_CAN_LOW                                                 0
#define RSSCOPE_VAL_CAN_HIGH                                                1

// rsscope_rngProtocolCANTechnology
#define RSSCOPE_VAL_CAN_V25                                                 0
#define RSSCOPE_VAL_CAN_V3                                                  1
#define RSSCOPE_VAL_CAN_V2                                                  2
#define RSSCOPE_VAL_CAN_V0                                                  3
#define RSSCOPE_VAL_CAN_MAN                                                 4

// rsscope_rngProtocolCANTriggMode
#define RSSCOPE_VAL_CAN_FRAME_START                                         0
#define RSSCOPE_VAL_CAN_FRAME_TYPE                                          1
#define RSSCOPE_VAL_CAN_MSG_ID                                              2
#define RSSCOPE_VAL_CAN_MSG_ID_DATA                                         3
#define RSSCOPE_VAL_CAN_ERR_COND                                            4

// rsscope_rngProtocolCANTriggFrameType
#define RSSCOPE_VAL_CAN_FRAME_TYPE_DATA                                     0
#define RSSCOPE_VAL_CAN_FRAME_TYPE_REMOTE                                   1
#define RSSCOPE_VAL_CAN_FRAME_TYPE_ERROR                                    2
#define RSSCOPE_VAL_CAN_FRAME_TYPE_OVER_LOAD                                3
#define RSSCOPE_VAL_CAN_FRAME_TYPE_ANY                                      4

// rsscope_rngProtocolCANIDType
#define RSSCOPE_VAL_CAN_FRAME_ID_TYPE_B11                                   0
#define RSSCOPE_VAL_CAN_FRAME_ID_TYPE_B29                                   1
#define RSSCOPE_VAL_CAN_FRAME_ID_TYPE_ANY                                   2

// rsscope_rngProtocolCANEndianness
#define RSSCOPE_VAL_CAN_FRAME_BIG_EDIAN                                     0
#define RSSCOPE_VAL_CAN_FRAME_LITTE_EDIAN                                   1

// rsscope_rngDisplayStyle
#define RSSCOPE_VAL_DISPLAY_STYLE_LINE                                      0
#define RSSCOPE_VAL_DISPLAY_STYLE_MARKER                                    1

// rsscope_rngSignalStyle
#define RSSCOPE_VAL_SIGNAL_STYLE_VECTORS                                    0
#define RSSCOPE_VAL_SIGNAL_STYLE_DOTS                                       1

// rsscope_rngSignalBarPostion
#define RSSCOPE_VAL_SIGNAL_BAR_POSITION_LEFT                                0
#define RSSCOPE_VAL_SIGNAL_BAR_POSITION_RIGHT                               1

// rsscope_rngCalibrationSourceFrequency
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ10                             0
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_GHZ1                              1
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_KHZ7900                           2
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_KHZ15800                          3
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ31_25                          4
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_KHZ31600                          5
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_KHZ63200                          6
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ250MB                          7
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_GHZ1_20DB                         8
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ62                             9
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ125                            10
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ250                            11
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ500                            12
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_KHZ505500                         13
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ31_25R                         14
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ1R                             15
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ31R                            16
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ498S                           17
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ1257_2S                        18
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ2491S                          19
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ4060S                          20
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ4350S                          21
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ4810S                          22
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ4991S                          23
#define RSSCOPE_VAL_CALIBRATION_FREQUENCY_MHZ5940S                          24

// rsscope_rngCalibrationOperatingMode
#define RSSCOPE_VAL_CALIBRATION_OPERATING_MODE_SKEW                         0
#define RSSCOPE_VAL_CALIBRATION_OPERATING_MODE_GAIN                         1

// rsscope_rngCalibrationDestination
#define RSSCOPE_VAL_CALIBRATION_DESTINATION_INTERNAL                        0
#define RSSCOPE_VAL_CALIBRATION_DESTINATION_EXTERNAL                        1

// rsscope_rngSelftestStatus
#define RSSCOPE_VAL_SELFTEST_FAILED                                         0
#define RSSCOPE_VAL_SELFTEST_PASSED                                         1
#define RSSCOPE_VAL_SELFTEST_UNDEFINED                                      2

// rsscope_rngHardcopyDevice
#define RSSCOPE_VAL_HARDCOPY_DEVICE_MEM                                     0
#define RSSCOPE_VAL_HARDCOPY_DEVICE_PRINT                                   1
#define RSSCOPE_VAL_HARDCOPY_DEVICE_CLIPBOARD                               2

// rsscope_rngHardcopyDeviceLang
#define RSSCOPE_VAL_HARDCOPY_DEVICE_LANG_PNG                                0
#define RSSCOPE_VAL_HARDCOPY_DEVICE_LANG_JPG                                1
#define RSSCOPE_VAL_HARDCOPY_DEVICE_LANG_BMP                                2
#define RSSCOPE_VAL_HARDCOPY_DEVICE_LANG_TIFF                               3
#define RSSCOPE_VAL_HARDCOPY_DEVICE_LANG_PDF                                4

// rsscope_rngHardcopyDeviceOrientation
#define RSSCOPE_VAL_HARDCOPY_ORIENTATION_PORTRAIT                           0
#define RSSCOPE_VAL_HARDCOPY_ORIENTATION_LANDSCAPE                          1

// rsscope_rngWaveformParameterXY
#define RSSCOPE_VAL_WAV_TNTR1                                               183
#define RSSCOPE_VAL_WAV_TNTR2                                               184
#define RSSCOPE_VAL_WAV_DNTR1                                               185
#define RSSCOPE_VAL_WAV_DNTR2                                               186
#define RSSCOPE_VAL_WAV_DDNTR1                                              187
#define RSSCOPE_VAL_WAV_DDNTR2                                              188
#define RSSCOPE_VAL_WAV_PNTR1                                               189
#define RSSCOPE_VAL_WAV_PNTR2                                               190
#define RSSCOPE_VAL_WAV_RNOT1                                               191
#define RSSCOPE_VAL_WAV_RNOT2                                               192
#define RSSCOPE_VAL_WAV_PJDT1                                               207
#define RSSCOPE_VAL_WAV_PJDT2                                               208
#define RSSCOPE_VAL_WAV_PNDT1                                               215
#define RSSCOPE_VAL_WAV_PNDT2                                               216

// rsscope_rngAttUnits
#define RSSCOPE_VAL_ATT_V                                                   0
#define RSSCOPE_VAL_ATT_A                                                   1
#define RSSCOPE_VAL_ATT_W                                                   2

// rsscope_rngEATScale
#define RSSCOPE_VAL_EAT_LIN                                                 0
#define RSSCOPE_VAL_EAT_LOG                                                 1

// rsscope_rngIntExt
#define RSSCOPE_VAL_INT                                                     0
#define RSSCOPE_VAL_EXT                                                     1

// rsscope_rngDSPTriggCoupling
#define RSSCOPE_VAL_DSP_TRIGGER_OFF                                         0
#define RSSCOPE_VAL_DSP_TRIGGER_RF_REJECT                                   1

// rsscope_rngEnvelopeType
#define RSSCOPE_VAL_ENVELOPE_MIN                                            0
#define RSSCOPE_VAL_ENVELOPE_MAX                                            1
#define RSSCOPE_VAL_ENVELOPE_BOTH                                           2

// rsscope_rngPatternFormat
#define RSSCOPE_VAL_PATTERN_BIN                                             0
#define RSSCOPE_VAL_PATTERN_OCT                                             1
#define RSSCOPE_VAL_PATTERN_DEC                                             2
#define RSSCOPE_VAL_PATTERN_HEX                                             3
#define RSSCOPE_VAL_PATTERN_ASCII                                           4
#define RSSCOPE_VAL_PATTERN_STRING                                          5

// rsscope_rngWaveformExportScope
#define RSSCOPE_VAL_WAV_EXPORT_COMPLETE                                     0
#define RSSCOPE_VAL_WAV_EXPORT_ZOOM                                         1
#define RSSCOPE_VAL_WAV_EXPORT_CURSOR                                       2
#define RSSCOPE_VAL_WAV_EXPORT_GATE                                         3
#define RSSCOPE_VAL_WAV_EXPORT_MANUAL                                       4

// rsscope_rngCursor
#define RSSCOPE_VAL_CURSOR_1                                                1
#define RSSCOPE_VAL_CURSOR_2                                                2
#define RSSCOPE_VAL_CURSOR_3                                                3
#define RSSCOPE_VAL_CURSOR_4                                                4

// rsscope_rngMeasurement
#define RSSCOPE_VAL_MEAS1                                                   1
#define RSSCOPE_VAL_MEAS2                                                   2
#define RSSCOPE_VAL_MEAS3                                                   3
#define RSSCOPE_VAL_MEAS4                                                   4
#define RSSCOPE_VAL_MEAS5                                                   5
#define RSSCOPE_VAL_MEAS6                                                   6
#define RSSCOPE_VAL_MEAS7                                                   7
#define RSSCOPE_VAL_MEAS8                                                   8

// rsscope_rngProbePredefinedCurrent
#define RSSCOPE_VAL_PROBE_FREE                                              0
#define RSSCOPE_VAL_PROBE_ZC10                                              1
#define RSSCOPE_VAL_PROBE_ZC20                                              2
#define RSSCOPE_VAL_PROBE_ZD01_100                                          3
#define RSSCOPE_VAL_PROBE_ZD01_1000                                         4
#define RSSCOPE_VAL_PROBE_ZC30                                              5
#define RSSCOPE_VAL_PROBE_ZZ80                                              6
#define RSSCOPE_VAL_PROBE_ZS10L                                             7
#define RSSCOPE_VAL_PROBE_ZD02                                              8
#define RSSCOPE_VAL_PROBE_ZD08                                              9
#define RSSCOPE_VAL_PROBE_ZC02100                                           10
#define RSSCOPE_VAL_PROBE_ZC021000                                          11
#define RSSCOPE_VAL_PROBE_ZC03                                              12
#define RSSCOPE_VAL_PROBE_ZD002A10                                          13
#define RSSCOPE_VAL_PROBE_ZD002A100                                         14
#define RSSCOPE_VAL_PROBE_ZD003A20                                          15
#define RSSCOPE_VAL_PROBE_ZD003A200                                         16
#define RSSCOPE_VAL_PROBE_ZC3101                                            17
#define RSSCOPE_VAL_PROBE_ZC311                                             18
#define RSSCOPE_VAL_PROBE_ZC3110                                            19

// rsscope_rngAmpRefLevSelection
#define RSSCOPE_VAL_AMPT_LEVEL_LOW                                          0
#define RSSCOPE_VAL_AMPT_LEVEL_MIDD                                         1
#define RSSCOPE_VAL_AMPT_LEVEL_UPP                                          2

// rsscope_rngAmplitudeDelayDirection
#define RSSCOPE_VAL_AMPT_DIRECTION_FRFI                                     0
#define RSSCOPE_VAL_AMPT_DIRECTION_FRLA                                     1

// rsscope_rngI2CPositionCondition
#define RSSCOPE_VAL_I2C_COND_ANY                                            0
#define RSSCOPE_VAL_I2C_COND_EQ                                             1
#define RSSCOPE_VAL_I2C_COND_GE                                             2
#define RSSCOPE_VAL_I2C_COND_RAN                                            3

// rsscope_rngSPIPositionCondition
#define RSSCOPE_VAL_SPI_COND_ANY                                            0
#define RSSCOPE_VAL_SPI_COND_EQ                                             1
#define RSSCOPE_VAL_SPI_COND_GE                                             3
#define RSSCOPE_VAL_SPI_COND_RAN                                            4

// rsscope_rngProtocolLINTriggerDataCondition
#define RSSCOPE_VAL_COND_LIN_DATA_EQ                                        0
#define RSSCOPE_VAL_COND_LIN_DATA_GT                                        1

// rsscope_rngLINDataTransfer
#define RSSCOPE_VAL_LIN_TRANSFER_BENDIAN                                    0
#define RSSCOPE_VAL_LIN_TRANSFER_LENDIAN                                    1

// rsscope_rngFlexRaySrcType
#define RSSCOPE_VAL_FLEXRAY_TYPE_SINGLE                                     0
#define RSSCOPE_VAL_FLEXRAY_TYPE_DIFF                                       1
#define RSSCOPE_VAL_FLEXRAY_TYPE_LOGIC                                      2

// rsscope_rngFlexRayPolarity
#define RSSCOPE_VAL_FLEXRAY_POLARITY_PLUS                                   0
#define RSSCOPE_VAL_FLEXRAY_POLARITY_MINUS                                  1

// rsscope_rngFlexRaySinglePreset
#define RSSCOPE_VAL_FLEXRAY_SINGLE_2500_150                                 0
#define RSSCOPE_VAL_FLEXRAY_SINGLE_2500_200                                 1
#define RSSCOPE_VAL_FLEXRAY_SINGLE_2500_250                                 2
#define RSSCOPE_VAL_FLEXRAY_SINGLE_2500_300                                 3
#define RSSCOPE_VAL_FLEXRAY_SINGLE_MAN                                      4

// rsscope_rngFlexRayDifferentialPreset
#define RSSCOPE_VAL_FLEXRAY_DIFF_MV150                                      0
#define RSSCOPE_VAL_FLEXRAY_DIFF_MV200                                      1
#define RSSCOPE_VAL_FLEXRAY_DIFF_MV250                                      2
#define RSSCOPE_VAL_FLEXRAY_DIFF_MV300                                      3
#define RSSCOPE_VAL_FLEXRAY_DIFF_MAN                                        4

// rsscope_rngFlexRayLogicPreset
#define RSSCOPE_VAL_FLEXRAY_LOGIC_V25                                       0
#define RSSCOPE_VAL_FLEXRAY_LOGIC_V165                                      1
#define RSSCOPE_VAL_FLEXRAY_LOGIC_V125                                      2
#define RSSCOPE_VAL_FLEXRAY_LOGIC_V09                                       3
#define RSSCOPE_VAL_FLEXRAY_LOGIC_V0                                        4
#define RSSCOPE_VAL_FLEXRAY_LOGIC_MAN                                       5

// rsscope_rngFlexRayBitRate
#define RSSCOPE_VAL_FLEXRAY_BITRATE_M10                                     0
#define RSSCOPE_VAL_FLEXRAY_BITRATE_M5                                      1
#define RSSCOPE_VAL_FLEXRAY_BITRATE_M25                                     2

// rsscope_rngFlexRayChannel
#define RSSCOPE_VAL_FLEXRAY_CHA                                             0
#define RSSCOPE_VAL_FLEXRAY_CHB                                             1

// rsscope_rngFlexRayTriggerType
#define RSSCOPE_VAL_FLEXRAY_FRAME_START                                     0
#define RSSCOPE_VAL_FLEXRAY_ID_DATA                                         1
#define RSSCOPE_VAL_FLEXRAY_SYMBOL                                          2
#define RSSCOPE_VAL_FLEXRAY_ERR_COND                                        3

// rsscope_rngFlexRayIndicatorBits
#define RSSCOPE_VAL_FLEXRAY_BITS_ZERO                                       0
#define RSSCOPE_VAL_FLEXRAY_BITS_ONE                                        1
#define RSSCOPE_VAL_FLEXRAY_BITS_DC                                         2

// rsscope_rngFlexRayCondition
#define RSSCOPE_VAL_COND_OFF                                                8

// rsscope_rngFlexRaySymbol
#define RSSCOPE_VAL_FLEXRAY_SYMBOL_CASMTS                                   0
#define RSSCOPE_VAL_FLEXRAY_SYMBOL_WAKEUP                                   1

// rsscope_rngFlexRayFrameStatus
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_OK                                  0
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_FSS                                 1
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_BSS                                 2
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_FES                                 3
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_IND                                 4
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_HCRC                                5
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_CRC                                 6
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_LENER                               7
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_WAK                                 8
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_MTS                                 9
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_INS                                 10
#define RSSCOPE_VAL_FLEXRAY_FRAME_STATE_HCFC                                11

// rsscope_rngFlexRayFrameType
#define RSSCOPE_VAL_FLEXRAY_FRAME_TYPE_UNKNOWN                              0
#define RSSCOPE_VAL_FLEXRAY_FRAME_TYPE_STATIC                               1
#define RSSCOPE_VAL_FLEXRAY_FRAME_TYPE_DYNAMIC                              2
#define RSSCOPE_VAL_FLEXRAY_FRAME_TYPE_WAKE                                 3
#define RSSCOPE_VAL_FLEXRAY_FRAME_TYPE_SYMBOL                               4

// rsscope_rngFlexRayFieldStatus
#define RSSCOPE_VAL_CAN_FRAME_STATE_OK                                      0
#define RSSCOPE_VAL_CAN_FRAME_STATE_UVAL                                    1
#define RSSCOPE_VAL_CAN_FRAME_STATE_INS                                     2

// rsscope_rngMSODisplayRepresentation
#define RSSCOPE_VAL_MSO_REPRESENTATION_COMBINED                             0
#define RSSCOPE_VAL_MSO_REPRESENTATION_ANALOG                               1

// rsscope_rngMSOClockSource
#define RSSCOPE_VAL_MSO_D0                                                  0
#define RSSCOPE_VAL_MSO_D1                                                  1
#define RSSCOPE_VAL_MSO_D2                                                  2
#define RSSCOPE_VAL_MSO_D3                                                  3
#define RSSCOPE_VAL_MSO_D4                                                  4
#define RSSCOPE_VAL_MSO_D5                                                  5
#define RSSCOPE_VAL_MSO_D6                                                  6
#define RSSCOPE_VAL_MSO_D7                                                  7
#define RSSCOPE_VAL_MSO_D8                                                  8
#define RSSCOPE_VAL_MSO_D9                                                  9
#define RSSCOPE_VAL_MSO_D10                                                 10
#define RSSCOPE_VAL_MSO_D11                                                 11
#define RSSCOPE_VAL_MSO_D12                                                 12
#define RSSCOPE_VAL_MSO_D13                                                 13
#define RSSCOPE_VAL_MSO_D14                                                 14
#define RSSCOPE_VAL_MSO_D15                                                 15

// rsscope_rngMSOHysteresis
#define RSSCOPE_VAL_MSO_HYSTERESIS_MAXIMUM                                  0
#define RSSCOPE_VAL_MSO_HYSTERESIS_ROBUST                                   1
#define RSSCOPE_VAL_MSO_HYSTERESIS_NORMAL                                   2

// rsscope_rngMSOTriggerType
#define RSSCOPE_VAL_MSO_EDGE_TRIGGER                                        0
#define RSSCOPE_VAL_MSO_WIDTH_TRIGGER                                       1
#define RSSCOPE_VAL_MSO_TIMEOUT_TRIGGER                                     2
#define RSSCOPE_VAL_MSO_DATA_TO_CLOCK_TRIGGER                               3
#define RSSCOPE_VAL_MSO_STATE_TRIGGER                                       4
#define RSSCOPE_VAL_MSO_PATTERN_TRIGGER                                     5
#define RSSCOPE_VAL_MSO_SERIAL_PATTERN_TRIGGER                              6
#define RSSCOPE_VAL_MSO_DATA_TO_CLOCK_SETUP_HOLD_TRIGGER                    7

// rsscope_rngMSOTriggerSource
#define RSSCOPE_VAL_MSO_DALL                                                16
#define RSSCOPE_VAL_MSO_MSOB1                                               17
#define RSSCOPE_VAL_MSO_MSOB2                                               18
#define RSSCOPE_VAL_MSO_MSOB3                                               19
#define RSSCOPE_VAL_MSO_MSOB4                                               20

// rsscope_rngMSOTimeoutCondition
#define RSSCOPE_VAL_MSO_TIMEOUT_LOW                                         0
#define RSSCOPE_VAL_MSO_TIMEOUT_HIGH                                        1
#define RSSCOPE_VAL_MSO_TIMEOUT_EITHER                                      2

// rsscope_rngMSOTriggerChannelState
#define RSSCOPE_VAL_MSO_LOW                                                 0
#define RSSCOPE_VAL_MSO_HIGH                                                1
#define RSSCOPE_VAL_MSO_DC                                                  2

// rsscope_rngMSOPatternTimeoutMode
#define RSSCOPE_VAL_PATTERN_TIMEOUT_EITHER                                  2

// rsscope_rngProtocolI2CRWBit
#define RSSCOPE_VAL_PROTOCOL_I2C_RW_BIT_SEPARATE                            0
#define RSSCOPE_VAL_PROTOCOL_I2C_RW_BIT_IN_ADDRESS                          1

// rsscope_rngProtocolLINTriggerCRCStandard
#define RSSCOPE_VAL_LIN_CRC_STANDARD_V1X                                    0
#define RSSCOPE_VAL_LIN_CRC_STANDARD_V2X                                    1
#define RSSCOPE_VAL_LIN_CRC_STANDARD_J2602                                  2
#define RSSCOPE_VAL_LIN_CRC_STANDARD_AUTO                                   3

// rsscope_rngNFCTechnology
#define RSSCOPE_VAL_NFC_A                                                   0
#define RSSCOPE_VAL_NFC_B                                                   1
#define RSSCOPE_VAL_NFC_F                                                   2

// rsscope_rngNFCTriggerBitRate
#define RSSCOPE_VAL_NFC_BIT_RATE_106                                        0
#define RSSCOPE_VAL_NFC_BIT_RATE_212                                        1
#define RSSCOPE_VAL_NFC_BIT_RATE_424                                        2

// rsscope_rngNFCTriggerEvent
#define RSSCOPE_VAL_NFC_EVENT_ALL                                           0
#define RSSCOPE_VAL_NFC_EVENT_SENS                                          1
#define RSSCOPE_VAL_NFC_EVENT_ALLB                                          2
#define RSSCOPE_VAL_NFC_EVENT_SENSB                                         3
#define RSSCOPE_VAL_NFC_EVENT_SOS48                                         4
#define RSSCOPE_VAL_NFC_EVENT_SOS96                                         5

// rsscope_rngMathResetMode
#define RSSCOPE_VAL_MATH_RESET_NONE                                         0
#define RSSCOPE_VAL_MATH_RESET_TIME                                         1
#define RSSCOPE_VAL_MATH_RESET_WFMS                                         2

// rsscope_rngIQInputType
#define RSSCOPE_VAL_IQ_INPUT_TYPE_REAL                                      0
#define RSSCOPE_VAL_IQ_INPUT_TYPE_COMPLEX                                   1

// rsscope_rngIQInputMode
#define RSSCOPE_VAL_IQ_INPUT_MODE_BASEBAND                                  0
#define RSSCOPE_VAL_IQ_INPUT_TYPE_RFIF                                      1

// rsscope_rngIQRealSideband
#define RSSCOPE_VAL_IQ_REAL_SIDEBAND_NORMAL                                 1
#define RSSCOPE_VAL_IQ_REAL_SIDEBAND_INVERSE                                0

// rsscope_rngIQComplexSideband
#define RSSCOPE_VAL_IQ_COMPLEX_SIDEBAND_NORMAL_UPP                          0
#define RSSCOPE_VAL_IQ_COMPLEX_SIDEBAND_NORMAL_LOW                          1
#define RSSCOPE_VAL_IQ_COMPLEX_SIDEBAND_INVERSE_UPP                         2
#define RSSCOPE_VAL_IQ_COMPLEX_SIDEBAND_INVERSE_LOW                         3

// rsscope_rngConfigureTVTriggerStandard
#define RSSCOPE_VAL_TV_STANDARD_CUSTOM                                      0
#define RSSCOPE_VAL_TV_STANDARD_PAL                                         1
#define RSSCOPE_VAL_TV_STANDARD_PALM                                        2
#define RSSCOPE_VAL_TV_STANDARD_NTSC                                        3
#define RSSCOPE_VAL_TV_STANDARD_SEC                                         4
#define RSSCOPE_VAL_TV_STANDARD_P480L60HZ                                   5
#define RSSCOPE_VAL_TV_STANDARD_P720L30HZ                                   6
#define RSSCOPE_VAL_TV_STANDARD_P720L50HZ                                   7
#define RSSCOPE_VAL_TV_STANDARD_P720L60HZ                                   8
#define RSSCOPE_VAL_TV_STANDARD_I1080L50HZ                                  9
#define RSSCOPE_VAL_TV_STANDARD_I1080L60HZ                                  10
#define RSSCOPE_VAL_TV_STANDARD_P1080L24HZ                                  11
#define RSSCOPE_VAL_TV_STANDARD_P1080L24HZSF                                12
#define RSSCOPE_VAL_TV_STANDARD_P1080L25HZ                                  13
#define RSSCOPE_VAL_TV_STANDARD_P1080L30HZ                                  14
#define RSSCOPE_VAL_TV_STANDARD_P1080L50HZ                                  15
#define RSSCOPE_VAL_TV_STANDARD_P1080L60HZ                                  16

// rsscope_rngTVTriggerMode
#define RSSCOPE_VAL_TV_MODE_ALL                                             0
#define RSSCOPE_VAL_TV_MODE_ODD                                             1
#define RSSCOPE_VAL_TV_MODE_EVEN                                            2
#define RSSCOPE_VAL_TV_MODE_ALIN                                            3
#define RSSCOPE_VAL_TV_MODE_LINE                                            4

// rsscope_rngTVTriggerField
#define RSSCOPE_VAL_TV_FIELD_ODD                                            0
#define RSSCOPE_VAL_TV_FIELD_EVEN                                           1

// rsscope_rngTVTriggerPulseType
#define RSSCOPE_VAL_TV_PULSE_BI_LEVEL                                       0
#define RSSCOPE_VAL_TV_PULSE_TRI_LEVEL                                      1

// rsscope_rngTVScanMode
#define RSSCOPE_VAL_TV_SCAN_MODE_INTERLACED                                 0
#define RSSCOPE_VAL_TV_SCAN_MODE_PROGRESSIVE                                1
#define RSSCOPE_VAL_TV_SCAN_MODE_SEGMENTED                                  2

// rsscope_rngResultBoxPosition
#define RSSCOPE_VAL_RESULT_BOX_POSITION_PREVIEW                             0
#define RSSCOPE_VAL_RESULT_BOX_POSITION_FLOATING                            1

// rsscope_rngAudioVariant
#define RSSCOPE_VAL_AUDIO_VARIANT_I2S                                       0
#define RSSCOPE_VAL_AUDIO_VARIANT_LJ                                        1
#define RSSCOPE_VAL_AUDIO_VARIANT_RJ                                        2
#define RSSCOPE_VAL_AUDIO_VARIANT_TDM                                       3

// rsscope_rngAudioClockPolarity
#define RSSCOPE_VAL_FALLING                                                 0
#define RSSCOPE_VAL_RISING                                                  1

// rsscope_rngAudioWSPolarity
#define RSSCOPE_VAL_INVERT                                                  1

// rsscope_rngAudioChannelOrder
#define RSSCOPE_VAL_AUDIO_ORDER_LEFT                                        0
#define RSSCOPE_VAL_AUDIO_ORDER_RIGHT                                       1

// rsscope_rngProtocolAudioBitOrder
#define RSSCOPE_VAL_AUDIO_MSBF                                              0
#define RSSCOPE_VAL_AUDIO_LSBF                                              1

// rsscope_rngAudioTriggerType
#define RSSCOPE_VAL_AUDIO_TRIGGER_DATA                                      0
#define RSSCOPE_VAL_AUDIO_TRIGGER_WINDOW                                    1
#define RSSCOPE_VAL_AUDIO_TRIGGER_COND                                      2
#define RSSCOPE_VAL_AUDIO_TRIGGER_WSEL                                      3
#define RSSCOPE_VAL_AUDIO_TRIGGER_ECON                                      4

// rsscope_rngAudioChannel
#define RSSCOPE_VAL_AUDIO_CHANNEL_ANY                                       0
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC1                                     1
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC2                                     2
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC3                                     3
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC4                                     4
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC5                                     5
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC6                                     6
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC7                                     7
#define RSSCOPE_VAL_AUDIO_CHANNEL_TDMC8                                     8
#define RSSCOPE_VAL_AUDIO_CHANNEL_LEFT                                      9
#define RSSCOPE_VAL_AUDIO_CHANNEL_RIGHT                                     10

// rsscope_rngProtocolDataFormat
#define RSSCOPE_VAL_DATA_FORMAT_HEX                                         0
#define RSSCOPE_VAL_DATA_FORMAT_OCT                                         1
#define RSSCOPE_VAL_DATA_FORMAT_BIN                                         2
#define RSSCOPE_VAL_DATA_FORMAT_ASC                                         3
#define RSSCOPE_VAL_DATA_FORMAT_SIGN                                        4
#define RSSCOPE_VAL_DATA_FORMAT_USIG                                        5

// rsscope_rngLongTermExportResult
#define RSSCOPE_VAL_MEASUREMENT_1                                           1
#define RSSCOPE_VAL_MEASUREMENT_2                                           2
#define RSSCOPE_VAL_MEASUREMENT_3                                           3
#define RSSCOPE_VAL_MEASUREMENT_4                                           4
#define RSSCOPE_VAL_MEASUREMENT_5                                           5
#define RSSCOPE_VAL_MEASUREMENT_6                                           6
#define RSSCOPE_VAL_MEASUREMENT_7                                           7
#define RSSCOPE_VAL_MEASUREMENT_8                                           8

// rsscope_rngLongTermExportType
#define RSSCOPE_VAL_LONG_TERM_EXPORT_TYPE_LONG_TERM                         0
#define RSSCOPE_VAL_LONG_TERM_EXPORT_TYPE_HISTOGRAM                         1
#define RSSCOPE_VAL_LONG_TERM_EXPORT_TYPE_LONG_TRAC                         4

// rsscope_rngCursorSearch
#define RSSCOPE_VAL_CURSOR_SEARCH_MAX                                       0
#define RSSCOPE_VAL_CURSOR_SEARCH_MAX_LEFT                                  1
#define RSSCOPE_VAL_CURSOR_SEARCH_MAX_RIGHT                                 2
#define RSSCOPE_VAL_CURSOR_SEARCH_MAX_NEXT                                  3

// rsscope_rngQuestionableRegister
#define RSSCOPE_VAL_QREGISTER_CHANNEL_OVERLOAD                              0
#define RSSCOPE_VAL_QREGISTER_TEMPERATURE                                   1
#define RSSCOPE_VAL_QREGISTER_LIMIT                                         2
#define RSSCOPE_VAL_QREGISTER_MARGIN                                        3
#define RSSCOPE_VAL_QREGISTER_MASK                                          4
#define RSSCOPE_VAL_QREGISTER_ADCS                                          5
#define RSSCOPE_VAL_QREGISTER_LAMPLITUDE                                    6
#define RSSCOPE_VAL_QREGISTER_PLL                                           7
#define RSSCOPE_VAL_QREGISTER_ZVC                                           8
#define RSSCOPE_VAL_QREGISTER_DEEMBEDDING                                   9
#define RSSCOPE_VAL_QREGISTER_FREQUENCY                                     10
#define RSSCOPE_VAL_QREGISTER_EFRONTEND                                     11

// rsscope_rngRegisterPart
#define RSSCOPE_VAL_REGISTER_PART_CONDITION                                 0
#define RSSCOPE_VAL_REGISTER_PART_ENABLE                                    1
#define RSSCOPE_VAL_REGISTER_PART_EVENT                                     2
#define RSSCOPE_VAL_REGISTER_PART_NTRANSITION                               3
#define RSSCOPE_VAL_REGISTER_PART_PTRANSITION                               4

// rsscope_rngStatisticsType
#define RSSCOPE_VAL_STATISTIC_TYPE_ACTUAL                                   0
#define RSSCOPE_VAL_STATISTIC_TYPE_AVERAGE                                  1
#define RSSCOPE_VAL_STATISTIC_TYPE_EVENT_COUNT                              2
#define RSSCOPE_VAL_STATISTIC_NEGATIVE_PEAK                                 3
#define RSSCOPE_VAL_STATISTIC_POSITIVE_PEAK                                 4
#define RSSCOPE_VAL_STATISTIC_RMS                                           5
#define RSSCOPE_VAL_STATISTIC_STANDARD_DEVIATION                            6
#define RSSCOPE_VAL_STATISTIC_WFM_COUNT                                     7
#define RSSCOPE_VAL_STATISTIC_RELIABILITY                                   8

// rsscope_rngRefLevelMeas
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_ABOVE_LOW                          0
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_BENEATH_LOW                        1
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_LOW                                2
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_MIDDLE                             3
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_UPPER                              4
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_SIGNAL_HIGH                        5
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_SIGNAL_LOW                         6
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_BENEATH_HIGH                       7
#define RSSCOPE_VAL_REFERENCE_LEVEL_MEAS_ABOVE_HIGH                         8

// rsscope_rngSearchTrigger
#define RSSCOPE_VAL_SEARCH_TRIGGER_EDGE                                     0
#define RSSCOPE_VAL_SEARCH_TRIGGER_WIDTH                                    1
#define RSSCOPE_VAL_SEARCH_TRIGGER_RUNT                                     2
#define RSSCOPE_VAL_SEARCH_TRIGGER_GLITCH                                   3
#define RSSCOPE_VAL_SEARCH_TRIGGER_WINDOW                                   4
#define RSSCOPE_VAL_SEARCH_TRIGGER_TIMEOUT                                  5
#define RSSCOPE_VAL_SEARCH_TRIGGER_INTERNAL                                 6
#define RSSCOPE_VAL_SEARCH_TRIGGER_SLEWRATE                                 7
#define RSSCOPE_VAL_SEARCH_TRIGGER_DATA2CLOCK                               8
#define RSSCOPE_VAL_SEARCH_TRIGGER_PATTERN                                  9
#define RSSCOPE_VAL_SEARCH_TRIGGER_S10                                      10
#define RSSCOPE_VAL_SEARCH_TRIGGER_S11                                      11
#define RSSCOPE_VAL_SEARCH_TRIGGER_STATE                                    12

// rsscope_rngJitterMainMeasurement
#define RSSCOPE_VAL_MEAS_JITTER_CCJ                                         0
#define RSSCOPE_VAL_MEAS_JITTER_NCJ                                         1
#define RSSCOPE_VAL_MEAS_JITTER_CCW                                         2
#define RSSCOPE_VAL_MEAS_JITTER_CCD                                         3
#define RSSCOPE_VAL_MEAS_JITTER_TIE                                         4
#define RSSCOPE_VAL_MEAS_JITTER_UINT                                        5
#define RSSCOPE_VAL_MEAS_JITTER_DRAT                                        6
#define RSSCOPE_VAL_MEAS_JITTER_SKWD                                        7
#define RSSCOPE_VAL_MEAS_JITTER_SKWP                                        8

// rsscope_rngJitterClockCycleBegin
#define RSSCOPE_VAL_FIRST                                                   3

// rsscope_rngJitterDataClockMode
#define RSSCOPE_VAL_JITTER_CLOCK_MODE_SIGNAL                                0
#define RSSCOPE_VAL_JITTER_CLOCK_MODE_SW1                                   1
#define RSSCOPE_VAL_JITTER_CLOCK_MODE_SW2                                   2
#define RSSCOPE_VAL_JITTER_CLOCK_MODE_HW                                    3

// rsscope_rngJitterDelayRelativePolarity
#define RSSCOPE_VAL_MATCHING                                                0
#define RSSCOPE_VAL_INVERSE                                                 1

// rsscope_rngCDRSoftwareInitialPhaseSync
#define RSSCOPE_VAL_CDR_INITIAL_PHASE_SYNC_SAMPLE                           0
#define RSSCOPE_VAL_CDR_INITIAL_PHASE_SYNC_DATA_EDGE                        1

// rsscope_rngCDRSelectedResults
#define RSSCOPE_VAL_CDR_SELECTED_RESULTS_ALL                                0
#define RSSCOPE_VAL_CDR_SELECTED_RESULTS_AI_SYNC                            1

// rsscope_rngCDRSoftwareAlgorithm
#define RSSCOPE_VAL_CDR_ALGORITHM_PLL                                       0
#define RSSCOPE_VAL_CDR_ALGORITHM_CFR                                       1
#define RSSCOPE_VAL_CDR_ALGORITHM_FF                                        2
#define RSSCOPE_VAL_CDR_ALGORITHM_PLLS                                      3

// rsscope_rngCDRPLLOrder
#define RSSCOPE_VAL_CDR_PLL_ORDER_FIRST                                     0
#define RSSCOPE_VAL_CDR_PLL_ORDER_SECOND                                    1

// RsScope_rngMaskTestEyeShape
#define RSSCOPE_VAL_MASK_TEST_EYE_SHAPE_SQUARE                              0
#define RSSCOPE_VAL_MASK_TEST_EYE_SHAPE_DIAMOND                             1
#define RSSCOPE_VAL_MASK_TEST_EYE_SHAPE_HEXAGON                             2
#define RSSCOPE_VAL_MASK_TEST_EYE_SHAPE_OCTAGON                             3

// RsScope_rngMaskTestResultState
#define RSSCOPE_VAL_STATE_FINISHED                                          0
#define RSSCOPE_VAL_STATE_RUNNING                                           1

// RsScope_rngMaskTestResult
#define RSSCOPE_VAL_RESULT_FAIL                                             0
#define RSSCOPE_VAL_RESULT_PASS                                             1

// RsScope_rngMaskTestEventAction
#define RSSCOPE_VAL_MASK_TEST_ACTION_NOACTION                               0
#define RSSCOPE_VAL_MASK_TEST_ACTION_SUCCESS                                1
#define RSSCOPE_VAL_MASK_TEST_ACTION_VIOLATION                              2

// RsScope_rngMaskTestDefinitionType
#define RSSCOPE_VAL_MASK_TEST_TYPE_USER                                     0
#define RSSCOPE_VAL_MASK_TEST_TYPE_WAVEFORM                                 1
#define RSSCOPE_VAL_MASK_TEST_TYPE_EYE                                      2
#define RSSCOPE_VAL_MASK_TEST_TYPE_PROT                                     3

// RsScope_rngMaskTestFailCondition
#define RSSCOPE_VAL_MASK_SAMPLES                                            0
#define RSSCOPE_VAL_MASK_ACQUISITIONS                                       1

// RsScope_rngMaskSegmentRegion
#define RSSCOPE_VAL_MASK_TEST_UPPER                                         0
#define RSSCOPE_VAL_MASK_TEST_LOWER                                         1
#define RSSCOPE_VAL_MASK_TEST_INNER                                         2

// RsScope_rngMaskWaveformUsedReference
#define RSSCOPE_VAL_MASK_TEST_REFERENCE1                                    1
#define RSSCOPE_VAL_MASK_TEST_REFERENCE2                                    2
#define RSSCOPE_VAL_MASK_TEST_REFERENCE3                                    3
#define RSSCOPE_VAL_MASK_TEST_REFERENCE4                                    4

// RsScope_rngI2CFrameStatus
#define RSSCOPE_VAL_I2C_FRAME_STATE_OK                                      0
#define RSSCOPE_VAL_I2C_FRAME_STATE_INCOMPLETE                              1
#define RSSCOPE_VAL_I2C_FRAME_STATE_UNEXPSTOP                               2
#define RSSCOPE_VAL_I2C_FRAME_STATE_INSUFFICIENT                            3
#define RSSCOPE_VAL_I2C_FRAME_STATE_ADDIFFERENT                             4
#define RSSCOPE_VAL_I2C_FRAME_STATE_UNKN                                    5

// RsScope_rngI2CFrameAddressType
#define RSSCOPE_VAL_I2C_AUTO                                                0

// RsScope_rngI2CFrameRWBit
#define RSSCOPE_VAL_I2C_ACCESS_BIT_UNDEFINED                                3

// RsScope_rngI2CFrameAckBit
#define RSSCOPE_VAL_I2C_EITHER                                              0
#define RSSCOPE_VAL_I2C_ACK                                                 1
#define RSSCOPE_VAL_I2C_NACK                                                2
#define RSSCOPE_VAL_I2C_INCOMPLETE                                          3

// RsScope_rngSPIFrameStatus
#define RSSCOPE_VAL_SPI_FRAME_STATE_OK                                      0
#define RSSCOPE_VAL_SPI_FRAME_STATE_INCOMPLETE_FIRST                        1
#define RSSCOPE_VAL_SPI_FRAME_STATE_INCOMPLETE_LAST                         2
#define RSSCOPE_VAL_SPI_FRAME_STATE_INSUFFICIENT                            3
#define RSSCOPE_VAL_SPI_FRAME_STATE_EMPTY                                   4

// RsScope_rngUARTWordStatus
#define RSSCOPE_VAL_UART_OK                                                 0
#define RSSCOPE_VAL_UART_FRSTART                                            1
#define RSSCOPE_VAL_UART_FREND                                              2
#define RSSCOPE_VAL_UART_FRME                                               3
#define RSSCOPE_VAL_UART_STERROR                                            4
#define RSSCOPE_VAL_UART_SPERROR                                            5
#define RSSCOPE_VAL_UART_PRERROR                                            6
#define RSSCOPE_VAL_UART_INSUFFICIENT                                       7
#define RSSCOPE_VAL_UART_BREAK                                              8

// RsScope_rngLINFrameStatus
#define RSSCOPE_VAL_LIN_FRAME_STATE_OK                                      0
#define RSSCOPE_VAL_LIN_FRAME_STATE_VERSION_ERR                             1
#define RSSCOPE_VAL_LIN_FRAME_STATE_STOP_ERR                                2
#define RSSCOPE_VAL_LIN_FRAME_STATE_PARITY_ERR                              3
#define RSSCOPE_VAL_LIN_FRAME_STATE_INSUFFICIENT                            4
#define RSSCOPE_VAL_LIN_FRAME_STATE_CHECKSUM                                5
#define RSSCOPE_VAL_LIN_FRAME_STATE_LENGTH_ERR                              6
#define RSSCOPE_VAL_LIN_FRAME_STATE_WAKEUP                                  7
#define RSSCOPE_VAL_LIN_FRAME_STATE_UART                                    8
#define RSSCOPE_VAL_LIN_FRAME_STATE_SYER                                    9
#define RSSCOPE_VAL_LIN_FRAME_STATE_CPER                                    10
#define RSSCOPE_VAL_LIN_FRAME_STATE_INC                                     11

// RsScope_rngLINFrameVersion
#define RSSCOPE_VAL_LIN_STANDARD_UNKNOWN                                    0

// RsScope_rngLINFieldStatus
#define RSSCOPE_VAL_LIN_FIELD_STATE_OK                                      0
#define RSSCOPE_VAL_LIN_FIELD_STATE_START_ERR                               1
#define RSSCOPE_VAL_LIN_FIELD_STATE_STOP_ERR                                2
#define RSSCOPE_VAL_LIN_FIELD_STATE_PARITY_ERR                              3
#define RSSCOPE_VAL_LIN_FIELD_STATE_INSUFFICIENT                            4
#define RSSCOPE_VAL_LIN_FIELD_STATE_UVAL                                    5
#define RSSCOPE_VAL_LIN_FIELD_STATE_NOEX                                    6

// RsScope_rngCANFrameStatus
#define RSSCOPE_VAL_CAN_FRAME_STATE_BIT_STUFF                               1
#define RSSCOPE_VAL_CAN_FRAME_STATE_CRC_DELIM                               2
#define RSSCOPE_VAL_CAN_FRAME_STATE_CRC                                     3
#define RSSCOPE_VAL_CAN_FRAME_STATE_END_ERR                                 4
#define RSSCOPE_VAL_CAN_FRAME_STATE_NO_ACK                                  6
#define RSSCOPE_VAL_CAN_FRAME_STATE_INSUFFICIENT                            7
#define RSSCOPE_VAL_CAN_FRAME_STATE_ACKD                                    5
#define RSSCOPE_VAL_CAN_FRAME_STATE_CAER                                    8
#define RSSCOPE_VAL_CAN_FRAME_STATE_FCER                                    9
#define RSSCOPE_VAL_CAN_FRAME_STATE_FORM                                    10
#define RSSCOPE_VAL_CAN_FRAME_STATE_SERR                                    11
#define RSSCOPE_VAL_CAN_FRAME_STATE_SFER                                    12
#define RSSCOPE_VAL_CAN_FRAME_STATE_SCER                                    13
#define RSSCOPE_VAL_CAN_FRAME_STATE_SAER                                    14
#define RSSCOPE_VAL_CAN_FRAME_STATE_SCAE                                    15
#define RSSCOPE_VAL_CAN_FRAME_STATE_SCFE                                    16

// RsScope_rngCANFrameMessageStatus
#define RSSCOPE_VAL_CAN_FRAME_STATE_UNDEFINED                               1
#define RSSCOPE_VAL_CAN_FRAME_STATE_ERROR                                   2

// RsScope_rngAudioFrameStatus
#define RSSCOPE_VAL_AUDIO_FRAME_STATE_OK                                    0
#define RSSCOPE_VAL_AUDIO_FRAME_STATE_ERR                                   1
#define RSSCOPE_VAL_AUDIO_FRAME_STATE_INS                                   2

// rsscope_rngDiagramType
#define RSSCOPE_VAL_DIAGRAM_HORIZONTAL                                      1
#define RSSCOPE_VAL_DIAGRAM_VERTICAL                                        2
#define RSSCOPE_VAL_DIAGRAM_NEW_TAB                                         3

// RsScope_rngSearchSortMode
#define RSSCOPE_VAL_SORT_MODE_POSITION                                      0
#define RSSCOPE_VAL_SORT_MODE_VALUE                                         1

// RsScope_rngSearchSource
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C1W1                                 1
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C1W2                                 2
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C1W3                                 3
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C2W1                                 4
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C2W2                                 5
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C2W3                                 6
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C3W1                                 7
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C3W2                                 8
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C3W3                                 9
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C4W1                                 10
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C4W2                                 11
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_C4W3                                 12
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M1                                   13
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M2                                   14
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M3                                   15
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M4                                   16
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_R1                                   17
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_R2                                   18
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_R3                                   19
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_R4                                   20
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D0                                   21
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D1                                   22
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D2                                   23
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D3                                   24
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D4                                   25
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D5                                   26
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D6                                   27
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D7                                   28
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D8                                   29
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D9                                   30
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D10                                  31
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D11                                  32
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D12                                  33
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D13                                  34
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D14                                  35
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_D15                                  36
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK1                                 37
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK2                                 38
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK3                                 39
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK4                                 40
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK5                                 41
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK6                                 42
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK7                                 43
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_TRK8                                 44
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_QUICK                                45
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_SBUS1                                46
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_SBUS2                                47
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_SBUS3                                48
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_SBUS4                                49
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_DIFF1                                50
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_DIFF2                                51
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_COMMON1                              52
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_COMMON2                              53
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1V1                                 54
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1V2                                 55
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1V3                                 56
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1V4                                 57
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1I1                                 58
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1I2                                 59
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1I3                                 60
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z1I4                                 61
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2V1                                 62
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2V2                                 63
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2V3                                 64
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2V4                                 65
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2I1                                 66
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2I2                                 67
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2I3                                 68
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_Z2I4                                 69
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M5                                   70
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M6                                   71
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M7                                   72
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_M8                                   73

// RsScope_rngSearchTriggerStateClockSource
#define RSSCOPE_VAL_CLOCK_SOURCE_C1W1                                       1
#define RSSCOPE_VAL_CLOCK_SOURCE_C2W1                                       2
#define RSSCOPE_VAL_CLOCK_SOURCE_C3W1                                       3
#define RSSCOPE_VAL_CLOCK_SOURCE_C4W1                                       4
#define RSSCOPE_VAL_CLOCK_SOURCE_M1                                         5
#define RSSCOPE_VAL_CLOCK_SOURCE_M2                                         6
#define RSSCOPE_VAL_CLOCK_SOURCE_M3                                         7
#define RSSCOPE_VAL_CLOCK_SOURCE_M4                                         8
#define RSSCOPE_VAL_CLOCK_SOURCE_M5                                         9
#define RSSCOPE_VAL_CLOCK_SOURCE_M6                                         10
#define RSSCOPE_VAL_CLOCK_SOURCE_M7                                         11
#define RSSCOPE_VAL_CLOCK_SOURCE_M8                                         12
#define RSSCOPE_VAL_CLOCK_SOURCE_R1                                         13
#define RSSCOPE_VAL_CLOCK_SOURCE_R2                                         14
#define RSSCOPE_VAL_CLOCK_SOURCE_R3                                         15
#define RSSCOPE_VAL_CLOCK_SOURCE_R4                                         16
#define RSSCOPE_VAL_CLOCK_SOURCE_D0                                         17
#define RSSCOPE_VAL_CLOCK_SOURCE_D1                                         18
#define RSSCOPE_VAL_CLOCK_SOURCE_D2                                         19
#define RSSCOPE_VAL_CLOCK_SOURCE_D3                                         20
#define RSSCOPE_VAL_CLOCK_SOURCE_D4                                         21
#define RSSCOPE_VAL_CLOCK_SOURCE_D5                                         22
#define RSSCOPE_VAL_CLOCK_SOURCE_D6                                         23
#define RSSCOPE_VAL_CLOCK_SOURCE_D7                                         24
#define RSSCOPE_VAL_CLOCK_SOURCE_D8                                         25
#define RSSCOPE_VAL_CLOCK_SOURCE_D9                                         26
#define RSSCOPE_VAL_CLOCK_SOURCE_D10                                        27
#define RSSCOPE_VAL_CLOCK_SOURCE_D11                                        28
#define RSSCOPE_VAL_CLOCK_SOURCE_D12                                        29
#define RSSCOPE_VAL_CLOCK_SOURCE_D13                                        30
#define RSSCOPE_VAL_CLOCK_SOURCE_D14                                        31
#define RSSCOPE_VAL_CLOCK_SOURCE_D15                                        32

// RsScope_rngHistogramType
#define RSSCOPE_VAL_HISTOGRAM_VERTICAL                                      0
#define RSSCOPE_VAL_HISTOGRAM_HORIZONTAL                                    1

// RsScope_rngPowerAnalysisSource
#define RSSCOPE_VAL_POWER_ANALYSIS_SOURCE_CH1                               1
#define RSSCOPE_VAL_POWER_ANALYSIS_SOURCE_CH2                               2
#define RSSCOPE_VAL_POWER_ANALYSIS_SOURCE_CH3                               3
#define RSSCOPE_VAL_POWER_ANALYSIS_SOURCE_CH4                               4

// RsScope_rngPowerAnalysisMeasurementType
#define RSSCOPE_VAL_POWER_MEAS_QUAL                                         0
#define RSSCOPE_VAL_POWER_MEAS_RUSH                                         1
#define RSSCOPE_VAL_POWER_MEAS_HARM                                         2
#define RSSCOPE_VAL_POWER_MEAS_MODU                                         3
#define RSSCOPE_VAL_POWER_MEAS_DONR                                         4
#define RSSCOPE_VAL_POWER_MEAS_SLEW                                         5
#define RSSCOPE_VAL_POWER_MEAS_SOA                                          6
#define RSSCOPE_VAL_POWER_MEAS_TURN                                         7
#define RSSCOPE_VAL_POWER_MEAS_SWIT                                         8
#define RSSCOPE_VAL_POWER_MEAS_EFF                                          9
#define RSSCOPE_VAL_POWER_MEAS_RIPP                                         10
#define RSSCOPE_VAL_POWER_MEAS_TRANS                                        11
#define RSSCOPE_VAL_POWER_MEAS_SPEC                                         12

// RsScope_rngPowerAnalyseProbeMode
#define RSSCOPE_VAL_PA_PROBE_MODE_SING                                      0
#define RSSCOPE_VAL_PA_PROBE_MODE_DIFF                                      1

// RsScope_rngPowerAnalysisReportPaperSize
#define RSSCOPE_VAL_POWER_ANALYSIS_PAPER_A4                                 0
#define RSSCOPE_VAL_POWER_ANALYSIS_PAPER_USL                                1

// RsScope_rngPowerAnalysisReportFont
#define RSSCOPE_VAL_POWER_ANALYSIS_FONT_ARIAL                               0
#define RSSCOPE_VAL_POWER_ANALYSIS_FONT_HELV                                1

// RsScope_rngPowerAnalysisReportContentSetup
#define RSSCOPE_VAL_POWER_ANALYSIS_REPORT_CONTENT_NEVER                     0
#define RSSCOPE_VAL_POWER_ANALYSIS_REPORT_CONTENT_ONCE                      1
#define RSSCOPE_VAL_POWER_ANALYSIS_REPORT_CONTENT_ALWAYS                    2

// RsScope_rngQualityType
#define RSSCOPE_VAL_QUALITY_TYPE_RMS                                        0
#define RSSCOPE_VAL_QUALITY_TYPE_FREQ                                       1
#define RSSCOPE_VAL_QUALITY_TYPE_CRES                                       2
#define RSSCOPE_VAL_QUALITY_TYPE_PEAK                                       3

// RsScope_rngQualityTypePower
#define RSSCOPE_VAL_QUALITY_TYPE_POWER_REAL                                 0
#define RSSCOPE_VAL_QUALITY_TYPE_POWER_REAC                                 1
#define RSSCOPE_VAL_QUALITY_TYPE_POWER_APP                                  2
#define RSSCOPE_VAL_QUALITY_TYPE_POWER_PFAC                                 3
#define RSSCOPE_VAL_QUALITY_TYPE_POWER_PHAS                                 4

// RsScope_rngPowerQualityFrequency
#define RSSCOPE_VAL_POWER_QUALITY_F50                                       0
#define RSSCOPE_VAL_POWER_QUALITY_F60                                       1
#define RSSCOPE_VAL_POWER_QUALITY_F360                                      2
#define RSSCOPE_VAL_POWER_QUALITY_F400                                      3
#define RSSCOPE_VAL_POWER_QUALITY_F650                                      4
#define RSSCOPE_VAL_POWER_QUALITY_F800                                      5
#define RSSCOPE_VAL_POWER_QUALITY_NF650                                     6
#define RSSCOPE_VAL_POWER_QUALITY_WF800                                     7
#define RSSCOPE_VAL_POWER_QUALITY_CUS                                       8

// RsScope_rngPowerScaling
#define RSSCOPE_VAL_POWER_SCALING_AUTO                                      0
#define RSSCOPE_VAL_POWER_SCALING_MAN                                       1

// RsScope_rngPowerCurrentHarmonicsStandard
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_ENA                          0
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_ENB                          1
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_ENC                          2
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_END                          3
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_MIL                          4
#define RSSCOPE_VAL_CURRENT_HARMONICS_STANDARD_RTC                          5

// RsScope_rngPowerCurrentHarmonicsFrequency
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F50                              0
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F60                              1
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F360                             2
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F400                             3
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F650                             4
#define RSSCOPE_VAL_CURRENT_HARMONICS_FREQ_F800                             5

// RsScope_rngPowerCurrentHarmonicsEvaluation
#define RSSCOPE_VAL_CURRENT_HARMONICS_EVAL_NOREVISED                        0
#define RSSCOPE_VAL_CURRENT_HARMONICS_EVAL_REVISED                          1

// RsScope_rngPowerCurrentHarmonicsVoltageResultsDisplay
#define RSSCOPE_VAL_CURRENT_HARMONICS_NOVOLTDISP                            0
#define RSSCOPE_VAL_CURRENT_HARMONICS_VOLTDISP                              1

// RsScope_rngPowerStatistics
#define RSSCOPE_VAL_MODULATION_STATISTICS_ACT                               0
#define RSSCOPE_VAL_MODULATION_STATISTICS_AVG                               1
#define RSSCOPE_VAL_MODULATION_STATISTICS_EVTC                              2
#define RSSCOPE_VAL_MODULATION_STATISTICS_NPE                               3
#define RSSCOPE_VAL_MODULATION_STATISTICS_PPE                               4
#define RSSCOPE_VAL_MODULATION_STATISTICS_RMS                               5
#define RSSCOPE_VAL_MODULATION_STATISTICS_STD                               6
#define RSSCOPE_VAL_MODULATION_STATISTICS_WFM                               7

// RsScope_rngPowerModulationResultType
#define RSSCOPE_VAL_MODULATION_RESULT_TYPE_FREQ                             0
#define RSSCOPE_VAL_MODULATION_RESULT_TYPE_DUTY                             1

// RsScope_rngPowerModulationType
#define RSSCOPE_VAL_MODULATION_TYPE_CONT                                    0
#define RSSCOPE_VAL_MODULATION_TYPE_TURNON                                  1

// RsScope_rngPowerSource
#define RSSCOPE_VAL_POWER_SOURCE_CURRENT                                    0
#define RSSCOPE_VAL_POWER_SOURCE_VOLTAGE                                    1

// RsScope_rngPowerSlewRateResultType
#define RSSCOPE_VAL_SLEW_RATE_TYPE_MIN                                      0
#define RSSCOPE_VAL_SLEW_RATE_TYPE_MAX                                      1

// RsScope_rngPowerSafeOperatingAreaScale
#define RSSCOPE_VAL_SCALE_LIN                                               0
#define RSSCOPE_VAL_SCALE_LOG                                               1

// RsScope_rngOnOffType
#define RSSCOPE_VAL_ON_OFF_TYPE_OFF                                         0
#define RSSCOPE_VAL_ON_OFF_TYPE_ON                                          1

// RsScope_rngPowerSwitchLossMeasTypes
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_TOF                            0
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_TON                            1
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_CON                            2
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_NCO                            3
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_TOT                            4
#define RSSCOPE_VAL_POWER_SWITCHINGLOSS_TYPE_SWF                            5

// RsScope_rngPowerRippleType
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_MIN                                   0
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_MAX                                   1
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_PDEL                                  2
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_STDD                                  3
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_PER                                   4
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_FREQ                                  5
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_PDCY                                  6
#define RSSCOPE_VAL_POWER_RIPPLE_TYPE_NDCY                                  7

// RsScope_rngPowerTransientResponseResult
#define RSSCOPE_VAL_POWER_TRANSIENT_MEAS_OVER                               0
#define RSSCOPE_VAL_POWER_TRANSIENT_MEAS_RTIM                               1
#define RSSCOPE_VAL_POWER_TRANSIENT_MEAS_DEL                                2
#define RSSCOPE_VAL_POWER_TRANSIENT_MEAS_PEAK                               3
#define RSSCOPE_VAL_POWER_TRANSIENT_MEAS_SETL                               4

// RsScope_rngTransientResponseTriggerSource
#define RSSCOPE_VAL_POWER_TR_TRIGGER_CHAN1                                  1
#define RSSCOPE_VAL_POWER_TR_TRIGGER_CHAN2                                  2
#define RSSCOPE_VAL_POWER_TR_TRIGGER_CHAN3                                  3
#define RSSCOPE_VAL_POWER_TR_TRIGGER_CHAN4                                  4

// RsScope_rngPowerRippleMeasure
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_ACT                                0
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_AVG                                1
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_EVTC                               2
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_NPE                                3
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_PPE                                4
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_RMS                                5
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_STDD                               6
#define RSSCOPE_VAL_POWER_RIPPLE_MEASURE_WFMC                               7

// rsscope_rngProtocolPackets
#define RSSCOPE_VAL_UART_PACKET_NONE                                        0
#define RSSCOPE_VAL_UART_PACKET_EWOR                                        1
#define RSSCOPE_VAL_UART_PACKET_TOUT                                        2

// rsscope_rngOnOffInputType
#define RSSCOPE_VAL_ON_OFF_INPUT_TYPE_AC                                    0
#define RSSCOPE_VAL_ON_OFF_INPUT_TYPE_DC                                    1

// rsscope_rngProtocolMIL1553ThresholdPreset
#define RSSCOPE_VAL_MIL1553_PRESET_V05                                      0
#define RSSCOPE_VAL_MIL1553_PRESET_V2                                       1
#define RSSCOPE_VAL_MIL1553_PRESET_V5                                       2
#define RSSCOPE_VAL_MIL1553_PRESET_V7                                       3
#define RSSCOPE_VAL_MIL1553_PRESET_MAN                                      4

// rsscope_rngProtocolARINC429Polarity
#define RSSCOPE_VAL_ARINC429_POLARITY_ALEG                                  0
#define RSSCOPE_VAL_ARINC429_POLARITY_BLEG                                  1

// rsscope_rngProtocolARINC429BitRateMode
#define RSSCOPE_VAL_ARINC429_BIT_RATE_MODE_LOW                              0
#define RSSCOPE_VAL_ARINC429_BIT_RATE_MODE_HIGH                             1

// rsscope_rngProtocolARINC429ThresholdPreset
#define RSSCOPE_VAL_ARINC429_PRESET_V25                                     0
#define RSSCOPE_VAL_ARINC429_PRESET_V5                                      1
#define RSSCOPE_VAL_ARINC429_PRESET_MAN                                     2

// rsscope_rngProtocolMIL1553TriggerMode
#define RSSCOPE_VAL_MIL1553_TRIGGER_STYP                                    0
#define RSSCOPE_VAL_MIL1553_TRIGGER_WTYP                                    1
#define RSSCOPE_VAL_MIL1553_TRIGGER_DATA                                    2
#define RSSCOPE_VAL_MIL1553_TRIGGER_CDST                                    3
#define RSSCOPE_VAL_MIL1553_TRIGGER_CMD                                     4
#define RSSCOPE_VAL_MIL1553_TRIGGER_STAT                                    5
#define RSSCOPE_VAL_MIL1553_TRIGGER_ERR                                     6

// rsscope_rngProtocolMIL1553SyncType
#define RSSCOPE_VAL_MIL1553_TRIGGER_SYNC_CST                                0
#define RSSCOPE_VAL_MIL1553_TRIGGER_SYNC_DATA                               1
#define RSSCOPE_VAL_MIL1553_TRIGGER_SYNC_ALL                                2

// rsscope_rngProtocolMIL1553TriggerCommandTransmitReceive
#define RSSCOPE_VAL_MIL1553_TRIGGER_COMMAND_TR_ZERO                         0
#define RSSCOPE_VAL_MIL1553_TRIGGER_COMMAND_TR_ONE                          1
#define RSSCOPE_VAL_MIL1553_TRIGGER_COMMAND_TR_DC                           2

// rsscope_rngProtocolMIL1553TriggerStatusFlags
#define RSSCOPE_VAL_MIL1553_TRIGGER_STATUS_FLAGS_ZERO                       0
#define RSSCOPE_VAL_MIL1553_TRIGGER_STATUS_FLAGS_ONE                        1
#define RSSCOPE_VAL_MIL1553_TRIGGER_STATUS_FLAGS_DC                         2

// rsscope_rngProtocolARINC429TriggerMode
#define RSSCOPE_VAL_ARINC429_TRIGGER_START                                  0
#define RSSCOPE_VAL_ARINC429_TRIGGER_STOP                                   1
#define RSSCOPE_VAL_ARINC429_TRIGGER_LABEL                                  2
#define RSSCOPE_VAL_ARINC429_TRIGGER_ERROR                                  3

// rsscope_rngProtocolMIL1553Polarity
#define RSSCOPE_VAL_MIL1553_POLARITY_NORMAL                                 0
#define RSSCOPE_VAL_MIL1553_POLARITY_INVERTED                               1

// rsscope_rngProtocolMIL1553WordType
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_UNKNOWN                               0
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_DATA                                  1
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_CMD                                   2
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_STAT                                  3
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_CMST                                  4
#define RSSCOPE_VAL_MIL1553_WORD_TYPE_IM                                    5

// rsscope_rngProtocolMIL1553WordOverallState
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_OK                                  0
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_SYNC                                1
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_MANC                                2
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_PAR                                 3
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_GAP                                 4
#define RSSCOPE_VAL_MIL1553_WORD_STATUS_RT                                  5

// rsscope_rngProtocolARINC429WordOverallState
#define RSSCOPE_VAL_ARINC_WORD_STATUS_OK                                    0
#define RSSCOPE_VAL_ARINC_WORD_STATUS_CODE                                  1
#define RSSCOPE_VAL_ARINC_WORD_STATUS_GAP                                   2
#define RSSCOPE_VAL_ARINC_WORD_STATUS_PAR                                   3

// rsscope_rngWaveformSelection
#define RSSCOPE_VAL_WFM_SELECTION_MIN                                       0
#define RSSCOPE_VAL_WFM_SELECTION_MAX                                       1
#define RSSCOPE_VAL_WFM_SELECTION_BOTH                                      2

// rsscope_rngProtocolDataSource
#define RSSCOPE_VAL_DATA_SOURCE_C1W1                                        0
#define RSSCOPE_VAL_DATA_SOURCE_C2W1                                        1
#define RSSCOPE_VAL_DATA_SOURCE_C3W1                                        2
#define RSSCOPE_VAL_DATA_SOURCE_C4W1                                        3
#define RSSCOPE_VAL_DATA_SOURCE_M1                                          4
#define RSSCOPE_VAL_DATA_SOURCE_M2                                          5
#define RSSCOPE_VAL_DATA_SOURCE_M3                                          6
#define RSSCOPE_VAL_DATA_SOURCE_M4                                          7
#define RSSCOPE_VAL_DATA_SOURCE_R1                                          8
#define RSSCOPE_VAL_DATA_SOURCE_R2                                          9
#define RSSCOPE_VAL_DATA_SOURCE_R3                                          10
#define RSSCOPE_VAL_DATA_SOURCE_R4                                          11
#define RSSCOPE_VAL_DATA_SOURCE_M5                                          12
#define RSSCOPE_VAL_DATA_SOURCE_M6                                          13
#define RSSCOPE_VAL_DATA_SOURCE_M7                                          14
#define RSSCOPE_VAL_DATA_SOURCE_M8                                          15

// rsscope_rngProbeDisplayDiff
#define RSSCOPE_VAL_PROBE_DISP_DIFF_DIFFERENTIAL                            0
#define RSSCOPE_VAL_PROBE_DISP_DIFF_SINGLEENDED                             1

// RsScope_rngSearchFlexRayFieldStatus
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_OK                                  0
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_START_ERR                           1
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_STOP_ERR                            2
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_PARITY_ERR                          3
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_INSUFFICIENT                        4
#define RSSCOPE_VAL_FLEXRAY_FIELD_STATE_UVAL                                5

// rsscope_rngCANStandard
#define RSSCOPE_VAL_CAN_STANDARD_CAN                                        0
#define RSSCOPE_VAL_CAN_STANDARD_CAN_FD                                     1
#define RSSCOPE_VAL_CAN_STANDARD_ANY                                        2

// rsscope_rngCANFDBits
#define RSSCOPE_VAL_CAN_FD_BIT_ZERO                                         0
#define RSSCOPE_VAL_CAN_FD_BIT_ONE                                          1
#define RSSCOPE_VAL_CAN_FD_BIT_DC                                           2

// rsscope_rngProtocolRFFEPreset
#define RSSCOPE_VAL_RFFE_V12                                                0
#define RSSCOPE_VAL_RFFE_V18                                                1
#define RSSCOPE_VAL_RFFE_MAN                                                2

// rsscope_rngProtocolRFFESequenceType
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_RZWR                                 0
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_RWR                                  1
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_RDR                                  2
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_ERWR                                 3
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_ERRD                                 4
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_ERWL                                 5
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_ERRL                                 6
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_ERROR                                7
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MASR                                 8
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MASW                                 9
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MASOHO                               10
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_IRSUM                                11
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_UNDEF                                12
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_UNDESC                               13
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MSKW                                 14
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MCTR                                 15
#define RSSCOPE_VAL_RFFE_SEQUENCE_TYPE_MCTW                                 16

// rsscope_rngProtocolRFFESequenceStatus
#define RSSCOPE_VAL_RFFE_STATUS_OK                                          0
#define RSSCOPE_VAL_RFFE_STATUS_SCC                                         1
#define RSSCOPE_VAL_RFFE_STATUS_GAP                                         2
#define RSSCOPE_VAL_RFFE_STATUS_PAR                                         3
#define RSSCOPE_VAL_RFFE_STATUS_LENG                                        4
#define RSSCOPE_VAL_RFFE_STATUS_BP                                          5
#define RSSCOPE_VAL_RFFE_STATUS_USEQ                                        6
#define RSSCOPE_VAL_RFFE_STATUS_INC                                         7
#define RSSCOPE_VAL_RFFE_STATUS_VERSION                                     8
#define RSSCOPE_VAL_RFFE_STATUS_NO_RESPONSE                                 9

// rsscope_rngProtocolRFFEByteStatus
#define RSSCOPE_VAL_RFFE_BYTE_STATE_OK                                      0
#define RSSCOPE_VAL_RFFE_BYTE_STATE_PARITY                                  1

// rsscope_rngProtocolRFFETriggerType
#define RSSCOPE_VAL_RFFE_TRIGGER_START                                      0
#define RSSCOPE_VAL_RFFE_TRIGGER_STOP                                       1
#define RSSCOPE_VAL_RFFE_TRIGGER_RZWR                                       2
#define RSSCOPE_VAL_RFFE_TRIGGER_RWR                                        3
#define RSSCOPE_VAL_RFFE_TRIGGER_RRD                                        4
#define RSSCOPE_VAL_RFFE_TRIGGER_ERWR                                       5
#define RSSCOPE_VAL_RFFE_TRIGGER_ERRD                                       6
#define RSSCOPE_VAL_RFFE_TRIGGER_ERWL                                       7
#define RSSCOPE_VAL_RFFE_TRIGGER_ERRL                                       8
#define RSSCOPE_VAL_RFFE_TRIGGER_ERROR                                      9
#define RSSCOPE_VAL_RFFE_TRIGGER_IRSUM                                      10
#define RSSCOPE_VAL_RFFE_TRIGGER_MSKW                                       11
#define RSSCOPE_VAL_RFFE_TRIGGER_MASOHO                                     12
#define RSSCOPE_VAL_RFFE_TRIGGER_MASW                                       13
#define RSSCOPE_VAL_RFFE_TRIGGER_MASR                                       14
#define RSSCOPE_VAL_RFFE_TRIGGER_MCTW                                       15
#define RSSCOPE_VAL_RFFE_TRIGGER_MCTR                                       16

// rsscope_rngProtocolMDIOThresholdPreset
#define RSSCOPE_VAL_MDIO_DEF                                                0
#define RSSCOPE_VAL_MDIO_MAN                                                1

// rsscope_rngProtocolMDIOWordStatus
#define RSSCOPE_VAL_MDIO_STATUS_OK                                          0
#define RSSCOPE_VAL_MDIO_STATUS_UNSYN                                       1
#define RSSCOPE_VAL_MDIO_STATUS_OPCO                                        2
#define RSSCOPE_VAL_MDIO_STATUS_SHORT                                       3
#define RSSCOPE_VAL_MDIO_STATUS_INC                                         4
#define RSSCOPE_VAL_MDIO_STATUS_TA_ERROR                                    5

// rsscope_rngProtocolMDIOTriggerType
#define RSSCOPE_VAL_MDIO_TRIGGER_START                                      0
#define RSSCOPE_VAL_MDIO_TRIGGER_STOP                                       1
#define RSSCOPE_VAL_MDIO_TRIGGER_DATA                                       2

// rsscope_rngProtocolMDIOTriggerStartCode
#define RSSCOPE_VAL_MDIO_START_CODE_ST00                                    0
#define RSSCOPE_VAL_MDIO_START_CODE_ST01                                    1
#define RSSCOPE_VAL_MDIO_START_CODE_ST0X                                    2

// rsscope_rngProtocolMDIOTriggerOperationCode
#define RSSCOPE_VAL_MDIO_OPERATION_CODE_OP00                                0
#define RSSCOPE_VAL_MDIO_OPERATION_CODE_OP01                                1
#define RSSCOPE_VAL_MDIO_OPERATION_CODE_OP10                                2
#define RSSCOPE_VAL_MDIO_OPERATION_CODE_OP11                                3
#define RSSCOPE_VAL_MDIO_OPERATION_CODE_OPXX                                4

// rsscope_rngProtocolEthernetVariant
#define RSSCOPE_VAL_ETHERNET_VARIANT_B10T                                   0
#define RSSCOPE_VAL_ETHERNET_VARIANT_B100TX                                 1

// rsscope_rngProtocolEthernetThresholdPreset
#define RSSCOPE_VAL_ETHERNET_PRESET_T0                                      0
#define RSSCOPE_VAL_ETHERNET_PRESET_T100                                    1
#define RSSCOPE_VAL_ETHERNET_PRESET_TX0                                     2
#define RSSCOPE_VAL_ETHERNET_PRESET_TX100                                   3
#define RSSCOPE_VAL_ETHERNET_PRESET_MAN                                     4

// rsscope_rngProtocolEthernetWordStatus
#define RSSCOPE_VAL_ETHERNET_STATUS_OK                                      0
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_PREAMBLE                            1
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_LENGTH                              2
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_SFD                                 3
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_CRC                                 4
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_UNC                                 5
#define RSSCOPE_VAL_ETHERNET_STATUS_ERR_INC                                 6

// rsscope_rngProtocolUSBTechnology
#define RSSCOPE_VAL_USB_LOW                                                 0
#define RSSCOPE_VAL_USB_FULL                                                1
#define RSSCOPE_VAL_USB_HIGH                                                2
#define RSSCOPE_VAL_USB_HSIC                                                3

// rsscope_rngProtocolUSBPacketStatus
#define RSSCOPE_VAL_USB_STATUS_OK                                           0
#define RSSCOPE_VAL_USB_STATUS_PID                                          1
#define RSSCOPE_VAL_USB_STATUS_CRC                                          2
#define RSSCOPE_VAL_USB_STATUS_BTST                                         3
#define RSSCOPE_VAL_USB_STATUS_GLIT                                         4
#define RSSCOPE_VAL_USB_STATUS_BYTE                                         5

// rsscope_rngProtocolUSBPacketPID
#define RSSCOPE_VAL_USB_PID_RES                                             0
#define RSSCOPE_VAL_USB_PID_OUT                                             1
#define RSSCOPE_VAL_USB_PID_IN                                              2
#define RSSCOPE_VAL_USB_PID_SOF                                             3
#define RSSCOPE_VAL_USB_PID_SETUP                                           4
#define RSSCOPE_VAL_USB_PID_D0                                              5
#define RSSCOPE_VAL_USB_PID_D1                                              6
#define RSSCOPE_VAL_USB_PID_D2                                              7
#define RSSCOPE_VAL_USB_PID_MD                                              8
#define RSSCOPE_VAL_USB_PID_ACK                                             9
#define RSSCOPE_VAL_USB_PID_NAK                                             10
#define RSSCOPE_VAL_USB_PID_STALL                                           11
#define RSSCOPE_VAL_USB_PID_NYET                                            12
#define RSSCOPE_VAL_USB_PID_PRE                                             13
#define RSSCOPE_VAL_USB_PID_SPLIT                                           14
#define RSSCOPE_VAL_USB_PID_PING                                            15
#define RSSCOPE_VAL_USB_PID_UNK                                             16

// rsscope_rngProtocolUSBTriggerType
#define RSSCOPE_VAL_USB_TRIGGER_SOP                                         0
#define RSSCOPE_VAL_USB_TRIGGER_EOP                                         1
#define RSSCOPE_VAL_USB_TRIGGER_RESET                                       2
#define RSSCOPE_VAL_USB_TRIGGER_SUSPEND                                     3
#define RSSCOPE_VAL_USB_TRIGGER_RESUME                                      4
#define RSSCOPE_VAL_USB_TRIGGER_TOKEN                                       5
#define RSSCOPE_VAL_USB_TRIGGER_DATA                                        6
#define RSSCOPE_VAL_USB_TRIGGER_HANDSHAKE                                   7
#define RSSCOPE_VAL_USB_TRIGGER_SPECIAL                                     8
#define RSSCOPE_VAL_USB_TRIGGER_ERROR                                       9

// rsscope_rngProtocolUSBTriggerToken
#define RSSCOPE_VAL_USB_TOKEN_OUT                                           0
#define RSSCOPE_VAL_USB_TOKEN_IN                                            1
#define RSSCOPE_VAL_USB_TOKEN_SOF                                           2
#define RSSCOPE_VAL_USB_TOKEN_SETUP                                         3

// rsscope_rngProtocolUSBTriggerDataType
#define RSSCOPE_VAL_USB_DATA_TYPE_D0                                        0
#define RSSCOPE_VAL_USB_DATA_TYPE_D1                                        1
#define RSSCOPE_VAL_USB_DATA_TYPE_D2                                        2
#define RSSCOPE_VAL_USB_DATA_TYPE_MD                                        3

// rsscope_rngProtocolUSBTriggerHandshake
#define RSSCOPE_VAL_USB_HANDSHAKE_ACK                                       0
#define RSSCOPE_VAL_USB_HANDSHAKE_NAK                                       1
#define RSSCOPE_VAL_USB_HANDSHAKE_STALL                                     2
#define RSSCOPE_VAL_USB_HANDSHAKE_NYET                                      3
#define RSSCOPE_VAL_USB_HANDSHAKE_ANY                                       4

// rsscope_rngProtocolUSBTriggerSpecialPID
#define RSSCOPE_VAL_USB_SPECIAL_PID_PREAMBLE                                0
#define RSSCOPE_VAL_USB_SPECIAL_PID_ERROR                                   1
#define RSSCOPE_VAL_USB_SPECIAL_PID_SPLIT                                   2
#define RSSCOPE_VAL_USB_SPECIAL_PID_PING                                    3

// rsscope_rngProtocolUSBTriggerErrorCondition
#define RSSCOPE_VAL_USB_ERROR_CONDITION_ANY                                 0
#define RSSCOPE_VAL_USB_ERROR_CONDITION_PID                                 1
#define RSSCOPE_VAL_USB_ERROR_CONDITION_CRC5                                2
#define RSSCOPE_VAL_USB_ERROR_CONDITION_CRC16                               3
#define RSSCOPE_VAL_USB_ERROR_CONDITION_BTST                                4
#define RSSCOPE_VAL_USB_ERROR_CONDITION_UNEX                                5
#define RSSCOPE_VAL_USB_ERROR_CONDITION_SE1                                 6
#define RSSCOPE_VAL_USB_ERROR_CONDITION_GLIT                                7

// rsscope_rngProtocolUSBPayloadCondition
#define RSSCOPE_VAL_USB_PAYLOAD_COND_ANY                                    0
#define RSSCOPE_VAL_USB_PAYLOAD_COND_EQ                                     1

// rsscope_rngProtocolUSBSCCheckStartComplete
#define RSSCOPE_VAL_USB_SC_COMPLETE                                         0
#define RSSCOPE_VAL_USB_SC_START                                            1
#define RSSCOPE_VAL_USB_SC_DC                                               2

// rsscope_rngByteOrder
#define RSSCOPE_VAL_MSBF                                                    0
#define RSSCOPE_VAL_LSBF                                                    1

// rsscope_rngHardcopyPrintColorSet
#define RSSCOPE_VAL_HARDCOPY_COLOR_SET_DEF1                                 1
#define RSSCOPE_VAL_HARDCOPY_COLOR_SET_DEF4                                 4

// RsScope_rngManchesterNRZCodingStandard
#define RSSCOPE_VAL_MANCHESTER_NRZ_CODING_STANDARD_MANC                     0
#define RSSCOPE_VAL_MANCHESTER_NRZ_CODING_STANDARD_MANT                     1
#define RSSCOPE_VAL_MANCHESTER_NRZ_CODING_STANDARD_NRZ                      2
#define RSSCOPE_VAL_MANCHESTER_NRZ_CODING_STANDARD_NRZU                     3

// RsScope_rngClockPhase
#define RSSCOPE_VAL_CLOCK_PHASE_AUTO                                        0
#define RSSCOPE_VAL_CLOCK_PHASE_FIRST_EDGE                                  1
#define RSSCOPE_VAL_CLOCK_PHASE_SECOND_EDGE                                 2

// RsScope_rngManchesterNRZThresholdPreset
#define RSSCOPE_VAL_MANCHESTER_NRZ_THRESHOLD_V05                            0
#define RSSCOPE_VAL_MANCHESTER_NRZ_THRESHOLD_V2                             1
#define RSSCOPE_VAL_MANCHESTER_NRZ_THRESHOLD_V5                             2
#define RSSCOPE_VAL_MANCHESTER_NRZ_THRESHOLD_V7                             3
#define RSSCOPE_VAL_MANCHESTER_NRZ_THRESHOLD_MAN                            4

// RsScope_rngNumericFormat
#define RSSCOPE_VAL_NUMERIC_FORMAT_DEC                                      0
#define RSSCOPE_VAL_NUMERIC_FORMAT_HEX                                      1
#define RSSCOPE_VAL_NUMERIC_FORMAT_OCT                                      2
#define RSSCOPE_VAL_NUMERIC_FORMAT_BIN                                      3

// RsScope_rngCellColor
#define RSSCOPE_VAL_CELL_COLOR_YELLOW                                       0
#define RSSCOPE_VAL_CELL_COLOR_BLUE                                         1
#define RSSCOPE_VAL_CELL_COLOR_GREEN                                        2
#define RSSCOPE_VAL_CELL_COLOR_PURPLE                                       3
#define RSSCOPE_VAL_CELL_COLOR_GRAY                                         4

// RsScope_rngCellResultColumn
#define RSSCOPE_VAL_CELL_RESULT_COLUMN_NONE                                 0
#define RSSCOPE_VAL_CELL_RESULT_COLUMN_COL1                                 1
#define RSSCOPE_VAL_CELL_RESULT_COLUMN_COL2                                 2
#define RSSCOPE_VAL_CELL_RESULT_COLUMN_COL3                                 3

// rsscope_rngManchesterNRZStatus
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_OK                                0
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_LENG                              1
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_UNKN                              2
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_INC                               3
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_PAR                               4
#define RSSCOPE_VAL_MANCHESTER_NRZ_STATUS_CRC                               5

// RsScope_rngSignalType
#define RSSCOPE_VAL_SIGNAL_TYPE_DIFF                                        0
#define RSSCOPE_VAL_SIGNAL_TYPE_SING                                        1

// RsScope_rngEbTbSyncSymbol
#define RSSCOPE_VAL_EBTB_SYNC_SYMBOL_K285                                   0
#define RSSCOPE_VAL_EBTB_SYNC_SYMBOL_K281                                   1
#define RSSCOPE_VAL_EBTB_SYNC_SYMBOL_K287                                   2
#define RSSCOPE_VAL_EBTB_SYNC_SYMBOL_CUS                                    3

// RsScope_rngEbTbDisplayFormat
#define RSSCOPE_VAL_EBTB_DISPLAY_FORMAT_KD                                  0
#define RSSCOPE_VAL_EBTB_DISPLAY_FORMAT_EB                                  1
#define RSSCOPE_VAL_EBTB_DISPLAY_FORMAT_TB                                  2

// RsScope_rngEbTbSymbolStatus
#define RSSCOPE_VAL_EBTB_STATUS_OK                                          0
#define RSSCOPE_VAL_EBTB_STATUS_UNKNOWN                                     1
#define RSSCOPE_VAL_EBTB_STATUS_DISPARITY                                   2
#define RSSCOPE_VAL_EBTB_STATUS_GLITCH                                      3

// RsScope_rngSENTTechnology
#define RSSCOPE_VAL_SENT_TECHNOLOGY_V25                                     0
#define RSSCOPE_VAL_SENT_TECHNOLOGY_MAN                                     1

// RsScope_rngSENTSerialFormat
#define RSSCOPE_VAL_SENT_SERIAL_FORMAT_NONE                                 0
#define RSSCOPE_VAL_SENT_SERIAL_FORMAT_SHORT                                1
#define RSSCOPE_VAL_SENT_SERIAL_FORMAT_ENHANCED                             2

// RsScope_rngSENTCRCVersion
#define RSSCOPE_VAL_SENT_CRC_VERSION_LEGACY                                 0
#define RSSCOPE_VAL_SENT_CRC_VERSION_V2010                                  1

// RsScope_rngSENTCRCMethod
#define RSSCOPE_VAL_SENT_CRC_METHOD_SAEJ                                    0
#define RSSCOPE_VAL_SENT_CRC_METHOD_TLE                                     1

// RsScope_rngSENTPausePulse
#define RSSCOPE_VAL_SENT_PAUSE_PULSE_NPP                                    0
#define RSSCOPE_VAL_SENT_PAUSE_PULSE_PP                                     1
#define RSSCOPE_VAL_SENT_PAUSE_PULSE_PPFL                                   2

// RsScope_rngSENTResultDisplay
#define RSSCOPE_SENT_RESULT_DISPLAY_TRSQ                                    0
#define RSSCOPE_SENT_RESULT_DISPLAY_SMSG                                    1
#define RSSCOPE_SENT_RESULT_DISPLAY_ALL                                     2

// RsScope_rngSENTStatus
#define RSSCOPE_VAL_SENT_STATUS_OK                                          0
#define RSSCOPE_VAL_SENT_STATUS_SYNC                                        1
#define RSSCOPE_VAL_SENT_STATUS_PULS                                        2
#define RSSCOPE_VAL_SENT_STATUS_CRC                                         3
#define RSSCOPE_VAL_SENT_STATUS_IRFL                                        4
#define RSSCOPE_VAL_SENT_STATUS_FORM                                        5
#define RSSCOPE_VAL_SENT_STATUS_INS                                         6

// RsScope_rngSENTFrameType
#define RSSCOPE_SENT_FRAME_TYPE_TRSQ                                        0
#define RSSCOPE_SENT_FRAME_TYPE_SMSG                                        1
#define RSSCOPE_SENT_FRAME_TYPE_EMSG                                        2

// RsScope_rngSENTIDType
#define RSSCOPE_VAL_SENT_ID_TYPE_B4                                         0
#define RSSCOPE_VAL_SENT_ID_TYPE_B8                                         1

// RsScope_rngSENTNibbleStatus
#define RSSCOPE_VAL_SENT_NIBBLE_STATUS_OK                                   0
#define RSSCOPE_VAL_SENT_NIBBLE_STATUS_UNDF                                 1

// RsScope_rngTriggerManchesterNRZType
#define RSSCOPE_VAL_TRIGGER_MANCHESTER_NRZ_TYPE_START                       0
#define RSSCOPE_VAL_TRIGGER_MANCHESTER_NRZ_TYPE_PATTERN                     1
#define RSSCOPE_VAL_TRIGGER_MANCHESTER_NRZ_TYPE_ADVANCED                    2

// RsScope_rngSENTTriggerType
#define RSSCOPE_VAL_SENT_TRIGGER_TYPE_CAL                                   0
#define RSSCOPE_VAL_SENT_TRIGGER_TYPE_TSEQ                                  1
#define RSSCOPE_VAL_SENT_TRIGGER_TYPE_SMSG                                  2
#define RSSCOPE_VAL_SENT_TRIGGER_TYPE_ERRC                                  3

// RsScope_rngSENTTriggerTSType
#define RSSCOPE_SENT_TRIGGER_TS_TYPE_STAT                                   0
#define RSSCOPE_SENT_TRIGGER_TS_TYPE_STDA                                   1

// RsScope_rngSENTTriggerSMType
#define RSSCOPE_SENT_TRIGGER_SM_TYPE_ID                                     0
#define RSSCOPE_SENT_TRIGGER_SM_TYPE_IDDT                                   1

// RsScope_rngTriggerEvent
#define RSSCOPE_VAL_TRIGGER_EVENT_NO_ACTION                                 0
#define RSSCOPE_VAL_TRIGGER_EVENT_TRIGGER                                   1

// RsScope_rngTriggerSerialBus
#define RSSCOPE_VAL_SERIAL_BUS_1                                            1
#define RSSCOPE_VAL_SERIAL_BUS_2                                            2
#define RSSCOPE_VAL_SERIAL_BUS_3                                            3
#define RSSCOPE_VAL_SERIAL_BUS_4                                            4

// RsScope_rngEbTbTriggerType
#define RSSCOPE_VAL_EBTB_TRIGGER_TYPE_SYMBOL                                0
#define RSSCOPE_VAL_EBTB_TRIGGER_TYPE_ERROR                                 1

// RsScope_rngEbTbSymbolType
#define RSSCOPE_VAL_EBTB_SYMBOL_TYPE_SYMBOL                                 0
#define RSSCOPE_VAL_EBTB_SYMBOL_TYPE_EXPRESSION                             1

// RsScope_rngEbTbFormat
#define RSSCOPE_VAL_EBTB_FORMAT_KD                                          0
#define RSSCOPE_VAL_EBTB_FORMAT_EB                                          1
#define RSSCOPE_VAL_EBTB_FORMAT_TB                                          2

// RsScope_rngEbTbKDCode
#define RSSCOPE_VAL_EBTB_KD_CODE_DXY                                        0
#define RSSCOPE_VAL_EBTB_KD_CODE_K280                                       1
#define RSSCOPE_VAL_EBTB_KD_CODE_K281                                       2
#define RSSCOPE_VAL_EBTB_KD_CODE_K282                                       3
#define RSSCOPE_VAL_EBTB_KD_CODE_K283                                       4
#define RSSCOPE_VAL_EBTB_KD_CODE_K284                                       5
#define RSSCOPE_VAL_EBTB_KD_CODE_K285                                       6
#define RSSCOPE_VAL_EBTB_KD_CODE_K286                                       7
#define RSSCOPE_VAL_EBTB_KD_CODE_K287                                       8
#define RSSCOPE_VAL_EBTB_KD_CODE_K237                                       9
#define RSSCOPE_VAL_EBTB_KD_CODE_K277                                       10
#define RSSCOPE_VAL_EBTB_KD_CODE_K297                                       11
#define RSSCOPE_VAL_EBTB_KD_CODE_K307                                       12

// RsScope_rngDPHYVariant
#define RSSCOPE_VAL_DPHY_VARIANT_DSI                                        0
#define RSSCOPE_VAL_DPHY_VARIANT_CSI2                                       1

// RsScope_rngDPHYThresholdPreset
#define RSSCOPE_VAL_DPHY_THRESHOLD_AUTO                                     0
#define RSSCOPE_VAL_DPHY_THRESHOLD_MAN                                      1

// RsScope_rngDPHYTriggerType
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_HS_SOP                                0
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_HS_EOP                                1
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_HS_PH                                 2
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_HS_DATA                               3
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_LP_ESC                                4
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_LP_TURN                               5
#define RSSCOPE_VAL_DPHY_TRIGGER_TYPE_LP_HSRQ                               6

// RsScope_rngDPHYStatus
#define RSSCOPE_VAL_DPHY_STATUS_OK                                          0
#define RSSCOPE_VAL_DPHY_STATUS_SYNC                                        1
#define RSSCOPE_VAL_DPHY_STATUS_GAP                                         2
#define RSSCOPE_VAL_DPHY_STATUS_PAR                                         3
#define RSSCOPE_VAL_DPHY_STATUS_LENG                                        4
#define RSSCOPE_VAL_DPHY_STATUS_UNK                                         5
#define RSSCOPE_VAL_DPHY_STATUS_INC                                         6

// RsScope_rngDPHYFrameType
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_HS_SP                                   0
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_HS_LP                                   1
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_HS_INC                                  2
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_LP_HSREQ                                3
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_LP_TA                                   4
#define RSSCOPE_VAL_DPHY_FRAME_TYPE_LP_ESC                                  5

// RsScope_rngSpaceWireThresholdPreset
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_V0                          0
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_V12                         1
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_V09                         2
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_MAN                         3
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_V125                        4
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_V165                        5
#define RSSCOPE_VAL_SPACE_WIRE_THRESHOLD_PRESET_25                          6

// RsScope_rngSpaceWireTriggerControlType
#define RSSCOPE_VAL_SPACE_WIRE_TRIGGER_CONTROL_TYPE_ANY                     0
#define RSSCOPE_VAL_SPACE_WIRE_TRIGGER_CONTROL_TYPE_FCT                     1
#define RSSCOPE_VAL_SPACE_WIRE_TRIGGER_CONTROL_TYPE_EOP                     2
#define RSSCOPE_VAL_SPACE_WIRE_TRIGGER_CONTROL_TYPE_EEP                     3

// RsScope_rngSpaceWireTriggerType
#define RSSCOPE_SPACE_WIRE_TRIGGER_TYPE_CTRL                                0
#define RSSCOPE_SPACE_WIRE_TRIGGER_TYPE_DATA                                1
#define RSSCOPE_SPACE_WIRE_TRIGGER_TYPE_NULL                                2
#define RSSCOPE_SPACE_WIRE_TRIGGER_TYPE_TIME                                3
#define RSSCOPE_SPACE_WIRE_TRIGGER_TYPE_ERROR                               4

// RsScope_rngSpaceWireFrameStatus
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_STATUS_OK                              0
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_STATUS_PAR                             1
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_STATUS_ESC                             2
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_STATUS_AMB                             3
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_STATUS_INC                             4

// RsScope_rngSpaceWireFrameType
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_DATA                              0
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_FCT                               1
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_EOP                               2
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_EEP                               3
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_ESC                               4
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_NULL                              5
#define RSSCOPE_VAL_SPACE_WIRE_FRAME_TYPE_TCOD                              6

// RsScope_rngGatingCursorSet
#define RSSCOPE_VAL_CURSOR_SET_CURSOR1                                      1
#define RSSCOPE_VAL_CURSOR_SET_CURSOR2                                      2
#define RSSCOPE_VAL_CURSOR_SET_CURSOR3                                      3
#define RSSCOPE_VAL_CURSOR_SET_CURSOR4                                      4

// RsScope_rngReportLogoType
#define RSSCOPE_VAL_REPORT_LOGO_TYPE_RS                                     0
#define RSSCOPE_VAL_REPORT_LOGO_TYPE_CUSTOM                                 1
#define RSSCOPE_VAL_REPORT_LOGO_TYPE_NONE                                   2

// RsScope_rngColorTableMode
#define RSSCOPE_VAL_COLOR_TABLE_MODE_INCIDENCE                              0
#define RSSCOPE_VAL_COLOR_TABLE_MODE_AMPLITUDE                              1

// RsScope_rngWaveformMultichannelImport
#define RSSCOPE_VAL_REFERENCE_WAV_MULTICH_NONE                              0
#define RSSCOPE_VAL_REFERENCE_WAV_MULTICH_WF1                               1
#define RSSCOPE_VAL_REFERENCE_WAV_MULTICH_WF2                               2
#define RSSCOPE_VAL_REFERENCE_WAV_MULTICH_WF3                               3
#define RSSCOPE_VAL_REFERENCE_WAV_MULTICH_WF4                               4

// RsScope_rngSearchTriggerSPIDataOperator
#define RSSCOPE_VAL_SPI_TRIGGER_DATA_EQU                                    0
#define RSSCOPE_VAL_SPI_TRIGGER_DATA_NEQ                                    1

// RsScope_rngSearchTriggerSPIDataPositionOperator
#define RSSCOPE_VAL_SPI_TRIGGER_DPO_ANY                                     0
#define RSSCOPE_VAL_SPI_TRIGGER_DPO_EQU                                     1
#define RSSCOPE_VAL_SPI_TRIGGER_DPO_GETH                                    2
#define RSSCOPE_VAL_SPI_TRIGGER_DPO_INR                                     3

// RsScope_rngNRZPolarityData
#define RSSCOPE_VAL_NRZ_POLARITY_DATA_ENALOW                                0
#define RSSCOPE_VAL_NRZ_POLARITY_DATA_ENAHIGH                               1

// RsScope_rngProtocolMPHY
#define RSSCOPE_VAL_MPHY_PROTOCOL_MPHY                                      0
#define RSSCOPE_VAL_MPHY_PROTOCOL_UNIPRO                                    1
#define RSSCOPE_VAL_MPHY_PROTOCOL_SSIC                                      2

// RsScope_rngMPHYDataSource
#define RSSCOPE_VAL_MPHY_DATA_NONE                                          0
#define RSSCOPE_VAL_MPHY_DATA_C1W1                                          1
#define RSSCOPE_VAL_MPHY_DATA_C1W2                                          2
#define RSSCOPE_VAL_MPHY_DATA_C1W3                                          3
#define RSSCOPE_VAL_MPHY_DATA_C2W1                                          4
#define RSSCOPE_VAL_MPHY_DATA_C2W2                                          5
#define RSSCOPE_VAL_MPHY_DATA_C2W3                                          6
#define RSSCOPE_VAL_MPHY_DATA_C3W1                                          7
#define RSSCOPE_VAL_MPHY_DATA_C3W2                                          8
#define RSSCOPE_VAL_MPHY_DATA_C3W3                                          9
#define RSSCOPE_VAL_MPHY_DATA_C4W1                                          10
#define RSSCOPE_VAL_MPHY_DATA_C4W2                                          11
#define RSSCOPE_VAL_MPHY_DATA_C4W3                                          12
#define RSSCOPE_VAL_MPHY_DATA_M1                                            13
#define RSSCOPE_VAL_MPHY_DATA_M2                                            14
#define RSSCOPE_VAL_MPHY_DATA_M3                                            15
#define RSSCOPE_VAL_MPHY_DATA_M4                                            16
#define RSSCOPE_VAL_MPHY_DATA_R1                                            17
#define RSSCOPE_VAL_MPHY_DATA_R2                                            18
#define RSSCOPE_VAL_MPHY_DATA_R3                                            19
#define RSSCOPE_VAL_MPHY_DATA_R4                                            20
#define RSSCOPE_VAL_MPHY_DATA_XY1                                           21
#define RSSCOPE_VAL_MPHY_DATA_XY2                                           22
#define RSSCOPE_VAL_MPHY_DATA_XY3                                           23
#define RSSCOPE_VAL_MPHY_DATA_XY4                                           24
#define RSSCOPE_VAL_MPHY_DATA_MRES1                                         25
#define RSSCOPE_VAL_MPHY_DATA_MRES2                                         26
#define RSSCOPE_VAL_MPHY_DATA_MRES3                                         27
#define RSSCOPE_VAL_MPHY_DATA_MRES4                                         28
#define RSSCOPE_VAL_MPHY_DATA_MRES5                                         29
#define RSSCOPE_VAL_MPHY_DATA_MRES6                                         30
#define RSSCOPE_VAL_MPHY_DATA_MRES7                                         31
#define RSSCOPE_VAL_MPHY_DATA_MRES8                                         32
#define RSSCOPE_VAL_MPHY_DATA_IMR                                           33
#define RSSCOPE_VAL_MPHY_DATA_QUICK                                         34
#define RSSCOPE_VAL_MPHY_DATA_SBUS1                                         35
#define RSSCOPE_VAL_MPHY_DATA_SBUS2                                         36
#define RSSCOPE_VAL_MPHY_DATA_SBUS3                                         37
#define RSSCOPE_VAL_MPHY_DATA_SBUS4                                         38
#define RSSCOPE_VAL_MPHY_DATA_D0                                            39
#define RSSCOPE_VAL_MPHY_DATA_D1                                            40
#define RSSCOPE_VAL_MPHY_DATA_D2                                            41
#define RSSCOPE_VAL_MPHY_DATA_D3                                            42
#define RSSCOPE_VAL_MPHY_DATA_D4                                            43
#define RSSCOPE_VAL_MPHY_DATA_D5                                            44
#define RSSCOPE_VAL_MPHY_DATA_D6                                            45
#define RSSCOPE_VAL_MPHY_DATA_D7                                            46
#define RSSCOPE_VAL_MPHY_DATA_D8                                            47
#define RSSCOPE_VAL_MPHY_DATA_D9                                            48
#define RSSCOPE_VAL_MPHY_DATA_D10                                           49
#define RSSCOPE_VAL_MPHY_DATA_D11                                           50
#define RSSCOPE_VAL_MPHY_DATA_D12                                           51
#define RSSCOPE_VAL_MPHY_DATA_D13                                           52
#define RSSCOPE_VAL_MPHY_DATA_D14                                           53
#define RSSCOPE_VAL_MPHY_DATA_D15                                           54
#define RSSCOPE_VAL_MPHY_DATA_MSOB1                                         55
#define RSSCOPE_VAL_MPHY_DATA_MSOB2                                         56
#define RSSCOPE_VAL_MPHY_DATA_MSOB3                                         57
#define RSSCOPE_VAL_MPHY_DATA_MSOB4                                         58
#define RSSCOPE_VAL_MPHY_DATA_MSOB5                                         59
#define RSSCOPE_VAL_MPHY_DATA_TRK1                                          60
#define RSSCOPE_VAL_MPHY_DATA_TRK2                                          61
#define RSSCOPE_VAL_MPHY_DATA_TRK3                                          62
#define RSSCOPE_VAL_MPHY_DATA_TRK4                                          63
#define RSSCOPE_VAL_MPHY_DATA_TRK5                                          64
#define RSSCOPE_VAL_MPHY_DATA_TRK6                                          65
#define RSSCOPE_VAL_MPHY_DATA_TRK7                                          66
#define RSSCOPE_VAL_MPHY_DATA_TRK8                                          67
#define RSSCOPE_VAL_MPHY_DATA_CDRSW1                                        68
#define RSSCOPE_VAL_MPHY_DATA_CDRSW2                                        69
#define RSSCOPE_VAL_MPHY_DATA_CDRHW                                         70
#define RSSCOPE_VAL_MPHY_DATA_AEYE1                                         71
#define RSSCOPE_VAL_MPHY_DATA_AEYE2                                         72
#define RSSCOPE_VAL_MPHY_DATA_AEYE3                                         73
#define RSSCOPE_VAL_MPHY_DATA_AEYE4                                         74
#define RSSCOPE_VAL_MPHY_DATA_SG1                                           75
#define RSSCOPE_VAL_MPHY_DATA_SG2                                           76
#define RSSCOPE_VAL_MPHY_DATA_SG3                                           77
#define RSSCOPE_VAL_MPHY_DATA_SG4                                           78
#define RSSCOPE_VAL_MPHY_DATA_SG1TL1                                        79
#define RSSCOPE_VAL_MPHY_DATA_SG1TL2                                        80
#define RSSCOPE_VAL_MPHY_DATA_SG2TL1                                        81
#define RSSCOPE_VAL_MPHY_DATA_SG2TL2                                        82
#define RSSCOPE_VAL_MPHY_DATA_SG3TL1                                        83
#define RSSCOPE_VAL_MPHY_DATA_SG3TL2                                        84
#define RSSCOPE_VAL_MPHY_DATA_SG4TL1                                        85
#define RSSCOPE_VAL_MPHY_DATA_SG4TL2                                        86
#define RSSCOPE_VAL_MPHY_DATA_M5                                            87
#define RSSCOPE_VAL_MPHY_DATA_M6                                            88
#define RSSCOPE_VAL_MPHY_DATA_M7                                            89
#define RSSCOPE_VAL_MPHY_DATA_M8                                            90

// RsScope_rngMPHYThresholdPreset
#define RSSCOPE_VAL_MPHY_THRESHOLD_PRESET_60MV                              0
#define RSSCOPE_VAL_MPHY_THRESHOLD_PRESET_120MV                             1
#define RSSCOPE_VAL_MPHY_THRESHOLD_PRESET_240MV                             2
#define RSSCOPE_VAL_MPHY_THRESHOLD_PRESET_MANUAL                            3

// RsScope_rngTriggerMPHYType
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_START                                 0
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_BURST                                 1
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_ADAPT                                 2
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_LCC                                   3
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_DLPDUSOF                              4
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_DLPDUCOF                              5
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_DLPDUEOF                              6
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_DLPDUNAC                              7
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_DLPDUAFC                              8
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_PACP                                  9
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_TRIGUPR0                              10
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_TRIGUPR1                              11
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_TRIGUPR2                              12
#define RSSCOPE_VAL_MPHY_TRIGGER_TYPE_ERR                                   13

// RsScope_rngTrigerMPHYLCCType
#define RSSCOPE_VAL_MPHY_LCC_TYPE_ANY                                       0
#define RSSCOPE_VAL_MPHY_LCC_TYPE_SLEEP                                     1
#define RSSCOPE_VAL_MPHY_LCC_TYPE_STALL                                     2
#define RSSCOPE_VAL_MPHY_LCC_TYPE_READCAP                                   3
#define RSSCOPE_VAL_MPHY_LCC_TYPE_READMFG                                   4
#define RSSCOPE_VAL_MPHY_LCC_TYPE_READVEND                                  5
#define RSSCOPE_VAL_MPHY_LCC_TYPE_WRITEATTR                                 6
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG0                                     7
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG1                                     8
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG2                                     9
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG3                                     10
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG4                                     11
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG5                                     12
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG6                                     13
#define RSSCOPE_VAL_MPHY_LCC_TYPE_PWMG7                                     14
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG1A                                     15
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG2A                                     16
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG3A                                     17
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG4A                                     18
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG1B                                     19
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG2B                                     20
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG3B                                     21
#define RSSCOPE_VAL_MPHY_LCC_TYPE_HSG4B                                     22
#define RSSCOPE_VAL_MPHY_LCC_TYPE_RESERVED                                  23

// RsScope_rngMPHYWordCondition
#define RSSCOPE_VAL_MPHY_WORD_COND_NEQ                                      0
#define RSSCOPE_VAL_MPHY_WORD_COND_EQU                                      1
#define RSSCOPE_VAL_MPHY_WORD_COND_LTH                                      2
#define RSSCOPE_VAL_MPHY_WORD_COND_LETH                                     3
#define RSSCOPE_VAL_MPHY_WORD_COND_GTH                                      4
#define RSSCOPE_VAL_MPHY_WORD_COND_GETH                                     5
#define RSSCOPE_VAL_MPHY_WORD_COND_INR                                      6
#define RSSCOPE_VAL_MPHY_WORD_COND_OOR                                      7

// RsScope_rngMPHYREQPattern
#define RSSCOPE_VAL_MPHY_REQ_PATTERN_ONE                                    0
#define RSSCOPE_VAL_MPHY_REQ_PATTERN_ZERO                                   1
#define RSSCOPE_VAL_MPHY_REQ_PATTERN_DC                                     2

// RsScope_rngMPHYFrameType
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_BURST                                   0
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_ADAPT                                   1
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_LCC                                     2
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_DLPDUSOF                                3
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_DLPDUCOF                                4
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_DLPDUEOF                                5
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_DLPDUNAC                                6
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_DLPDUAFC                                7
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_PACP                                    8
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_TRIGUPR0                                9
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_TRIGUPR1                                10
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_TRIGUPR2                                11
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_SKIP                                    12
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_FILLER                                  13
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_SPACER                                  14
#define RSSCOPE_VAL_MPHY_FRAME_TYPE_UNKNOWN                                 15

// RsScope_rngMPHYFrameState
#define RSSCOPE_VAL_MPHY_FRAME_STATE_OK                                     0
#define RSSCOPE_VAL_MPHY_FRAME_STATE_RSVDERROR                              1
#define RSSCOPE_VAL_MPHY_FRAME_STATE_CMDERROR                               2
#define RSSCOPE_VAL_MPHY_FRAME_STATE_LENGTHERROR                            3
#define RSSCOPE_VAL_MPHY_FRAME_STATE_SYMBOLERROR                            4
#define RSSCOPE_VAL_MPHY_FRAME_STATE_UNKOWNERROR                            5
#define RSSCOPE_VAL_MPHY_FRAME_STATE_INVALID                                6

// RsScope_rngScopeModel
#define RSSCOPE_VAL_MODEL_RTO1012                                           0
#define RSSCOPE_VAL_MODEL_RTO1014                                           1
#define RSSCOPE_VAL_MODEL_RTO1022                                           2
#define RSSCOPE_VAL_MODEL_RTO1024                                           3
#define RSSCOPE_VAL_MODEL_RTO1044                                           4
#define RSSCOPE_VAL_MODEL_RTO1002                                           5
#define RSSCOPE_VAL_MODEL_RTO1004                                           6
#define RSSCOPE_VAL_MODEL_RTO1094                                           7
#define RSSCOPE_VAL_MODEL_RTO2012                                           8
#define RSSCOPE_VAL_MODEL_RTO2014                                           9
#define RSSCOPE_VAL_MODEL_RTO2022                                           10
#define RSSCOPE_VAL_MODEL_RTO2024                                           11
#define RSSCOPE_VAL_MODEL_RTO2032                                           12
#define RSSCOPE_VAL_MODEL_RTO2034                                           13
#define RSSCOPE_VAL_MODEL_RTO2044                                           14
#define RSSCOPE_VAL_MODEL_RTO2062                                           15
#define RSSCOPE_VAL_MODEL_RTO2004                                           16
#define RSSCOPE_VAL_MODEL_RTE1022                                           17
#define RSSCOPE_VAL_MODEL_RTE1024                                           18
#define RSSCOPE_VAL_MODEL_RTE1032                                           19
#define RSSCOPE_VAL_MODEL_RTE1034                                           20
#define RSSCOPE_VAL_MODEL_RTE1052                                           21
#define RSSCOPE_VAL_MODEL_RTE1054                                           22
#define RSSCOPE_VAL_MODEL_RTE1102                                           23
#define RSSCOPE_VAL_MODEL_RTE1104                                           24
#define RSSCOPE_VAL_MODEL_RTE1102N                                          25
#define RSSCOPE_VAL_MODEL_RTE1104N                                          26
#define RSSCOPE_VAL_MODEL_RTE1152                                           27
#define RSSCOPE_VAL_MODEL_RTE1154                                           28
#define RSSCOPE_VAL_MODEL_RTE1202                                           29
#define RSSCOPE_VAL_MODEL_RTE1204                                           30
#define RSSCOPE_VAL_MODEL_RTO64                                             31

// RsScope_rngScopeSeries
#define RSSCOPE_VAL_SERIES_RTO                                              0
#define RSSCOPE_VAL_SERIES_RTE                                              1
#define RSSCOPE_VAL_SERIES_RTP                                              2

// RsScope_rngScopeFamily
#define RSSCOPE_VAL_SCOPE_FAMILY_RTO                                        0
#define RSSCOPE_VAL_SCOPE_FAMILY_RTO2000                                    1
#define RSSCOPE_VAL_SCOPE_FAMILY_RTE                                        2
#define RSSCOPE_VAL_SCOPE_FAMILY_RTO6                                       3
#define RSSCOPE_VAL_SCOPE_FAMILY_RTP                                        4
#define RSSCOPE_VAL_SCOPE_FAMILY_RTPFL                                      5

// RsScope_rngDataSignalType
#define RSSCOPE_VAL_DATA_SIGNAL_TYPE_SOURCE                                 0
#define RSSCOPE_VAL_DATA_SIGNAL_TYPE_SPECTRUM                               1
#define RSSCOPE_VAL_DATA_SIGNAL_TYPE_CORRELATION                            2
#define RSSCOPE_VAL_DATA_SIGNAL_TYPE_MEAS                                   3
#define RSSCOPE_VAL_DATA_SIGNAL_TYPE_NONE                                   4

// RsScope_rngWaveformGeneratorOperationMode
#define RSSCOPE_VAL_WAVE_GEN_MODE_FUNC                                      0
#define RSSCOPE_VAL_WAVE_GEN_MODE_MOD                                       1
#define RSSCOPE_VAL_WAVE_GEN_MODE_SWE                                       2
#define RSSCOPE_VAL_WAVE_GEN_MODE_ARBG                                      3

// RsScope_rngWaveformGeneratorFunctionType
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_SIN                              0
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_SQU                              1
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_RAMP                             2
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_DC                               3
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_PULS                             4
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_SINC                             5
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_CARD                             6
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_GAUS                             7
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_LORN                             8
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_EXPR                             9
#define RSSCOPE_VAL_WAVE_GEN_FUNCTION_TYPE_EXPF                             10

// RsScope_rngWaveformGeneratorModulationType
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_TYPE_AM                             0
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_TYPE_FM                             1
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_TYPE_PWM                            2
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_TYPE_FSK                            3

// RsScope_rngWaveformGeneratorModulationSignal
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_SIGNAL_SIN                          0
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_SIGNAL_SQU                          1
#define RSSCOPE_VAL_WAVE_GEN_MODULATION_SIGNAL_RAMP                         2

// RsScope_rngWaveformGeneratorArbitrarySource
#define RSSCOPE_VAL_WAVE_GEN_ARBITRARY_SOURCE_ARB                           0
#define RSSCOPE_VAL_WAVE_GEN_ARBITRARY_SOURCE_SCOP                          1

// RsScope_rngWaveformGeneratorRunMode
#define RSSCOPE_WAVE_GEN_RUN_MODE_SING                                      0
#define RSSCOPE_WAVE_GEN_RUN_MODE_CONT                                      1

// RsScope_rngWaveformGeneratorArbitraryMultichannelWaveform
#define RSSCOPE_VAL_WAVE_GEN_IMPORT_WFM1                                    1
#define RSSCOPE_VAL_WAVE_GEN_IMPORT_WFM2                                    2
#define RSSCOPE_VAL_WAVE_GEN_IMPORT_WFM3                                    3
#define RSSCOPE_VAL_WAVE_GEN_IMPORT_WFM4                                    4

// RsScope_rngWaveformGeneratorArbitraryScopeSource
#define RSSCOPE_VAL_WAVE_GEN_C1W1                                           1
#define RSSCOPE_VAL_WAVE_GEN_C1W2                                           2
#define RSSCOPE_VAL_WAVE_GEN_C1W3                                           3
#define RSSCOPE_VAL_WAVE_GEN_C2W1                                           4
#define RSSCOPE_VAL_WAVE_GEN_C2W2                                           5
#define RSSCOPE_VAL_WAVE_GEN_C2W3                                           6
#define RSSCOPE_VAL_WAVE_GEN_C3W1                                           7
#define RSSCOPE_VAL_WAVE_GEN_C3W2                                           8
#define RSSCOPE_VAL_WAVE_GEN_C3W3                                           9
#define RSSCOPE_VAL_WAVE_GEN_C4W1                                           10
#define RSSCOPE_VAL_WAVE_GEN_C4W2                                           11
#define RSSCOPE_VAL_WAVE_GEN_C4W3                                           12
#define RSSCOPE_VAL_WAVE_GEN_R1                                             13
#define RSSCOPE_VAL_WAVE_GEN_R2                                             14
#define RSSCOPE_VAL_WAVE_GEN_R3                                             15
#define RSSCOPE_VAL_WAVE_GEN_R4                                             16
#define RSSCOPE_VAL_WAVE_GEN_NONE                                           17
#define RSSCOPE_VAL_WAVE_GEN_DIFF1                                          18
#define RSSCOPE_VAL_WAVE_GEN_DIFF2                                          19
#define RSSCOPE_VAL_WAVE_GEN_COMMON1                                        20
#define RSSCOPE_VAL_WAVE_GEN_COMMON2                                        21

// RsScope_rngWaveformGeneratorLoad
#define RSSCOPE_ATTR_WAVE_GEN_OUTPUT_LOAD_FIFT                              0
#define RSSCOPE_ATTR_WAVE_GEN_OUTPUT_LOAD_HIZ                               1

// RsScope_rngGeneratorSynchronization
#define RSSCOPE_GENERATOR_SYNCHRONIZATION_NONE                              0
#define RSSCOPE_GENERATOR_SYNCHRONIZATION_GEN12                             1
#define RSSCOPE_GENERATOR_SYNCHRONIZATION_G1PG                              2
#define RSSCOPE_GENERATOR_SYNCHRONIZATION_G2PG                              3
#define RSSCOPE_GENERATOR_SYNCHRONIZATION_G12PG                             4

// RsScope_rngGeneratorAlignmentOverallState
#define RSSCOPE_VAL_GENERATOR_ALIGNMENT_STATE_FAIL                          0
#define RSSCOPE_VAL_GENERATOR_ALIGNMENT_STATE_PASS                          1
#define RSSCOPE_VAL_GENERATOR_ALIGNMENT_STATE_NOAL                          2

// RsScope_rngCXPIDisplayOrder
#define RSSCOPE_VAL_CXPI_DISPLAY_ORDER_TRANSMITTED                          0
#define RSSCOPE_VAL_CXPI_DISPLAY_ORDER_LOGICAL                              1

// RsScope_rngCXPIFrameStatus
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_OK                                    0
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_INC                                   1
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_IBS                               2
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_IFS                               3
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_LENGTH                            4
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_CRC                               5
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_PARITY                            6
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_DLC                               7
#define RSSCOPE_VAL_CXPI_FRAME_STATUS_ERR_UART                              8

// RsScope_rngCXPIFrameType
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_NORMAL                                  0
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_NPOLL                                   1
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_LPOLL                                   2
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_SLEEP                                   3
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_LONG                                    4
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_PID                                     5
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_PTYPE                                   6
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_PTPID                                   7
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_IFS                                     8
#define RSSCOPE_VAL_CXPI_FRAME_TYPE_UNKNOWN                                 9

// RsScope_rngCXPITriggerType
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_START                                 0
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_NORMAL                                1
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_NPOLL                                 2
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_LPOLL                                 3
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_SLEEP                                 4
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_LONG                                  5
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_PID                                   6
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_PTYPE                                 7
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_PTPID                                 8
#define RSSCOPE_VAL_CXPI_TRIGGER_TYPE_ERROR                                 9

// RsScope_rngUSB31Gen1ScrambleMode
#define RSSCOPE_VAL_USB31_GEN1_SCRAMBLE_MODE_SCRM                           0
#define RSSCOPE_VAL_USB31_GEN1_SCRAMBLE_MODE_NSCR                           1

// RsScope_rngUSB31Gen1FrameStatus
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_OK                              0
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_INC                             1
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_UNC                             2
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_UNK                             3
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_CRC                             4
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_LENG                            5
#define RSSCOPE_VAL_USB31_GEN1_FRAME_STATUS_VOOR                            6

// RsScope_rngUSB31Gen1PacketType
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_TSEQ                             0
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_TS1T                             1
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_TS2T                             2
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_SLF                              3
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_U2IT                             4
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_VDT                              5
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_PCAP                             6
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_PCNF                             7
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_PCNR                             8
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_LDM                              9
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_ACK                              10
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_NRDY                             11
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_ERDY                             12
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_STAT                             13
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_STAL                             14
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_FWAK                             15
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_LTM                              16
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_BIAM                             17
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_HRR                              18
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_SSPD                             19
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_PING                             20
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_PNGR                             21
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_DPH                              22
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_DPP                              23
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_DPPA                             24
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_ITP                              25
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_LC                               26
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_SKIP                             27
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_BRST                             28
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_BDAT                             29
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_BERC                             30
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_BCNT                             31
#define RSSCOPE_VAL_USB31_GEN1_PACKET_TYPE_IDLE                             32

// RsScope_rngBitState
#define RSSCOPE_VAL_BIT_STATE_ZERO                                          0
#define RSSCOPE_VAL_BIT_STATE_ONE                                           1
#define RSSCOPE_VAL_BIT_STATE_DC                                            2

// RsScope_rngUSBPDFrameStatus
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_OK                                  0
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_UNKN                                1
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_INC                                 2
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_PRE                                 3
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_SOP                                 4
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_CRC                                 5
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_LENG                                6
#define RSSCOPE_VAL_USB_PD_FRAME_STATUS_FBFB                                7

// RsScope_rngUSBPDFrameType
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_START                                 0
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_RESET                                 1
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_CTRL                                  2
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_DATA                                  3
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_BIST                                  4
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_RQST                                  5
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_SINK                                  6
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_SRC                                   7
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_VEND                                  8
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_BATT                                  9
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_ALRT                                  10
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XMSG                                  11
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XSRC                                  12
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XSTA                                  13
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XGBC                                  14
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XGBS                                  15
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XBAC                                  16
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XGMI                                  17
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XMFI                                  18
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XSRQ                                  19
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XSRS                                  20
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XFRQ                                  21
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_XFRS                                  22
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_TEST                                  23
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_LOWP                                  24
#define RSSCOPE_VAL_USB_PD_FRAME_TYPE_UNKN                                  25

// RsScope_rngUSBPDTriggerType
#define RSSCOPE_VAL_USB_PD_TRIGGER_TYPE_START                               0
#define RSSCOPE_VAL_USB_PD_TRIGGER_TYPE_FRAME                               1
#define RSSCOPE_VAL_USB_PD_TRIGGER_TYPE_ERROR                               2

// RsScope_rngPCIeGeneration
#define RSSCOPE_PCIE_GENERATION_V1                                          1
#define RSSCOPE_PCIE_GENERATION_V2                                          2
#define RSSCOPE_PCIE_GENERATION_V3                                          3

// RsScope_rngPCIeLink
#define RSSCOPE_VAL_PCIE_LINK_X1                                            0
#define RSSCOPE_VAL_PCIE_LINK_X2                                            1
#define RSSCOPE_VAL_PCIE_LINK_X4                                            2

// RsScope_rngPCIeCDRPLLOrder
#define RSSCOPE_VAL_PCIE_PLL_CDR_ORDER_FIRST                                1
#define RSSCOPE_VAL_PCIE_PLL_CDR_ORDER_SECOND                               2

// RsScope_rngPCIeCDRInitialPhaseSync
#define RSSCOPE_VAL_PCIE_CDR_PHASE_SYNC_SAMPLE                              0
#define RSSCOPE_VAL_PCIE_CDR_PHASE_SYNC_DATAEDGE                            1

// RsScope_rngPCIeCDRSelectedResults
#define RSSCOPE_VAL_PCIE_CDR_SELECTED_RESULTS_ALL                           0
#define RSSCOPE_VAL_PCIE_CDR_SELECTED_RESULTS_AISYNC                        1

// RsScope_rngPCIeTriggerType
#define RSSCOPE_VAL_PCIE_TRIGGER_TYPE_TLP                                   0
#define RSSCOPE_VAL_PCIE_TRIGGER_TYPE_DLLP                                  1
#define RSSCOPE_VAL_PCIE_TRIGGER_TYPE_ORD                                   2
#define RSSCOPE_VAL_PCIE_TRIGGER_TYPE_ERR                                   3

// RsScope_rngPCIeTLP
#define RSSCOPE_VAL_PCIE_TLP_ANY                                            0
#define RSSCOPE_VAL_PCIE_TLP_MEM                                            1
#define RSSCOPE_VAL_PCIE_TLP_IO                                             2
#define RSSCOPE_VAL_PCIE_TLP_CFG                                            3
#define RSSCOPE_VAL_PCIE_TLP_MSG                                            4
#define RSSCOPE_VAL_PCIE_TLP_CPL                                            5
#define RSSCOPE_VAL_PCIE_TLP_FETCH                                          6
#define RSSCOPE_VAL_PCIE_TLP_SWAP                                           7
#define RSSCOPE_VAL_PCIE_TLP_CAS                                            8

// RsScope_rngPCIeTLPTC
#define RSSCOPE_VAL_PCIE_TLP_TC_ZERO                                        0
#define RSSCOPE_VAL_PCIE_TLP_TC_ONE                                         1
#define RSSCOPE_VAL_PCIE_TLP_TC_TWO                                         2
#define RSSCOPE_VAL_PCIE_TLP_TC_THREE                                       3
#define RSSCOPE_VAL_PCIE_TLP_TC_FOUR                                        4
#define RSSCOPE_VAL_PCIE_TLP_TC_FIVE                                        5
#define RSSCOPE_VAL_PCIE_TLP_TC_SIX                                         6
#define RSSCOPE_VAL_PCIE_TLP_TC_SEVEN                                       7
#define RSSCOPE_VAL_PCIE_TLP_TC_ANY                                         8

// RsScope_rngPCIeTLPOrdering
#define RSSCOPE_VAL_PCIE_TLP_ORDERING_ANY                                   0
#define RSSCOPE_VAL_PCIE_TLP_ORDERING_STRONG                                1
#define RSSCOPE_VAL_PCIE_TLP_ORDERING_RELAX                                 2

// RsScope_rngPCIeTLPSnoop
#define RSSCOPE_VAL_PCIE_TLP_SNOOP_ANY                                      0
#define RSSCOPE_VAL_PCIE_TLP_SNOOP_YES                                      1
#define RSSCOPE_VAL_PCIE_TLP_SNOOP_NO                                       2

// RsScope_rngPCIeTLPReadWrite
#define RSSCOPE_VAL_PCIE_TLP_RW_ANY                                         0
#define RSSCOPE_VAL_PCIE_TLP_RW_READ                                        1
#define RSSCOPE_VAL_PCIE_TLP_RW_WRITE                                       2

// RsScope_rngPCIeTLPAddressType
#define RSSCOPE_VAL_PCIE_TLP_ADDRESS_TYPE_ANY                               0
#define RSSCOPE_VAL_PCIE_TLP_ADDRESS_TYPE_X32                               1
#define RSSCOPE_VAL_PCIE_TLP_ADDRESS_TYPE_X64                               2

// RsScope_rngPCIeTLPType
#define RSSCOPE_VAL_PCIE_TLP_TYPE_ANY                                       0
#define RSSCOPE_VAL_PCIE_TLP_TYPE_TYPE0                                     1
#define RSSCOPE_VAL_PCIE_TLP_TYPE_TYPE1                                     2

// RsScope_rngPCIeTLPRouting
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_ANY                                    0
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_ROOTCOMPLEX                            1
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_DEVICEID                               2
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_BROADCAST                              3
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_LOCAL                                  4
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_GATHERED                               5
#define RSSCOPE_VAL_PCIE_TLP_ROUTING_ADDRESS                                6

// RsScope_rngPCIeTLPStatus
#define RSSCOPE_VAL_PCIE_TLP_STATUS_ANY                                     0
#define RSSCOPE_VAL_PCIE_TLP_STATUS_SUCCESS                                 1
#define RSSCOPE_VAL_PCIE_TLP_STATUS_UNSUPPORTED                             2
#define RSSCOPE_VAL_PCIE_TLP_STATUS_RETRY                                   3
#define RSSCOPE_VAL_PCIE_TLP_STATUS_ABORT                                   4

// RsScope_rngPCIeDLLP
#define RSSCOPE_VAL_PCIE_DLLP_ANY                                           0
#define RSSCOPE_VAL_PCIE_DLLP_MRDLLP                                        1
#define RSSCOPE_VAL_PCIE_DLLP_ACK                                           2
#define RSSCOPE_VAL_PCIE_DLLP_NAK                                           3
#define RSSCOPE_VAL_PCIE_DLLP_INITFC1                                       4
#define RSSCOPE_VAL_PCIE_DLLP_INITFC2                                       5
#define RSSCOPE_VAL_PCIE_DLLP_UPDATEFC                                      6
#define RSSCOPE_VAL_PCIE_DLLP_PM                                            7
#define RSSCOPE_VAL_PCIE_DLLP_VENDOR                                        8

// RsScope_rngPCIeDLLPMRType
#define RSSCOPE_VAL_PCIE_DLLP_MR_TYPE_INIT                                  0
#define RSSCOPE_VAL_PCIE_DLLP_MR_TYPE_RESET                                 1
#define RSSCOPE_VAL_PCIE_DLLP_MR_TYPE_UPDATEFC                              2
#define RSSCOPE_VAL_PCIE_DLLP_MR_TYPE_INITFC1                               3
#define RSSCOPE_VAL_PCIE_DLLP_MR_TYPE_INITFC2                               4

// RsScope_rngPCIeState
#define RSSCOPE_VAL_PCIE_STATE_ANY                                          0
#define RSSCOPE_VAL_PCIE_STATE_YES                                          1
#define RSSCOPE_VAL_PCIE_STATE_NO                                           2

// RsScope_rngPCIeDevicePortType
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_ZERO                              0
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_ONE                               1
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_TWO                               2
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_THREE                             3
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_FOUR                              4
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_FIVE                              5
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_SIX                               6
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_SEVEN                             7
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_EIGHT                             8
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_NINE                              9
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_TEN                               10
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_ELEVEN                            11
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_TWELVE                            12
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_THIRTEEN                          13
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_FOURTEEN                          14
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_FIFTEEN                           15
#define RSSCOPE_VAL_PCIE_DEVICE_PORT_TYPE_ANY                               16

// RsScope_rngPCIeVLNumber
#define RSSCOPE_VAL_PCIE_VL_NUMBER_ZERO                                     0
#define RSSCOPE_VAL_PCIE_VL_NUMBER_ONE                                      1
#define RSSCOPE_VAL_PCIE_VL_NUMBER_TWO                                      2
#define RSSCOPE_VAL_PCIE_VL_NUMBER_THREE                                    3
#define RSSCOPE_VAL_PCIE_VL_NUMBER_FOUR                                     4
#define RSSCOPE_VAL_PCIE_VL_NUMBER_FIVE                                     5
#define RSSCOPE_VAL_PCIE_VL_NUMBER_SIX                                      6
#define RSSCOPE_VAL_PCIE_VL_NUMBER_SEVEN                                    7
#define RSSCOPE_VAL_PCIE_VL_NUMBER_ANY                                      8

// RsScope_rngPCIeDLLPMRTLPType
#define RSSCOPE_VAL_PCIE_DLLP_MR_TLP_TYPE_ANY                               0
#define RSSCOPE_VAL_PCIE_DLLP_MR_TLP_TYPE_POSTED                            1
#define RSSCOPE_VAL_PCIE_DLLP_MR_TLP_TYPE_NONPOSTED                         2
#define RSSCOPE_VAL_PCIE_DLLP_MR_TLP_TYPE_COMPLETION                        3

// RsScope_rngPCIeTriggerDLLPMRA
#define RSSCOPE_VAL_PCIE_DLLP_MR_A_ANY                                      0
#define RSSCOPE_VAL_PCIE_DLLP_MR_A_ACK                                      1
#define RSSCOPE_VAL_PCIE_DLLP_MR_A_REQUEST                                  2

// RsScope_rngPCIeDLLPMRCreditType
#define RSSCOPE_VAL_PCIE_DLLP_MR_CREDIT_ANY                                 0
#define RSSCOPE_VAL_PCIE_DLLP_MR_CREDIT_DATA                                1
#define RSSCOPE_VAL_PCIE_DLLP_MR_CREDIT_HEADER                              2

// RsScope_rngPCIeDLLPVHGroup
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_ZERO                                 0
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_ONE                                  1
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_TWO                                  2
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_THREE                                3
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_FOUR                                 4
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_FIVE                                 5
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_SIX                                  6
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_SEVEN                                7
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_EIGHT                                8
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_NINE                                 9
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_TEN                                  10
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_ELEVEN                               11
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_TWELVE                               12
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_THIRTEEN                             13
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_FOURTEEN                             14
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_FIFTEEN                              15
#define RSSCOPE_VAL_PCIE_DLLP_VH_GROUP_ANY                                  16

// RsScope_rngPCIeDLLPFCCreditType
#define RSSCOPE_VAL_PCIE_DLLP_FC_CREDIT_TYPE_ANY                            0
#define RSSCOPE_VAL_PCIE_DLLP_FC_CREDIT_TYPE_POSTED                         1
#define RSSCOPE_VAL_PCIE_DLLP_FC_CREDIT_TYPE_NONPOSTED                      2
#define RSSCOPE_VAL_PCIE_DLLP_FC_CREDIT_TYPE_COMPLETION                     3

// RsScope_rngPCIeDLLPVCID
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_ZERO                                    0
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_ONE                                     1
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_TWO                                     2
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_THREE                                   3
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_FOUR                                    4
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_FIVE                                    5
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_SIX                                     6
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_SEVEN                                   7
#define RSSCOPE_VAL_PCIE_DLLP_VC_ID_ANY                                     8

// RsScope_rngPCIeDLLPPMType
#define RSSCOPE_VAL_PCIE_DLLP_PM_TYPE_ANY                                   0
#define RSSCOPE_VAL_PCIE_DLLP_PM_TYPE_ENTERL1                               1
#define RSSCOPE_VAL_PCIE_DLLP_PM_TYPE_ENTERL23                              2
#define RSSCOPE_VAL_PCIE_DLLP_PM_TYPE_ACTREQL1                              3
#define RSSCOPE_VAL_PCIE_DLLP_PM_TYPE_REQUESTACK1                           4

// RsScope_rngPCIeOSETType
#define RSSCOPE_VAL_PCIE_OSET_TYPE_SKP                                      0
#define RSSCOPE_VAL_PCIE_OSET_TYPE_TS1                                      1
#define RSSCOPE_VAL_PCIE_OSET_TYPE_TS2                                      2
#define RSSCOPE_VAL_PCIE_OSET_TYPE_FTS                                      3
#define RSSCOPE_VAL_PCIE_OSET_TYPE_EIOS                                     4
#define RSSCOPE_VAL_PCIE_OSET_TYPE_EIEOS                                    5
#define RSSCOPE_VAL_PCIE_OSET_TYPE_COMP                                     6
#define RSSCOPE_VAL_PCIE_OSET_TYPE_SDS                                      7

// RsScope_rngPCIePacketStatus
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_OK                                   0
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_MALF                                 1
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_CRC                              2
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_ECRC                             3
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_LCRC                             4
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_LENGTH                           5
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_TLP_PREFIX                       6
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_MEE                              7
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_ERR_UNC                              8
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_FCRC                                 9
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_FPERROR                              10
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_OUT_RANGE                            11
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_INCOMPLETE                           12
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_SYNC_ERROR                           13
#define RSSCOPE_VAL_PCIE_PACKET_STATUS_UNKNOWN                              14

// RsScope_rngPCIePacketType
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRD32                                  0
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRD64                                  1
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRDLK32                                2
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRDLK64                                3
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MWR32                                  4
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MWR64                                  5
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IORD                                   6
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IOWR                                   7
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CFGRD0                                 8
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CFGWR0                                 9
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CFGRD1                                 10
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CFGWR1                                 11
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MSG                                    12
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MSGD                                   13
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CPL                                    14
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CPLD                                   15
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CPLLK                                  16
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CPLDLK                                 17
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_FA32                                   18
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_FA64                                   19
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SWP32                                  20
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SWP64                                  21
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CAS32                                  22
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_CAS64                                  23
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_LPRFX                                  24
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_EPRFX                                  25
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_ACK                                    26
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_NAK                                    27
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_PMEL1                                  28
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_PMEL23                                 29
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_PMASRL1                                30
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_PMRA                                   31
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_VENDS                                  32
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC1P                                  33
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC1NP                                 34
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC1CPL                                35
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC2P                                  36
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC2NP                                 37
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IFC2CPL                                38
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UPDFCP                                 39
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UPDFCNP                                40
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UPDFCCPL                               41
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRUPDFC                                42
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRIFC1                                 43
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRIFC2                                 44
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRINIT                                 45
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MRRESET                                46
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UNK                                    47
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SKPOS                                  48
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_EIOS                                   49
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_FTSOS                                  50
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_TS1OS                                  51
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_TS2OS                                  52
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_EIEOS                                  53
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_COMPL                                  54
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_MCOMPL                                 55
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_DCOMPL                                 56
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UDEF                                   57
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_IDLE                                   58
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SDS                                    59
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_EDB                                    60
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_EDS                                    61
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SDAT                                   62
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SCTR                                   63
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_PMUX                                   64
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UNKTLP                                 65
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_UNKDLLP                                66
#define RSSCOPE_VAL_PCIE_PACKET_TYPE_SINV                                   67

// RsScope_rngPCIePacketCPS
#define RSSCOPE_VAL_PCIE_PACKET_CPS_RESERVED                                0
#define RSSCOPE_VAL_PCIE_PACKET_CPS_SC                                      1
#define RSSCOPE_VAL_PCIE_PACKET_CPS_UR                                      2
#define RSSCOPE_VAL_PCIE_PACKET_CPS_CRS                                     3
#define RSSCOPE_VAL_PCIE_PACKET_CPS_CA                                      4

// RsScope_rngCANFrameFormErrorCause
#define RSSCOPE_VAL_CAN_FRAME_FORM_ERROR_CAUSE_NONE                         0
#define RSSCOPE_VAL_CAN_FRAME_FORM_ERROR_CAUSE_CRCD                         1
#define RSSCOPE_VAL_CAN_FRAME_FORM_ERROR_CAUSE_ACKD                         2
#define RSSCOPE_VAL_CAN_FRAME_FORM_ERROR_CAUSE_FSBE                         3
#define RSSCOPE_VAL_CAN_FRAME_FORM_ERROR_CAUSE_RES                          4

// RsScope_rngCANFDStandard
#define RSSCOPE_VAL_CAN_FD_STANDARD_ISO                                     0
#define RSSCOPE_VAL_CAN_FD_STANDARD_NISO                                    1

// RsScope_rngEthernetWordFrameType
#define RSSCOPE_VAL_ETHERNET_WORD_FRAME_TYPE_MAC                            0
#define RSSCOPE_VAL_ETHERNET_WORD_FRAME_TYPE_IDLE                           1
#define RSSCOPE_VAL_ETHERNET_WORD_FRAME_TYPE_SLEEP                          2
#define RSSCOPE_VAL_ETHERNET_WORD_FRAME_TYPE_EOS                            3
#define RSSCOPE_VAL_ETHERNET_WORD_FRAME_TYPE_UNKNOWN                        4

// RsScope_rngModularProbeMode
#define RSSCOPE_VAL_PROBE_MODE_DIFFERENTIAL                                 0
#define RSSCOPE_VAL_PROBE_MODE_COMMON                                       1
#define RSSCOPE_VAL_PROBE_MODE_POSITIVE                                     2
#define RSSCOPE_VAL_PROBE_MODE_NEGATIVE                                     3

// rsscope_rngSpectrumResultMeasType
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_CPOWER                             0
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_ACPOWER                            1
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_OBWIDTH                            2
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_SBWIDTH                            3
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_TOI                                4
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_AMMOD                              5
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_THD                                6
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_THDPCT                             7
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_THDA                               8
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_THDU                               9
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_THDR                               10
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_PLIST                              11
#define RSSCOPE_VAL_SPECTRUM_MEAS_RESULT_HAR                                12

// RsScope_rngSpectrumFrameType
#define RSSCOPE_VAL_SPECTRUM_FRAME_TYPE_NOFRAME                             0
#define RSSCOPE_VAL_SPECTRUM_FRAME_TYPE_UNDERLINE                           1
#define RSSCOPE_VAL_SPECTRUM_FRAME_TYPE_FULL                                2

// RsScope_rngFFTSpectrumColorTableMode
#define RSSCOPE_VAL_FFT_COLOR_TABLE_MODE_INCIDENCE                          0
#define RSSCOPE_VAL_FFT_COLOR_TABLE_MODE_AMPLITUDE                          1

// RsScope_rngCursorSource
#define RSSCOPE_VAL_CURSOR_C1W1                                             1
#define RSSCOPE_VAL_CURSOR_C1W2                                             2
#define RSSCOPE_VAL_CURSOR_C1W3                                             3
#define RSSCOPE_VAL_CURSOR_C2W1                                             4
#define RSSCOPE_VAL_CURSOR_C2W2                                             5
#define RSSCOPE_VAL_CURSOR_C2W3                                             6
#define RSSCOPE_VAL_CURSOR_C3W1                                             7
#define RSSCOPE_VAL_CURSOR_C3W2                                             8
#define RSSCOPE_VAL_CURSOR_C3W3                                             9
#define RSSCOPE_VAL_CURSOR_C4W1                                             10
#define RSSCOPE_VAL_CURSOR_C4W2                                             11
#define RSSCOPE_VAL_CURSOR_C4W3                                             12
#define RSSCOPE_VAL_CURSOR_M1                                               13
#define RSSCOPE_VAL_CURSOR_M2                                               14
#define RSSCOPE_VAL_CURSOR_M3                                               15
#define RSSCOPE_VAL_CURSOR_M4                                               16
#define RSSCOPE_VAL_CURSOR_R1                                               17
#define RSSCOPE_VAL_CURSOR_R2                                               18
#define RSSCOPE_VAL_CURSOR_R3                                               19
#define RSSCOPE_VAL_CURSOR_R4                                               20
#define RSSCOPE_VAL_CURSOR_XY1                                              21
#define RSSCOPE_VAL_CURSOR_XY2                                              22
#define RSSCOPE_VAL_CURSOR_XY3                                              23
#define RSSCOPE_VAL_CURSOR_XY4                                              24
#define RSSCOPE_VAL_CURSOR_D0                                               39
#define RSSCOPE_VAL_CURSOR_D1                                               40
#define RSSCOPE_VAL_CURSOR_D2                                               41
#define RSSCOPE_VAL_CURSOR_D3                                               42
#define RSSCOPE_VAL_CURSOR_D4                                               43
#define RSSCOPE_VAL_CURSOR_D5                                               44
#define RSSCOPE_VAL_CURSOR_D6                                               45
#define RSSCOPE_VAL_CURSOR_D7                                               46
#define RSSCOPE_VAL_CURSOR_D8                                               47
#define RSSCOPE_VAL_CURSOR_D9                                               48
#define RSSCOPE_VAL_CURSOR_D10                                              49
#define RSSCOPE_VAL_CURSOR_D11                                              50
#define RSSCOPE_VAL_CURSOR_D12                                              51
#define RSSCOPE_VAL_CURSOR_D13                                              52
#define RSSCOPE_VAL_CURSOR_D14                                              53
#define RSSCOPE_VAL_CURSOR_D15                                              54
#define RSSCOPE_VAL_CURSOR_MSOB1                                            55
#define RSSCOPE_VAL_CURSOR_MSOB2                                            56
#define RSSCOPE_VAL_CURSOR_MSOB3                                            57
#define RSSCOPE_VAL_CURSOR_MSOB4                                            58
#define RSSCOPE_VAL_CURSOR_TRK1                                             60
#define RSSCOPE_VAL_CURSOR_TRK2                                             61
#define RSSCOPE_VAL_CURSOR_TRK3                                             62
#define RSSCOPE_VAL_CURSOR_TRK4                                             63
#define RSSCOPE_VAL_CURSOR_TRK5                                             64
#define RSSCOPE_VAL_CURSOR_TRK6                                             65
#define RSSCOPE_VAL_CURSOR_TRK7                                             66
#define RSSCOPE_VAL_CURSOR_TRK8                                             67
#define RSSCOPE_VAL_CURSOR_SG1                                              75
#define RSSCOPE_VAL_CURSOR_SG2                                              76
#define RSSCOPE_VAL_CURSOR_SG3                                              77
#define RSSCOPE_VAL_CURSOR_SG4                                              78
#define RSSCOPE_VAL_CURSOR_SG1TL1                                           79
#define RSSCOPE_VAL_CURSOR_SG1TL2                                           80
#define RSSCOPE_VAL_CURSOR_SG2TL1                                           81
#define RSSCOPE_VAL_CURSOR_SG2TL2                                           82
#define RSSCOPE_VAL_CURSOR_SG3TL1                                           83
#define RSSCOPE_VAL_CURSOR_SG3TL2                                           84
#define RSSCOPE_VAL_CURSOR_SG4TL1                                           85
#define RSSCOPE_VAL_CURSOR_SG4TL2                                           86
#define RSSCOPE_VAL_CURSOR_Z1V1                                             87
#define RSSCOPE_VAL_CURSOR_Z1V2                                             88
#define RSSCOPE_VAL_CURSOR_Z1V3                                             89
#define RSSCOPE_VAL_CURSOR_Z1V4                                             90
#define RSSCOPE_VAL_CURSOR_Z1I1                                             91
#define RSSCOPE_VAL_CURSOR_Z1I2                                             92
#define RSSCOPE_VAL_CURSOR_Z1I3                                             93
#define RSSCOPE_VAL_CURSOR_Z1I4                                             94
#define RSSCOPE_VAL_CURSOR_Z2V1                                             95
#define RSSCOPE_VAL_CURSOR_Z2V2                                             96
#define RSSCOPE_VAL_CURSOR_Z2V3                                             97
#define RSSCOPE_VAL_CURSOR_Z2V4                                             98
#define RSSCOPE_VAL_CURSOR_Z2I1                                             99
#define RSSCOPE_VAL_CURSOR_Z2I2                                             100
#define RSSCOPE_VAL_CURSOR_Z2I3                                             101
#define RSSCOPE_VAL_CURSOR_Z2I4                                             102
#define RSSCOPE_VAL_CURSOR_DIFF1                                            103
#define RSSCOPE_VAL_CURSOR_DIFF2                                            104
#define RSSCOPE_VAL_CURSOR_COMMON1                                          105
#define RSSCOPE_VAL_CURSOR_COMMON2                                          106
#define RSSCOPE_VAL_CURSOR_EYE1                                             107
#define RSSCOPE_VAL_CURSOR_EYE2                                             108
#define RSSCOPE_VAL_CURSOR_EYE3                                             109
#define RSSCOPE_VAL_CURSOR_EYE4                                             110
#define RSSCOPE_VAL_CURSOR_TDRZ                                             111
#define RSSCOPE_VAL_CURSOR_TDRH                                             112
#define RSSCOPE_VAL_CURSOR_TDRR                                             113
#define RSSCOPE_VAL_CURSOR_M5                                               114
#define RSSCOPE_VAL_CURSOR_M6                                               115
#define RSSCOPE_VAL_CURSOR_M7                                               116
#define RSSCOPE_VAL_CURSOR_M8                                               117
#define RSSCOPE_VAL_CURSOR_SG5                                              118
#define RSSCOPE_VAL_CURSOR_SG6                                              119
#define RSSCOPE_VAL_CURSOR_SG7                                              120
#define RSSCOPE_VAL_CURSOR_SG8                                              121
#define RSSCOPE_VAL_CURSOR_SG5TL1                                           122
#define RSSCOPE_VAL_CURSOR_SG5TL2                                           123
#define RSSCOPE_VAL_CURSOR_SG6TL1                                           124
#define RSSCOPE_VAL_CURSOR_SG6TL2                                           125
#define RSSCOPE_VAL_CURSOR_SG7TL1                                           126
#define RSSCOPE_VAL_CURSOR_SG7TL2                                           127
#define RSSCOPE_VAL_CURSOR_SG8TL1                                           128
#define RSSCOPE_VAL_CURSOR_SG8TL2                                           129
#define RSSCOPE_VAL_CURSOR_BATHTUB1                                         130
#define RSSCOPE_VAL_CURSOR_BATHTUB2                                         131
#define RSSCOPE_VAL_CURSOR_BMEAS1                                           132
#define RSSCOPE_VAL_CURSOR_BMEAS2                                           133
#define RSSCOPE_VAL_CURSOR_SRESPONSE1                                       134
#define RSSCOPE_VAL_CURSOR_SRESPONSE2                                       135
#define RSSCOPE_VAL_CURSOR_SRTRACK1                                         136
#define RSSCOPE_VAL_CURSOR_SRTRACK2                                         137
#define RSSCOPE_VAL_CURSOR_SDTRACK1                                         138
#define RSSCOPE_VAL_CURSOR_SDTRACK2                                         139
#define RSSCOPE_VAL_CURSOR_TJTRACK1                                         140
#define RSSCOPE_VAL_CURSOR_TJTRACK2                                         141
#define RSSCOPE_VAL_CURSOR_DJTRACK1                                         142
#define RSSCOPE_VAL_CURSOR_DJTRACK2                                         143
#define RSSCOPE_VAL_CURSOR_DDJTRACK1                                        144
#define RSSCOPE_VAL_CURSOR_DDJTRACK2                                        145
#define RSSCOPE_VAL_CURSOR_PJTRACK1                                         146
#define RSSCOPE_VAL_CURSOR_PJTRACK2                                         147
#define RSSCOPE_VAL_CURSOR_RJTRACK1                                         148
#define RSSCOPE_VAL_CURSOR_RJTRACK2                                         149
#define RSSCOPE_VAL_CURSOR_TJSPECTRUM1                                      150
#define RSSCOPE_VAL_CURSOR_TJSPECTRUM2                                      151
#define RSSCOPE_VAL_CURSOR_DDJSPECTRUM1                                     152
#define RSSCOPE_VAL_CURSOR_DDJSPECTRUM2                                     153
#define RSSCOPE_VAL_CURSOR_PJSPECTRUM1                                      154
#define RSSCOPE_VAL_CURSOR_PJSPECTRUM2                                      155
#define RSSCOPE_VAL_CURSOR_RJSPECTRUM1                                      156
#define RSSCOPE_VAL_CURSOR_RJSPECTRUM2                                      157
#define RSSCOPE_VAL_CURSOR_SRHIST1                                          158
#define RSSCOPE_VAL_CURSOR_SRHIST2                                          159
#define RSSCOPE_VAL_CURSOR_SDHIST1                                          160
#define RSSCOPE_VAL_CURSOR_SDHIST2                                          161
#define RSSCOPE_VAL_CURSOR_TJHIST1                                          162
#define RSSCOPE_VAL_CURSOR_TJHIST2                                          163
#define RSSCOPE_VAL_CURSOR_DJHIST1                                          164
#define RSSCOPE_VAL_CURSOR_DJHIST2                                          165
#define RSSCOPE_VAL_CURSOR_DDJHIST1                                         166
#define RSSCOPE_VAL_CURSOR_DDJHIST2                                         167
#define RSSCOPE_VAL_CURSOR_PJHIST1                                          168
#define RSSCOPE_VAL_CURSOR_PJHIST2                                          169
#define RSSCOPE_VAL_CURSOR_RJHIST1                                          170
#define RSSCOPE_VAL_CURSOR_RJHIST2                                          171
#define RSSCOPE_VAL_CURSOR_SEYE1                                            172
#define RSSCOPE_VAL_CURSOR_SEYE2                                            173
#define RSSCOPE_VAL_CURSOR_NBATHTUB1                                        174
#define RSSCOPE_VAL_CURSOR_NBATHTUB2                                        175
#define RSSCOPE_VAL_CURSOR_NBMEAS1                                          176
#define RSSCOPE_VAL_CURSOR_NBMEAS2                                          177
#define RSSCOPE_VAL_CURSOR_TNHIST1                                          178
#define RSSCOPE_VAL_CURSOR_TNHIST2                                          179
#define RSSCOPE_VAL_CURSOR_DNHIST1                                          180
#define RSSCOPE_VAL_CURSOR_DNHIST2                                          181
#define RSSCOPE_VAL_CURSOR_DDNHIST1                                         182
#define RSSCOPE_VAL_CURSOR_DDNHIST2                                         183
#define RSSCOPE_VAL_CURSOR_PNHIST1                                          184
#define RSSCOPE_VAL_CURSOR_PNHIST2                                          185
#define RSSCOPE_VAL_CURSOR_RNHIST1                                          186
#define RSSCOPE_VAL_CURSOR_RNHIST2                                          187
#define RSSCOPE_VAL_CURSOR_TNTRACK1                                         188
#define RSSCOPE_VAL_CURSOR_TNTRACK2                                         189
#define RSSCOPE_VAL_CURSOR_DNTRACK1                                         190
#define RSSCOPE_VAL_CURSOR_DNTRACK2                                         191
#define RSSCOPE_VAL_CURSOR_DDNTRACK1                                        192
#define RSSCOPE_VAL_CURSOR_DDNTRACK2                                        193
#define RSSCOPE_VAL_CURSOR_PNTRACK1                                         194
#define RSSCOPE_VAL_CURSOR_PNTRACK2                                         195
#define RSSCOPE_VAL_CURSOR_RNOTRACK1                                        196
#define RSSCOPE_VAL_CURSOR_RNOTRACK2                                        197
#define RSSCOPE_VAL_CURSOR_TNSPECTRUM1                                      198
#define RSSCOPE_VAL_CURSOR_TNSPECTRUM2                                      199
#define RSSCOPE_VAL_CURSOR_DDNSPECTRUM1                                     200
#define RSSCOPE_VAL_CURSOR_DDNSPECTRUM2                                     201
#define RSSCOPE_VAL_CURSOR_PNSPECTRUM1                                      202
#define RSSCOPE_VAL_CURSOR_PNSPECTRUM2                                      203
#define RSSCOPE_VAL_CURSOR_RNOSPECTRUM1                                     204
#define RSSCOPE_VAL_CURSOR_RNOSPECTRUM2                                     205

// RsScope_rngUSBPDPacketType
#define RSSCOPE_VAL_USB_PD_PACKET_TYPE_CONTROL                              0
#define RSSCOPE_VAL_USB_PD_PACKET_TYPE_DATA                                 1
#define RSSCOPE_VAL_USB_PD_PACKET_TYPE_EXTENDED                             2
#define RSSCOPE_VAL_USB_PD_PACKET_TYPE_RESET                                3
#define RSSCOPE_VAL_USB_PD_PACKET_TYPE_TEST_FRAME                           4

// RsScope_rngUSB31Gen1FrameType
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_TSEQ                              0
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_TS1T                              1
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_TS2T                              2
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_SLF                               3
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_U2IT                              4
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_VDT                               5
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_PCAP                              6
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_PCNF                              7
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_PCNR                              8
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_LDM                               9
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_ACK                               10
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_NRDY                              11
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_ERDY                              12
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_STAT                              13
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_STAL                              14
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_FWAK                              15
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_LTM                               16
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_BIAM                              17
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_HRR                               18
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_SSPD                              19
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_PING                              20
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_PNGR                              21
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_DPH                               22
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_DPP                               23
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_DPPA                              24
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_ITP                               25
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_LC                                26
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_SKIP                              27
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_BRST                              28
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_BDAT                              29
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_BERC                              30
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_BCNT                              31
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_IDLE                              32
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_UHP                               33
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_ULMP                              34
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_UTP                               35
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_UDVN                              36
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_UDEF                              37
#define RSSCOPE_VAL_USB31_GEN1_FRAME_TYPE_ERR                               38

// RsScope_rngCursorStyle
#define RSSCOPE_VAL_CURSOR_STYLE_LINES                                      0
#define RSSCOPE_VAL_CURSOR_STYLE_LRH                                        1
#define RSSCOPE_VAL_CURSOR_STYLE_VLRH                                       2
#define RSSCOPE_VAL_CURSOR_STYLE_RHOM                                       3

// RsScope_rngZVCDecimationMode
#define RSSCOPE_VAL_ZVC_DECIMATION_SAMPLE                                   0
#define RSSCOPE_VAL_ZVC_DECIMATION_PDET                                     1
#define RSSCOPE_VAL_ZVC_DECIMATION_HRES                                     2

// RsScope_rngZVCResetOverload
#define RSSCOPE_VAL_ZVC_RESET_OVERLOAD_ADJUSTED                             0
#define RSSCOPE_VAL_ZVC_RESET_OVERLOAD_ORIGINAL                             1

// RsScope_rngZVCShuntMode
#define RSSCOPE_VAL_ZVC_SHUNT_MODE_INTERNAL                                 0
#define RSSCOPE_VAL_ZVC_SHUNT_MODE_EXTERNAL                                 1

// RsScope_rngZVCShuntIntMax
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A100R01                                   0
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A40R01                                    1
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A45M10                                    2
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A4M510                                    3
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A45U10K                                   4
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_A4U510K                                   5

// RsScope_rngZVCShuntExtMaxVoltage
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_VOLTAGE_V450                              0
#define RSSCOPE_VAL_ZVC_SHUNT_MAX_VOLTAGE_V045                              1

// RsScope_rngEbTbTriggerSymbolType
#define RSSCOPE_VAL_EBTB_SYMB_TYPE_SYMBOL                                   0
#define RSSCOPE_VAL_EBTB_SYMB_TYPE_EXPRESSION                               1

// RsScope_rngEbTbSymbTrgSymbolFormat
#define RSSCOPE_VAL_EBTB_TRIGGER_SYMB_FORMAT_KD                             0
#define RSSCOPE_VAL_EBTB_TRIGGER_SYMB_FORMAT_EB                             1
#define RSSCOPE_VAL_EBTB_TRIGGER_SYMB_FORMAT_TB                             2

// RsScope_rngEbTbTriggerDataCharacter
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_DXY                         0
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K280                        1
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K281                        2
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K282                        3
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K283                        4
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K284                        5
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K285                        6
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K286                        7
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K287                        8
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K237                        9
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K277                        10
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K297                        11
#define RSSCOPE_VAL_EBTB_TRIGGER_CHARACTER_DATA_K307                        12

// rsscope_rngProtocolDDRSource
#define RSSCOPE_VAL_DDR_SOURCE_C1W1                                         0
#define RSSCOPE_VAL_DDR_SOURCE_C2W1                                         1
#define RSSCOPE_VAL_DDR_SOURCE_C3W1                                         2
#define RSSCOPE_VAL_DDR_SOURCE_C4W1                                         3
#define RSSCOPE_VAL_DDR_SOURCE_M1                                           4
#define RSSCOPE_VAL_DDR_SOURCE_M2                                           5
#define RSSCOPE_VAL_DDR_SOURCE_M3                                           6
#define RSSCOPE_VAL_DDR_SOURCE_M4                                           7
#define RSSCOPE_VAL_DDR_SOURCE_R1                                           8
#define RSSCOPE_VAL_DDR_SOURCE_R2                                           9
#define RSSCOPE_VAL_DDR_SOURCE_R3                                           10
#define RSSCOPE_VAL_DDR_SOURCE_R4                                           11
#define RSSCOPE_VAL_DDR_SOURCE_D0                                           12
#define RSSCOPE_VAL_DDR_SOURCE_D1                                           13
#define RSSCOPE_VAL_DDR_SOURCE_D2                                           14
#define RSSCOPE_VAL_DDR_SOURCE_D3                                           15
#define RSSCOPE_VAL_DDR_SOURCE_D4                                           16
#define RSSCOPE_VAL_DDR_SOURCE_D5                                           17
#define RSSCOPE_VAL_DDR_SOURCE_D6                                           18
#define RSSCOPE_VAL_DDR_SOURCE_D7                                           19
#define RSSCOPE_VAL_DDR_SOURCE_D8                                           20
#define RSSCOPE_VAL_DDR_SOURCE_D9                                           21
#define RSSCOPE_VAL_DDR_SOURCE_D10                                          22
#define RSSCOPE_VAL_DDR_SOURCE_D11                                          23
#define RSSCOPE_VAL_DDR_SOURCE_D12                                          24
#define RSSCOPE_VAL_DDR_SOURCE_D13                                          25
#define RSSCOPE_VAL_DDR_SOURCE_D14                                          26
#define RSSCOPE_VAL_DDR_SOURCE_D15                                          27
#define RSSCOPE_VAL_DDR_SOURCE_M5                                           28
#define RSSCOPE_VAL_DDR_SOURCE_M6                                           29
#define RSSCOPE_VAL_DDR_SOURCE_M7                                           30
#define RSSCOPE_VAL_DDR_SOURCE_M8                                           31

// RsScope_rngDDRFrameStatus
#define RSSCOPE_VAL_DDR_FRAME_STATE_OK                                      0
#define RSSCOPE_VAL_DDR_FRAME_STATE_UNKN                                    1
#define RSSCOPE_VAL_DDR_FRAME_STATE_INC                                     2
#define RSSCOPE_VAL_DDR_FRAME_STATE_LENG                                    3

// RsScope_rngProtocolDDRFrameType
#define RSSCOPE_VAL_DDR_FRAME_TYPE_READ                                     0
#define RSSCOPE_VAL_DDR_FRAME_TYPE_WRITE                                    1
#define RSSCOPE_VAL_DDR_FRAME_TYPE_UNKNOWN                                  2
#define RSSCOPE_VAL_DDR_FRAME_TYPE_RDNC                                     3
#define RSSCOPE_VAL_DDR_FRAME_TYPE_WRNC                                     4

// RsScope_rngProtocolDPHYPhysicalConfiguration
#define RSSCOPE_VAL_DPHY_CONFIG_D1CN                                        0
#define RSSCOPE_VAL_DPHY_CONFIG_D1CL                                        1
#define RSSCOPE_VAL_DPHY_CONFIG_D2CN                                        2
#define RSSCOPE_VAL_DPHY_CONFIG_D2CL                                        3
#define RSSCOPE_VAL_DPHY_CONFIG_D3CN                                        4
#define RSSCOPE_VAL_DPHY_CONFIG_D3NL                                        5
#define RSSCOPE_VAL_DPHY_CONFIG_D4NN                                        6

// RsScope_rngAntialiasing
#define RSSCOPE_VAL_ANTIALIASING_OFF                                        0
#define RSSCOPE_VAL_ANTIALIASING_ON                                         1
#define RSSCOPE_VAL_ANTIALIASING_DEFAULT                                    2

// RsScope_rngDeembedingComponentType
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_CABLE                        0
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_FIXTURE                      1
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_ADAPTER                      2
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_CUSTOM                       3
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_RT_ZA10                      4
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_RT_ZA16                      5
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_RT_ZA17                      6
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_PROBE                        7
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_DUT                          8
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_INPUT                        9
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_PROVEN_PROBE                 10
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_PROVEN_CABLE                 11
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_COPROBES                     12
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_TYPE_EXTF                         13

// RsScope_rngDeembeddingComponentImpedanceType
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_IMPEDANCE_TYPE_DEFAULT            0
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_IMPEDANCE_TYPE_CONSTANT           1
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_IMPEDANCE_TYPE_S1P                2
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_IMPEDANCE_TYPE_S2P                3

// RsScope_rngDeembeddingComponentMode
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_MODE_PROBING                      0
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_MODE_TERMINATING                  1

// RsScope_rngDisplayResultTableDefaultPosition
#define RSSCOPE_VAL_RESULT_TABLE_POSITION_PREVIEW                           0
#define RSSCOPE_VAL_RESULT_TABLE_POSITION_FLOAT                             1
#define RSSCOPE_VAL_RESULT_TABLE_POSITION_DOCK                              2

// RsScope_rngEyeDiagramFilterBitSequenceMode
#define RSSCOPE_VAL_EYE_DIAGRAM_FILTER_BIT_SEQUENCE_MODE_ALL_BITS           0
#define RSSCOPE_VAL_EYE_DIAGRAM_FILTER_BIT_SEQUENCE_MODE_LEVEL_TRANSITION   1
#define RSSCOPE_VAL_EYE_DIAGRAM_FILTER_BIT_SEQUENCE_MODE_CONSTANT_LEVEL     2
#define RSSCOPE_VAL_EYE_DIAGRAM_FILTER_BIT_SEQUENCE_MODE_BIT_PATTERN        3

// RsScope_rngEyeDiagramHorizontalSettingsTimeUnits
#define RSSCOPE_VAL_TIME_UNITS_ABSOLUTE_TIME                                0
#define RSSCOPE_VAL_TIME_UNITS_UNIT_INTERVALS                               1

// RsScope_rngProbeDeembeddingImpedanceType
#define RSSCOPE_VAL_PROBE_IMPEDANCE_TYPE_DEFAULT                            0
#define RSSCOPE_VAL_PROBE_IMPEDANCE_TYPE_CONSTANT                           1
#define RSSCOPE_VAL_PROBE_IMPEDANCE_TYPE_S1P                                2
#define RSSCOPE_VAL_PROBE_IMPEDANCE_TYPE_S2P                                3

// RsScope_rngDeembeddingProbingMode
#define RSSCOPE_VAL_PROBING_MODE_PROBING                                    0
#define RSSCOPE_VAL_PROBING_MODE_TERMINATING                                1

// RsScope_rngProbeVoltageRange
#define RSSCOPE_VAL_PROBE_VOLTAGE_RANGE_AUTO                                0
#define RSSCOPE_VAL_PROBE_VOLTAGE_RANGE_MHIGH                               1
#define RSSCOPE_VAL_PROBE_VOLTAGE_RANGE_MLOW                                2

// RsScope_rngQuickActionMode
#define RSSCOPE_VAL_QUICK_ACTION_MODE_NONE                                  0
#define RSSCOPE_VAL_QUICK_ACTION_MODE_APPLICATION                           1
#define RSSCOPE_VAL_QUICK_ACTION_MODE_RECALL                                2
#define RSSCOPE_VAL_QUICK_ACTION_MODE_CLEAR                                 3

// RsScope_rngStartMode
#define RSSCOPE_VAL_START_MODE_AUTO                                         0
#define RSSCOPE_VAL_START_MODE_EXPLICIT                                     1

// RsScope_rngStopMode
#define RSSCOPE_VAL_STOP_MODE_AUTO                                          0
#define RSSCOPE_VAL_STOP_MODE_EXPLICIT                                      1
#define RSSCOPE_VAL_STOP_MODE_ERROR                                         2
#define RSSCOPE_VAL_STOP_MODE_BUFFER_FULL                                   3

// RsScope_rngEthernetTriggerType
#define RSSCOPE_VAL_ETHERNET_TRIGGER_TYPE_START                             0
#define RSSCOPE_VAL_ETHERNET_TRIGGER_TYPE_PATTERN                           1
#define RSSCOPE_VAL_ETHERNET_TRIGGER_TYPE_ADVANCED_FRAME                    2
#define RSSCOPE_VAL_ETHERNET_TRIGGER_TYPE_ADVANCED_ERROR                    3

// RsScope_rng100BASE_T1FrameType
#define RSSCOPE_VAL_FRAME_TYPE_START                                        0
#define RSSCOPE_VAL_FRAME_TYPE_MAC                                          1
#define RSSCOPE_VAL_FRAME_TYPE_IDLE                                         2
#define RSSCOPE_VAL_FRAME_TYPE_ERROR                                        3

// RsScope_rngSignalReverseType
#define RSSCOPE_VAL_SIGNAL_TYPE_DIS                                         2

// RsScope_rngSignalDirection
#define RSSCOPE_VAL_MASTER                                                  0
#define RSSCOPE_VAL_SLAVE                                                   1
#define RSSCOPE_VAL_AUTO_DIRECTION                                          2

// RsScope_rngProtocol100BASE_T1FrameType
#define RSSCOPE_VAL_100BASE_T1_FRAME_TYPE_IDLE                              0
#define RSSCOPE_VAL_100BASE_T1_FRAME_TYPE_MAC                               1
#define RSSCOPE_VAL_100BASE_T1_FRAME_TYPE_FILLER                            2
#define RSSCOPE_VAL_100BASE_T1_FRAME_TYPE_UNKNOWN                           3

// RsScope_rngMPHYFrameCellState
#define RSSCOPE_VAL_MPHY_FRAME_STATE_INCOMPOLETE                            7
#define RSSCOPE_VAL_MPHY_FRAME_STATE_UNCORRELATED                           8
#define RSSCOPE_VAL_MPHY_FRAME_STATE_CRCERROR                               9
#define RSSCOPE_VAL_MPHY_FRAME_STATE_VOOR                                   10

// RsScope_rngMPHYSSICFrameType
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_TSEQ                               0
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_TS1                                1
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_TS2                                2
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_SLF                                3
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_U2IT                               4
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_VDT                                5
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_PCAP                               6
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_PCNF                               7
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_PCNR                               8
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_LDM                                9
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_ACK                                10
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_NRDY                               11
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_ERDY                               12
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_STAT                               13
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_STAL                               14
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_FWAK                               15
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_LTM                                16
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_BIAM                               17
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_HRR                                18
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_SSPD                               19
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_PING                               20
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_PNGR                               21
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_DPH                                22
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_DPP                                23
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_DPPA                               24
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_ITP                                25
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_LC                                 26
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_SKIP                               27
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_BRST                               28
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_BDAT                               29
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_BERC                               30
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_BCNT                               31
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_IDLE                               32
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_UHP                                33
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_ULMP                               34
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_UTP                                35
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_UDVN                               36
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_UDEF                               37
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_ERR                                38
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_TS1A                               39
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_TS1B                               40
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_DPHN                               41
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_CTLB                               42
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_DATB                               43
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_SYNC                               44
#define RSSCOPE_VAL_MPHY_SSIC_FRAME_TYPE_SDS                                45

// RsScope_rngMPHYScrambleMode
#define RSSCOPE_VAL_MPHY_SCRAMBLE_MODE_SCRM                                 0
#define RSSCOPE_VAL_MPHY_SCRAMBLE_MODE_NSCR                                 1

// RsScope_rngProtocolUSB31Gen1Type
#define RSSCOPE_VAL_USB31_GEN1_TYPE_SS                                      0
#define RSSCOPE_VAL_USB31_GEN1_TYPE_SSP                                     1

// RsScope_rngDeembeddingComponentPort
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_PORT_1                            1
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_PORT_2                            2
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_PORT_3                            3
#define RSSCOPE_VAL_DEEMBEDDING_COMPONENT_PORT_4                            4

// RsScope_rngDelimiter
#define RSSCOPE_VAL_SEMICOLON                                               0
#define RSSCOPE_VAL_COMMA                                                   1
#define RSSCOPE_VAL_SPACE                                                   2
#define RSSCOPE_VAL_TAB                                                     3
#define RSSCOPE_VAL_COLON                                                   4

// rsscope_rngEyeDiagramSource
#define RSSCOPE_VAL_EYE_SOURCE_C1W1                                         0
#define RSSCOPE_VAL_EYE_SOURCE_C2W1                                         1
#define RSSCOPE_VAL_EYE_SOURCE_C3W1                                         2
#define RSSCOPE_VAL_EYE_SOURCE_C4W1                                         3
#define RSSCOPE_VAL_EYE_SOURCE_M1                                           4
#define RSSCOPE_VAL_EYE_SOURCE_M2                                           5
#define RSSCOPE_VAL_EYE_SOURCE_M3                                           6
#define RSSCOPE_VAL_EYE_SOURCE_M4                                           7
#define RSSCOPE_VAL_EYE_SOURCE_R1                                           8
#define RSSCOPE_VAL_EYE_SOURCE_R2                                           9
#define RSSCOPE_VAL_EYE_SOURCE_R3                                           10
#define RSSCOPE_VAL_EYE_SOURCE_R4                                           11
#define RSSCOPE_VAL_EYE_SOURCE_M5                                           12
#define RSSCOPE_VAL_EYE_SOURCE_M6                                           13
#define RSSCOPE_VAL_EYE_SOURCE_M7                                           14
#define RSSCOPE_VAL_EYE_SOURCE_M8                                           15

// RsScope_rngEyeDiagramVerticalReferenceLevel
#define RSSCOPE_VAL_REF_LEVEL_LOWER                                         0
#define RSSCOPE_VAL_REF_LEVEL_MIDDLE                                        1
#define RSSCOPE_VAL_REF_LEVEL_UPPER                                         2

// RsScope_rngEyeDiagramEyeStripeDisplayMode
#define RSSCOPE_VAL_EYE_DIAGRAM_DISPLAY_MODE_NEVER                          0
#define RSSCOPE_VAL_EYE_DIAGRAM_DISPLAY_MODE_MASK_TEST_ONLY                 1
#define RSSCOPE_VAL_EYE_DIAGRAM_DISPLAY_MODE_ALWAYS                         2

// RsScope_rngEyeDiagramGateCouplingMode
#define RSSCOPE_VAL_GATE_COUPLING_MODE_NONE                                 0
#define RSSCOPE_VAL_GATE_COUPLING_MODE_CURSOR                               1
#define RSSCOPE_VAL_GATE_COUPLING_MODE_ZOOM                                 2

// rsscope_rngEyeDiagramSignalCondition
#define RSSCOPE_VAL_COND_INR                                                5
#define RSSCOPE_VAL_COND_OOR                                                6

// RsScope_rngGPIBTerminator
#define RSSCOPE_VAL_TERMINATOR_LFEOI                                        0
#define RSSCOPE_VAL_TERMINATOR_EOI                                          1

// RsScope_rngProbeTipModule
#define RSSCOPE_VAL_PROBE_TIP_NONE                                          0
#define RSSCOPE_VAL_PROBE_TIP_ZMA10                                         1
#define RSSCOPE_VAL_PROBE_TIP_ZMA12                                         2
#define RSSCOPE_VAL_PROBE_TIP_ZMA15                                         3
#define RSSCOPE_VAL_PROBE_TIP_ZMA30                                         4
#define RSSCOPE_VAL_PROBE_TIP_ZMA40                                         5
#define RSSCOPE_VAL_PROBE_TIP_ZMA50                                         6
#define RSSCOPE_VAL_PROBE_TIP_ZMA14                                         7
#define RSSCOPE_VAL_PROBE_TIP_CUSTOM                                        8

// RsScope_rngProbeDeembeddingZMA30SelectTipDistance
#define RSSCOPE_VAL_PROBE_ZMA30_TIP_DISTANCE_16                             0
#define RSSCOPE_VAL_PROBE_ZMA30_TIP_DISTANCE_25                             1
#define RSSCOPE_VAL_PROBE_ZMA30_TIP_DISTANCE_45                             2
#define RSSCOPE_VAL_PROBE_ZMA30_TIP_DISTANCE_75                             3

// RsScope_rngProbeDeembeddingZMA40SelectTipSubmodule
#define RSSCOPE_VAL_PROBE_ZMA40_TIP_NONE                                    0
#define RSSCOPE_VAL_PROBE_ZMA40_TIP_SRCS                                    1

// RsScope_rngRemoteTraceFileFormat
#define RSSCOPE_VAL_FILE_TYPE_ASCII                                         0
#define RSSCOPE_VAL_FILE_TYPE_XML                                           1

// RsScope_rngConditionAndOr
#define RSSCOPE_VAL_CONDITIONS_AND                                          0
#define RSSCOPE_VAL_CONDITIONS_OR                                           1

// RsScope_rngComplexWordPatternCondition
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_IN_RANGE                      0
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_OUT_OF_RANGE                  1
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_EQUAL                         2
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_NOT_EQUAL                     3
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_LESS_THAN                     4
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_LESS_OR_EQUAL                 5
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_GREATER_THAN                  6
#define RSSCOPE_VAL_COMPLEX_PATTERN_CONDITION_GREATER_OR_EQUAL              7

// RsScope_rngSerialPatternType
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_SBP                                 0
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_DBP                                 1
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_CBP                                 2
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_PRBS                                3
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_EBTB                                4
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_I32B                                5
#define RSSCOPE_VAL_SERIAL_PATTERN_MODE_I30B                                6

// RsScope_rngProbeConverterType
#define RSSCOPE_VAL_PROBE_CONVERTER_NONE                                    0
#define RSSCOPE_VAL_PROBE_CONVERTER_Z1M                                     1

// RsScope_rngProbeRTZ1MBandwidthLimit
#define RSSCOPE_VAL_PROBE_Z1M_BANDWIDTH_FULL                                0
#define RSSCOPE_VAL_PROBE_Z1M_BANDWIDTH_B200                                1
#define RSSCOPE_VAL_PROBE_Z1M_BANDWIDTH_B20                                 2

// RsScope_rngComplexWordAlignmentType
#define RSSCOPE_VAL_COMPLEX_WORD_ALIGNMENT_PATTERN                          0
#define RSSCOPE_VAL_COMPLEX_WORD_ALIGNMENT_TIMEOUT                          1

// RsScope_rngComplexWordIdleRange
#define RSSCOPE_VAL_COMPLEX_WORD_IDLE_IN_RANGE                              0
#define RSSCOPE_VAL_COMPLEX_WORD_IDLE_OUT_OF_RANGE                          1

// RsScope_rngComplexWordBitOrder
#define RSSCOPE_VAL_COMPLEX_WORD_LEAST_FIRST                                0
#define RSSCOPE_VAL_COMPLEX_WORD_MOST_FIRST                                 1

// RsScope_rngPRBSSequence
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS7                                     0
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS9                                     1
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS11                                    2
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS15                                    3
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS16                                    4
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS17                                    5
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS20                                    6
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS23                                    7
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS29                                    8
#define RSSCOPE_VAL_PRBS_SEQUENCE_PRBS31                                    9

// RsScope_rngEbTbAlignmentSymbol
#define RSSCOPE_VAL_EBTB_ALIGNMENT_SYMBOL_K281                              0
#define RSSCOPE_VAL_EBTB_ALIGNMENT_SYMBOL_K285                              1
#define RSSCOPE_VAL_EBTB_ALIGNMENT_SYMBOL_K287                              2

// RsScope_rngEbTbScrambling
#define RSSCOPE_VAL_EBTB_UNSCRABLED                                         0
#define RSSCOPE_VAL_EBTB_SCRABLED                                           1

// RsScope_rngI32BType
#define RSSCOPE_VAL_I32B_TYPE_CONTROL_BLOCK                                 0
#define RSSCOPE_VAL_I32B_TYPE_DATA_BLOCK                                    1

// RsScope_rngFrameID
#define RSSCOPE_VAL_EBTB_FRAME_ID_K280                                      0

// RsScope_rngDifferentialOutput
#define RSSCOPE_VAL_DIFFERENTIAL_OUTPUT_POSITIVE                            0
#define RSSCOPE_VAL_DIFFERENTIAL_OUTPUT_NEGATIVE                            1
#define RSSCOPE_VAL_DIFFERENTIAL_OUTPUT_DIFF                                2
#define RSSCOPE_VAL_DIFFERENTIAL_OUTPUT_COMMON                              3

// RsScope_rngSpectrumResultMode
#define RSSCOPE_VAL_SPECTRUM_RESULT_MODE_ABSOLUTE                           0
#define RSSCOPE_VAL_SPECTRUM_RESULT_MODE_RELATIVE                           1

// RsScope_rngPulseSourceClockMode
#define RSSCOPE_VAL_PULSE_SOURCE_CLOCK_LOCKED                               0
#define RSSCOPE_VAL_PULSE_SOURCE_CLOCK_FREERUNNING                          1

// RsScope_rngDDRStandard
#define RSSCOPE_VAL_DDR_STANDARD_DDR3                                       0
#define RSSCOPE_VAL_DDR_STANDARD_DDR4                                       1

// RsScope_rngCalibrationResult
#define RSSCOPE_VAL_CALIBRATION_RESULT_FAIL                                 0
#define RSSCOPE_VAL_CALIBRATION_RESULT_PASS                                 1
#define RSSCOPE_VAL_CALIBRATION_RESULT_NOAL                                 2

// RsScope_rngHardwareSerialStandard
#define RSSCOPE_VAL_SERIAL_STANDARD_CUSTOM                                  0
#define RSSCOPE_VAL_SERIAL_STANDARD_USB20                                   1
#define RSSCOPE_VAL_SERIAL_STANDARD_DISPPORT11                              4
#define RSSCOPE_VAL_SERIAL_STANDARD_FIBCHAN1                                6
#define RSSCOPE_VAL_SERIAL_STANDARD_FIBCHAN2                                7
#define RSSCOPE_VAL_SERIAL_STANDARD_HDMI12                                  11
#define RSSCOPE_VAL_SERIAL_STANDARD_PCIGEN1                                 14
#define RSSCOPE_VAL_SERIAL_STANDARD_USB31_GEN1                              20
#define RSSCOPE_VAL_SERIAL_STANDARD_DISPPORT_12                             21
#define RSSCOPE_VAL_SERIAL_STANDARD_FIB_CHAN4                               22
#define RSSCOPE_VAL_SERIAL_STANDARD_FIB_CHAN8                               23
#define RSSCOPE_VAL_SERIAL_STANDARD_HDMI_14                                 24
#define RSSCOPE_VAL_SERIAL_STANDARD_HDMI_20                                 25
#define RSSCOPE_VAL_SERIAL_STANDARD_PCI_GEN2                                26
#define RSSCOPE_VAL_SERIAL_STANDARD_SATA_GEN1                               27
#define RSSCOPE_VAL_SERIAL_STANDARD_SATA_GEN2                               28
#define RSSCOPE_VAL_SERIAL_STANDARD_SATA_GEN3                               29
#define RSSCOPE_VAL_SERIAL_STANDARD_SAS_GEN1                                30
#define RSSCOPE_VAL_SERIAL_STANDARD_SAS_GEN2                                31
#define RSSCOPE_VAL_SERIAL_STANDARD_XAUII                                   32

// RsScope_rngBitRateSource
#define RSSCOPE_VAL_BIT_RATE_SOURCE_C1W1                                    0
#define RSSCOPE_VAL_BIT_RATE_SOURCE_C2W1                                    1
#define RSSCOPE_VAL_BIT_RATE_SOURCE_C3W1                                    2
#define RSSCOPE_VAL_BIT_RATE_SOURCE_C4W1                                    3
#define RSSCOPE_VAL_BIT_RATE_SOURCE_M1                                      4
#define RSSCOPE_VAL_BIT_RATE_SOURCE_M2                                      5
#define RSSCOPE_VAL_BIT_RATE_SOURCE_M3                                      6
#define RSSCOPE_VAL_BIT_RATE_SOURCE_M4                                      7
#define RSSCOPE_VAL_BIT_RATE_SOURCE_R1                                      8
#define RSSCOPE_VAL_BIT_RATE_SOURCE_R2                                      9
#define RSSCOPE_VAL_BIT_RATE_SOURCE_R3                                      10
#define RSSCOPE_VAL_BIT_RATE_SOURCE_R4                                      11

// RsScope_rngSoftwareSerialStandard
#define RSSCOPE_VAL_SERIAL_STANDARD_USB31GEN1                               2
#define RSSCOPE_VAL_SERIAL_STANDARD_USB31GEN2                               3
#define RSSCOPE_VAL_SERIAL_STANDARD_DISPPORT12                              5
#define RSSCOPE_VAL_SERIAL_STANDARD_FIBCHAN4                                8
#define RSSCOPE_VAL_SERIAL_STANDARD_FIBCHAN8                                9
#define RSSCOPE_VAL_SERIAL_STANDARD_FIBCHAN16                               10
#define RSSCOPE_VAL_SERIAL_STANDARD_HDMI14                                  12
#define RSSCOPE_VAL_SERIAL_STANDARD_HDMI20                                  13
#define RSSCOPE_VAL_SERIAL_STANDARD_PCIGEN2                                 15
#define RSSCOPE_VAL_SERIAL_STANDARD_PCIGEN3                                 16
#define RSSCOPE_VAL_SERIAL_STANDARD_PCIGEN4                                 17
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN1500                             18
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN11667                            19
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN1                                20
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN2500                             21
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN21667                            22
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN2                                23
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN3500                             24
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN31667                            25
#define RSSCOPE_VAL_SERIAL_STANDARD_SATAGEN3                                26
#define RSSCOPE_VAL_SERIAL_STANDARD_SASGEN1                                 27
#define RSSCOPE_VAL_SERIAL_STANDARD_SASGEN2                                 28
#define RSSCOPE_VAL_SERIAL_STANDARD_SASGEN3                                 29
#define RSSCOPE_VAL_SERIAL_STANDARD_TB10G                                   30
#define RSSCOPE_VAL_SERIAL_STANDARD_XAUI                                    31

// RsScope_rngDifferentialInput
#define RSSCOPE_VAL_DIFFERENTIAL_INPUT_C1W1                                 1
#define RSSCOPE_VAL_DIFFERENTIAL_INPUT_C2W1                                 2
#define RSSCOPE_VAL_DIFFERENTIAL_INPUT_C3W1                                 3
#define RSSCOPE_VAL_DIFFERENTIAL_INPUT_C4W1                                 4

// RsScope_rngEyeDiagramDDRFrameFilter
#define RSSCOPE_VAL_DDR_FRAME_FILTER_ANY                                    0
#define RSSCOPE_VAL_DDR_FRAME_FILTER_ANY_CONSEC                             1
#define RSSCOPE_VAL_DDR_FRAME_FILTER_READ                                   2
#define RSSCOPE_VAL_DDR_FRAME_FILTER_WRITE                                  3
#define RSSCOPE_VAL_DDR_FRAME_FILTER_READ_NONCONSEC                         4
#define RSSCOPE_VAL_DDR_FRAME_FILTER_WRITE_NONCONSEC                        5

// RsScope_rngTriggerToFrameDirection
#define RSSCOPE_VAL_TRIGGER_TO_FRAME_DIRECTION_T2F                          0
#define RSSCOPE_VAL_TRIGGER_TO_FRAME_DIRECTION_F2T                          1

// RsScope_rngProbeAdapterType
#define RSSCOPE_VAL_PROBE_ADAPTER_NONE                                      0
#define RSSCOPE_VAL_PROBE_ADAPTER_Z2T                                       1

// RsScope_rngProbePredefinedTektronics
#define RSSCOPE_VAL_TEKTONICS_PROBE_NONE                                    0
#define RSSCOPE_VAL_TEKTONICS_PROBE_P5205A50                                1
#define RSSCOPE_VAL_TEKTONICS_PROBE_P5205A500                               2
#define RSSCOPE_VAL_TEKTONICS_PROBE_P5210A100                               3
#define RSSCOPE_VAL_TEKTONICS_PROBE_P5210A1000                              4
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6205                                   5
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6241                                   6
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6243                                   7
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6245                                   8
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6246A1                                 9
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6246A10                                10
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6247A1                                 11
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6247A10                                12
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6248A1                                 13
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6248A10                                14
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6249                                   15
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6250A5                                 16
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6250A50                                17
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6251A5                                 18
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6251A50                                19
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6701B                                  20
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6703B                                  21
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6711                                   22
#define RSSCOPE_VAL_TEKTONICS_PROBE_P6713                                   23
#define RSSCOPE_VAL_TEKTONICS_PROBE_TCP202                                  24

// RsScope_rngTDRTDTAnalysisType
#define RSSCOPE_VAL_TDR_TDT_ANALYSIS_TYPE_TDR                               0
#define RSSCOPE_VAL_TDR_TDT_ANALYSIS_TYPE_TDT                               1
#define RSSCOPE_VAL_TDR_TDT_ANALYSIS_TYPE_BOTH                              2

// RsScope_rngTDRTDTPulseChannel
#define RSSCOPE_VAL_TDR_TDT_CHANNEL_C1W1                                    1
#define RSSCOPE_VAL_TDR_TDT_CHANNEL_C2W1                                    2
#define RSSCOPE_VAL_TDR_TDT_CHANNEL_C3W1                                    3
#define RSSCOPE_VAL_TDR_TDT_CHANNEL_C4W1                                    4

// RsScope_rngTDRTDTDomain
#define RSSCOPE_VAL_TDR_TDT_DOMAIN_TIME                                     0
#define RSSCOPE_VAL_TDR_TDT_DOMAIN_DISTANCE_METRES                          1
#define RSSCOPE_VAL_TDR_TDT_DOMAIN_DISTANCE_INCHES                          2

// RsScope_rngProbeChannel
#define RSSCOPE_VAL_ZVC_CHANNEL_V1                                          0
#define RSSCOPE_VAL_ZVC_CHANNEL_V2                                          2
#define RSSCOPE_VAL_ZVC_CHANNEL_V3                                          1
#define RSSCOPE_VAL_ZVC_CHANNEL_V4                                          3
#define RSSCOPE_VAL_ZVC_CHANNEL_I1                                          4
#define RSSCOPE_VAL_ZVC_CHANNEL_I2                                          5
#define RSSCOPE_VAL_ZVC_CHANNEL_I3                                          6
#define RSSCOPE_VAL_ZVC_CHANNEL_I4                                          7

// RsScope_rngTDRTDTConfiguration
#define RSSCOPE_VAL_TDR_TDT_CONFIGURATION_SINGLE_ENDED                      0
#define RSSCOPE_VAL_TDR_TDT_CONFIGURATION_DIFFERENTIAL                      1

// RsScope_rngRFFEReadMode
#define RSSCOPE_VAL_RFFE_READ_MODE_STRD                                     0
#define RSSCOPE_VAL_RFFE_READ_MODE_SREAD                                    1

// RsScope_rngRFFEVersion
#define RSSCOPE_VAL_RFFE_VERSION_V1DX                                       0
#define RSSCOPE_VAL_RFFE_VERSION_V2D0                                       1
#define RSSCOPE_VAL_RFFE_VERSION_V2D1                                       2
#define RSSCOPE_VAL_RFFE_VERSION_V3D0                                       3

// RsScope_rngDecimalSymbol
#define RSSCOPE_VAL_DECIMAL_SYMBOL_POINT                                    0
#define RSSCOPE_VAL_DECIMAL_SYMBOL_COMMA                                    1

// RsScope_rngProtocolEthernetTriggerDataCondition
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_EQU                               0
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_NEQ                               1
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_LTH                               2
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_LETH                              3
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_GTH                               4
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_GETH                              5
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_INR                               6
#define RSSCOPE_VAL_ETHERNET_TRIGGER_COND_OOR                               7

// RsScope_rngProtocolRFFETriggerMaskCondition
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_EQU                                   0
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_NEQ                                   1
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_LTH                                   2
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_LETH                                  3
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_GTH                                   4
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_GETH                                  5
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_INR                                   6
#define RSSCOPE_VAL_RFFE_TRIGGER_COND_OOR                                   7

// RsScope_rngAdvancedJitterSignalType
#define RSSCOPE_VAL_ADVANCED_JITTER_SIGNAL_TYPE_CLOCK                       0
#define RSSCOPE_VAL_ADVANCED_JITTER_SIGNAL_TYPE_DATA_NRZ                    1

// RsScope_rngAdvancedJitterReferenceSource
#define RSSCOPE_VAL_ADVANCED_JITTER_REFERENCE_SOURCE_CDR                    0
#define RSSCOPE_VAL_ADVANCED_JITTER_REFERENCE_SOURCE_CLOCK                  1

// RsScope_rngAdvancedJitterReferenceCDRSource
#define RSSCOPE_VAL_ADVANCED_JITTER_CDR_SW1                                 1
#define RSSCOPE_VAL_ADVANCED_JITTER_CDR_SW2                                 2
#define RSSCOPE_VAL_ADVANCED_JITTER_CDR_SIGN                                3
#define RSSCOPE_VAL_ADVANCED_JITTER_CDR_HW                                  4
#define RSSCOPE_VAL_ADVANCED_JITTER_CDR_REF                                 5

// RsScope_rngAdvancedJitterResultsBathtubPlotType
#define RSSCOPE_VAL_BATHTUP_PLOT_TOTAL_JITTER                               0
#define RSSCOPE_VAL_BATHTUP_PLOT_DATA_AND_RANDOM_JITTER                     1
#define RSSCOPE_VAL_BATHTUP_PLOT_TOTAL_DDJ                                  2
#define RSSCOPE_VAL_BATHTUP_PLOT_TOTAL_DDJP                                 3
#define RSSCOPE_VAL_BATHTUP_PLOT_TOTAL_DDJB                                 4
#define RSSCOPE_VAL_BATHTUP_PLOT_TOTAL_DDJO                                 5

// RsScope_rngAdvancedJitterSyntheticEyePlot
#define RSSCOPE_VAL_ADVANCED_JITTER_SYNTHETIC_EYE_DETERMINISTIC             0
#define RSSCOPE_VAL_ADVANCED_JITTER_SYNTHETIC_EYE_DATA_DEPENDENT            1
#define RSSCOPE_VAL_ADVANCED_JITTER_SYNTHETIC_EYE_DDPH                      2
#define RSSCOPE_VAL_ADVANCED_JITTER_SYNTHETIC_EYE_DDPV                      3

// RsScope_rngAdvancedJitterResultsDiagramTransitions
#define RSSCOPE_VAL_ADVANCED_JITTER_TRANSITIONS_BOTH                        0
#define RSSCOPE_VAL_ADVANCED_JITTER_TRANSITIONS_RISING                      1
#define RSSCOPE_VAL_ADVANCED_JITTER_TRANSITIONS_FALLING                     2

// RsScope_rngAdvancedJitterScalingMeasurement
#define RSSCOPE_VAL_ADVANCED_JITTER_SCALING_SYMBOL_RATE                     1
#define RSSCOPE_VAL_ADVANCED_JITTER_SCALING_SYMBOL_DURATION                 2

// RsScope_rngAdvancedJitterPeriodicDirection
#define RSSCOPE_VAL_ADVANCED_JITTER_PERIODIC_DIRECTION_UNDEFINED            0
#define RSSCOPE_VAL_ADVANCED_JITTER_PERIODIC_DIRECTION_VERTICAL             1
#define RSSCOPE_VAL_ADVANCED_JITTER_PERIODIC_DIRECTION_HORIZONTAL_EXTRINSIC 2
#define RSSCOPE_VAL_ADVANCED_JITTER_PERIODIC_DIRECTION_HORIZONTAL_INTRINSIC 3

// rsscope_rngWaveformParameterHistogram
#define RSSCOPE_VAL_WAV_RNHIST1                                             181
#define RSSCOPE_VAL_WAV_RNHIST2                                             182
#define RSSCOPE_VAL_WAV_RJDHIST1                                            205
#define RSSCOPE_VAL_WAV_RJDHIST2                                            206

// rsscope_rngProtocolMeasurementType
#define RSSCOPE_VAL_MEAS_PROTOCOL_NONE                                      0
#define RSSCOPE_VAL_MEAS_PROTOCOL_AUDIO                                     1
#define RSSCOPE_VAL_MEAS_PROTOCOL_FRAME_TO_FRAME                            2
#define RSSCOPE_VAL_MEAS_PROTOCOL_TRIGGER_TO_FRAME                          3
#define RSSCOPE_VAL_MEAS_PROTOCOL_FIELD_VALUE                               4
#define RSSCOPE_VAL_MEAS_PROTOCOL_GAP                                       5
#define RSSCOPE_VAL_MEAS_PROTOCOL_MBITRATE                                  6
#define RSSCOPE_VAL_MEAS_PROTOCOL_SBITRATE                                  7
#define RSSCOPE_VAL_MEAS_PROTOCOL_BUS_IDLE                                  8
#define RSSCOPE_VAL_MEAS_PROTOCOL_FRAME_COUNT                               9
#define RSSCOPE_VAL_MEAS_PROTOCOL_FRAME_ERROR_COUNT                         10
#define RSSCOPE_VAL_MEAS_PROTOCOL_FRAME_ERROR_RATE                          11
#define RSSCOPE_VAL_MEAS_PROTOCOL_CONSECUTIVE_FRAME_ERROR_RATE              12

// rsscope_rngProtocolUSBSearchDataType
#define RSSCOPE_VAL_USB_DATA_TYPE_ANY                                       4

// rsscope_rngProtocolUSBSearchSpecialPID
#define RSSCOPE_VAL_USB_SPECIAL_PID_ANY                                     4

// rsscope_rngProtocolUSBSearchToken
#define RSSCOPE_VAL_USB_TOKEN_ANY                                           4

// RsScope_rngIQInputSampleRate
#define RSSCOPE_VAL_IQ_SRATE_10_GSA                                         0
#define RSSCOPE_VAL_IQ_SRATE_20_GSA                                         1
#define RSSCOPE_VAL_IQ_SRATE_40_GSA                                         2

// RsScope_rngAdvancedJitterResultsDiagramLevels
#define RSSCOPE_VAL_ADVANCED_JITTER_LEVELS_BOTH                             0
#define RSSCOPE_VAL_ADVANCED_JITTER_LEVELS_LOW                              1
#define RSSCOPE_VAL_ADVANCED_JITTER_LEVELS_HIGH                             2

// RsScope_rngProtocol1000BASE_T1FrameStatus
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_OK                                    0
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_INCOMPLETE                            1
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_ERR_FEC                               2
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_ERR_ZERO                              3
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_ERR_OOR                               4
#define RSSCOPE_VAL_TBTO_FRAME_STATUS_ERR_CRC                               5

// RsScope_rngProtocol1000BASE_T1FrameType
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_IDLE                                    0
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_MAC                                     1
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_OAM                                     2
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_RSFEC                                   3
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_ZEROTSYM                                4
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_UNKNOWN                                 5
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_BH                                      6
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_CTLADDRR                                7
#define RSSCOPE_VAL_TBTO_FRAME_TYPE_CTLCODE                                 8

// RsScope_rngUSBDSPChannelLength
#define RSSCOPE_VAL_USBDSP_CHANNEL_LENGTH_OFF                               0
#define RSSCOPE_VAL_USBDSP_CHANNEL_LENGTH_LOWFLTR                           1
#define RSSCOPE_VAL_USBDSP_CHANNEL_LENGTH_HIGHFLTR                          2

// RsScope_rngEbTbSearchType
#define RSSCOPE_VAL_EBTB_SEARCH_TYPE_KD                                     0
#define RSSCOPE_VAL_EBTB_SEARCH_TYPE_EB                                     1
#define RSSCOPE_VAL_EBTB_SEARCH_TYPE_TB                                     2
#define RSSCOPE_VAL_EBTB_SEARCH_TYPE_EXPRESSION                             3
#define RSSCOPE_VAL_EBTB_SEARCH_TYPE_ERROR                                  4

// RsScope_rngTriggerTLPATType
#define RSSCOPE_VAL_TRIGGER_TLPAT_TYPE_ANY                                  0
#define RSSCOPE_VAL_TRIGGER_TLPAT_TYPE_UNTRANSLATED                         1
#define RSSCOPE_VAL_TRIGGER_TLPAT_TYPE_TRANSLATED_REQ                       2
#define RSSCOPE_VAL_TRIGGER_TLPAT_TYPE_TRANSLATED                           3
#define RSSCOPE_VAL_TRIGGER_TLPAT_TYPE_UNRECOGNISED_REQ                     4

// RsScope_rngJitterDataMeasurementUnit
#define RSSCOPE_VAL_JITTER_DATA_MEASUREMENT_UNIT_BIT_S                      0
#define RSSCOPE_VAL_JITTER_DATA_MEASUREMENT_UNIT_HZ                         1

// RsScope_rngArithmeticOperationType
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBM                           0
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DB                            1
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DB_HZ                         2
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DB_GHZ                        3
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBC                           4
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBC_HZ                        5
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBPW_HZ                       6
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBW                           7
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBPW                          8
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBM_HZ                        9
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMW                          10
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_W                             11
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_MW                            12
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_W_HZ                          13
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_J                             14
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_S                           15
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_A_S                           16
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBV                           17
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMV                          18
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMV_HZ                       19
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMV_MHZ                      20
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV                          21
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV_HZ                       22
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV_SQRT_HZ                  23
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV_MHZ                      24
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV_M                        25
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMV_M_HZ                     26
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUV_M_MHZ                    27
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V                             28
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_MV                            29
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UV                            30
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VPP                           31
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VV                            32
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UV_HZ                         33
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UV_M_HZ                       34
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_SQRT_HZ                     35
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBA                           36
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMA                          37
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMA_HZ                       38
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMA_MHZ                      39
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA                          40
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_HZ                       41
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_SQRT_HZ                  42
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_MHZ                      43
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_M                        44
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_M_HZ                     45
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUA_M_MHZ                    46
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_A                             47
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UA_HZ                         48
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UA_M_HZ                       49
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_A_SQRT_HZ                     50
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_PCT                           51
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBPT                          52
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBPT_HZ                       53
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_H                             54
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_PH_GHZ                        55
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_F                             56
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_FF_GHZ                        57
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_OHM                           58
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_SIEMENS                       59
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_S                             60
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBPS                          61
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBNS                          62
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBUS                          63
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMS                          64
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBS                           65
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_HZ                            66
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBHZ                          67
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBKHZ                         68
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBMHZ                         69
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DBGHZ                         70
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_M                             71
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_IN                            72
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DEG                           73
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_RAD                           74
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_SYMB                          75
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VA_LIN                        76
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VA_LOG                        77
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_NONE                          78
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_IRE                           79
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_MILES                         80
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_SYMB_S                        81
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_MSYMB_S                       82
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_MBIT_S                        83
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_BIT_S                         84
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_BIT                           85
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_WORD                          86
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_PPM                           87
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_PER_SEC                       88
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_S_DIV                         89
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_HZ_DIV                        90
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_DIV                         91
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_A_DIV                         92
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_OHM_DIV                       93
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_NONE_DIV                      94
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_DIV                           95
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_BER                           96
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_S_S                           97
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_BAUD                          98
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_TDEG                          99
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VS                            100
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_USER                          101
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UINV                          102
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_W_DIV                         103
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_V                           104
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_A_V                           105
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_W_V                           106
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_BYTS                          107
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_A                           108
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_V_W                           109
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VA                            110
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_VAR                           111
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_UI                            112
#define RSSCOPE_VAL_ARITHMETIC_OPERATION_TYPE_LN                            113

// RsScope_rngSpectrumArithmeticOperator
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_OPERATOR_ADDITION                   0
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_OPERATOR_SUBTRACTION                1
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_OPERATOR_MULTIPLICATION             2
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_OPERATOR_DIVISION                   3

// RsScope_rngAmplitudeTimeArithmeticParameterMeasurementType
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_HIGH           0
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_LOW            1
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_AMPLITUDE      2
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_MAXIMUM        3
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_MINIMUM        4
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PDELTA         5
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_MEAN           6
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_RMS            7
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_STDDEV         8
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_POVERSHOOT     9
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_NOVERSHOOT     10
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_AREA           11
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_RTIME          12
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_FTIME          13
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PPULSE         14
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_NPULSE         15
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PERIOD         16
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_FREQUENCY      17
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PDCYCLE        18
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_NDCYCLE        19
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CYCAREA        20
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CYCMEAN        21
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CYCRMS         22
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CYCSTDDEV      23
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PULCNT         24
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_DELAY          25
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PHASE          26
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_BWIDTH         27
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PSWITCHING     28
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_NSWITCHING     29
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PULSETRAIN     30
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_EDGECOUNT      31
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SETUP          32
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_HOLD           33
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SHT            34
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SHR            35
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CCJITTER       36
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_NCJITTER       37
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CCWIDTH        38
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_CCDUTYCYCLE    39
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_TIE            40
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_UINTERVAL      41
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_DRATE          42
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SKWDELAY       43
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SKWPHASE       44
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_DTOTRIGGER     45
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_PROBEMETER     46
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SLERISING      47
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_SLEFALLING     48
#define RSSCOPE_VAL_AMPLITUDE_TIME_ARITHMETIC_OPERATION_TYPE_ATAR           49

// RsScope_rngSpectrumArithmeticMeasurementSpectrum
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_CPOWER         0
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_AC_POWER       1
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_OBWIDTH        2
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_TOI            3
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_AMMOD          4
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THD            5
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THD_PCT        6
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THD_A          7
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THD_U          8
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THD_R          9
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_PEAK_LIST      10
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_HAR            11
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_THDF           12
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_SPAR           13
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_MEASUREMENT_SPECTRUM_SBW            14

// RsScope_rngSpectrumArithmeticParameterGroup
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_IMEAS               0
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS1               1
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS2               2
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS3               3
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS4               4
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS5               5
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS6               6
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS7               7
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_MEAS8               8
#define RSSCOPE_VAL_SPECTRUM_ARITHMETIC_PARAMETER_GROUP_QUIC                9

// RsScope_rngArithmeticMeasurementType
#define RSSCOPE_VAL_ARITHMETIC_MEASUREMENT_TYPE_MEASUREMENT                 0
#define RSSCOPE_VAL_ARITHMETIC_MEASUREMENT_TYPE_CONSTANT                    1

// RsScope_rngFFTType
#define RSSCOPE_VAL_FFT_TYPE_MAGNITUDE                                      0
#define RSSCOPE_VAL_FFT_TYPE_PHASE                                          1

// RsScope_rngTriggerConditionType
#define RSSCOPE_VAL_TRIGGER_CONDITION_TYPE_KD_SYMBOL                        0
#define RSSCOPE_VAL_TRIGGER_CONDITION_TYPE_EB_PATTERN                       1
#define RSSCOPE_VAL_TRIGGER_CONDITION_TYPE_TB_PATTERN                       2
#define RSSCOPE_VAL_TRIGGER_CONDITION_TYPE_EXPRESSION                       3
#define RSSCOPE_VAL_TRIGGER_CONDITION_TYPE_ERROR                            4

// RsScope_rngI30BType
#define RSSCOPE_VAL_I30_B_TYPE_OS                                           0
#define RSSCOPE_VAL_I30_B_TYPE_DAT                                          1

// RsScope_rngTriggerOutAction
#define RSSCOPE_VAL_TRIGGER_OUT_NO_ACTION                                   0
#define RSSCOPE_VAL_TRIGGER_OUT_TRIGGER                                     1

// rsscope_rngExternalFrontendChannel
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_CHANNEL1                              1
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_CHANNEL2                              2
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_CHANNEL3                              3
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_CHANNEL4                              4

// rsscope_rngExtFrontendMeasSetup
#define RSSCOPE_VAL_EXT_FRONTEND_SETUP_COULO                                0
#define RSSCOPE_VAL_EXT_FRONTEND_SETUP_COUREF                               1
#define RSSCOPE_VAL_EXT_FRONTEND_SETUP_ADVANCED                             2

// rsscope_rngExtFrontendScalingMode
#define RSSCOPE_VAL_EF_SCAL_MODE_RF                                         0
#define RSSCOPE_VAL_EF_SCAL_MODE_IF                                         1

// rsscope_rngExternalFrontendLOInput
#define RSSCOPE_VAL_EXT_FRONTEND_LO_INPUT_INTERNAL                          0
#define RSSCOPE_VAL_EXT_FRONTEND_LO_INPUT_EXTERNAL                          1

// rsscope_rngExportEyeSelect
#define RSSCOPE_VAL_EXPORT_EYE_SELECT_EYE1                                  0
#define RSSCOPE_VAL_EXPORT_EYE_SELECT_EYE2                                  1
#define RSSCOPE_VAL_EXPORT_EYE_SELECT_EYE3                                  2
#define RSSCOPE_VAL_EXPORT_EYE_SELECT_EYE4                                  3

// rsscope_rngExportEyeSource
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_NONE                                  0
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C1W1                                  1
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C1W2                                  2
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C1W3                                  3
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C1W4                                  4
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C2W1                                  5
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C2W2                                  6
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C2W3                                  7
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C2W4                                  8
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C3W1                                  9
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C3W2                                  10
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C3W3                                  11
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C3W4                                  12
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C4W1                                  13
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C4W2                                  14
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C4W3                                  15
#define RSSCOPE_VAL_EXPORT_EYE_SOURCE_C4W4                                  16

// rsscope_rngEyeDiagramSoftwareCDR
#define RSSCOPE_VAL_EYE_DIAGRAM_SOFTWARE_CDR_SW1                            0
#define RSSCOPE_VAL_EYE_DIAGRAM_SOFTWARE_CDR_SW2                            1

// rsscope_rngTimingReferenceCDRType
#define RSSCOPE_VAL_TIMING_REFERENCE_CDR_TYPE_SW                            0
#define RSSCOPE_VAL_TIMING_REFERENCE_CDR_TYPE_HW                            1

// rsscope_rngTimingReferenceEdgeType
#define RSSCOPE_VAL_TIMING_REFERENCE_EDGE_TYPE_POSITIVE                     0
#define RSSCOPE_VAL_TIMING_REFERENCE_EDGE_TYPE_NEGATIVE                     1
#define RSSCOPE_VAL_TIMING_REFERENCE_EDGE_TYPE_EITHER                       2

// rsscope_rngTimingReferenceClockLevel
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_LEVEL_UPPER                      0
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_LEVEL_MIDDLE                     1
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_LEVEL_LOWER                      2

// rsscope_rngTimingReferenceClockSourceType
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_C1W1                 0
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_C2W1                 1
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_C3W1                 2
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_C4W1                 3
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M1                   4
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M2                   5
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M3                   6
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M4                   7
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M5                   8
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M6                   9
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M7                   10
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_M8                   11
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_R1                   12
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_R2                   13
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_R3                   14
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_R4                   15
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D0                   16
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D1                   17
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D2                   18
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D3                   19
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D4                   20
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D5                   21
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D6                   22
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D7                   23
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D8                   24
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D9                   25
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D10                  26
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D11                  27
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D12                  28
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D13                  29
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D14                  30
#define RSSCOPE_VAL_TIMING_REFERENCE_CLOCK_SOURCE_TYPE_D15                  31

// rsscope_rngTimingReferenceProtocolSerialBusIndex
#define RSSCOPE_VAL_TIMING_PROTOCOL_SERIAL_BUS_1                            0
#define RSSCOPE_VAL_TIMING_PROTOCOL_SERIAL_BUS_2                            1
#define RSSCOPE_VAL_TIMING_PROTOCOL_SERIAL_BUS_3                            2
#define RSSCOPE_VAL_TIMING_PROTOCOL_SERIAL_BUS_4                            3

// rsscope_rngTimingReferenceSignalSource
#define RSSCOPE_VAL_TIMING_REFERENCE_SIGNAL_SOURCE_CLOCK                    0
#define RSSCOPE_VAL_TIMING_REFERENCE_SIGNAL_SOURCE_CDR                      1
#define RSSCOPE_VAL_TIMING_REFERENCE_SIGNAL_SOURCE_PROTOCOL                 2

// rsscope_rngEyeJitterMeasurementHeightAlgorithm
#define RSSCOPE_VAL_EYE_JITTER_HEIGHT_ALGORITHM_ACTHEIGHT                   0
#define RSSCOPE_VAL_EYE_JITTER_HEIGHT_ALGORITHM_TSIGMA                      1

// RsScope_rngEyeJitterMeasurementWidthAlgorithm
#define RSSCOPE_VAL_EYE_JITTER_WIDTH_ALGORITHM_ACTWIDTH                     0
#define RSSCOPE_VAL_EYE_JITTER_WIDTH_ALGORITHM_TSIGMA                       1

// rsscope_rngEyeJitterMeasurementAlgorithm
#define RSSCOPE_VAL_EYE_JITTER_ALGORITHM_MEAN                               0
#define RSSCOPE_VAL_EYE_JITTER_ALGORITHM_PEAK                               1
#define RSSCOPE_VAL_EYE_JITTER_ALGORITHM_INNPEAK                            2
#define RSSCOPE_VAL_EYE_JITTER_ALGORITHM_OUTPEAK                            3

// RsScope_rngOpticalMeasurementValidRange
#define RSSCOPE_VAL_OPTICAL_MEASUREMENT_RANGE_ILIMIT                        0
#define RSSCOPE_VAL_OPTICAL_MEASUREMENT_RANGE_ULIMIT                        1
#define RSSCOPE_VAL_OPTICAL_MEASUREMENT_RANGE_LLIMIT                        2
#define RSSCOPE_VAL_OPTICAL_MEASUREMENT_RANGE_OLIMIT                        3

// RsScope_rngOpticalMeasurementUnit
#define RSSCOPE_VAL_OPTICAL_UNIT_WATT                                       0
#define RSSCOPE_VAL_OPTICAL_UNIT_DBM                                        1

// RsScope_rngCDRFilesAlgorithm
#define RSSCOPE_VAL_CDR_FILES_ALGORITHM_CFREQUENCY                          0
#define RSSCOPE_VAL_CDR_FILES_ALGORITHM_FF                                  1

// RsScope_rngCDRFilesAnalogSource
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_C1                              0
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_C2                              1
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_C3                              2
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_C4                              3
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_DIFF1                           4
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_DIFF2                           5
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_COMMON1                         6
#define RSSCOPE_VAL_CDR_FILES_ANALOG_SOURCE_COMMON2                         7

// RsScope_rngSearchEthernetType
#define RSSCOPE_VAL_SEARCH_ETHERNET_TYPE_FRAME                              0
#define RSSCOPE_VAL_SEARCH_ETHERNET_TYPE_ERROR                              1

// RsScope_rngCDRTriggerEyeAlgorithm
#define RSSCOPE_VAL_CDR_TRIGGER_ALGORITHM_CFREQUENCY                        0
#define RSSCOPE_VAL_CDR_TRIGGER_ALGORITHM_FF                                1

// RsScope_rngCDRTriggerEyeSerialStandard
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_CUSTOM                  0
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_USB20                   1
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_USB31GEN1               2
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_USB31GEN2               3
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_DISPPORT11              4
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_DISPPORT12              5
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_FIBCHAN1                6
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_FIBCHAN2                7
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_FIBCHAN4                8
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_FIBCHAN8                9
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_HDMI12                  10
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_HDMI14                  11
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_HDMI20                  12
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_PCIGEN1                 13
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_PCIGEN2                 14
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_PCIGEN3                 15
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_PCIGEN4                 16
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN1500             17
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN11667            18
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN1                19
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN2500             20
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN21667            21
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN2                22
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN3500             23
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN31667            24
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SATAGEN3                25
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SASGEN1                 26
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SASGEN2                 27
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_SASGEN3                 28
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_TB10G                   29
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SERIAL_STANDARD_XAUI                    30

// RsScope_rngCDRTriggerEyeSource
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SOURCE_C1                               0
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SOURCE_C2                               1
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SOURCE_C3                               2
#define RSSCOPE_VAL_CDR_TRIGGER_EYE_SOURCE_C4                               3

// RsScope_rngTriggerEventTriggerOut
#define RSSCOPE_VAL_TRIGGER_EVENT_TRIGGER_OUT_NOACTION                      0
#define RSSCOPE_VAL_TRIGGER_EVENT_TRIGGER_OUT_TRIGGER                       1

// RsScope_rngTriggerSequenceEvent
#define RSSCOPE_VAL_TRIGGER_SEQUENCE_EVENT_SINGLE                           0
#define RSSCOPE_VAL_TRIGGER_SEQUENCE_EVENT_SEQUENCE                         1

// RsScope_rngClockSignalEdge
#define RSSCOPE_VAL_CLOCK_SIGNAL_EDGE_POSITIVE                              0
#define RSSCOPE_VAL_CLOCK_SIGNAL_EDGE_NEGATIVE                              1
#define RSSCOPE_VAL_CLOCK_SIGNAL_EDGE_EITHER                                2

// RsScope_rngSerialPatternReferenceSource
#define RSSCOPE_VAL_SERIAL_PATTERN_REFERENCE_SOURCE_CLOCK                   0
#define RSSCOPE_VAL_SERIAL_PATTERN_REFERENCE_SOURCE_CDR                     1

// RsScope_rngExternalFrontendRFConnector
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_RF_CONNECTOR_1                        1
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_RF_CONNECTOR_2                        2
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_RF_CONNECTOR_3                        3

// RsScope_rngExternalFrontendFrequencyBandConfigSelection
#define RSSCOPE_VAL_FREQUENCY_BAND_CONFIG_SELECTION_IFLOW                   0
#define RSSCOPE_VAL_FREQUENCY_BAND_CONFIG_SELECTION_IFHIGH                  1
#define RSSCOPE_VAL_FREQUENCY_BAND_CONFIG_SELECTION_SPURO                   2
#define RSSCOPE_VAL_FREQUENCY_BAND_CONFIG_SELECTION_EVMO                    3

//repcap Channel
#define RSSCOPE_REPCAP_CHANNEL_CH1                                          1
#define RSSCOPE_REPCAP_CHANNEL_CH2                                          2
#define RSSCOPE_REPCAP_CHANNEL_CH3                                          3
#define RSSCOPE_REPCAP_CHANNEL_CH4                                          4
#define RSSCOPE_REPCAP_CHANNEL_CHEXT                                        5

//repcap Waveform
#define RSSCOPE_REPCAP_WAVEFORM_W0                                          1
#define RSSCOPE_REPCAP_WAVEFORM_W1                                          2
#define RSSCOPE_REPCAP_WAVEFORM_W2                                          3
#define RSSCOPE_REPCAP_WAVEFORM_W3                                          4

//repcap Trigger
#define RSSCOPE_REPCAP_TRIGGER_TRIGA                                        1
#define RSSCOPE_REPCAP_TRIGGER_TRIGB                                        2
#define RSSCOPE_REPCAP_TRIGGER_TRIGR                                        3

//repcap Cursor
#define RSSCOPE_REPCAP_CURSOR_C1                                            1
#define RSSCOPE_REPCAP_CURSOR_C2                                            2
#define RSSCOPE_REPCAP_CURSOR_C3                                            3
#define RSSCOPE_REPCAP_CURSOR_C4                                            4

//repcap CPosition
#define RSSCOPE_REPCAP_CPOSITION_P1                                         1
#define RSSCOPE_REPCAP_CPOSITION_P2                                         2

//repcap TriggerSource
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCH1                                  1
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCH2                                  2
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCH3                                  3
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCH4                                  4
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSEXT                                  5
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSLINE                                 6
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1V1                                 7
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1V2                                 8
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1V3                                 9
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1V4                                 10
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1I1                                 11
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1I2                                 12
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1I3                                 13
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ1I4                                 14
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2V1                                 15
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2V2                                 16
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2V3                                 17
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2V4                                 18
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2I1                                 19
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2I2                                 20
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2I3                                 21
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSZ2I4                                 22
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSDIFF1                                23
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSDIFF2                                24
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCOMMON1                              25
#define RSSCOPE_REPCAP_TRIGGERSOURCE_TSCOMMON2                              26

//repcap TriggerType
#define RSSCOPE_REPCAP_TRIGGERTYPE_EDGE                                     1
#define RSSCOPE_REPCAP_TRIGGERTYPE_WIDTH                                    2
#define RSSCOPE_REPCAP_TRIGGERTYPE_RUNT                                     3
#define RSSCOPE_REPCAP_TRIGGERTYPE_GLITCH                                   4
#define RSSCOPE_REPCAP_TRIGGERTYPE_WINDOW                                   5
#define RSSCOPE_REPCAP_TRIGGERTYPE_TIMEOUT                                  6
#define RSSCOPE_REPCAP_TRIGGERTYPE_INTERVAL                                 7
#define RSSCOPE_REPCAP_TRIGGERTYPE_SLEW                                     8
#define RSSCOPE_REPCAP_TRIGGERTYPE_DATA2CLOCK                               9
#define RSSCOPE_REPCAP_TRIGGERTYPE_PATTERN                                  10
#define RSSCOPE_REPCAP_TRIGGERTYPE_EXTERNAL                                 11
#define RSSCOPE_REPCAP_TRIGGERTYPE_T11                                      12
#define RSSCOPE_REPCAP_TRIGGERTYPE_T12                                      13
#define RSSCOPE_REPCAP_TRIGGERTYPE_NFC                                      14
#define RSSCOPE_REPCAP_TRIGGERTYPE_TV                                       15
#define RSSCOPE_REPCAP_TRIGGERTYPE_CDR                                      16

//repcap Measurement
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS1                                    1
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS2                                    2
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS3                                    3
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS4                                    4
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS5                                    5
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS6                                    6
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS7                                    7
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS8                                    8
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS9                                    9
#define RSSCOPE_REPCAP_MEASUREMENT_MEAS10                                   10

//repcap AmptMeasurementType
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT1                            1
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT2                            2
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT3                            3
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT4                            4
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT5                            5
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT6                            6
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT7                            7
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT8                            8
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT9                            9
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT10                           10
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT11                           11
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT12                           12
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT13                           13
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT14                           14
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT15                           15
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT16                           16
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT17                           17
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT18                           18
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT19                           19
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT20                           20
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT21                           21
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT22                           22
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT23                           23
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT24                           24
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT25                           25
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT26                           26
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT27                           27
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT28                           28
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT29                           29
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT30                           30
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT47                           31
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT31                           32
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT32                           33
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT35                           34
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT36                           35
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT33                           36
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT34                           37
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT46                           38
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT48                           39
#define RSSCOPE_REPCAP_AMPTMEASUREMENTTYPE_AMPT49                           40

//repcap EyeMeasurementType
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE1                              1
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE2                              2
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE3                              3
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE4                              4
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE5                              5
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE6                              6
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE7                              7
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE8                              8
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE9                              9
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE10                             10
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE11                             11
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE12                             12
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE13                             13
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE14                             14
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE15                             15
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE16                             16
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE17                             17
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE18                             18
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE19                             19
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE20                             20
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE21                             21
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE22                             22
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE23                             23
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE24                             24
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE25                             25
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE26                             26
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE27                             27
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE28                             28
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE29                             29
#define RSSCOPE_REPCAP_EYEMEASUREMENTTYPE_EYE30                             30

//repcap HistogramMeasurementType
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST1                       1
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST2                       2
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST3                       3
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST4                       4
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST5                       5
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST6                       6
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST7                       7
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST8                       8
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST9                       9
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST10                      10
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST11                      11
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST12                      12
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST13                      13
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST14                      14
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST15                      15
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST16                      16
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST17                      17
#define RSSCOPE_REPCAP_HISTOGRAMMEASUREMENTTYPE_HIST18                      18

//repcap SpectrumMeasurementType
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC1                        1
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC2                        2
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC3                        3
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC4                        4
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC5                        5
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC6                        6
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC7                        7
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC8                        8
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC9                        9
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC10                       10
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC11                       11
#define RSSCOPE_REPCAP_SPECTRUMMEASUREMENTTYPE_SPEC12                       12

//repcap Math
#define RSSCOPE_REPCAP_MATH_M1                                              1
#define RSSCOPE_REPCAP_MATH_M2                                              2
#define RSSCOPE_REPCAP_MATH_M3                                              3
#define RSSCOPE_REPCAP_MATH_M4                                              4
#define RSSCOPE_REPCAP_MATH_M5                                              5
#define RSSCOPE_REPCAP_MATH_M6                                              6
#define RSSCOPE_REPCAP_MATH_M7                                              7
#define RSSCOPE_REPCAP_MATH_M8                                              8

//repcap WfmSuffix
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMNONE                                    1
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC1W1                                    2
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC1W2                                    3
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC1W3                                    4
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC2W1                                    5
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC2W2                                    6
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC2W3                                    7
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC3W1                                    8
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC3W2                                    9
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC3W3                                    10
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC4W1                                    11
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC4W2                                    12
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMC4W3                                    13
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH1                                   14
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH2                                   15
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH3                                   16
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH4                                   17
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMREF1                                    18
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMREF2                                    19
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMREF3                                    20
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMREF4                                    21
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMXY1                                     22
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMXY2                                     23
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMXY3                                     24
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMXY4                                     25
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS1                                   26
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS2                                   27
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS3                                   28
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS4                                   29
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS5                                   30
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS6                                   31
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS7                                   32
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMEAS8                                   33
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSBUS1                                   34
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSBUS2                                   35
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSBUS3                                   36
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSBUS4                                   37
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD0                                      38
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD1                                      39
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD2                                      40
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD3                                      41
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD4                                      42
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD5                                      43
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD6                                      44
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD7                                      45
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD8                                      46
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD9                                      47
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD10                                     48
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD11                                     49
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD12                                     50
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD13                                     51
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD14                                     52
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMD15                                     53
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMSO1                                    54
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMSO2                                    55
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMSO3                                    56
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMSO4                                    57
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK1                                    58
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK2                                    59
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK3                                    60
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK4                                    61
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK5                                    62
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK6                                    63
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK7                                    64
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTRK8                                    65
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM1                               66
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM2                               67
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM3                               68
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM4                               69
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG1TL1                                  70
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG1TL2                                  71
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG2TL1                                  72
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG2TL2                                  73
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG3TL1                                  74
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG3TL2                                  75
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG4TL1                                  76
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG4TL2                                  77
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMEYE1                                    78
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMEYE2                                    79
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMEYE3                                    80
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMEYE4                                    81
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1V1                                    82
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1V2                                    83
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1V3                                    84
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1V4                                    85
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1I1                                    86
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1I2                                    87
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1I3                                    88
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ1I4                                    89
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2V1                                    90
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2V2                                    91
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2V3                                    92
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2V4                                    93
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2I1                                    94
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2I2                                    95
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2I3                                    96
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMZ2I4                                    97
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDIFF1                                   98
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDIFF2                                   99
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMCOMMON1                                 100
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMCOMMON2                                 101
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTDRZ                                    102
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTDRH                                    103
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTDRR                                    104
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH5                                   105
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH6                                   106
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH7                                   107
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMMATH8                                   108
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM5                               109
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM6                               110
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM7                               111
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSPECTRUM8                               112
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG5TL1                                  113
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG5TL2                                  114
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG6TL1                                  115
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG6TL2                                  116
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG7TL1                                  117
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG7TL2                                  118
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG8TL1                                  119
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSG8TL2                                  120
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP1                                     121
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP2                                     122
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP3                                     123
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP4                                     124
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP5                                     125
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP6                                     126
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP7                                     127
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP8                                     128
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP9                                     129
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMHP10                                    130
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBATHTUB1                                131
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBATHMEAS1                               132
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSTEPRESP1                               133
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSRHIST1                                 134
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSDHIST1                                 135
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJHIST1                                 136
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDJHIST1                                 137
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJHIST1                                138
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJHIST1                                 139
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJOHIST1                                140
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSRTRACK1                                141
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJTRACK1                                142
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDJTRACK1                                143
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJTRACK1                               144
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJTRACK1                                145
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJTRACK1                                146
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJSPECTRUM1                             147
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJSPECTRUM1                            148
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJSPECTRUM1                             149
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJSPECTRUM1                             150
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSEYE1                                   151
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBATHTUB2                                152
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBATHMEAS2                               153
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSTEPRESP2                               154
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSRHIST2                                 155
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSDHIST2                                 156
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJHIST2                                 157
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDJHIST2                                 158
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJHIST2                                159
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJHIST2                                 160
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJOHIST2                                161
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSRTRACK2                                162
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSDTRACK2                                163
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJTRACK2                                164
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJTRACK2                               165
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJTRACK2                                166
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJTRACK2                                167
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTJSPECTRUM2                             168
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDJSPECTRUM2                            169
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJSPECTRUM2                             170
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJSPECTRUM2                             171
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMSEYE2                                   172
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMNBATHTUB1                               173
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMNBATHMEAS1                              174
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNHIST1                                 175
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDNHIST1                                 176
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNHIST1                                177
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNHIST1                                 178
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNOTRACK1                               179
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNTRACK1                                180
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNTRACK1                               181
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNTRACK1                                182
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNTRACK1                                183
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNSPECTRUM1                             184
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNSPECTRUM1                            185
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNSPECTRUM1                             186
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNSPECTRUM1                             187
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMNBATHTUB2                               188
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMNBATHMEAS2                              189
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNHIST2                                 190
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDNHIST2                                 191
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNHIST2                                192
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNHIST2                                 193
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNOHIST2                                194
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNTRACK2                                195
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNTRACK2                               196
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNTRACK2                                197
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNTRACK2                                198
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMTNSPECTRUM2                             199
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMDDNSPECTRUM2                            200
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNSPECTRUM2                             201
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNSPECTRUM2                             202
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDHIST1                                203
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBUJHIST1                                204
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJHIST1                                 205
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDTRACK1                               206
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDSPECTRUM1                            207
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDHIST2                                208
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBUJHIST2                                209
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRJHIST2                                 210
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDTRACK2                               211
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPJDSPECTRUM2                            212
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDHIST1                                213
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBUNHIST1                                214
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNHIST1                                 215
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDTRACK1                               216
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDSPECTRUM1                            217
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDHIST2                                218
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMBUNHIST2                                219
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMRNHIST2                                 220
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDTRACK2                               221
#define RSSCOPE_REPCAP_WFMSUFFIX_WFMPNDSPECTRUM2                            222

//repcap ReferenceWfm
#define RSSCOPE_REPCAP_REFERENCEWFM_RW1                                     1
#define RSSCOPE_REPCAP_REFERENCEWFM_RW2                                     2
#define RSSCOPE_REPCAP_REFERENCEWFM_RW3                                     3
#define RSSCOPE_REPCAP_REFERENCEWFM_RW4                                     4

//repcap SerialBus
#define RSSCOPE_REPCAP_SERIALBUS_SB1                                        1
#define RSSCOPE_REPCAP_SERIALBUS_SB2                                        2
#define RSSCOPE_REPCAP_SERIALBUS_SB3                                        3
#define RSSCOPE_REPCAP_SERIALBUS_SB4                                        4

//repcap Destination
#define RSSCOPE_REPCAP_DESTINATION_DE1                                      1
#define RSSCOPE_REPCAP_DESTINATION_DE2                                      2

//repcap XYDiagram
#define RSSCOPE_REPCAP_XYDIAGRAM_XY1                                        1
#define RSSCOPE_REPCAP_XYDIAGRAM_XY2                                        2
#define RSSCOPE_REPCAP_XYDIAGRAM_XY3                                        3
#define RSSCOPE_REPCAP_XYDIAGRAM_XY4                                        4

//repcap CANTimeSeg
#define RSSCOPE_REPCAP_CANTIMESEG_TS1                                       1
#define RSSCOPE_REPCAP_CANTIMESEG_TS2                                       2

//repcap ORSlot
#define RSSCOPE_REPCAP_ORSLOT_ORSLOT1                                       1
#define RSSCOPE_REPCAP_ORSLOT_ORSLOT2                                       2
#define RSSCOPE_REPCAP_ORSLOT_ORSLOT3                                       3
#define RSSCOPE_REPCAP_ORSLOT_ORSLOT4                                       4

//repcap SourceNumber
#define RSSCOPE_REPCAP_SOURCENUMBER_SN1                                     1
#define RSSCOPE_REPCAP_SOURCENUMBER_SN2                                     2
#define RSSCOPE_REPCAP_SOURCENUMBER_SN3                                     3
#define RSSCOPE_REPCAP_SOURCENUMBER_SN4                                     4

//repcap Line
#define RSSCOPE_REPCAP_LINE_DATA                                            1
#define RSSCOPE_REPCAP_LINE_ENABLE                                          2

//repcap DigitalChannel
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D0                                    0
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D1                                    1
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D2                                    2
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D3                                    3
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D4                                    4
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D5                                    5
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D6                                    6
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D7                                    7
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D8                                    8
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D9                                    9
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D10                                   10
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D11                                   11
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D12                                   12
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D13                                   13
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D14                                   14
#define RSSCOPE_REPCAP_DIGITALCHANNEL_D15                                   15

//repcap ChannelGroup
#define RSSCOPE_REPCAP_CHANNELGROUP_CG1                                     1
#define RSSCOPE_REPCAP_CHANNELGROUP_CG2                                     2
#define RSSCOPE_REPCAP_CHANNELGROUP_CG3                                     3
#define RSSCOPE_REPCAP_CHANNELGROUP_CG4                                     4

//repcap ConditionNumber
#define RSSCOPE_REPCAP_CONDITIONNUMBER_CON1                                 1
#define RSSCOPE_REPCAP_CONDITIONNUMBER_CON2                                 2
#define RSSCOPE_REPCAP_CONDITIONNUMBER_CON3                                 3
#define RSSCOPE_REPCAP_CONDITIONNUMBER_CON4                                 4

//repcap TDMChannel
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM1                                      1
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM2                                      2
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM3                                      3
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM4                                      4
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM5                                      5
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM6                                      6
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM7                                      7
#define RSSCOPE_REPCAP_TDMCHANNEL_TDM8                                      8

//repcap JitterMeasurementType
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT1                          0
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT2                          1
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT3                          2
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT4                          3
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT5                          4
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT6                          5
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT7                          6
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT8                          7
#define RSSCOPE_REPCAP_JITTERMEASUREMENTTYPE_JITT9                          8

//repcap SW
#define RSSCOPE_REPCAP_SW_SW1                                               1
#define RSSCOPE_REPCAP_SW_SW2                                               2

//repcap Gate
#define RSSCOPE_REPCAP_GATE_GATE1                                           1
#define RSSCOPE_REPCAP_GATE_GATE2                                           2
#define RSSCOPE_REPCAP_GATE_GATE3                                           3
#define RSSCOPE_REPCAP_GATE_GATE4                                           4
#define RSSCOPE_REPCAP_GATE_GATE5                                           5

//repcap ResultNumber
#define RSSCOPE_REPCAP_RESULTNUMBER_RES1                                    1
#define RSSCOPE_REPCAP_RESULTNUMBER_RES2                                    2
#define RSSCOPE_REPCAP_RESULTNUMBER_RES3                                    3
#define RSSCOPE_REPCAP_RESULTNUMBER_RES4                                    4
#define RSSCOPE_REPCAP_RESULTNUMBER_RES5                                    5
#define RSSCOPE_REPCAP_RESULTNUMBER_RES6                                    6
#define RSSCOPE_REPCAP_RESULTNUMBER_RES7                                    7
#define RSSCOPE_REPCAP_RESULTNUMBER_RES8                                    8

//repcap ResultHarmonics
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM1                                1
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM2                                2
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM3                                3
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM4                                4
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM5                                5
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM6                                6
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM7                                7
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM8                                8
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM9                                9
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM10                               10
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM11                               11
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM12                               12
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM13                               13
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM14                               14
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM15                               15
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM16                               16
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM17                               17
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM18                               18
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM19                               19
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM20                               20
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM21                               21
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM22                               22
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM23                               23
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM24                               24
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM25                               25
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM26                               26
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM27                               27
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM28                               28
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM29                               29
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM30                               30
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM31                               31
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM32                               32
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM33                               33
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM34                               34
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM35                               35
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM36                               36
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM37                               37
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM38                               38
#define RSSCOPE_REPCAP_RESULTHARMONICS_HARM39                               39
#define RSSCOPE_REPCAP_RESULTHARMONICS_HERM40                               40

//repcap Timeline
#define RSSCOPE_REPCAP_TIMELINE_TL1                                         1
#define RSSCOPE_REPCAP_TIMELINE_TL2                                         2

//repcap Math2
#define RSSCOPE_REPCAP_MATH2_M21                                            1
#define RSSCOPE_REPCAP_MATH2_M22                                            2
#define RSSCOPE_REPCAP_MATH2_M23                                            3
#define RSSCOPE_REPCAP_MATH2_M24                                            4
#define RSSCOPE_REPCAP_MATH2_M25                                            5
#define RSSCOPE_REPCAP_MATH2_M26                                            6
#define RSSCOPE_REPCAP_MATH2_M27                                            7
#define RSSCOPE_REPCAP_MATH2_M28                                            8

//repcap WaveformGenerator
#define RSSCOPE_REPCAP_WAVEFORMGENERATOR_WG1                                1
#define RSSCOPE_REPCAP_WAVEFORMGENERATOR_WG2                                2

//repcap FieldNumber
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD1                                   1
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD2                                   2
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD3                                   3
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD4                                   4
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD5                                   5
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD6                                   6
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD7                                   7
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD8                                   8
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD9                                   9
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD10                                  10
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD11                                  11
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD12                                  12
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD13                                  13
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD14                                  14
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD15                                  15
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD16                                  16
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD17                                  17
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD18                                  18
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD19                                  19
#define RSSCOPE_REPCAP_FIELDNUMBER_FIELD20                                  20

//repcap ZVCZ
#define RSSCOPE_REPCAP_ZVCZ_ZVCZ1                                           1
#define RSSCOPE_REPCAP_ZVCZ_ZVCZ2                                           2

//repcap ZVCV
#define RSSCOPE_REPCAP_ZVCV_ZVCV1                                           1
#define RSSCOPE_REPCAP_ZVCV_ZVCV2                                           2
#define RSSCOPE_REPCAP_ZVCV_ZVCV3                                           3
#define RSSCOPE_REPCAP_ZVCV_ZVCV4                                           4

//repcap ZVCI
#define RSSCOPE_REPCAP_ZVCI_ZVCI1                                           1
#define RSSCOPE_REPCAP_ZVCI_ZVCI2                                           2
#define RSSCOPE_REPCAP_ZVCI_ZVCI3                                           3
#define RSSCOPE_REPCAP_ZVCI_ZVCI4                                           4

//repcap EyeDiagram
#define RSSCOPE_REPCAP_EYEDIAGRAM_ED1                                       1
#define RSSCOPE_REPCAP_EYEDIAGRAM_ED2                                       2
#define RSSCOPE_REPCAP_EYEDIAGRAM_ED3                                       3
#define RSSCOPE_REPCAP_EYEDIAGRAM_ED4                                       4

//repcap ComplexCondition
#define RSSCOPE_REPCAP_COMPLEXCONDITION_COMPLEX1                            1
#define RSSCOPE_REPCAP_COMPLEXCONDITION_COMPLEX2                            2
#define RSSCOPE_REPCAP_COMPLEXCONDITION_COMPLEX3                            3
#define RSSCOPE_REPCAP_COMPLEXCONDITION_COMPLEX4                            4

//repcap EbTbSymbol
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB1                                     1
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB2                                     2
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB3                                     3
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB4                                     4
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB5                                     5
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB6                                     6
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB7                                     7
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB8                                     8
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB9                                     9
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB10                                    10
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB11                                    11
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB12                                    12
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB13                                    13
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB14                                    14
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB15                                    15
#define RSSCOPE_REPCAP_EBTBSYMBOL_EBTB16                                    16

//repcap CoupledChannel
#define RSSCOPE_REPCAP_COUPLEDCHANNEL_CPLCH1                                1
#define RSSCOPE_REPCAP_COUPLEDCHANNEL_CPLCH2                                2
#define RSSCOPE_REPCAP_COUPLEDCHANNEL_CPLCH3                                3
#define RSSCOPE_REPCAP_COUPLEDCHANNEL_CPLCH4                                4

//repcap DifferentialSignal
#define RSSCOPE_REPCAP_DIFFERENTIALSIGNAL_DIFF1                             1
#define RSSCOPE_REPCAP_DIFFERENTIALSIGNAL_DIFF2                             2

//repcap DecodeTable
#define RSSCOPE_REPCAP_DECODETABLE_DECTBL1                                  1
#define RSSCOPE_REPCAP_DECODETABLE_DECTBL2                                  2
#define RSSCOPE_REPCAP_DECODETABLE_DECTBL3                                  3
#define RSSCOPE_REPCAP_DECODETABLE_DECTBL4                                  4
#define RSSCOPE_REPCAP_DECODETABLE_DECTBL5                                  5

//repcap TDRTDTSignal
#define RSSCOPE_REPCAP_TDRTDTSIGNAL_IMPED                                   1
#define RSSCOPE_REPCAP_TDRTDTSIGNAL_RCOEFF                                  2
#define RSSCOPE_REPCAP_TDRTDTSIGNAL_PRESP                                   3

//repcap AdvJitterMeas
#define RSSCOPE_REPCAP_ADVJITTERMEAS_JA1                                    1
#define RSSCOPE_REPCAP_ADVJITTERMEAS_JA2                                    2

//repcap AdvJitterComponent
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_F_SYMB                            1
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_T_SYMB                            2
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_EC                                3
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_TJ_BER                            4
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_RJ                                5
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_DDIRAC                            6
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_TJ                                7
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_DJ                                8
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_DDJ                               9
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_DCD                               10
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_PJ                                11
#define RSSCOPE_REPCAP_ADVJITTERCOMPONENT_ISI                               12

//repcap AdvJitterPeriodicComponent
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC1                 1
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC2                 2
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC3                 3
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC4                 4
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC5                 5
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC6                 6
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC7                 7
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC8                 8
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC9                 9
#define RSSCOPE_REPCAP_ADVJITTERPERIODICCOMPONENT_PERIODIC10                10

//repcap ArithmeticParameter
#define RSSCOPE_REPCAP_ARITHMETICPARAMETER_ARITHMETICPARM1                  1
#define RSSCOPE_REPCAP_ARITHMETICPARAMETER_ARITHMETICPARM2                  2

//repcap FrontendPosition
#define RSSCOPE_REPCAP_FRONTENDPOSITION_FRONTENDPOS1                        1
#define RSSCOPE_REPCAP_FRONTENDPOSITION_FRONTENDPOS2                        2
#define RSSCOPE_REPCAP_FRONTENDPOSITION_FRONTENDPOS3                        3
#define RSSCOPE_REPCAP_FRONTENDPOSITION_FRONTENDPOS4                        4

//repcap OpticalMeasurement
#define RSSCOPE_REPCAP_OPTICALMEASUREMENT_OPTICAL1                          1
#define RSSCOPE_REPCAP_OPTICALMEASUREMENT_OPTICAL2                          2
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSSCOPE_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSSCOPE_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSSCOPE_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSSCOPE_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

 /****************************************************************************
  *---------------- Constant definition  ------------------------------------*
  ****************************************************************************/
#define RSSCOPE_VAL_MASK_TEST_EVENT_BEEP     0
#define RSSCOPE_VAL_MASK_TEST_EVENT_STOP     1
#define RSSCOPE_VAL_MASK_TEST_EVENT_PRINT    2
#define RSSCOPE_VAL_MASK_TEST_EVENT_SAVE_WFM 3
#define RSSCOPE_VAL_MASK_TEST_EVENT_REPORT   4
#define RSSCOPE_VAL_MASK_TEST_EVENT_RUN_EXEC 5
#define RSSCOPE_VAL_MASK_TEST_EVENT_TRIG_OUT 6

#define RSSCOPE_VAL_MASK_TEST_ACTION_CREATE 0
#define RSSCOPE_VAL_MASK_TEST_ACTION_DELETE 1

#define RSSCOPE_VAL_MASK_TEST_SOURCE_C1W1 1
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C1W2 2
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C1W3 3
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C2W1 4
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C2W2 5
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C2W3 6
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C3W1 7
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C3W2 8
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C3W3 9
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C4W1 10
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C4W2 11
#define RSSCOPE_VAL_MASK_TEST_SOURCE_C4W3 12
#define RSSCOPE_VAL_MASK_TEST_SOURCE_M1   13
#define RSSCOPE_VAL_MASK_TEST_SOURCE_M2   14
#define RSSCOPE_VAL_MASK_TEST_SOURCE_M3   15
#define RSSCOPE_VAL_MASK_TEST_SOURCE_M4   16
#define RSSCOPE_VAL_MASK_TEST_SOURCE_R1   17
#define RSSCOPE_VAL_MASK_TEST_SOURCE_R2   18
#define RSSCOPE_VAL_MASK_TEST_SOURCE_R3   19
#define RSSCOPE_VAL_MASK_TEST_SOURCE_R4   20
#define RSSCOPE_VAL_MASK_TEST_SOURCE_XY1  21
#define RSSCOPE_VAL_MASK_TEST_SOURCE_XY2  22
#define RSSCOPE_VAL_MASK_TEST_SOURCE_XY3  23
#define RSSCOPE_VAL_MASK_TEST_SOURCE_XY4  24

#define RSSCOPE_VAL_ADD     0
#define RSSCOPE_VAL_REMOVE  1
#define RSSCOPE_VAL_INSERT  2

#define RSSCOPE_VAL_CHANNEL_1   1
#define RSSCOPE_VAL_CHANNEL_2   2
#define RSSCOPE_VAL_CHANNEL_3   3
#define RSSCOPE_VAL_CHANNEL_4   4
#define RSSCOPE_VAL_CHANNEL_EXT 5

#define RSSCOPE_VAL_TRIGGER_A 1
#define RSSCOPE_VAL_TRIGGER_B 2
#define RSSCOPE_VAL_TRIGGER_R 3

#define RSSCOPE_VAL_MEASUREMENT_SOURCE_NONE 0
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR1  37
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR2  38
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR3  39
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR4  40
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR5  41
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR6  42
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR7  43
#define RSSCOPE_VAL_MEASUREMENT_SOURCE_MR8  44

#define RSSCOPE_VAL_MEASUREMENT_EVENT_BEEP             0
#define RSSCOPE_VAL_MEASUREMENT_EVENT_STOP             1
#define RSSCOPE_VAL_MEASUREMENT_EVENT_PRINT            2
#define RSSCOPE_VAL_MEASUREMENT_EVENT_SAVE_WFM         3
#define RSSCOPE_VAL_MEASUREMENT_EVENT_TRIGGEROUT    4
#define RSSCOPE_VAL_MEASUREMENT_EVENT_SAVE_REPORT   5
#define RSSCOPE_VAL_MEASUREMENT_EVENT_RUN_EXE       6

#define RSSCOPE_VAL_MEASUREMENT_ACTION_NOACTION  0
#define RSSCOPE_VAL_MEASUREMENT_ACTION_SUCCESS   1
#define RSSCOPE_VAL_MEASUREMENT_ACTION_VIOLATION 2

#define RSSCOPE_VAL_INIT_SINGLE              0
#define RSSCOPE_VAL_INIT_CONTINUOUS          1
#define RSSCOPE_VAL_INIT_FORCE               2
#define RSSCOPE_VAL_INIT_SINGLE_WITHOUT_WAIT 3

#define RSSCOPE_VAL_REG_COV   0
#define RSSCOPE_VAL_REG_TEMP  1
#define RSSCOPE_VAL_REG_LIM   2
#define RSSCOPE_VAL_REG_MARG  3
#define RSSCOPE_VAL_REG_MASK  4
#define RSSCOPE_VAL_REG_ADCS  5
#define RSSCOPE_VAL_REG_FREQ  6
#define RSSCOPE_VAL_REG_LAMP  7
#define RSSCOPE_VAL_REG_PPL   8
#define RSSCOPE_VAL_REG_ZVCOV 9
#define RSSCOPE_VAL_REG_DEEM  10

#define RSSCOPE_VAL_REG_COND   0
#define RSSCOPE_VAL_REG_ENABLE 1
#define RSSCOPE_VAL_REG_EVENT  2
#define RSSCOPE_VAL_REG_NTR    3
#define RSSCOPE_VAL_REG_PTR    4

#define RSSCOPE_VAL_FILE_COPY    0
#define RSSCOPE_VAL_FILE_MOVE    1
#define RSSCOPE_VAL_FILE_DELETE  2
#define RSSCOPE_VAL_FILE_NEW_DIR 3
#define RSSCOPE_VAL_FILE_CDIR    4
#define RSSCOPE_VAL_FILE_RDIR    5
#define RSSCOPE_VAL_FILE_CDRIVE  6

#define RSSCOPE_VAL_MEM_SAVE    0
#define RSSCOPE_VAL_MEM_RECALL  1

#define RSSCOPE_VAL_CHANNEL1_AND_2 1
#define RSSCOPE_VAL_CHANNEL3_AND_4 2
#define RSSCOPE_VAL_CHANNEL_ALL    3

#define RSSCOPE_VAL_STATISTIC_ACTUAL    0
#define RSSCOPE_VAL_STATISTIC_AVG       1
#define RSSCOPE_VAL_STATISTIC_EVT_COUNT 2
#define RSSCOPE_VAL_STATISTIC_NEG_PEAK  3
#define RSSCOPE_VAL_STATISTIC_POS_PEAK  4
#define RSSCOPE_VAL_STATISTIC_STD_DEV   6
#define RSSCOPE_VAL_STATISTIC_WAVEFORM  7

#define RSSCOPE_VAL_SEARCH_PEAK  0
#define RSSCOPE_VAL_SEARCH_LEFT  1
#define RSSCOPE_VAL_SEARCH_RIGHT 2
#define RSSCOPE_VAL_SEARCH_NEXT  3

#define RSSCOPE_VAL_WAV_SELECT  0
#define RSSCOPE_VAL_WAV_OPEN    1
#define RSSCOPE_VAL_WAV_SAVE    2
#define RSSCOPE_VAL_WAV_DELETE  3

#define RSSCOPE_VAL_SEARCH_CATEGORY_TRIG    0
#define RSSCOPE_VAL_SEARCH_CATEGORY_FREQ    1

#define RSSCOPE_VAL_SEARCH_RESULT_NEXT      0
#define RSSCOPE_VAL_SEARCH_RESULT_ALL       1

#define RSSCOPE_VAL_COPY_FROM_A     0
#define RSSCOPE_VAL_COPY_FROM_B     1

#define RSSCOPE_VAL_BUS_1    1
#define RSSCOPE_VAL_BUS_2    2
#define RSSCOPE_VAL_BUS_3    3
#define RSSCOPE_VAL_BUS_4    4

#define RSSCOPE_VAL_I2C_SCL     0
#define RSSCOPE_VAL_I2C_SDA     1

#define RSSCOPE_VAL_SPI_SCLK    0
#define RSSCOPE_VAL_SPI_SSEL    1
#define RSSCOPE_VAL_SPI_MISO    2
#define RSSCOPE_VAL_SPI_MOSI    3

#define RSSCOPE_VAL_LIN_FIELD_SYNC   0
#define RSSCOPE_VAL_LIN_FIELD_CHKSUM 1

#define RSSCOPE_VAL_CAN_FIELD_DLC 0
#define RSSCOPE_VAL_CAN_FIELD_CRC 1
#define RSSCOPE_VAL_CAN_FIELD_ACK 2

#define RSSCOPE_VAL_DIAGRAM_NONE       0

#define RSSCOPE_VAL_HARDCOPY_DESTINATION_PNG  0
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_JPG  1
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_BMP  2
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_TIFF 3
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_CLP  4
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_PRN  5
#define RSSCOPE_VAL_HARDCOPY_DESTINATION_PDF  6

#define RSSCOPE_VAL_EBTB_TYPE_D_PLUS  0
#define RSSCOPE_VAL_EBTB_TYPE_D_MINUS  1
#define RSSCOPE_VAL_EBTB_TYPE_DIFF  2

#define RSSCOPE_VAL_REF_LEVEL_MEAS_BINN 0
#define RSSCOPE_VAL_REF_LEVEL_MEAS_BOUT 1
#define RSSCOPE_VAL_REF_LEVEL_MEAS_LOW  2
#define RSSCOPE_VAL_REF_LEVEL_MEAS_MIDD 3
#define RSSCOPE_VAL_REF_LEVEL_MEAS_UPP  4
#define RSSCOPE_VAL_REF_LEVEL_MEAS_SIGH 5
#define RSSCOPE_VAL_REF_LEVEL_MEAS_SIGL 6
#define RSSCOPE_VAL_REF_LEVEL_MEAS_TINN 7
#define RSSCOPE_VAL_REF_LEVEL_MEAS_TOUT 8

#define RSSCOPE_VAL_TS_ABS 0
#define RSSCOPE_VAL_TS_REL 1

#define RSSCOPE_VAL_FLEXRAY_FIELD_FLAGS       0
#define RSSCOPE_VAL_FLEXRAY_FIELD_PAY_LENGTH  1
#define RSSCOPE_VAL_FLEXRAY_FIELD_FRAME_ID    2
#define RSSCOPE_VAL_FLEXRAY_FIELD_HCRC        3
#define RSSCOPE_VAL_FLEXRAY_FIELD_FCRC        4

#define RSSCOPE_VAL_FLEXRAY_SOURCE_DATA    0
#define RSSCOPE_VAL_FLEXRAY_SOURCE_ENABLE  1

#define RSSCOPE_VAL_AMPT_SLOPE_PULSE    0
#define RSSCOPE_VAL_AMPT_SLOPE_EDGE     1
#define RSSCOPE_VAL_AMPT_SLOPE_CLOCK    2
#define RSSCOPE_VAL_AMPT_SLOPE_MEAS        3

#define RSSCOPE_VAL_AMPT_REF_TYPE_CLOCK 0
#define RSSCOPE_VAL_AMPT_REF_TYPE_DATA  1

#define RSSCOPE_VAL_UART_PACKETS_NONE 0

#define RSSCOPE_VAL_MASK_TEST_SAVE      0
#define RSSCOPE_VAL_MASK_TEST_OPEN      1
#define RSSCOPE_VAL_MASK_TEST_DELETE    2
#define RSSCOPE_VAL_MASK_TEST_CLEAR_ALL 3

#define RSSCOPE_VAL_LEFT  0
#define RSSCOPE_VAL_RIGHT 1

#define RSSCOPE_VAL_JITTER_SOURCE_DATA  0
#define RSSCOPE_VAL_JITTER_SOURCE_CLOCK 1

#define RSSCOPE_VAL_POWER_ANALYSIS_SELECT_ALL     0
#define RSSCOPE_VAL_POWER_ANALYSIS_SELECT_NONE    1
#define RSSCOPE_VAL_POWER_ANALYSIS_SELECT_REMOVE  2
#define RSSCOPE_VAL_POWER_ANALYSIS_SELECT_INVERT  3

#define RSSCOPE_VAL_HARMONICS_TYPE_FREQUENCY     0
#define RSSCOPE_VAL_HARMONICS_TYPE_VALUE         1
#define RSSCOPE_VAL_HARMONICS_TYPE_MAXIMUM       2
#define RSSCOPE_VAL_HARMONICS_TYPE_LIMIT         3

#define RSSCOPE_VAL_POWER_ANALYSIS_ADD        0
#define RSSCOPE_VAL_POWER_ANALYSIS_INS        1
#define RSSCOPE_VAL_POWER_ANALYSIS_REMOVE     2

#define RSSCOPE_VAL_SPECTRUM_TYPE_FREQUENCY 0
#define RSSCOPE_VAL_SPECTRUM_TYPE_LEVEL     1

#define RSSCOPE_VAL_POWER_ANALYSIS_FILE_NEW        0
#define RSSCOPE_VAL_POWER_ANALYSIS_FILE_NAME       1
#define RSSCOPE_VAL_POWER_ANALYSIS_FILE_SAVE       2
#define RSSCOPE_VAL_POWER_ANALYSIS_FILE_DELETE     3

#define RSSCOPE_VAL_PROBE_RES_COMMON        0
#define RSSCOPE_VAL_PROBE_RES_DIFFERENTIAL  1
#define RSSCOPE_VAL_PROBE_RES_POSITIVE      2
#define RSSCOPE_VAL_PROBE_RES_NEGATIVE      3
#define RSSCOPE_VAL_PROBE_RES_SINGLE_ENDED  4

#define RSSCOPE_VAL_MEASUREMENT_9           9
#define RSSCOPE_VAL_MEASUREMENT_10          10

#define RSSCOPE_VAL_SOURCE_CLOCK     0
#define RSSCOPE_VAL_SOURCE_DATA      1

#define RSSCOPE_VAL_USB_TYPE_D_PLUS     0
#define RSSCOPE_VAL_USB_TYPE_D_MINUS    1
#define RSSCOPE_VAL_USB_TYPE_DIFF       2
#define RSSCOPE_VAL_USB_TYPE_DATA       3
#define RSSCOPE_VAL_USB_TYPE_STROBE     4

#define RSSCOPE_VAL_THRESHOLD_TYPE_HIGH       0
#define RSSCOPE_VAL_THRESHOLD_TYPE_LOW        1
#define RSSCOPE_VAL_THRESHOLD_TYPE_HYSTERESIS 2

#define RSSCOPE_VAL_SAVE 0
#define RSSCOPE_VAL_OPEN 1

#define RSSCOPE_VAL_DPHY_LANE_CP  0
#define RSSCOPE_VAL_DPHY_LANE_DN0 1
#define RSSCOPE_VAL_DPHY_LANE_DP0 2
#define RSSCOPE_VAL_DPHY_LANE_DP1 3
#define RSSCOPE_VAL_DPHY_LANE_DP2 4
#define RSSCOPE_VAL_DPHY_LANE_DP3 5

#define RSSCOPE_VAL_DPHY_HS_DATA        0
#define RSSCOPE_VAL_COND_LP_ESCAPE_MODE 1

#define RSSCOPE_VAL_SPACE_WIRE_SIGNAL_STROBE 0
#define RSSCOPE_VAL_SPACE_WIRE_SIGNAL_DATA   1

#define RSSCOPE_VAL_DLANE1 0
#define RSSCOPE_VAL_DLANE2 1
#define RSSCOPE_VAL_DLANE3 2
#define RSSCOPE_VAL_DLANE4 3

#define RSSCOPE_VAL_MPHY_WORD_ONE   0
#define RSSCOPE_VAL_MPHY_WORD_TWO   1
#define RSSCOPE_VAL_MPHY_WORD_THREE 2
#define RSSCOPE_VAL_MPHY_WORD_FOUR  3

#define RSSCOPE_VAL_SPI_PATTERN_MISO 0
#define RSSCOPE_VAL_SPI_PATTERN_MOSI 1

#define RSSCOPE_VAL_FAST_SWEEP_NORMAL 0
#define RSSCOPE_VAL_FAST_SWEEP_FAST   1

#define RSSCOPE_VAL_ZVC_PROBE_CURRENT 0
#define RSSCOPE_VAL_ZVC_PROBE_VOLTAGE 1

#define RSSCOPE_VAL_DIRECTION_FORWARD 0
#define RSSCOPE_VAL_DIRECTION_REVERSE 1

#define RSSCOPE_VAL_DDR_TYPE_DATA   0
#define RSSCOPE_VAL_DDR_TYPE_STROBE 1

#define RSSCOPE_VAL_DEEMBEDDING_FILE_ACTION_SAVE   0
#define RSSCOPE_VAL_DEEMBEDDING_FILE_ACTION_LOAD   1
#define RSSCOPE_VAL_DEEMBEDDING_FILE_ACTION_DELETE 2

#define RSSCOPE_VAL_DEEMBEDDING_FILE_PORT_1 1
#define RSSCOPE_VAL_DEEMBEDDING_FILE_PORT_2 2

#define RSSCOPE_VAL_SHIFT_BIT_LEFT 0
#define RSSCOPE_VAL_SHIFT_BIT_RIGHT 1

#define RSSCOPE_VAL_MEAS_TYPE_CPOW   0
#define RSSCOPE_VAL_MEAS_TYPE_OBW    2
#define RSSCOPE_VAL_MEAS_TYPE_SBW    3
#define RSSCOPE_VAL_MEAS_TYPE_THDA   4
#define RSSCOPE_VAL_MEAS_TYPE_THDU   5
#define RSSCOPE_VAL_MEAS_TYPE_THD    6
#define RSSCOPE_VAL_MEAS_TYPE_THDPCT 7
#define RSSCOPE_VAL_MEAS_TYPE_THDR   8
#define RSSCOPE_VAL_MEAS_TYPE_PLIS   9
#define RSSCOPE_VAL_MEAS_TYPE_HAR    10
#define RSSCOPE_VAL_MEAS_TYPE_THDF   11

#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_CH1        1
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_CH2        2
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_CH3        3
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_CH4        4
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_EXT        5
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_LINE        6
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1V1        7
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1V2        8
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1V3        9
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1V4        10
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1I1        11
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1I2        12
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1I3        13
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z1I4        14
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2V1        15
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2V2        16
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2V3        17
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2V4        18
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2I1        19
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2I2        20
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2I3        21
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_Z2I4        22
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_DIFF1        23
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_DIFF2        24
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_COMMON1    25
#define RSSCOPE_VAL_TRIGGER_SOURCE_REPCAP_COMMON2    26

#define RSSCOPE_VAL_TDR_TDT_SIGNAL_IMPEDANCE        1
#define RSSCOPE_VAL_TDR_TDT_SIGNAL_REFLECTION_COEFF    2
#define RSSCOPE_VAL_TDR_TDT_SIGNAL_PULSE_RESPONSE    3

#define RSSCOPE_VAL_ADVANCED_JITTER_SCALING_JITTER  5

#define RSSCOPE_VAL_TYPE_MAX 0
#define RSSCOPE_VAL_TYPE_MIN 1

#define RSSCOPE_VAL_EXTERNAL_FRONTEND_IF 0
#define RSSCOPE_VAL_EXTERNAL_FRONTEND_RF 1

  // These definitions are for backwards compatibility.
#define RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADRESS_NACK RSSCOPE_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_NACK
#define RSSCOPE_ATTR_PROTOCOL_AUDIO_TRACK_WAVEFORM_HEADER RSSCOPE_ATTR_TRACK_WAVEFORM_HEADER
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQENCY_HIGHPASS RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQUENCY_HIGHPASS
#define RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQENCY_LOWPASS RSSCOPE_ATTR_EXTERNAL_TRIGGER_FILTER_CUT_OFF_FREQUENCY_LOWPASS
#define RSSCOPE_VAL_DSP_TRIGGER_RF_REFECT RSSCOPE_VAL_DSP_TRIGGER_RF_REJECT
#define RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_CLECK_EDGE RSSCOPE_ATTR_MSO_SERIAL_PATTERN_TRIGGER_CLOCK_EDGE

/***************************************************************************
*---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rsscope_init(ViRsrc     resourceName,
                               ViBoolean  IDQuery,
                               ViBoolean  resetDevice,
                               ViSession* instrSession);

ViStatus _VI_FUNC rsscope_InitWithOptions(ViRsrc     resourceName,
                                          ViBoolean  IDQuery,
                                          ViBoolean  resetDevice,
                                          ViString   optionString,
                                          ViSession* instrSession);

ViStatus _VI_FUNC rsscope_Autoset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureAcquisitionType(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   waveform,
                                                   ViInt32   acquisitionType);

ViStatus _VI_FUNC rsscope_ConfigureAcquisitionRecord(ViSession instrSession,
                                                     ViReal64  timePerRecord,
                                                     ViReal64  acquisitionStartTime);

ViStatus _VI_FUNC rsscope_QueryNumberOfAcquisitions(ViSession instrSession,
                                                    ViInt32*  numberOfAcquisitions);

ViStatus _VI_FUNC rsscope_ConfigureTimeBase(ViSession instrSession,
                                            ViReal64  timeScale,
                                            ViInt32   referencePoint,
                                            ViBoolean restrictOffset);

ViStatus _VI_FUNC rsscope_ConfigureRollMode(ViSession instrSession,
                                            ViInt32   mode,
                                            ViInt32   minRollModeGain);

ViStatus _VI_FUNC rsscope_QueryDivisions(ViSession instrSession,
                                         ViInt32*  divisions);

ViStatus _VI_FUNC rsscope_ConfigureTimeSelectDependency(ViSession instrSession,
                                                        ViInt32   timeSelectDependency);

ViStatus _VI_FUNC rsscope_ConfigureAutoAdjustment(ViSession instrSession,
                                                  ViBoolean autoAdjustment);

ViStatus _VI_FUNC rsscope_ConfigureSampleRate(ViSession instrSession,
                                              ViReal64  sampleRate);

ViStatus _VI_FUNC rsscope_ConfigureResolution(ViSession instrSession,
                                              ViReal64  resolution);

ViStatus _VI_FUNC rsscope_QueryADCSampleRate(ViSession instrSession,
                                             ViReal64* ADCSampleRate);

ViStatus _VI_FUNC rsscope_ConfigureRecordLength(ViSession instrSession,
                                                ViInt32   recordLength);

ViStatus _VI_FUNC rsscope_ConfigureRecordLengthLimit(ViSession instrSession,
                                                     ViInt32   lengthLimit);

ViStatus _VI_FUNC rsscope_ConfigureAcquisitionSampleRate(ViSession instrSession,
                                                         ViReal64  acquisitionSampleRate);

ViStatus _VI_FUNC rsscope_ConfigureAcquisitionTime(ViSession instrSession,
                                                   ViReal64  acquisitionTime);

ViStatus _VI_FUNC rsscope_ConfigureResolutionEnhancement(ViSession instrSession,
                                                         ViInt32   resolutionEnhancement);

ViStatus _VI_FUNC rsscope_ConfigureInterpolation(ViSession instrSession,
                                                 ViInt32   interpolation);

ViStatus _VI_FUNC rsscope_ConfigureWaveformState(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   waveform,
                                                 ViBoolean enableWaveform);

ViStatus _VI_FUNC rsscope_ConfigureWaveformArithmetic(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   waveform,
                                                      ViInt32   arithmetic);

ViStatus _VI_FUNC rsscope_ConfigureNumberOfAverages(ViSession instrSession,
                                                    ViInt32   numberOfAverages);

ViStatus _VI_FUNC rsscope_ConfigureUltraSegmentation(ViSession instrSession,
                                                     ViBoolean ultraSegmentationEnabled,
                                                     ViBoolean ultraSegmentationDependecy);

ViStatus _VI_FUNC rsscope_ConfigureUltraSegmentationAutoReplay(
                            ViSession instrSession,
                            ViBoolean autoReplay);

ViStatus _VI_FUNC rsscope_ConfigureWaveformAcquisitionCoupleChannelsEnabled(
                            ViSession instrSession,
                            ViBoolean autoReplay);

ViStatus _VI_FUNC rsscope_ConfigureMultiwaveformAcquisitionEnabled(
                            ViSession instrSession,
                            ViBoolean multiwaveform);

ViStatus _VI_FUNC rsscope_ConfigureChannel(ViSession instrSession,
                                           ViInt32   channel,
                                           ViBoolean channelEnabled,
                                           ViReal64  verticalRange,
                                           ViReal64  verticalOffset,
                                           ViInt32   verticalCoupling);

ViStatus _VI_FUNC rsscope_ConfigureChannelInvert(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean invert);

ViStatus _VI_FUNC rsscope_ConfigureChannelGroundConnection(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean groundConnection);

ViStatus _VI_FUNC rsscope_ConfigureChannelOffset(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  offset);

ViStatus _VI_FUNC rsscope_ConfigureChannelVerticalScale(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64  verticalScale);

ViStatus _VI_FUNC rsscope_ConfigureChannelBandwidth(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   bandwidth);

ViStatus _VI_FUNC rsscope_ConfigureChannelMeasurementImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  inputImpedance);

ViStatus _VI_FUNC rsscope_ConfigureChannelOverload(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean overload);

ViStatus _VI_FUNC rsscope_ConfigureChannelAntialiasing(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   antialiasing);

ViStatus _VI_FUNC rsscope_ConfigureChannelDigitalFilter(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViBoolean enable,
                                                        ViReal64  cutOff);

ViStatus _VI_FUNC rsscope_ConfigureChannelDigitalFilterTrigger(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   reserved,
                            ViInt32   coupling,
                            ViReal64  RFRejectBW);

ViStatus _VI_FUNC rsscope_ConfigureChannelExternalAttenuation(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   scale,
                            ViReal64  attenuation);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialSignal(ViSession instrSession,
                                                      ViInt32   differentialSignal,
                                                      ViBoolean enable,
                                                      ViInt32   positiveInput,
                                                      ViInt32   negativeInput,
                                                      ViInt32   outputA,
                                                      ViInt32   outputB);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialOffset(ViSession instrSession,
                                                      ViInt32   differentialSignal,
                                                      ViReal64  commonOffset,
                                                      ViReal64  differentialOffset);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialPosition(ViSession instrSession,
                                                        ViInt32   differentialSignal,
                                                        ViReal64  commonPosition,
                                                        ViReal64  differentialPosition);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialScale(ViSession instrSession,
                                                     ViInt32   differentialSignal,
                                                     ViReal64  commonScale,
                                                     ViReal64  differentialScale);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialEnabled(ViSession instrSession,
                                                       ViInt32   differentialSignal,
                                                       ViBoolean commonEnabled,
                                                       ViBoolean differentialEnabled);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialSignalPositiveNegative(
                            ViSession instrSession,
                            ViInt32   differentialSignal,
                            ViBoolean negativeSignal,
                            ViBoolean positiveSignal);

ViStatus _VI_FUNC rsscope_ConfigureDifferentialCouplingEnabled(
                            ViSession instrSession,
                            ViInt32   differentialSignal,
                            ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureCoupleVerticalChannelSettingsEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   coupledChannel,
                            ViBoolean couplingEnabled);

ViStatus _VI_FUNC rsscope_QueryVerticalChannelSettingsCoupled(
                            ViSession  instrSession,
                            ViInt32    channel,
                            ViInt32    coupledChannel,
                            ViBoolean* couplingEnabled);

ViStatus _VI_FUNC rsscope_ConfigureProbe(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean channelVisible,
                                         ViReal64  offset);

ViStatus _VI_FUNC rsscope_QueryProbeState(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32*  state);

ViStatus _VI_FUNC rsscope_QueryProbeCharacteristics(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   bufferSize,
                                                    ViChar    type[],
                                                    ViChar    name[],
                                                    ViReal64* inputImpedance,
                                                    ViReal64* inputCapacitance,
                                                    ViReal64* attenuation,
                                                    ViReal64* bandwidth);

ViStatus _VI_FUNC rsscope_ConfigureProbeMicroButtonAction(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   microButtonAction);

ViStatus _VI_FUNC rsscope_ProbeAutoZero(ViSession instrSession,
                                        ViInt32   channel);

ViStatus _VI_FUNC rsscope_ProbeUseAutoZero(ViSession instrSession,
                                           ViInt32   channel,
                                           ViBoolean useAutoZero);

ViStatus _VI_FUNC rsscope_ConfigureProbeZeroAdjustValue(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64  zeroAdjustValue);

ViStatus _VI_FUNC rsscope_ProbeSaveToProbe(ViSession instrSession,
                                           ViInt32   channel);

ViStatus _VI_FUNC rsscope_ProbeSetOffsetToMean(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsscope_ProbeDegauss(ViSession instrSession,
                                       ViInt32   channel);

ViStatus _VI_FUNC rsscope_QueryProbeAttributes(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   bufferSize,
                                               ViChar    softwareVersion[],
                                               ViChar    productionDate[],
                                               ViChar    partNumber[],
                                               ViChar    serialNumber[]);

ViStatus _VI_FUNC rsscope_ConfigureProbeFirmwarePath(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  firmwarePath);

ViStatus _VI_FUNC rsscope_UpdateProbeFirmware(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rsscope_QueryProbeFirmwareUpdateStatus(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32*  firmwareUpdateStatus);

ViStatus _VI_FUNC rsscope_ProbeSelftest(ViSession instrSession,
                                        ViInt32   channel);

ViStatus _VI_FUNC rsscope_QueryProbeSelftestResult(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bufferSize,
                                                   ViChar    selftestResult[]);

ViStatus _VI_FUNC rsscope_QueryProbeSelftestStatus(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32*  selftestStatus);

ViStatus _VI_FUNC rsscope_ConfigureProbeDetection(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureProbeAttenuation(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   verticalUnit,
                                                    ViReal64  attenuation);

ViStatus _VI_FUNC rsscope_ConfigureProbeGain(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  gain);

ViStatus _VI_FUNC rsscope_QueryDetectedProbeGain(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* gain);

ViStatus _VI_FUNC rsscope_ConfigureCurrentProbePredefined(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   predefinedProbe);

ViStatus _VI_FUNC rsscope_ConfigureProbePredefinedTektronicsProbe(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   predefinedTektronicsProbe);

ViStatus _VI_FUNC rsscope_ConfigureProbeDMOffset(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  DMOffset);

ViStatus _VI_FUNC rsscope_ConfigureProbeCMOffset(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  CMOffset);

ViStatus _VI_FUNC rsscope_ConfigureProbeNegativeOffset(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  negativeOffset);

ViStatus _VI_FUNC rsscope_ConfigureProbePositiveOffset(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  positiveOffset);

ViStatus _VI_FUNC rsscope_ConfigureProbeMode(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   probeMode);

ViStatus _VI_FUNC rsscope_ConfigureProbeAttenuatorRTZA15(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean attenuatorRTZA15);

ViStatus _VI_FUNC rsscope_ConfigureProbeRTZHD(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   voltageRange,
                                              ViBoolean bandwidthLimit,
                                              ViBoolean overrangeBuzzer);

ViStatus _VI_FUNC rsscope_QueryProbeAdapterType(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32*  adapterType);

ViStatus _VI_FUNC rsscope_QueryProbeConverterType(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32*  converterType);

ViStatus _VI_FUNC rsscope_ConfigureProbeRTZ1MBandwidthLimit(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   bandwidthLimit);

ViStatus _VI_FUNC rsscope_ProbeRTZ1MSelfAlign(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rsscope_ConfigureProbeDeembeddingSelectTipModule(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   tipModule,
                            ViInt32   ZMA30Submodule,
                            ViInt32   ZMA40Submodule);

ViStatus _VI_FUNC rsscope_ConfigureProbeDeembeddingCustomTipFile(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  deembeddingCustomTipFile);

ViStatus _VI_FUNC rsscope_ConfigureProbeDeembeddingMode(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   mode,
                                                        ViReal64  bandwidth,
                                                        ViInt32   measurementMode);

ViStatus _VI_FUNC rsscope_ConfigureProbeDeembeddingInputMode(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   deembeddingInputMode);

ViStatus _VI_FUNC rsscope_ConfigureProbeDeembeddingSourceImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean removeProbeLoading,
                            ViInt32   impedanceType,
                            ViReal64  impedance,
                            ViString  sParameterFile);

ViStatus _VI_FUNC rsscope_ConfigureProbeMeter(ViSession instrSession,
                                              ViInt32   channel,
                                              ViBoolean probeMeter,
                                              ViBoolean visibility,
                                              ViInt32   measureVoltage);

ViStatus _VI_FUNC rsscope_QueryProbeMeterResults(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   resultType,
                                                 ViReal64* result);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbe(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean channelVisible,
                                                     ViReal64  offset);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeState(ViSession instrSession,
                                                      ViInt32*  state);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeCharacteristics(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    type[],
                            ViChar    name[],
                            ViReal64* inputImpedance,
                            ViReal64* inputCapacitance,
                            ViReal64* attenuation,
                            ViReal64* bandwidth);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeMicroButtonAction(
                            ViSession instrSession,
                            ViInt32   microButtonAction);

ViStatus _VI_FUNC rsscope_TriggerInputProbeAutoZero(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeCMOffset(ViSession instrSession,
                                                             ViReal64  CMOffset);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeAttenuatorRTZA15(
                            ViSession instrSession,
                            ViBoolean attenuatorRTZA15);

ViStatus _VI_FUNC rsscope_TriggerInputProbeSetOffsetToMean(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeAttributes(ViSession instrSession,
                                                           ViInt32   bufferSize,
                                                           ViChar    softwareVersion[],
                                                           ViChar    productionDate[],
                                                           ViChar    partNumber[],
                                                           ViChar    serialNumber[]);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeFirmwarePath(
                            ViSession instrSession,
                            ViString  firmwarePath);

ViStatus _VI_FUNC rsscope_UpdateTriggerInputProbeFirmware(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeFirmwareUpdateStatus(
                            ViSession instrSession,
                            ViInt32*  firmwareUpdateStatus);

ViStatus _VI_FUNC rsscope_TriggerInputProbeSelftest(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeSelftestResult(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    selftestResult[]);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeSelftestStatus(
                            ViSession instrSession,
                            ViInt32*  selftestStatus);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeDetection(
                            ViSession instrSession,
                            ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeAttenuation(
                            ViSession instrSession,
                            ViInt32   verticalUnit,
                            ViReal64  attenuation);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeGain(ViSession instrSession,
                                                         ViReal64  gain);

ViStatus _VI_FUNC rsscope_QueryDetectedTriggerInputProbeGain(ViSession instrSession,
                                                             ViReal64* gain);

ViStatus _VI_FUNC rsscope_ConfigureCurrentTriggerInputProbePredefined(
                            ViSession instrSession,
                            ViInt32   predefinedProbe);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeACCoupling(
                            ViSession instrSession,
                            ViBoolean ACCoupling);

ViStatus _VI_FUNC rsscope_TriggerInputProbeDegauss(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeMode(ViSession instrSession,
                                                         ViInt32   probeMode);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeRTZHD(ViSession instrSession,
                                                          ViBoolean bandwidthLimit,
                                                          ViBoolean overrangeBuzzer);

ViStatus _VI_FUNC rsscope_ConfigureTriggerInputProbeMeter(ViSession instrSession,
                                                          ViBoolean probeMeter,
                                                          ViBoolean visibility,
                                                          ViInt32   measureVoltage);

ViStatus _VI_FUNC rsscope_QueryTriggerInputProbeMeterResults(ViSession instrSession,
                                                             ViInt32   resultType,
                                                             ViReal64* result);

ViStatus _VI_FUNC rsscope_ConfigureProbeTerminationVoltageMode(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureProbeTerminationVoltage(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean state,
                                                           ViReal64  adjustment);

ViStatus _VI_FUNC rsscope_QueryProbeTerminationVoltageMeasure(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64* measurement);

ViStatus _VI_FUNC rsscope_ConfigureZVCProbe(ViSession instrSession,
                                            ViReal64  bandwidth,
                                            ViInt32   decimationMode);

ViStatus _VI_FUNC rsscope_QueryZVCProbeInformations(ViSession instrSession,
                                                    ViInt32   multiChannel,
                                                    ViInt32   arraySize,
                                                    ViChar    probeName[],
                                                    ViChar    partNumber[],
                                                    ViChar    serialNumber[],
                                                    ViChar    firmware[]);

ViStatus _VI_FUNC rsscope_ConfigureZVCEnabled(ViSession instrSession,
                                              ViInt32   multiChannel,
                                              ViInt32   probe,
                                              ViInt32   probeParameter,
                                              ViBoolean enabled);

ViStatus _VI_FUNC rsscope_QueryZVCBandwidth(ViSession instrSession,
                                            ViInt32   multiChannel,
                                            ViInt32   probe,
                                            ViInt32   probeParameter,
                                            ViReal64* bandwidth);

ViStatus _VI_FUNC rsscope_ConfigureZVCResolutionCoupled(ViSession instrSession,
                                                        ViBoolean coupled);

ViStatus _VI_FUNC rsscope_ConfigureZVCImpedance(ViSession instrSession,
                                                ViInt32   multiChannel,
                                                ViInt32   probe,
                                                ViInt32   probeParameter,
                                                ViInt32   impedance);

ViStatus _VI_FUNC rsscope_ConfigureZVCOffsets(ViSession instrSession,
                                              ViInt32   multiChannel,
                                              ViInt32   probe,
                                              ViInt32   probeParameter,
                                              ViReal64  offset,
                                              ViReal64  deskew);

ViStatus _VI_FUNC rsscope_ConfigureZVCVertical(ViSession instrSession,
                                               ViInt32   multiChannel,
                                               ViInt32   probe,
                                               ViInt32   probeParameter,
                                               ViReal64  position,
                                               ViReal64  scale);

ViStatus _VI_FUNC rsscope_ConfigureZVCResetOverload(ViSession instrSession,
                                                    ViInt32   multiChannel,
                                                    ViInt32   probe,
                                                    ViInt32   probeParameter,
                                                    ViInt32   resetOverload);

ViStatus _VI_FUNC rsscope_QueryZVCOverload(ViSession  instrSession,
                                           ViInt32    multiChannel,
                                           ViInt32    probe,
                                           ViInt32    probeParameter,
                                           ViBoolean* overloadDetected);

ViStatus _VI_FUNC rsscope_ConfigureZVCShuntMode(ViSession instrSession,
                                                ViInt32   multiChannel,
                                                ViInt32   currentChannel,
                                                ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureZVCShuntExternal(ViSession instrSession,
                                                    ViInt32   multiChannel,
                                                    ViInt32   currentChannel,
                                                    ViInt32   maximumVoltage,
                                                    ViReal64  externalValue);

ViStatus _VI_FUNC rsscope_ConfigureZVCShuntInternalMaximum(ViSession instrSession,
                                                           ViInt32   multiChannel,
                                                           ViInt32   currentChannel,
                                                           ViInt32   maximumCurrent);

ViStatus _VI_FUNC rsscope_ConfigureZVCShuntMaximumCurrent(ViSession instrSession,
                                                          ViInt32   multiChannel,
                                                          ViInt32   currentChannel,
                                                          ViReal64* maximumCurrent);

ViStatus _VI_FUNC rsscope_FetchZVCWaveformHeader(ViSession instrSession,
                                                 ViInt32   waveformSource,
                                                 ViReal64* xStart,
                                                 ViReal64* xStop,
                                                 ViInt32*  recordLength,
                                                 ViInt32*  valuesPerSample);

ViStatus _VI_FUNC rsscope_FetchZVCWaveform(ViSession instrSession,
                                           ViInt32   waveformSource,
                                           ViInt32   bufferSize,
                                           ViReal64  waveformArray[],
                                           ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_DetectZVCZeroOffset(ViSession instrSession,
                                              ViInt32   multiChannel,
                                              ViInt32   probeParameter);

ViStatus _VI_FUNC rsscope_ConfigureZVCZeroOffsetUse(ViSession instrSession,
                                                    ViInt32   multiChannel,
                                                    ViInt32   probeParameter,
                                                    ViBoolean use);

ViStatus _VI_FUNC rsscope_QueryZVCZeroOffsetStatus(ViSession  instrSession,
                                                   ViInt32    multiChannel,
                                                   ViInt32    probeParameter,
                                                   ViBoolean* status);

ViStatus _VI_FUNC rsscope_ConfigureCalibrationSourceState(ViSession instrSession,
                                                          ViBoolean calibrationSourceState);

ViStatus _VI_FUNC rsscope_ConfigureCalibration(ViSession instrSession,
                                               ViInt32   sourceFrequency,
                                               ViInt32   operatingMode,
                                               ViInt32   destination);

ViStatus _VI_FUNC rsscope_QueryCalibrationResult(ViSession instrSession,
                                                 ViInt32*  calibrationResult);

ViStatus _VI_FUNC rsscope_QueryCalibrationDate(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    date[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryCalibrationTime(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    time[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureReferenceOscillator(ViSession instrSession,
                                                       ViBoolean useExternalReference,
                                                       ViReal64  externalReference);

ViStatus _VI_FUNC rsscope_ConfigureSkew(ViSession instrSession,
                                        ViInt32   channel,
                                        ViBoolean useSkewOffset,
                                        ViReal64  skewOffset);

ViStatus _VI_FUNC rsscope_ConfigureProbeSkewOffset(ViSession instrSession,
                                                   ViBoolean probeSkewOffset);

ViStatus _VI_FUNC rsscope_ConfigureSkewExtendedRange(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean extendedRange);

ViStatus _VI_FUNC rsscope_ConfigureHighDefinition(ViSession instrSession,
                                                  ViBoolean state,
                                                  ViReal64  bandwidth);

ViStatus _VI_FUNC rsscope_QueryHighDefinitionResolution(ViSession instrSession,
                                                        ViReal64* resolution);

ViStatus _VI_FUNC rsscope_ConfigureTrigger(ViSession instrSession,
                                           ViInt32   trigger,
                                           ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_ConfigureSerialBusSource(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   serialBusSource);

ViStatus _VI_FUNC rsscope_ConfigureTriggerCoupling(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViBoolean eventCoupling,
                                                   ViBoolean sourceCoupling);

ViStatus _VI_FUNC rsscope_ConfigureTriggerModifier(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   triggerModifier);

ViStatus _VI_FUNC rsscope_TriggerLevelAutoFind(ViSession instrSession,
                                               ViInt32   trigger);

ViStatus _VI_FUNC rsscope_ConfigureTriggerChannelLevel(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   triggerSource,
                                                       ViReal64  triggerLevel);

ViStatus _VI_FUNC rsscope_ConfigureEdgeTriggerSource(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   triggerSource,
                                                     ViReal64  triggerLevel,
                                                     ViInt32   triggerSlope);

ViStatus _VI_FUNC rsscope_ConfigureEdgeExternalTrigger(ViSession instrSession,
                                                       ViInt32   coupling,
                                                       ViInt32   filter,
                                                       ViInt32   cutOffFrequency);

ViStatus _VI_FUNC rsscope_ConfigureEdgeExternalTriggerGround(ViSession instrSession,
                                                             ViBoolean connectToGround);

ViStatus _VI_FUNC rsscope_ConfigureEdgeExternalTriggerNoiseReject(
                            ViSession instrSession,
                            ViBoolean noiseReject);

ViStatus _VI_FUNC rsscope_ConfigureRuntTriggerSource(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   triggerSource,
                                                     ViReal64  runtLowThreshold,
                                                     ViReal64  runtHighThreshold,
                                                     ViInt32   runtPolarity);

ViStatus _VI_FUNC rsscope_ConfigureRuntTriggerRange(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  runtWidth,
                                                    ViReal64  runtDelta,
                                                    ViInt32   runtCondition);

ViStatus _VI_FUNC rsscope_ConfigureGlitchTriggerSource(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   triggerSource,
                                                       ViReal64  triggerLevel,
                                                       ViReal64  glitchWidth,
                                                       ViInt32   glitchPolarity,
                                                       ViInt32   glitchCondition);

ViStatus _VI_FUNC rsscope_ConfigureWidthTriggerSource(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   triggerSource,
                                                      ViReal64  triggerLevel,
                                                      ViReal64  width,
                                                      ViReal64  widthDelta,
                                                      ViInt32   widthPolarity,
                                                      ViInt32   widthCondition);

ViStatus _VI_FUNC rsscope_ConfigureWindowTriggerSource(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   triggerSource,
                                                       ViReal64  windowLowerLimit,
                                                       ViReal64  windowUpperLimit,
                                                       ViReal64  windowWidth,
                                                       ViReal64  windowDelta,
                                                       ViInt32   windowCondition);

ViStatus _VI_FUNC rsscope_ConfigureWindowTriggerTimeCondition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   timeCondition);

ViStatus _VI_FUNC rsscope_ConfigureTimeoutTriggerSource(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   triggerSource,
                                                        ViReal64  triggerLevel,
                                                        ViReal64  timeoutValue,
                                                        ViInt32   timeoutCondition);

ViStatus _VI_FUNC rsscope_ConfigureIntervalTriggerSource(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   triggerSource,
                                                         ViReal64  triggerLevel,
                                                         ViReal64  intervalWidth,
                                                         ViReal64  intervalDelta,
                                                         ViInt32   intervalPolarity,
                                                         ViInt32   intervalCondition);

ViStatus _VI_FUNC rsscope_ConfigureSlewRateTriggerSource(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   triggerSource,
                                                         ViReal64  slewRateLowerLimit,
                                                         ViReal64  slewRateUpperLimit,
                                                         ViInt32   slewRatePolarity,
                                                         ViInt32   slewRateCondition);

ViStatus _VI_FUNC rsscope_ConfigureSlewRateTriggerRange(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViReal64  slewRate,
                                                        ViReal64  slewRateDelta);

ViStatus _VI_FUNC rsscope_ConfigureData2ClockTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource,
                                                           ViReal64  dataLevel,
                                                           ViInt32   clockSource,
                                                           ViReal64  clockLevel,
                                                           ViReal64  holdTime,
                                                           ViReal64  setupTime,
                                                           ViInt32   data2ClockPolarity);

ViStatus _VI_FUNC rsscope_ConfigureData2ClockSignalEdge(ViSession instrSession,
                                                        ViInt32   signalEdge);

ViStatus _VI_FUNC rsscope_ConfigurePatternTriggerSource(ViSession instrSession,
                                                        ViInt32   patternMode,
                                                        ViInt32   timeoutCondition,
                                                        ViReal64  timeout,
                                                        ViReal64  patternWidth,
                                                        ViReal64  patternDelta,
                                                        ViInt32   patternCondition);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource,
                            ViReal64  dataLevel,
                            ViInt32   clockSource,
                            ViReal64  clockLevel,
                            ViString  pattern,
                            ViInt32   patternPolarity);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternReferenceSource(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   referenceSource);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternTriggerType(ViSession instrSession,
                                                            ViInt32   patternType);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternSingleBitPattern(
                            ViSession instrSession,
                            ViString  pattern,
                            ViInt32   patternLength);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternDualBitPattern(
                            ViSession instrSession,
                            ViString  patternA,
                            ViInt32   patternLengthA,
                            ViString  patternB,
                            ViInt32   patternLengthB);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternComplexWordAlignment(
                            ViSession instrSession,
                            ViInt32   alignmentType,
                            ViInt32   alignmentLength,
                            ViString  alignmentPattern,
                            ViReal64  alignmentTimeout,
                            ViInt32   idleRange,
                            ViInt32   patternLogic,
                            ViInt32   bitOrder);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternComplexWordCondition(
                            ViSession instrSession,
                            ViInt32   complexCondition,
                            ViBoolean conditionEnabled,
                            ViInt32   bitOffset,
                            ViInt32   patternLength,
                            ViInt32   searchRange,
                            ViInt32   condition,
                            ViString  pattern,
                            ViString  patternRangeEnd);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternPRBSError(ViSession instrSession,
                                                          ViReal64  bitErrorRate,
                                                          ViReal64  nominalBitRate,
                                                          ViInt32   sequence);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternEbTb(ViSession instrSession,
                                                     ViInt32   alignmentSymbol,
                                                     ViInt32   scrambling,
                                                     ViBoolean disparityErrorEnabled,
                                                     ViBoolean symbolErrorEnabled);

ViStatus _VI_FUNC rsscope_QuerySerialPatternEbTbRowCount(ViSession instrSession,
                                                         ViInt32*  rowCount);

ViStatus _VI_FUNC rsscope_SerialPatternEbTbAppendSymbol(ViSession instrSession,
                                                        ViString  kOrDSymbol,
                                                        ViString  ebBit,
                                                        ViInt32*  rowCount);

ViStatus _VI_FUNC rsscope_SerialPatternEbTbModifySymbol(ViSession instrSession,
                                                        ViInt32   tableRow,
                                                        ViString  kOrDSymbol,
                                                        ViString  ebBit);

ViStatus _VI_FUNC rsscope_QuerySerialPatternEbTbRunningDisparity(
                            ViSession instrSession,
                            ViInt32   tableRow,
                            ViChar    tbRDPlus[],
                            ViChar    tbRDMinus[]);

ViStatus _VI_FUNC rsscope_SerialPatternEbTbClearTable(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternEbTbFrameID(ViSession instrSession,
                                                            ViInt32   ebTbFrameID);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternI30B(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  alignmentPattern,
                                                     ViString  skipStart,
                                                     ViString  skipEnd,
                                                     ViInt32   skipBytes,
                                                     ViInt32   type,
                                                     ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureSerialPatternI32B(ViSession instrSession,
                                                     ViString  alignmentPattern,
                                                     ViString  skipStart,
                                                     ViString  skipEnd,
                                                     ViInt32   skipBytes,
                                                     ViInt32   type,
                                                     ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureSerialBusTriggerSource(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   protocol);

ViStatus _VI_FUNC rsscope_ConfigureLineTriggerSlope(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   triggerSlope);

ViStatus _VI_FUNC rsscope_ConfigureNFCTrigger(ViSession instrSession,
                                              ViInt32   triggerSource,
                                              ViInt32   technology,
                                              ViInt32   bitRate,
                                              ViInt32   event,
                                              ViReal64  triggerLevel);

ViStatus _VI_FUNC rsscope_ConfigureHWCDRTrigger(ViSession instrSession,
                                                ViInt32   trigger,
                                                ViInt32   serialStandard,
                                                ViReal64  dataLevel,
                                                ViInt32   algorithm,
                                                ViReal64  samplingTime);

ViStatus _VI_FUNC rsscope_QueryCDRTriggerEyeSource(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32*  source);

ViStatus _VI_FUNC rsscope_ConfigureHWCDRTriggerBitRate(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViReal64  nominalBitRate,
                                                       ViBoolean continuousEstimation);

ViStatus _VI_FUNC rsscope_EstimateCDRTriggerEyeBitRate(ViSession instrSession,
                                                       ViInt32   trigger);

ViStatus _VI_FUNC rsscope_ConfigureHWCDRTriggerBandwidth(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViReal64  bandwidth,
                                                         ViInt32   relativeBandwidth);

ViStatus _VI_FUNC rsscope_ConfigureTVTrigger(ViSession instrSession,
                                             ViInt32   triggerSource,
                                             ViInt32   standard,
                                             ViInt32   mode,
                                             ViInt32   lineNumber,
                                             ViInt32   lineField,
                                             ViReal64  triggerLevel,
                                             ViInt32   signalPolarity);

ViStatus _VI_FUNC rsscope_ConfigureTVTriggerCustomSettings(ViSession instrSession,
                                                           ViInt32   pulseType,
                                                           ViReal64  linePeriod,
                                                           ViReal64  pulseWidth,
                                                           ViInt32   scanMode);

ViStatus _VI_FUNC rsscope_ConfigureNoiseReject(ViSession instrSession,
                                               ViInt32   trigger,
                                               ViInt32   triggerSource,
                                               ViInt32   hysteresisMode,
                                               ViReal64  absoluteHysteresis);

ViStatus _VI_FUNC rsscope_ConfigureNoiseRejectHysteresisScale(
                            ViSession instrSession,
                            ViInt32   triggerSource,
                            ViInt32   mode,
                            ViReal64  absoluteHysteresis,
                            ViReal64  relativeHysteresis);

ViStatus _VI_FUNC rsscope_ConfigureNoiseRejectHysteresisRangeInDivisions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   triggerSource,
                            ViReal64  rangeInDivisions);

ViStatus _VI_FUNC rsscope_ConfigureTriggerLinesDisplay(ViSession instrSession,
                                                       ViBoolean showTriggerLinesPermanently);

ViStatus _VI_FUNC rsscope_ConfigureTriggerOutSignal(ViSession instrSession,
                                                    ViBoolean enable,
                                                    ViInt32   polarity,
                                                    ViReal64  pulseLength);

ViStatus _VI_FUNC rsscope_QueryTriggerOutDelay(ViSession instrSession,
                                               ViReal64* delay);

ViStatus _VI_FUNC rsscope_ConfigureEventTrigger(ViSession instrSession,
                                                ViInt32   beep,
                                                ViInt32   print,
                                                ViInt32   saveWaveform);

ViStatus _VI_FUNC rsscope_ConfigureEventTriggerRunExternalApplication(
                            ViSession instrSession,
                            ViInt32   runExternalApplication);

ViStatus _VI_FUNC rsscope_ConfigureEventTriggerOut(ViSession instrSession,
                                                   ViInt32   triggerOut);

ViStatus _VI_FUNC rsscope_ConfigureZoneLogicalExpression(ViSession instrSession,
                                                         ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureZoneTriggerInHistoryReplayState(
                            ViSession instrSession,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureTriggerQualification(ViSession instrSession,
                                                        ViInt32   triggerType,
                                                        ViInt32   trigger,
                                                        ViBoolean qualificationEnabled,
                                                        ViInt32   channel,
                                                        ViBoolean channelEnabled,
                                                        ViInt32   channelLogic);

ViStatus _VI_FUNC rsscope_ConfigureTriggerQualificationMultichannelLogic(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   triggerType,
                            ViBoolean qualificationEnabled,
                            ViInt32   channelCombination,
                            ViInt32   multichannelLogic);

ViStatus _VI_FUNC rsscope_ConfigureTriggerSequenceMode(ViSession instrSession,
                                                       ViInt32   sequenceMode);

ViStatus _VI_FUNC rsscope_ConfigureAOnlyTriggerSequence(ViSession instrSession,
                                                        ViInt32   holdoffMode,
                                                        ViReal64  holdoffTime,
                                                        ViInt32   holdoffEvents,
                                                        ViReal64  randomMinTime,
                                                        ViReal64  randomMaxTime);

ViStatus _VI_FUNC rsscope_QueryAOnlyTriggerSequenceAutoTimeResult(
                            ViSession instrSession,
                            ViReal64* autoTime);

ViStatus _VI_FUNC rsscope_TriggerSequenceHoldoffAutoScale(ViSession instrSession,
                                                          ViReal64  autoScale);

ViStatus _VI_FUNC rsscope_ConfigureABRTriggerSequence(ViSession instrSession,
                                                      ViBoolean eventCoupling,
                                                      ViReal64  sequenceDelay,
                                                      ViInt32   bEventsCount,
                                                      ViBoolean resetByTimeoutEnabled,
                                                      ViReal64  resetTimeout,
                                                      ViBoolean resetByEventEnabled);

ViStatus _VI_FUNC rsscope_ConfigureTriggerSequenceEvent(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   sequenceEvent);

ViStatus _VI_FUNC rsscope_ConfigureDisplayUpdate(ViSession instrSession,
                                                 ViBoolean displayInRemote);

ViStatus _VI_FUNC rsscope_ConfigureDisplayMessage(ViSession instrSession,
                                                  ViBoolean state,
                                                  ViString  text);

ViStatus _VI_FUNC rsscope_ConfigureDisplayGateTransparency(ViSession instrSession,
                                                           ViInt32   transparency);

ViStatus _VI_FUNC rsscope_ConfigureDisplayClearResults(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureDisplayResultsOnExternalMonitorEnabled(
                            ViSession instrSession,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDisplayDialogsOnExternalMonitorEnabled(
                            ViSession instrSession,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigurePersistence(ViSession instrSession,
                                               ViBoolean enable,
                                               ViBoolean infinite,
                                               ViReal64  time);

ViStatus _VI_FUNC rsscope_ResetPersistence(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureSignalStyle(ViSession instrSession,
                                               ViInt32   intensity,
                                               ViInt32   style);

ViStatus _VI_FUNC rsscope_ConfigureWaveformColor(ViSession instrSession,
                                                 ViInt32   waveform,
                                                 ViBoolean useColorTable,
                                                 ViString  tableName,
                                                 ViInt64   signalColor);

ViStatus _VI_FUNC rsscope_AddColorTable(ViSession instrSession,
                                        ViString  tableName);

ViStatus _VI_FUNC rsscope_RemoveColorTable(ViSession instrSession,
                                           ViString  tableName);

ViStatus _VI_FUNC rsscope_ColorTableAppendRow(ViSession instrSession,
                                              ViString  tableName);

ViStatus _VI_FUNC rsscope_ColorTableInsertRow(ViSession instrSession,
                                              ViString  tableName,
                                              ViInt32   index);

ViStatus _VI_FUNC rsscope_ColorTableDefineRow(ViSession instrSession,
                                              ViString  tableName,
                                              ViInt32   index,
                                              ViReal64  cumulativePercentage,
                                              ViInt64   color);

ViStatus _VI_FUNC rsscope_ColorTableRemoveRow(ViSession instrSession,
                                              ViString  tableName,
                                              ViInt32   index);

ViStatus _VI_FUNC rsscope_QueryColorTableCount(ViSession instrSession,
                                               ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryColorTableRowCount(ViSession instrSession,
                                                  ViString  tableName,
                                                  ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryColorTableRow(ViSession instrSession,
                                             ViString  tableName,
                                             ViInt32   index,
                                             ViReal64* cumulativePercentage,
                                             ViInt32*  color);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDiagram(ViSession instrSession,
                                                      ViBoolean showGrid,
                                                      ViBoolean showCrosshair,
                                                      ViBoolean showLabels,
                                                      ViBoolean showTabsAlways,
                                                      ViBoolean yGridFixed);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementXGridFixed(ViSession instrSession,
                                                         ViBoolean xGridFixed);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDiagramFineGridScale(
                            ViSession instrSession,
                            ViBoolean showFineGridScale);

ViStatus _VI_FUNC rsscope_ShowSignalBar(ViSession instrSession,
                                        ViBoolean enable,
                                        ViInt32   position);

ViStatus _VI_FUNC rsscope_ConfigureSignalBarAutoHide(ViSession instrSession,
                                                     ViBoolean autoHide,
                                                     ViBoolean hideHead,
                                                     ViReal64  hideAfter,
                                                     ViReal64  hidingTransparency);

ViStatus _VI_FUNC rsscope_ConfigureSignalBarColor(ViSession instrSession,
                                                  ViInt32   borderColor,
                                                  ViInt32   fillColor);

ViStatus _VI_FUNC rsscope_ConfigureResultBoxPosition(ViSession instrSession,
                                                     ViInt32   position);

ViStatus _VI_FUNC rsscope_AddDiagram(ViSession instrSession,
                                     ViString  existingDiagram,
                                     ViInt32   newDiagramPosition,
                                     ViBoolean insertBefore,
                                     ViInt32   source,
                                     ViString  newDiagramName);

ViStatus _VI_FUNC rsscope_DisplayDiagram(ViSession instrSession,
                                         ViString  diagramName);

ViStatus _VI_FUNC rsscope_RemoveDiagram(ViSession instrSession,
                                        ViString  diagramName);

ViStatus _VI_FUNC rsscope_RenameDiagram(ViSession instrSession,
                                        ViString  diagramName,
                                        ViString  newName);

ViStatus _VI_FUNC rsscope_ShowWaveformInDiagram(ViSession instrSession,
                                                ViString  diagramName,
                                                ViInt32   source);

ViStatus _VI_FUNC rsscope_AddWaveformToDiagram(ViSession instrSession,
                                               ViString  diagramName,
                                               ViInt32   source,
                                               ViBoolean assignToXAxis);

ViStatus _VI_FUNC rsscope_RemoveWaveformFromDiagram(ViSession instrSession,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsscope_AddLabel(ViSession instrSession,
                                   ViString  labelID,
                                   ViInt32   source,
                                   ViString  labelText,
                                   ViInt32   positionMode,
                                   ViReal64  xPosition,
                                   ViReal64  yPosition);

ViStatus _VI_FUNC rsscope_RemoveLabel(ViSession instrSession,
                                      ViString  labelID,
                                      ViInt32   source);

ViStatus _VI_FUNC rsscope_ListLabelIDs(ViSession instrSession,
                                       ViInt32   source,
                                       ViInt32   bufferSize,
                                       ViChar    labelIDs[],
                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_EditLabelText(ViSession instrSession,
                                        ViString  labelID,
                                        ViInt32   source,
                                        ViString  labelText);

ViStatus _VI_FUNC rsscope_QueryLabelText(ViSession instrSession,
                                         ViString  labelID,
                                         ViInt32   source,
                                         ViInt32   bufferSize,
                                         ViChar    labelText[]);

ViStatus _VI_FUNC rsscope_ConfigureLabelShow(ViSession instrSession,
                                             ViInt32   source,
                                             ViBoolean labelShow);

ViStatus _VI_FUNC rsscope_ConfigureLabelPositionMode(ViSession instrSession,
                                                     ViInt32   source,
                                                     ViInt32   positionMode);

ViStatus _VI_FUNC rsscope_ConfigureLabelAbsolutePosition(ViSession instrSession,
                                                         ViString  labelID,
                                                         ViInt32   source,
                                                         ViReal64  xPosition,
                                                         ViReal64  yPosition);

ViStatus _VI_FUNC rsscope_ConfigureLabelRelativePosition(ViSession instrSession,
                                                         ViString  labelID,
                                                         ViInt32   source,
                                                         ViReal64  xPosition,
                                                         ViReal64  yPosition);

ViStatus _VI_FUNC rsscope_ConfigureLabelFontSize(ViSession instrSession,
                                                 ViInt32   fontSize);

ViStatus _VI_FUNC rsscope_WaveformLabelState(ViSession instrSession,
                                             ViString  labelID,
                                             ViInt32   source,
                                             ViBoolean state);

ViStatus _VI_FUNC rsscope_AddDiagramZoom(ViSession instrSession,
                                         ViString  diagramName,
                                         ViInt32   newDiagramPosition,
                                         ViBoolean insertBefore,
                                         ViString  newZoomDiagramName,
                                         ViReal64  xStart,
                                         ViReal64  xStop,
                                         ViReal64  yStart,
                                         ViReal64  yStop);

ViStatus _VI_FUNC rsscope_AddDiagramZoomCoupled(ViSession instrSession,
                                                ViString  diagramName,
                                                ViString  newZoomDiagramName,
                                                ViReal64  xOffset,
                                                ViReal64  yOffset);

ViStatus _VI_FUNC rsscope_RemoveDiagramZoom(ViSession instrSession,
                                            ViString  diagramName,
                                            ViString  zoomDiagramName);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomOverlay(ViSession instrSession,
                                                      ViBoolean zoomOverlay);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomVerticalStartStop(
                            ViSession instrSession,
                            ViString  diagramName,
                            ViString  zoomDiagramName,
                            ViInt32   mode,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomHorizontalStartStop(
                            ViSession instrSession,
                            ViString  diagramName,
                            ViString  zoomDiagramName,
                            ViInt32   mode,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomVerticalPositionRange(
                            ViSession instrSession,
                            ViString  diagramName,
                            ViString  zoomDiagramName,
                            ViInt32   mode,
                            ViReal64  position,
                            ViReal64  range);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomHorizontalPositionRange(
                            ViSession instrSession,
                            ViString  diagramName,
                            ViString  zoomDiagramName,
                            ViInt32   mode,
                            ViReal64  position,
                            ViReal64  range);

ViStatus _VI_FUNC rsscope_ConfigureDiagramZoomPositionCoupling(
                            ViSession instrSession,
                            ViString  diagramName,
                            ViString  zoomDiagramName,
                            ViBoolean positionCoupling);

ViStatus _VI_FUNC rsscope_ConfigureXYDiagram(ViSession instrSession,
                                             ViInt32   XYDiagramNumber,
                                             ViBoolean XYDiagramState,
                                             ViBoolean constantXYRatio,
                                             ViInt32   xSource,
                                             ViInt32   ySource);

ViStatus _VI_FUNC rsscope_SwapXYDiagram(ViSession instrSession,
                                        ViInt32   XYDiagramNumber);

ViStatus _VI_FUNC rsscope_ConfigureHistoryState(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   waveform,
                                                ViBoolean enableHistory);

ViStatus _VI_FUNC rsscope_ConfigureHistoryStartStop(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   waveform,
                                                    ViInt32   start,
                                                    ViInt32   stop);

ViStatus _VI_FUNC rsscope_ConfigureHistoryAcquisitionView(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   waveform,
                                                          ViInt32   acquisition);

ViStatus _VI_FUNC rsscope_ConfigureHistoryAcquisitionTime(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   waveform,
                                                          ViReal64  timePerAcquisition);

ViStatus _VI_FUNC rsscope_ConfigureHistoryAutoRepeat(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   waveform,
                                                     ViBoolean autoRepeat);

ViStatus _VI_FUNC rsscope_HistoryPlaybackControl(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   waveform);

ViStatus _VI_FUNC rsscope_QueryHistoryTimeStamp(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   waveform,
                                                ViInt32   mode,
                                                ViInt32   bufferSize,
                                                ViChar    timeStamp[]);

ViStatus _VI_FUNC rsscope_QueryHistoryTimeReference(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   waveform,
                                                    ViReal64* timeReference);

ViStatus _VI_FUNC rsscope_QueryHistoryDate(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   waveform,
                                           ViInt32   bufferSize,
                                           ViChar    date[]);

ViStatus _VI_FUNC rsscope_QueryHistoryAcquisitionsCount(ViSession instrSession,
                                                        ViInt32   reserved,
                                                        ViInt32*  count);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementState(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViBoolean measurementState);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementSource(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViInt32   signalSource,
                                                     ViInt32   signalSource2);

ViStatus _VI_FUNC rsscope_ConfigureMeasSource(ViSession instrSession,
                                              ViInt32   measurement,
                                              ViInt32   signalSource,
                                              ViInt32   signalSource2);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementLimitCheck(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureMultipleMeasurement(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViBoolean multipleMeasurement);

ViStatus _VI_FUNC rsscope_ConfigureMultipleMeasurementNumber(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementCount);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementCategory(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   category);

ViStatus _VI_FUNC rsscope_EnableAdditionalMeasurements(ViSession instrSession,
                                                       ViInt32   measurement);

ViStatus _VI_FUNC rsscope_DisableAdditionalMeasurements(ViSession instrSession,
                                                        ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ClearMeasurementStatisticData(ViSession instrSession,
                                                        ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementEventActions(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   event,
                                                           ViInt32   action);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDisplayIntermediateResults(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean displayResultLines,
                            ViBoolean displayReferenceLevels);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDisplayStyle(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   displayStyle);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDisplayResultTablePosition(
                            ViSession instrSession,
                            ViInt32   position);

ViStatus _VI_FUNC rsscope_ConfigureMeasurementDisplayGroupResultDialogs(
                            ViSession instrSession,
                            ViBoolean groupResultDialogs);

ViStatus _VI_FUNC rsscope_ReadMeasurementResults(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   arraySize,
                                                 ViReal64  results[],
                                                 ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ConfigureCursor(ViSession instrSession,
                                          ViInt32   cursor,
                                          ViBoolean cursorState,
                                          ViInt32   dataSource,
                                          ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureCursorSecondSource(ViSession instrSession,
                                                      ViInt32   cursor,
                                                      ViBoolean enabled,
                                                      ViInt32   secondSource);

ViStatus _VI_FUNC rsscope_AllCursorsOff(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureCursorShowInAllDiagrams(ViSession instrSession,
                                                           ViBoolean showInAllDiagrams);

ViStatus _VI_FUNC rsscope_ConfigureCursorResultTablePosition(ViSession instrSession,
                                                             ViInt32   tablePosition);

ViStatus _VI_FUNC rsscope_ConfigureCursorPosition(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViReal64  xPosition1,
                                                  ViReal64  xPosition2,
                                                  ViReal64  yPosition1,
                                                  ViReal64  yPosition2);

ViStatus _VI_FUNC rsscope_ConfigureCursorCoupling(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViBoolean xCoupling,
                                                  ViBoolean yCoupling);

ViStatus _VI_FUNC rsscope_ConfigureCursorWaveformTracking(ViSession instrSession,
                                                          ViInt32   cursor,
                                                          ViBoolean tracking);

ViStatus _VI_FUNC rsscope_ConfigureCursorEnvelopeWaveformSelection(
                            ViSession instrSession,
                            ViInt32   cursor,
                            ViInt32   firstCursorPosition,
                            ViInt32   secondCursorPosition);

ViStatus _VI_FUNC rsscope_QueryCursorDistance(ViSession instrSession,
                                              ViInt32   cursor,
                                              ViInt32   direction,
                                              ViReal64* cursorDistance);

ViStatus _VI_FUNC rsscope_QueryCursorInverseDistance(ViSession instrSession,
                                                     ViInt32   cursor,
                                                     ViReal64* cursorDistance);

ViStatus _VI_FUNC rsscope_QueryCursorHorizontalDeltaSlope(ViSession instrSession,
                                                          ViInt32   cursor,
                                                          ViReal64* horizontalDeltaSlope);

ViStatus _VI_FUNC rsscope_CursorSearch(ViSession instrSession,
                                       ViInt32   cursor,
                                       ViInt32   search);

ViStatus _VI_FUNC rsscope_ConfigureCursorPeakExcursion(ViSession instrSession,
                                                       ViInt32   cursor,
                                                       ViInt32   peakExcursion);

ViStatus _VI_FUNC rsscope_ConfigureCursorThreshold(ViSession instrSession,
                                                   ViInt32   cursor,
                                                   ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureCursorLabel(ViSession instrSession,
                                               ViInt32   cursor,
                                               ViString  x1Label,
                                               ViString  x2Label,
                                               ViString  y1Label,
                                               ViString  y2Label);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeMainMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeSettings(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   signalThreshold,
                                                         ViReal64  areaLevel,
                                                         ViInt32   pulseTrainCount);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeSlope(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32   countType,
                                                      ViInt32   slope);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeAdvancedDelaySetup(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   sourceNumber,
                            ViInt32   levelSelection,
                            ViInt32   slope,
                            ViInt32   direction,
                            ViInt32   edgeNumber);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeReferenceLevel(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   type,
                            ViInt32   referenceLevel);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeLimitCheck(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementType,
                                                           ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeLimitCheckLimits(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViReal64  lowerLimit,
                            ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeLimitCheckMargins(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViReal64  lowerMargin,
                            ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureEnvelopeMeasurement(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   envelope);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeDelayToTrigger(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   slope,
                            ViInt32   referenceLevel);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticParameterMeasurementType(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   measurementType);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticParameterOperand(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   operand);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticParameterGroup(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   measurementGroup);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticParameterMeasurementSpectrum(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   spectrum);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticOperator(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   arithmeticOperator);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticConstantSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  constant,
                            ViInt32   constantUnit);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticCustomNameSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean state,
                            ViString  name);

ViStatus _VI_FUNC rsscope_ConfigureAmplitudeTimeArithmeticCustomUnitSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean state,
                            ViString  unit);

ViStatus _VI_FUNC rsscope_ConfigureJitterMainMeasurement(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureJitterAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureJitterClockMeasurementCycleBegin(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   cycleBegin);

ViStatus _VI_FUNC rsscope_ConfigureJitterClockMeasurementCycleOffset(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   cycleOffset);

ViStatus _VI_FUNC rsscope_ConfigureJitterClockMeasurementPulsePolarity(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   pulsePolarity);

ViStatus _VI_FUNC rsscope_ConfigureJitterDataMeasurementClockMode(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   clockMode);

ViStatus _VI_FUNC rsscope_ConfigureJitterDataMeasurementSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   source,
                            ViInt32   slope);

ViStatus _VI_FUNC rsscope_ConfigureJitterDelayMeasurement(ViSession instrSession,
                                                          ViInt32   measurement1,
                                                          ViInt32   edgePolarity,
                                                          ViInt32   measurement2,
                                                          ViInt32   relativePolarity);

ViStatus _VI_FUNC rsscope_ConfigureJitterDataMeasurementUnit(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   unit);

ViStatus _VI_FUNC rsscope_ConfigureJitterLimitCheck(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   measurementType,
                                                    ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureJitterLimitCheckLimits(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   measurementType,
                                                          ViReal64  lowerLimit,
                                                          ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureJitterLimitCheckMargins(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementType,
                                                           ViReal64  lowerMargin,
                                                           ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterAnalyzedSignal(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   analyzedSource,
                            ViInt32   signalType);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterSerialStandard(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   serialStandard);

ViStatus _VI_FUNC rsscope_AdvancedJitterQuickStartAnalysis(ViSession instrSession,
                                                           ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceSource(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   referenceSource);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceSignalClock(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   clockSource,
                            ViInt64   nominalBitrate,
                            ViInt32   clockEdge,
                            ViReal64  UIOffset);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceClockFrequency(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  clockFrequency);

ViStatus _VI_FUNC rsscope_RunAdvancedJitterReferenceClockFreqEstimation(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceClockMultiplierFactor(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   clockMultiplier);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceClockOffset(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  clockOffset);

ViStatus _VI_FUNC rsscope_RunAdvancedJitterReferenceClockOffsetEstimation(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceClockSamplingTime(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  samplingTime);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterReferenceClockDataRate(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64* dataRate);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterReferenceSignalCDR(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   CDRSource);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterGating(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViBoolean useGate,
                                                        ViInt32   couplingMode,
                                                        ViInt32   coupledCursor,
                                                        ViString  diagramName,
                                                        ViString  zoomName);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterGateArea(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   mode,
                                                          ViReal64  start,
                                                          ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionStepResponse(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  length);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionEstimateStepResponse(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterDecompositionStepResponseEstimatedMax(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64* estimatedMax);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionStepPosition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   stepPosition);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionTargetBER(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   targetExponent);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionDisplaySettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean jitterInterleaved,
                            ViBoolean periodicJitterLabels,
                            ViBoolean periodicNoiseLabels);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionSelectAllBasicJitterComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionSelectAllJitterComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionClearSelectedBasicJitterComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionClearSelectedJitterComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionComponentEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionSelectAllNoiseComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_AdvancedJitterDecompositionClearSelectedNoiseComponents(
                            ViSession instrSession,
                            ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionPeriodicComponentsEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionMaxPeriodicJitterComponents(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   verticalComponents,
                            ViInt32   horizontalComponents,
                            ViBoolean PJTableEnabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterDecompositionOtherBoundedUncorrelatedEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean resultsEnabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterGeneralResults(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean statisticsEnabled,
                            ViBoolean stepResponseEnabled,
                            ViBoolean bathtubEnabled,
                            ViInt32   bathtubPlot,
                            ViBoolean syntheticEyeEnabled,
                            ViInt32   syntheticEyePlot);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterBathtubComponents(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean periodicComponentsEnabled,
                            ViBoolean OBUJComponentsEnabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsNoiseBathtubPlot(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean plotEnabled,
                            ViBoolean periodicComponentsEnabled,
                            ViBoolean OBUNComponentsEnabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsSyntheticEyePeriodicComponentsEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean horizontalComponentsEnabled,
                            ViBoolean verticalComponentsEnabled);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterComponentSpecificResults(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViBoolean histogram,
                            ViBoolean track,
                            ViBoolean spectrum);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsDiagramTransitions(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   transitions);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsDiagramLevels(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   diagramLevels);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsScaling(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   maxNumOfBins,
                            ViBoolean continuousAutoScale);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsScalingManual(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViReal64  scale,
                            ViReal64  offset);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsScalingAutoJitter(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean basicJitterAutoScale,
                            ViBoolean spectrumAutoScale);

ViStatus _VI_FUNC rsscope_ConfigureAdvancedJitterResultsScalingAutoNoise(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean noiseAutoScale,
                            ViBoolean spectrumAutoScale);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentPeakToPeak(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* peakToPeak);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStandardDeviation(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* standardDeviation);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsWaveformCount(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViInt64*  waveformCount);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsPeakToPeak(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* peakToPeak);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsStandardDeviation(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* standardDeviation);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsMaxPeakToPeak(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* maxPeakToPeak);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsMaxStandardDeviation(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* maxStandardDeviation);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsMinPeakToPeak(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* minPeakToPeak);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsComponentStatisticsMinStandardDeviation(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   component,
                            ViReal64* minStandardDeviation);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsPeriodicComponentCount(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32*  componentCount);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsPeriodicComponentFrequency(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   periodicComponent,
                            ViInt64*  frequency);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsPeriodicComponentValue(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   periodicComponent,
                            ViReal64* value);

ViStatus _VI_FUNC rsscope_QueryAdvancedJitterResultsPeriodicComponentDirection(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   periodicComponent,
                            ViInt32*  direction);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterMainMeasurement(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterLimitCheck(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   measurementType,
                                                       ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterLimitCheckLimits(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementType,
                                                             ViReal64  lowerLimit,
                                                             ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterLimitCheckMargins(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViReal64  lowerMargin,
                            ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterGeneralSettings(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViReal64  start,
                                                            ViReal64  stop,
                                                            ViInt32   algorithm,
                                                            ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterHeight(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViInt32   algorithm,
                                                   ViReal64  start,
                                                   ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterWidth(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViInt32   algorithm,
                                                  ViBoolean useMeasurementWindow,
                                                  ViReal64  start,
                                                  ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterDutyCycleDistortion(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  level);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterLevel(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViBoolean useMeasurementLevel,
                                                  ViReal64  level);

ViStatus _VI_FUNC rsscope_ConfigureEyeJitterRiseTimeFallTimeLevel(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  localStartLevel,
                            ViReal64  localStopLevel);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumMainMeasurement(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumSettings(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   nDBDown,
                                                    ViReal64  channelBandwidth,
                                                    ViReal64  channelCenterFrequency,
                                                    ViReal64  occupiedBandwidth,
                                                    ViInt32   reserved);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumPeakExcursion(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   peakExcursion);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumLimitCheck(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32   measurementType,
                                                      ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumLimitCheckLimits(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32   measurementType,
                                                            ViReal64  lowerLimit,
                                                            ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumLimitCheckMargins(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementType,
                                                             ViReal64  lowerMargin,
                                                             ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumMaxNumberOfResults(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViInt32   maxNumberOfResults);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultMode(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32   measurementType,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAbsoluteThreshold(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViReal64  absoluteThreshold);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultLabelsState(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementType,
                                                             ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultLabelsFrameType(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViInt32   frameType);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultLabelsInverse(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViBoolean inverse);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultLabelsMaximumPeaks(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViInt32   maximumPeaks);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumResultLabelsShowFrequency(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViBoolean showFrequency);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticParameterMeasuerementType(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   measuerementType);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticParameterOperand(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   operand);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticParameterGroup(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   measurementGroup);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticParameterMeasurementSpectrum(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   parameter,
                            ViInt32   spectrum);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticOperator(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   arithmeticOperator);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticConstantSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  constant,
                            ViInt32   constantUnit);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticCustomNameSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean state,
                            ViString  name);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumArithmeticCustomUnitSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean state,
                            ViString  unit);

ViStatus _VI_FUNC rsscope_ConfigureOpticalMeasurementUnit(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   unit);

ViStatus _VI_FUNC rsscope_ConfigureOpticalMeasurementModulationAmplitude(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureOpticalMeasurementValidRange(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   opticalMeasurement,
                            ViInt32   validRange);

ViStatus _VI_FUNC rsscope_ConfigureOpticalMeasurementLimitCheckLimits(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   opticalMeasurement,
                            ViReal64  lowerLimit,
                            ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureOpticalMeasurementLimitCheckMargins(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   opticalMeasurement,
                            ViReal64  lowerMargin,
                            ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureHistogramMainMeasurement(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureHistogramAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_SelectHistogram(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViString  measurementType);

ViStatus _VI_FUNC rsscope_ConfigureHistogramProbabilityDomainMarkerSettings(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   reference,
                            ViInt32   delta);

ViStatus _VI_FUNC rsscope_ConfigureHistogramLimitCheck(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   measurementType,
                                                       ViInt32   limitCheck);

ViStatus _VI_FUNC rsscope_ConfigureHistogramLimitCheckLimits(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementType,
                                                             ViReal64  lowerLimit,
                                                             ViReal64  upperLimit);

ViStatus _VI_FUNC rsscope_ConfigureHistogramLimitCheckMargins(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementType,
                            ViReal64  lowerMargin,
                            ViReal64  upperMargin);

ViStatus _VI_FUNC rsscope_ConfigureHistogramDisplay(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViBoolean displaySourceHistogram);

ViStatus _VI_FUNC rsscope_CreateNewHistogram(ViSession instrSession,
                                             ViString  histogramName,
                                             ViInt32   histogramSource,
                                             ViBoolean relativeValues,
                                             ViReal64  xStart,
                                             ViReal64  xStop,
                                             ViReal64  yStart,
                                             ViReal64  yStop,
                                             ViInt32   orientation);

ViStatus _VI_FUNC rsscope_ConfigureHistogramSource(ViSession instrSession,
                                                   ViString  histogramName,
                                                   ViInt32   histogramSource);

ViStatus _VI_FUNC rsscope_ResetHistogram(ViSession instrSession,
                                         ViString  histogramName);

ViStatus _VI_FUNC rsscope_RemoveHistogram(ViSession instrSession,
                                          ViString  histogramName);

ViStatus _VI_FUNC rsscope_ConfigureHistogramType(ViSession instrSession,
                                                 ViString  histogramName,
                                                 ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureHistogramVertical(ViSession instrSession,
                                                     ViString  histogramName,
                                                     ViInt32   mode,
                                                     ViReal64  start,
                                                     ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureHistogramHorizontal(ViSession instrSession,
                                                       ViString  histogramName,
                                                       ViInt32   mode,
                                                       ViReal64  start,
                                                       ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureHistogramLayoutState(ViSession instrSession,
                                                        ViString  histogramName,
                                                        ViBoolean histogramState);

ViStatus _VI_FUNC rsscope_ConfigureGateState(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViBoolean useGate);

ViStatus _VI_FUNC rsscope_ConfigureGateShow(ViSession instrSession,
                                            ViInt32   measurement,
                                            ViBoolean showGate);

ViStatus _VI_FUNC rsscope_ConfigureGateDefinitionZoom(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViBoolean zoomCoupling,
                                                      ViInt32   reserved);

ViStatus _VI_FUNC rsscope_ConfigureGateZoomDiagram(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViString  diagramName,
                                                   ViString  zoomName);

ViStatus _VI_FUNC rsscope_ConfigureGateDefinitionCursor(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViBoolean coupling,
                                                        ViInt32   cursorSet);

ViStatus _VI_FUNC rsscope_ConfigureGateCoupling(ViSession instrSession,
                                                ViInt32   measurement,
                                                ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureGateDefinitionStartStop(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   mode,
                                                           ViReal64  start,
                                                           ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureGateNoise(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   evaluationArea);

ViStatus _VI_FUNC rsscope_ConfigureLongTermState(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViBoolean longTermState);

ViStatus _VI_FUNC rsscope_ConfigureLongTermTotalMeasurementTime(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   totalMeasurementTime);

ViStatus _VI_FUNC rsscope_ConfigureLongTermMeasurementPoints(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32   measurementPoints);

ViStatus _VI_FUNC rsscope_ConfigureLongTermVerticalScaling(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViReal64  verticalScale,
                                                           ViReal64  verticalOffset);

ViStatus _VI_FUNC rsscope_ConfigureLongTermVerticalContinuousAutoScaling(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean continuousAutoScale);

ViStatus _VI_FUNC rsscope_LongTermVerticalAutoScale(ViSession instrSession,
                                                    ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureStatisticsState(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViBoolean statistics);

ViStatus _VI_FUNC rsscope_ConfigureHistogramState(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViBoolean showHistogram);

ViStatus _VI_FUNC rsscope_ConfigureResetStatisticsSettings(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   resetStatisticsMode,
                                                           ViReal64  resetTime,
                                                           ViInt32   resetCount);

ViStatus _VI_FUNC rsscope_ConfigureResetStatisticsMeasurementsCount(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementsCount);

ViStatus _VI_FUNC rsscope_ResetStatistics(ViSession instrSession,
                                          ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureStatisticsNumberOfBins(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   numberOfBins);

ViStatus _VI_FUNC rsscope_ConfigureEnvironmentSensorState(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViBoolean useSensor);

ViStatus _VI_FUNC rsscope_ConfigureProtocolMainMeasurement(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementFunction);

ViStatus _VI_FUNC rsscope_ConfigureProtocolAdditionalMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureFrameToFrame(ViSession instrSession,
                                                ViInt32   measurement,
                                                ViString  fromFrame,
                                                ViString  fromField,
                                                ViString  fromValue,
                                                ViString  toFrame,
                                                ViString  toField,
                                                ViString  toValue);

ViStatus _VI_FUNC rsscope_ConfigureTriggerToFrame(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViInt32   direction,
                                                  ViString  frame,
                                                  ViString  field,
                                                  ViString  value);

ViStatus _VI_FUNC rsscope_ConfigureFieldValueMeasurement(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViString  frame,
                                                         ViString  field,
                                                         ViString  value,
                                                         ViString  fieldToBeTracked);

ViStatus _VI_FUNC rsscope_ConfigureMainBitRate(ViSession instrSession,
                                               ViInt32   measurement,
                                               ViString  name,
                                               ViString  field,
                                               ViString  value);

ViStatus _VI_FUNC rsscope_ConfigureSecondaryBitRate(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViString  name,
                                                    ViString  field,
                                                    ViString  value);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevel(ViSession instrSession,
                                                          ViInt32   waveform,
                                                          ViInt32   referenceLevelMode,
                                                          ViInt32   levelDefinition,
                                                          ViInt32   userLevelSelection);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelAutoSettings(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViInt32   signalLevelMode,
                            ViBoolean histogramAveraging,
                            ViInt32   averageCount);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceUserSignalLevel(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  topDistance,
                            ViReal64  bottomDistance,
                            ViReal64  highSignalLevel,
                            ViReal64  lowSignalLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformUserReferenceLevel(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  topDistance,
                            ViReal64  bottomDistance,
                            ViReal64  upperLevel,
                            ViReal64  lowerLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformUserMiddleReferenceLevel(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  middleLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelRelativeLevels(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViInt32   relativeLevels);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelRelativeUserLevels(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViInt32   upperLevel,
                            ViInt32   middleLevel,
                            ViInt32   lowerLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelHysteresis(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelTube(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  topOuter,
                            ViReal64  topInner,
                            ViReal64  bottomInner,
                            ViReal64  bottomOuter);

ViStatus _VI_FUNC rsscope_ConfigureWaveformReferenceLevelTubeRelative(
                            ViSession instrSession,
                            ViInt32   waveform,
                            ViReal64  relativeOuter,
                            ViReal64  relativeInner);

ViStatus _VI_FUNC rsscope_ActualRecordLength(ViSession instrSession,
                                             ViInt32*  actualRecordLength);

ViStatus _VI_FUNC rsscope_SampleMode(ViSession instrSession,
                                     ViInt32*  sampleMode);

ViStatus _VI_FUNC rsscope_SampleRate(ViSession instrSession,
                                     ViReal64* sampleRate);

ViStatus _VI_FUNC rsscope_AutoProbeSenseValue(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* autoProbeSenseValue);

ViStatus _VI_FUNC rsscope_QueryMaskTestResults(ViSession instrSession,
                                               ViString  maskName,
                                               ViUInt32* acquisitionsCompleted,
                                               ViUInt32* acquisitionsRemaining,
                                               ViInt32*  state,
                                               ViUInt32* sampleHits,
                                               ViUInt32* acquisitionHits,
                                               ViUInt32* failRate,
                                               ViInt32*  testResult);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestActionsOnEvent(ViSession instrSession,
                                                          ViString  maskName,
                                                          ViInt32   event,
                                                          ViInt32   action);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestDefinition(ViSession instrSession,
                                                      ViInt32   action,
                                                      ViString  maskName);

ViStatus _VI_FUNC rsscope_ConvertMaskTestToUser(ViSession instrSession,
                                                ViString  maskName);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestEnable(ViSession instrSession,
                                                  ViString  maskName,
                                                  ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestDefinitionType(ViSession instrSession,
                                                          ViString  maskName,
                                                          ViInt32   definitionType);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSource(ViSession instrSession,
                                                  ViString  maskName,
                                                  ViInt32   maskSource);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSettings(ViSession instrSession,
                                                    ViString  maskName,
                                                    ViInt32   failCondition,
                                                    ViUInt32  violationTolerance);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSavePath(ViSession instrSession,
                                                    ViString  maskTestName,
                                                    ViString  savePath);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestManagerOperations(ViSession instrSession,
                                                             ViInt32   operation,
                                                             ViString  maskTestName);

ViStatus _VI_FUNC rsscope_ClearMaskTestSegments(ViSession instrSession,
                                                ViString  maskTestName);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSegments(ViSession instrSession,
                                                    ViString  maskName,
                                                    ViInt32   maskSegment,
                                                    ViBoolean state,
                                                    ViInt32   region);

ViStatus _VI_FUNC rsscope_QueryMaskTestSegmentsCount(ViSession instrSession,
                                                     ViString  maskName,
                                                     ViInt32   maskSegment,
                                                     ViInt32*  segmentsNumber);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSegmentsOperation(ViSession instrSession,
                                                             ViString  maskName,
                                                             ViInt32   maskSegment,
                                                             ViInt32   action);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSegmentDefinition(ViSession instrSession,
                                                             ViString  maskName,
                                                             ViInt32   maskSegment,
                                                             ViInt32   pointIndex,
                                                             ViReal64  xValue,
                                                             ViReal64  yValue);

ViStatus _VI_FUNC rsscope_QueryMaskTestSegmentDefinitionCount(
                            ViSession instrSession,
                            ViString  maskName,
                            ViInt32   maskSegment,
                            ViInt32*  pointsNumber);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestSegmentDefinitionOperation(
                            ViSession instrSession,
                            ViString  maskName,
                            ViInt32   definitionOfSegment,
                            ViInt32   pointIndex,
                            ViInt32   action);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestRescale(ViSession instrSession,
                                                   ViInt32   definitionOfSegment,
                                                   ViString  maskName,
                                                   ViReal64  offsetX,
                                                   ViInt32   factorX,
                                                   ViReal64  offsetY,
                                                   ViInt32   factorY);

ViStatus _VI_FUNC rsscope_MaskTestRecalculate(ViSession instrSession,
                                              ViInt32   definitionOfSegment,
                                              ViString  maskName);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestLabelState(ViSession instrSession,
                                                      ViBoolean showLabels);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestNameState(ViSession instrSession,
                                                     ViBoolean showName);

ViStatus _VI_FUNC rsscope_RenameMaskTest(ViSession instrSession,
                                         ViString  oldMaskName,
                                         ViString  newMaskName);

ViStatus _VI_FUNC rsscope_ConfigureMaskViolationHighlighting(ViSession instrSession,
                                                             ViBoolean highlightHits,
                                                             ViBoolean infiniteHighlight,
                                                             ViReal64  highlightTime,
                                                             ViInt64   matchColor);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestMaskColors(ViSession instrSession,
                                                      ViInt64   maskWithoutViolation,
                                                      ViInt64   maskWithViolation,
                                                      ViInt64   maskWithContact);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestWaveformCopy(ViSession instrSession,
                                                        ViString  maskName,
                                                        ViInt32   usedReference);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestWaveformRescale(ViSession instrSession,
                                                           ViString  maskName,
                                                           ViReal64  horizontalWidth,
                                                           ViReal64  verticalWidth,
                                                           ViInt32   verticalStretch,
                                                           ViReal64  verticalPosition);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestEyeShape(ViSession instrSession,
                                                    ViString  maskName,
                                                    ViInt32   shape);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestEyePolygon(ViSession instrSession,
                                                      ViString  maskName,
                                                      ViReal64  mainWidth,
                                                      ViReal64  mainHeight,
                                                      ViReal64  minorWidth,
                                                      ViReal64  minorHeight,
                                                      ViBoolean copyLeft,
                                                      ViReal64  interpatternLength,
                                                      ViBoolean copyRight);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestEyeTopBottom(ViSession instrSession,
                                                        ViString  maskName,
                                                        ViBoolean topState,
                                                        ViReal64  offsetTop,
                                                        ViReal64  width,
                                                        ViBoolean bottomState,
                                                        ViReal64  offsetBottom,
                                                        ViBoolean symmetric);

ViStatus _VI_FUNC rsscope_ConfigureMaskTestEyeCenter(ViSession instrSession,
                                                     ViString  maskName,
                                                     ViReal64  horizontal,
                                                     ViReal64  vertical);

ViStatus _VI_FUNC rsscope_NewSearch(ViSession instrSession,
                                    ViString  searchName);

ViStatus _VI_FUNC rsscope_DeleteSearch(ViSession instrSession,
                                       ViString  searchName);

ViStatus _VI_FUNC rsscope_ConfigureSearchSource(ViSession instrSession,
                                                ViString  searchName,
                                                ViInt32   searchConditionSource);

ViStatus _VI_FUNC rsscope_ConfigureSearchCategory(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   searchCategory);

ViStatus _VI_FUNC rsscope_ConfigureSearchControl(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViBoolean searchOnline);

ViStatus _VI_FUNC rsscope_PerformSearch(ViSession instrSession,
                                        ViString  searchName,
                                        ViInt32   searchResults);

ViStatus _VI_FUNC rsscope_ClearSearchResults(ViSession instrSession,
                                             ViString  searchName);

ViStatus _VI_FUNC rsscope_QuerySearchResults(ViSession instrSession,
                                             ViString  searchName,
                                             ViInt32   bufferSize,
                                             ViInt32   acquisitionIndex[],
                                             ViReal64  xPosition[],
                                             ViReal64  yPosition[],
                                             ViInt32   typeOfSearchResult[],
                                             ViInt32   slope[],
                                             ViReal64  timeResult[],
                                             ViInt32*  actualValues);

ViStatus _VI_FUNC rsscope_SearchTriggerCopyConfiguration(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   triggerType,
                                                         ViInt32   copyFrom);

ViStatus _VI_FUNC rsscope_ConfigureEdgeTriggerSearch(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean triggerState,
                                                     ViInt32   searchSource,
                                                     ViReal64  triggerLevel,
                                                     ViInt32   triggerSlope);

ViStatus _VI_FUNC rsscope_ConfigureGlitchTriggerSearch(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViBoolean triggerState,
                                                       ViInt32   searchSource,
                                                       ViReal64  triggerLevel,
                                                       ViReal64  glitchWidth,
                                                       ViInt32   glitchPolarity,
                                                       ViInt32   glitchCondition);

ViStatus _VI_FUNC rsscope_ConfigureWidthTriggerSearch(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViBoolean triggerState,
                                                      ViInt32   searchSource,
                                                      ViReal64  triggerLevel,
                                                      ViReal64  width,
                                                      ViReal64  widthDelta,
                                                      ViInt32   widthPolarity,
                                                      ViInt32   widthRange);

ViStatus _VI_FUNC rsscope_ConfigureRuntTriggerSearch(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean triggerState,
                                                     ViInt32   searchSource,
                                                     ViReal64  runtLowThreshold,
                                                     ViReal64  runtHighThreshold,
                                                     ViInt32   runtPolarity);

ViStatus _VI_FUNC rsscope_ConfigureRuntTriggerSearchRange(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViReal64  runtWidth,
                                                          ViReal64  runtDelta,
                                                          ViInt32   runtRange);

ViStatus _VI_FUNC rsscope_ConfigureWindowTriggerSearch(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViBoolean triggerState,
                                                       ViInt32   searchSource,
                                                       ViReal64  windowLowerLimit,
                                                       ViReal64  windowUpperLimit);

ViStatus _VI_FUNC rsscope_ConfigureWindowTriggerSearchRange(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   verticalCondition,
                                                            ViInt32   timeCondition,
                                                            ViReal64  windowWidth,
                                                            ViReal64  windowDelta);

ViStatus _VI_FUNC rsscope_ConfigureTimeoutTriggerSearch(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViBoolean triggerState,
                                                        ViInt32   searchSource,
                                                        ViReal64  triggerLevel,
                                                        ViReal64  timeoutValue,
                                                        ViInt32   timeoutCondition);

ViStatus _VI_FUNC rsscope_ConfigureIntervalTriggerSearch(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean triggerState,
                                                         ViInt32   searchSource,
                                                         ViReal64  triggerLevel,
                                                         ViReal64  intervalWidth,
                                                         ViReal64  intervalDelta,
                                                         ViInt32   intervalPolarity,
                                                         ViInt32   intervalCondition);

ViStatus _VI_FUNC rsscope_ConfigureSlewRateTriggerSearch(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean triggerState,
                                                         ViInt32   searchSource,
                                                         ViReal64  slewRateLowerLimit,
                                                         ViReal64  slewRateUpperLimit);

ViStatus _VI_FUNC rsscope_ConfigureSlewRateTriggerSearchRange(
                            ViSession instrSession,
                            ViString  searchName,
                            ViReal64  slewRate,
                            ViReal64  slewRateDelta,
                            ViInt32   slewRateCondition,
                            ViInt32   slewRatePolarity);

ViStatus _VI_FUNC rsscope_ConfigureData2ClockTriggerSearch(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViBoolean triggerState,
                                                           ViInt32   searchSource,
                                                           ViReal64  dataLevel,
                                                           ViInt32   clockSource,
                                                           ViReal64  clockLevel,
                                                           ViReal64  holdTime,
                                                           ViReal64  setupTime,
                                                           ViInt32   clockEdge);

ViStatus _VI_FUNC rsscope_ConfigureStateTriggerSearch(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViBoolean triggerState,
                                                      ViInt32   clockSource,
                                                      ViInt32   clockEdge,
                                                      ViReal64  clockLevel);

ViStatus _VI_FUNC rsscope_ConfigureStateTriggerSearchQualification(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   channel,
                            ViBoolean channelEnabled,
                            ViInt32   channelLogic);

ViStatus _VI_FUNC rsscope_ConfigureStateTriggerSearchQualificationMultichannelLogic(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   channelCombination,
                            ViInt32   multichannelLogic);

ViStatus _VI_FUNC rsscope_ConfigurePatternTriggerSearch(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViBoolean triggerState,
                                                        ViInt32   patternMode,
                                                        ViInt32   timeoutCondition,
                                                        ViReal64  timeout,
                                                        ViReal64  patternWidth,
                                                        ViReal64  patternDelta,
                                                        ViInt32   patternCondition);

ViStatus _VI_FUNC rsscope_ConfigurePatternTriggerSearchQualification(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   channel,
                            ViBoolean channelEnabled,
                            ViInt32   channelLogic);

ViStatus _VI_FUNC rsscope_ConfigurePatternTriggerSearchQualificationMultichannelLogic(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   channelCombination,
                            ViInt32   multichannelLogic);

ViStatus _VI_FUNC rsscope_QueryTriggerSearchCondition(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   bufferSize,
                                                      ViChar    searchLogic[]);

ViStatus _VI_FUNC rsscope_ConfigureSearchGateState(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViBoolean useGate);

ViStatus _VI_FUNC rsscope_ConfigureSearchGateShow(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViBoolean showGate);

ViStatus _VI_FUNC rsscope_ConfigureSearchGateDefinitionZoom(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViBoolean zoomCoupling,
                                                            ViInt32   reserved);

ViStatus _VI_FUNC rsscope_ConfigureSearchGateDefinitionZoomDiagram(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  diagram,
                            ViString  zoom);

ViStatus _VI_FUNC rsscope_ConfigureSearchGateDefinitionStartStop(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   mode,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureSearchResultTable(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean showResultTable,
                                                     ViInt32   sortMode,
                                                     ViBoolean sortAscending,
                                                     ViInt32   maxResultCount);

ViStatus _VI_FUNC rsscope_ConfigureSearchZoomWindowState(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean showSearchZoomWindows);

ViStatus _VI_FUNC rsscope_ConfigureSearchZoomWindowXAxis(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   horizonatalMode,
                                                         ViReal64  position,
                                                         ViReal64  range);

ViStatus _VI_FUNC rsscope_ConfigureSearchZoomWindowYAxis(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   verticalMode,
                                                         ViReal64  position,
                                                         ViReal64  range);

ViStatus _VI_FUNC rsscope_ConfigureSearchNoiseReject(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   searchSource,
                                                     ViBoolean useNoiseReject,
                                                     ViInt32   hysteresisMode,
                                                     ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureDecodeState(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureBusLabel(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViString  busLabel);

ViStatus _VI_FUNC rsscope_ShowDecodeTable(ViSession instrSession,
                                          ViInt32   serialBus,
                                          ViBoolean showTable);

ViStatus _VI_FUNC rsscope_ConfigureProtocolResultTableZoomCouplingEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean zoomCouplingEnabled);

ViStatus _VI_FUNC rsscope_ConfigureProtocolResultTablePosition(
                            ViSession instrSession,
                            ViInt32   position);

ViStatus _VI_FUNC rsscope_ConfigureDataFormat(ViSession instrSession,
                                              ViInt32   dataFormat);

ViStatus _VI_FUNC rsscope_ConfigureBusDataFormat(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   dataFormat);

ViStatus _VI_FUNC rsscope_ConfigureShowThresholdLines(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureShowDetails(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureLabelList(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureBusLabelListFile(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViString  fileName);

ViStatus _VI_FUNC rsscope_SetReferenceLevels(ViSession instrSession,
                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_AutosetProtocolThresholdAndBitrate(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_ConfigureProtocolExportSettings(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViBoolean includeFrameTiming,
                                                          ViBoolean includeDetails);

ViStatus _VI_FUNC rsscope_ExportProtocolToFile(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViString  fileName);

ViStatus _VI_FUNC rsscope_ConfigureI2CSource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   line,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureI2CThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   preset,
                                                ViReal64  SCLThreshold,
                                                ViReal64  SDAThreshold);

ViStatus _VI_FUNC rsscope_ConfigureI2CRWBit(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   RWBit);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerType(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerAddress(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   addressType,
                                                     ViInt32   RWBitAddress,
                                                     ViInt32   condition,
                                                     ViString  addressMin,
                                                     ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerAddressORState(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   ORSlot,
                                                            ViBoolean ORSlotState);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerAddressOR(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   ORSlot,
                                                       ViInt32   addressType,
                                                       ViInt32   RWBitAddress,
                                                       ViString  address);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerData(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  addressMin,
                                                  ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerDataPosition(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   condition,
                                                          ViInt32   indexMin,
                                                          ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CTriggerNoAck(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViBoolean addressNack,
                                                   ViBoolean dataWriteNack,
                                                   ViBoolean dataReadNack);

ViStatus _VI_FUNC rsscope_QueryI2CFrameCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryI2CFrameStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32*  status,
                                              ViReal64* frameStart,
                                              ViReal64* frameStop,
                                              ViInt32*  addressType,
                                              ViInt32*  address,
                                              ViInt32*  RWBit,
                                              ViInt32*  ackBit);

ViStatus _VI_FUNC rsscope_QueryI2CFrameAccessBitStart(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViReal64* accessBitStart);

ViStatus _VI_FUNC rsscope_QueryI2CFrameSlaveAddress(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32*  address);

ViStatus _VI_FUNC rsscope_QueryI2CFrameAddressAckBitStartTime(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* addressStart);

ViStatus _VI_FUNC rsscope_QueryI2CFrameAddressAckBitStart(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViReal64* ackBitStart);

ViStatus _VI_FUNC rsscope_QueryI2CFrameAddressComplete(ViSession  instrSession,
                                                       ViInt32    serialBus,
                                                       ViInt32    frame,
                                                       ViBoolean* complete);

ViStatus _VI_FUNC rsscope_QueryI2CFrameBitRate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_QueryI2CFrameLength(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32*  length);

ViStatus _VI_FUNC rsscope_QueryI2CFrameData(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   frame,
                                            ViInt32   byteNumber,
                                            ViInt32*  data,
                                            ViInt32*  ackBit);

ViStatus _VI_FUNC rsscope_QueryI2CFrameDataByteStart(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   byteNumber,
                                                     ViReal64* startTime);

ViStatus _VI_FUNC rsscope_QueryI2CFrameDataByteAcknowledgeBitStart(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViReal64* startTime);

ViStatus _VI_FUNC rsscope_QueryI2CFrameDataComplete(ViSession  instrSession,
                                                    ViInt32    serialBus,
                                                    ViInt32    frame,
                                                    ViInt32    byteNumber,
                                                    ViBoolean* complete);

ViStatus _VI_FUNC rsscope_QueryI2CFrameAllData(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32   arraySize,
                                               ViInt32   data[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryI2CFrameLabel(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   bufferSize,
                                             ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchType(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchCriteria(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean start,
                                                     ViBoolean repeatedStart,
                                                     ViBoolean stop,
                                                     ViBoolean nack,
                                                     ViBoolean address,
                                                     ViBoolean addressOR,
                                                     ViBoolean addressData);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchAddress(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   addressType,
                                                    ViInt32   RWBitAddress,
                                                    ViInt32   condition,
                                                    ViString  addressMin,
                                                    ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchAddressORState(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   ORSlot,
                                                           ViBoolean ORSlotState);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchAddressOR(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   ORSlot,
                                                      ViInt32   addressType,
                                                      ViInt32   RWBitAddress,
                                                      ViString  address);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchData(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   condition,
                                                 ViString  addressMin,
                                                 ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchDataPosition(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   condition,
                                                         ViInt32   indexMin,
                                                         ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_ConfigureI2CSearchNoAck(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViBoolean addressNack,
                                                  ViBoolean dataWriteNack,
                                                  ViBoolean dataReadNack);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameStatus(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViInt32*  status,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  addressType,
                                                    ViInt32*  address,
                                                    ViInt32*  RWBit,
                                                    ViInt32*  ackBit);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameAccessBitStart(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   frame,
                                                            ViReal64* accessBitStart);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameSlaveAddress(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32*  address);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameAddressAckBitStartTime(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViReal64* addressStart);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameAddressAckBitStart(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViReal64* ackBitStart);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameAddressComplete(ViSession  instrSession,
                                                             ViString   searchName,
                                                             ViInt32    frame,
                                                             ViBoolean* complete);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameLength(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViInt32*  length);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   frame,
                                                  ViInt32   byteNumber,
                                                  ViInt32*  data,
                                                  ViInt32*  ackBit);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameDataByteStart(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32   byteNumber,
                                                           ViReal64* startTime);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameDataByteAcknowledgeBitStart(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViReal64* startTime);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameDataComplete(ViSession  instrSession,
                                                          ViString   searchName,
                                                          ViInt32    frame,
                                                          ViInt32    byteNumber,
                                                          ViBoolean* complete);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameAllData(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32   arraySize,
                                                     ViInt32   data[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryI2CSearchFrameLabel(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   frame,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureSPISource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   line,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureSPIThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   preset,
                                                ViReal64  clockThreshold,
                                                ViReal64  SSThreshold,
                                                ViReal64  MISOThreshold,
                                                ViReal64  MOSIThreshold);

ViStatus _VI_FUNC rsscope_ConfigureSPIPolarity(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   line,
                                               ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureSPIWord(ViSession instrSession,
                                           ViInt32   serialBus,
                                           ViInt32   bitOrder,
                                           ViInt32   wordLength);

ViStatus _VI_FUNC rsscope_ConfigureSPIFrameStart(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frameCondition,
                                                 ViReal64  clockTimeout);

ViStatus _VI_FUNC rsscope_ConfigureSPITriggerType(ViSession instrSession,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSPITriggerData(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  MOSIPattern,
                                                  ViString  MISOPattern);

ViStatus _VI_FUNC rsscope_ConfigureSPITriggerDataPosition(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   condition,
                                                          ViInt32   searchMode,
                                                          ViInt32   indexMin,
                                                          ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_QuerySPIFrameCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySPIWordCount(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   frame,
                                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySPIFrameStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViReal64* frameStart,
                                              ViReal64* frameStop,
                                              ViInt32*  status);

ViStatus _VI_FUNC rsscope_QuerySPIFrameBitRate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_QuerySPIFrameData(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   frame,
                                            ViInt32   word,
                                            ViReal64* valueStart,
                                            ViReal64* valueStop,
                                            ViInt32*  MOSIValue,
                                            ViInt32*  MISOValue);

ViStatus _VI_FUNC rsscope_QuerySPIFrameAllData(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32   arraySize,
                                               ViInt32   data[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySPIFrameFormattedValue(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   word,
                                                      ViInt32   line,
                                                      ViInt32   bufferSize,
                                                      ViChar    formattedValue[]);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchMode(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchDataOperator(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   dataOperator);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchDataPositionOperator(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   dataPositionOperator);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchDataPosition(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   position);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchDataAlignment(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   dataAlignment);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchDataPositionTo(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   positionTo);

ViStatus _VI_FUNC rsscope_ConfigureSPISearchPattern(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   selectPattern,
                                                    ViString  pattern);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrame(ViSession instrSession,
                                              ViInt32   frame,
                                              ViString  searchName,
                                              ViReal64* start,
                                              ViReal64* stop);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameStatus(ViSession instrSession,
                                                    ViInt32   frame,
                                                    ViString  searchName,
                                                    ViInt32   bufferSize,
                                                    ViChar    status[]);

ViStatus _VI_FUNC rsscope_QuerySPIFrameResultCount(ViSession instrSession,
                                                   ViInt32   frame,
                                                   ViInt32*  resultCount);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameData(ViSession instrSession,
                                                  ViInt32   frame,
                                                  ViString  searchName,
                                                  ViInt32   arraySize,
                                                  ViInt32   data[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameWordCount(ViSession instrSession,
                                                       ViInt32   frame,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameWord(ViSession instrSession,
                                                  ViInt32   frame,
                                                  ViInt32   word,
                                                  ViString  searchName,
                                                  ViReal64* start,
                                                  ViReal64* stop);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameWordMISO(ViSession instrSession,
                                                      ViInt32   frame,
                                                      ViInt32   word,
                                                      ViString  searchName,
                                                      ViReal64* MISO);

ViStatus _VI_FUNC rsscope_QuerySPISearchFrameWordMOSI(ViSession instrSession,
                                                      ViInt32   frame,
                                                      ViInt32   word,
                                                      ViString  searchName,
                                                      ViReal64* MOSI);

ViStatus _VI_FUNC rsscope_ConfigureUARTSource(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   line,
                                              ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureUARTThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   preset,
                                                 ViReal64  rxThreshold,
                                                 ViReal64  txThreshold);

ViStatus _VI_FUNC rsscope_ConfigureUART(ViSession instrSession,
                                        ViInt32   serialBus,
                                        ViInt32   bitRate,
                                        ViInt32   stopBits,
                                        ViInt32   dataBits,
                                        ViInt32   parity,
                                        ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureUARTPackets(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   packets,
                                               ViInt32   endWord,
                                               ViReal64  packetsTimeout);

ViStatus _VI_FUNC rsscope_ConfigureUARTTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type,
                                                   ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureUARTTriggerData(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   condition,
                                                   ViString  pattern,
                                                   ViInt32   position,
                                                   ViInt32   indexMin,
                                                   ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_QueryUARTFrameCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryUARTFrameData(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   word,
                                             ViInt32*  source,
                                             ViInt32*  status,
                                             ViReal64* start,
                                             ViInt32*  txValue,
                                             ViInt32*  rxValue);

ViStatus _VI_FUNC rsscope_QueryUARTPrimaryBitRate(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_ConfigureLINSource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureLINThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   preset,
                                                ViReal64  manualThreshold);

ViStatus _VI_FUNC rsscope_ConfigureLINPolarity(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureLINStandard(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   standard,
                                               ViInt32   bitRate);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerType(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerID(ViSession instrSession,
                                                ViInt32   trigger,
                                                ViInt32   condition,
                                                ViString  IDMin,
                                                ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerIDOR(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   ORSlot,
                                                  ViBoolean ORSlotState,
                                                  ViString  frameID);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerData(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  dataMin,
                                                  ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerDataSetup(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   condition,
                                                       ViInt32   dataLength,
                                                       ViInt32   transfer);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerErrorConditions(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViBoolean checksum,
                                                             ViBoolean IDParityError,
                                                             ViBoolean syncError);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerCRCErrorPattern(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViString  frameID,
                                                             ViInt32   dataLength);

ViStatus _VI_FUNC rsscope_ConfigureLINTriggerCRCErrorStandard(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   standard);

ViStatus _VI_FUNC rsscope_QueryLINFrameCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryLINFrameStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32*  frameStatus,
                                              ViReal64* frameStart,
                                              ViReal64* frameStop,
                                              ViInt32*  version);

ViStatus _VI_FUNC rsscope_QueryLINFrameID(ViSession instrSession,
                                          ViInt32   serialBus,
                                          ViInt32   frame,
                                          ViInt32*  value,
                                          ViInt32*  parity,
                                          ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryLINFrameField(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   field,
                                             ViInt32*  fieldValue,
                                             ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryLINFrameBitRate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_QueryLINFrameData(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   frame,
                                            ViInt32   byteNumber,
                                            ViInt32*  data,
                                            ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryLINFrameAllData(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32   arraySize,
                                               ViInt32   data[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryLINFrameAllSymbolicData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   arraySize,
                                                       ViChar    symbolicData[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ExportLINFrameAllSymbolicDataToFile(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViString  fileName,
                            ViUInt32  timeout);

ViStatus _VI_FUNC rsscope_QueryLINFrameLabel(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   bufferSize,
                                             ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchType(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchCriteria(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean startOfFrame,
                                                     ViBoolean identifier,
                                                     ViBoolean identifierOR,
                                                     ViBoolean identifierData,
                                                     ViBoolean wakeupFrame,
                                                     ViBoolean errorCondition);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchID(ViSession instrSession,
                                               ViString  searchName,
                                               ViInt32   condition,
                                               ViString  IDMin,
                                               ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchIDOR(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   ORSlot,
                                                 ViBoolean ORSlotState,
                                                 ViString  frameID);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchData(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   condition,
                                                 ViString  dataMin,
                                                 ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchDataSetup(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   condition,
                                                      ViInt32   dataLength,
                                                      ViInt32   transfer);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchErrorConditions(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViBoolean checksum,
                                                            ViBoolean IDParityError,
                                                            ViBoolean syncError);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchCRCErrorPattern(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViString  frameID,
                                                            ViInt32   dataLength);

ViStatus _VI_FUNC rsscope_ConfigureLINSearchCRCErrorStandard(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   standard);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameStatus(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViInt32*  frameStatus,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  version);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameID(ViSession instrSession,
                                                ViString  searchName,
                                                ViInt32   frame,
                                                ViInt32*  value,
                                                ViInt32*  parity,
                                                ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameField(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  fieldValue,
                                                   ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   frame,
                                                  ViInt32   byteNumber,
                                                  ViInt32*  data,
                                                  ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameAllData(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32   arraySize,
                                                     ViInt32   data[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryLINSearchFrameLabel(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   frame,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[]);

ViStatus _VI_FUNC rsscope_QuerySearchLINFrameSymbolicData(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32   bufferSize,
                                                          ViChar    data[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySearchLINFrameSymbolicDataExport(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureCANSource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   line,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureCANThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   preset,
                                                ViReal64  manualThreshold);

ViStatus _VI_FUNC rsscope_ConfigureCANBitRate(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   bitRate);

ViStatus _VI_FUNC rsscope_ConfigureCANFD(ViSession instrSession,
                                         ViInt32   serialBus,
                                         ViBoolean enable,
                                         ViInt32   bitRate);

ViStatus _VI_FUNC rsscope_ConfigureCANFDStandard(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   standard);

ViStatus _VI_FUNC rsscope_ConfigureCANFDJumpWidth(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  jumpWidth);

ViStatus _VI_FUNC rsscope_ConfigureCANFDSamplePointAbsolute(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViReal64  timeSegment1,
                                                            ViReal64  timeSegment2);

ViStatus _VI_FUNC rsscope_ConfigureCANFDSamplePointRelative(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViReal64  samplePoint);

ViStatus _VI_FUNC rsscope_ConfigureCANJumpWidth(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViReal64  jumpWidth);

ViStatus _VI_FUNC rsscope_ConfigureCANSamplePointAbsolute(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViReal64  timeSegment1,
                                                          ViReal64  timeSegment2);

ViStatus _VI_FUNC rsscope_ConfigureCANSamplePointRelative(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViReal64  samplePoint);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerType(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   type,
                                                  ViInt32   frameType);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerStandard(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   standard);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerFDBits(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   FDF,
                                                    ViInt32   BRS,
                                                    ViInt32   ESI);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerID(ViSession instrSession,
                                                ViInt32   trigger,
                                                ViInt32   IDType,
                                                ViInt32   condition,
                                                ViString  IDMin,
                                                ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerData(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   transfer,
                                                  ViInt32   condition,
                                                  ViString  dataMin,
                                                  ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerDlc(ViSession instrSession,
                                                 ViInt32   trigger,
                                                 ViInt32   condition,
                                                 ViInt32   DLC);

ViStatus _VI_FUNC rsscope_QueryCANTriggerNumberOfDataBytes(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32*  numberOfDataBytes);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerDataPosition(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   condition,
                                                          ViInt32   positionMin,
                                                          ViInt32   positionMax);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerErrorConditions(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViBoolean CRC,
                                                             ViBoolean stuffing,
                                                             ViBoolean form,
                                                             ViBoolean ack);

ViStatus _VI_FUNC rsscope_ConfigureCANTriggerStuffCountError(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViBoolean stuffCountError);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicTriggerMessage(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViString  message,
                                                             ViBoolean triggerOnSignal);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicTriggerSignal(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViString  signal,
                                                            ViInt32   condition,
                                                            ViReal64  dataMin,
                                                            ViReal64  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicTriggerSignalEnumValue(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   enumValue);

ViStatus _VI_FUNC rsscope_QueryCANFrameCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryCANFrameFDStandard(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32*  standard);

ViStatus _VI_FUNC rsscope_QueryCANFrameStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32*  frameStatus,
                                              ViReal64* frameStart,
                                              ViReal64* frameStop,
                                              ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryCANFrameID(ViSession instrSession,
                                          ViInt32   serialBus,
                                          ViInt32   frame,
                                          ViInt32*  IDType,
                                          ViInt32*  IDValue,
                                          ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryCANFrameField(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   field,
                                             ViInt32*  fieldValue,
                                             ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryCANFrameBitRate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_QueryCANFrameBitStuffingError(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViReal64* errorPosition);

ViStatus _VI_FUNC rsscope_QueryCANFrameData(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   frame,
                                            ViInt32   byteNumber,
                                            ViInt32*  data,
                                            ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryCANFrameAllData(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32   arraySize,
                                               ViInt32   data[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryCANFrameAllSymbolicData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   bufferSize,
                                                       ViChar    result[]);

ViStatus _VI_FUNC rsscope_QueryCANFrameLabel(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   bufferSize,
                                             ViChar    label[]);

ViStatus _VI_FUNC rsscope_QueryCANFrameNumberOfBytes(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  numberOfBytes);

ViStatus _VI_FUNC rsscope_QueryCANFrameFormErrorCause(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  formErrorCause);

ViStatus _VI_FUNC rsscope_QueryCANFrameFDStuffCount(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32*  stuffCount);

ViStatus _VI_FUNC rsscope_ExportCANFrameAllSymbolicDataToFile(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViString  fileName,
                            ViUInt32  timeout);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchState(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsscope_CANSearchCopyFromA(ViSession instrSession,
                                             ViString  searchName);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchCriteria(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean startOfFrame,
                                                     ViBoolean frameType,
                                                     ViBoolean frameIdentifier,
                                                     ViBoolean identifierData,
                                                     ViBoolean errorCondition);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchSymbolic(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchFrameType(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   frameType);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchStandard(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   standard);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchID(ViSession instrSession,
                                               ViString  searchName,
                                               ViInt32   IDType,
                                               ViInt32   condition,
                                               ViString  IDMin,
                                               ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchFDBits(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   FDF,
                                                   ViInt32   BRS,
                                                   ViInt32   ESI);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchData(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   transfer,
                                                 ViInt32   condition,
                                                 ViString  dataMin,
                                                 ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchDlc(ViSession instrSession,
                                                ViString  searchName,
                                                ViInt32   condition,
                                                ViInt32   DLC);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchDataPosition(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   condition,
                                                         ViInt32   positionMin,
                                                         ViInt32   positionMax);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchErrorConditions(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViBoolean CRC,
                                                            ViBoolean stuffing,
                                                            ViBoolean form,
                                                            ViBoolean ack);

ViStatus _VI_FUNC rsscope_ConfigureCANSearchStuffCountError(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViBoolean stuffCountError);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicSearchMessage(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViString  message,
                                                            ViBoolean searchOnSignal);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicSearchSignal(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViString  signal,
                                                           ViInt32   condition,
                                                           ViReal64  dataMin,
                                                           ViReal64  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureCANSymbolicSearchSignalEnumValue(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   enumValue);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameStatus(ViSession instrSession,
                                                    ViInt32   frame,
                                                    ViString  searchName,
                                                    ViInt32*  frameStatus,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameID(ViSession instrSession,
                                                ViInt32   frame,
                                                ViString  searchName,
                                                ViInt32*  IDType,
                                                ViInt32*  IDValue,
                                                ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameField(ViSession instrSession,
                                                   ViInt32   frame,
                                                   ViString  searchName,
                                                   ViInt32   field,
                                                   ViInt32*  fieldValue,
                                                   ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameBitStuffingError(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViString  searchName,
                            ViReal64* errorPosition);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameData(ViSession instrSession,
                                                  ViInt32   frame,
                                                  ViInt32   byteNumber,
                                                  ViString  searchName,
                                                  ViInt32*  data,
                                                  ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameAllData(ViSession instrSession,
                                                     ViInt32   frame,
                                                     ViString  searchName,
                                                     ViInt32   arraySize,
                                                     ViInt32   data[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameSymbolicData(ViSession instrSession,
                                                          ViInt32   frame,
                                                          ViString  searchName,
                                                          ViInt32   bufferSize,
                                                          ViChar    result[]);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameLabel(ViSession instrSession,
                                                   ViInt32   frame,
                                                   ViString  searchName,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[]);

ViStatus _VI_FUNC rsscope_QueryCANFDSearchFrameStandard(ViSession instrSession,
                                                        ViInt32   frame,
                                                        ViString  searchName,
                                                        ViInt32*  frameStandard);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameNumberOfBytes(ViSession instrSession,
                                                           ViInt32   frame,
                                                           ViString  searchName,
                                                           ViInt32*  numberOfBytes);

ViStatus _VI_FUNC rsscope_QueryCANSearchFrameFormErrorCause(ViSession instrSession,
                                                            ViInt32   frame,
                                                            ViString  searchName,
                                                            ViInt32*  formErrorCause);

ViStatus _VI_FUNC rsscope_QueryCANFDSearchFrameStuffCount(ViSession instrSession,
                                                          ViInt32   frame,
                                                          ViString  searchName,
                                                          ViInt32*  stuffCount);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySource(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   line,
                                                 ViInt32   waveformSource,
                                                 ViInt32   channel,
                                                 ViBoolean separateHeaderBits,
                                                 ViInt32   bitRate);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySourceType(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   sourceType);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayThresholdSingle(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   polarity,
                                                          ViInt32   preset,
                                                          ViReal64  manualThresholdHigh,
                                                          ViReal64  manualThresholdLow);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayThresholdDifferential(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   preset,
                            ViReal64  manualThresholdHigh,
                            ViReal64  manualThresholdLow);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayThresholdLogic(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   preset,
                                                         ViReal64  manualThresholdDataLine,
                                                         ViReal64  manualThresholdEnableLine);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerType(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerIndicatorBits(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   payloadPreamble,
                            ViInt32   nullFrame,
                            ViInt32   syncFrame,
                            ViInt32   startupFrame);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerFrameID(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   condition,
                                                         ViString  IDMin,
                                                         ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerPayloadLength(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViInt32   payloadMin,
                            ViInt32   payloadMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerCycleCount(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   condition,
                                                            ViInt32   cycleMin,
                                                            ViInt32   cycleMax,
                                                            ViInt32   cycleStep);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerData(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   condition,
                                                      ViString  dataMin,
                                                      ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViInt32   positionMin,
                            ViInt32   positionMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerSymbol(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   symbol);

ViStatus _VI_FUNC rsscope_ConfigureFlexRayTriggerErrorConditions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean FSS,
                            ViBoolean BSS,
                            ViBoolean FES,
                            ViBoolean headerCRC,
                            ViBoolean payloadCRC);

ViStatus _VI_FUNC rsscope_QueryFlexRayFrameCount(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryFlexRayCycleCount(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryFlexRayFrameStatus(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32*  frameStatus,
                                                  ViReal64* frameStart,
                                                  ViReal64* frameStop,
                                                  ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryFlexRayFrameField(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32   field,
                                                 ViInt32*  fieldValue,
                                                 ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryFlexRayFrameAllData(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   arraySize,
                                                   ViInt32   data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryFlexRayFrameLabel(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32   bufferSize,
                                                 ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchState(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsscope_FlexRaySearchCopyFromA(ViSession instrSession,
                                                 ViString  searchName);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchCriteria(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean startOfFrame,
                                                         ViBoolean symbol,
                                                         ViBoolean identifierData,
                                                         ViBoolean errorCondition);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchIndicatorBits(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   payloadPreamble,
                            ViInt32   nullFrame,
                            ViInt32   syncFrame,
                            ViInt32   startupFrame);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchFrameID(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   condition,
                                                        ViString  IDMin,
                                                        ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchPayloadLength(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViInt32   payloadMin,
                            ViInt32   payloadMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchCycleCount(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   condition,
                                                           ViInt32   cycleMin,
                                                           ViInt32   cycleMax,
                                                           ViInt32   cycleStep);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchData(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   condition,
                                                     ViString  dataMin,
                                                     ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchDataPosition(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   condition,
                                                             ViInt32   positionMin,
                                                             ViInt32   positionMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchID(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   reserved,
                                                   ViString  IDMin,
                                                   ViString  IDMax);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchSymbol(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   symbol);

ViStatus _VI_FUNC rsscope_ConfigureFlexRaySearchErrorConditions(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean FSS,
                            ViBoolean BSS,
                            ViBoolean FES,
                            ViBoolean headerCRC,
                            ViBoolean payloadCRC);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchFrameCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchCycleCount(ViSession instrSession,
                                                       ViInt32   frame,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchFrameStatus(ViSession instrSession,
                                                        ViInt32   frame,
                                                        ViString  searchName,
                                                        ViInt32*  frameStatus,
                                                        ViReal64* frameStart,
                                                        ViReal64* frameStop,
                                                        ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchFrameField(ViSession instrSession,
                                                       ViInt32   frame,
                                                       ViString  searchName,
                                                       ViInt32   field,
                                                       ViInt32*  fieldValue,
                                                       ViInt32*  fieldStatus);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchFrameAllData(ViSession instrSession,
                                                         ViInt32   frame,
                                                         ViString  searchName,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryFlexRaySearchFrameLabel(ViSession instrSession,
                                                       ViInt32   frame,
                                                       ViString  searchName,
                                                       ViInt32   bufferSize,
                                                       ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureAudioVariant(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   variant);

ViStatus _VI_FUNC rsscope_ConfigureAudioClockLine(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   waveformSource,
                                                  ViInt32   polarity,
                                                  ViReal64  treshold);

ViStatus _VI_FUNC rsscope_ConfigureAudioWSLine(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   waveformSource,
                                               ViInt32   polarity,
                                               ViReal64  treshold);

ViStatus _VI_FUNC rsscope_ConfigureAudioDataLine(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   waveformSource,
                                                 ViInt32   polarity,
                                                 ViReal64  treshold);

ViStatus _VI_FUNC rsscope_ConfigureAudioTresholdsCoupling(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViBoolean coupling,
                                                          ViReal64  treshold);

ViStatus _VI_FUNC rsscope_ConfigureAudioI2SSettings(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   wordLength,
                                                    ViInt32   channelOrder,
                                                    ViInt32   bitOrder,
                                                    ViInt32   channelOffset,
                                                    ViInt32   channelLength);

ViStatus _VI_FUNC rsscope_ConfigureAudioTDMSettings(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   TDMChannels,
                                                    ViInt32   frameOffset,
                                                    ViInt32   channelLength,
                                                    ViInt32   channelOffset,
                                                    ViInt32   wordLength,
                                                    ViInt32   bitOrder);

ViStatus _VI_FUNC rsscope_ConfigureAudioDataTrigger(ViSession instrSession,
                                                    ViInt32   conditionNumber,
                                                    ViInt32   channel,
                                                    ViInt32   condition,
                                                    ViString  addressMin,
                                                    ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureAudioWindowTrigger(ViSession instrSession,
                                                      ViInt32   conditionNumber,
                                                      ViInt32   channel,
                                                      ViInt32   condition,
                                                      ViString  addressMin,
                                                      ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureAudioWindowTriggerLength(ViSession instrSession,
                                                            ViInt32   windowLength);

ViStatus _VI_FUNC rsscope_ConfigureAudioConditionTrigger(ViSession instrSession,
                                                         ViInt32   conditionNumber,
                                                         ViInt32   channel,
                                                         ViInt32   condition,
                                                         ViString  addressMin,
                                                         ViString  addressMax);

ViStatus _VI_FUNC rsscope_ConfigureAudioWordSelectTrigger(ViSession instrSession,
                                                          ViInt32   slope);

ViStatus _VI_FUNC rsscope_ConfigureAudioErrorConditionTrigger(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryAudioFrameCount(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryAudioFrameStatus(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   frame,
                                                ViInt32*  frameStatus,
                                                ViReal64* frameStart,
                                                ViReal64* frameStop);

ViStatus _VI_FUNC rsscope_QueryAudioFrameChannelStatus(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   channel,
                                                       ViInt32*  channelStatus,
                                                       ViReal64* channelValue);

ViStatus _VI_FUNC rsscope_QueryAudioFrameTDMStatus(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   channelNumber,
                                                   ViInt32*  TDMStatus,
                                                   ViReal64* TDMValue);

ViStatus _VI_FUNC rsscope_ConfigureAudioTrackWaveform(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   channel,
                                                      ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureAudioTrackEnabled(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViBoolean state);

ViStatus _VI_FUNC rsscope_FetchAudioTrackWaveform(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViInt32   waveformSize,
                                                  ViReal64  waveformArray[],
                                                  ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchAudioTrackWaveformHeader(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViInt32   bufferSize,
                                                        ViChar    referenceWaveformHeader[]);

ViStatus _VI_FUNC rsscope_FetchAudioTrackWaveformDataType(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   bufferSize,
                                                          ViChar    dataType[]);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553Source(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553Polarity(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553Threshold(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   preset,
                                                    ViReal64  thresholdHigh,
                                                    ViReal64  thresholdLow);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553Timing(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViBoolean minGapState,
                                                 ViReal64  minGap,
                                                 ViBoolean maxResponseState,
                                                 ViReal64  maxResponse);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerType(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerSyncType(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerDataRTAPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerDataPattern(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViInt32   condition,
                                                             ViString  dataMin,
                                                             ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerDataIndex(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   condition,
                                                           ViInt32   indexMin,
                                                           ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandStatusRTAPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandStatusInfoPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  infoMin,
                            ViString  infoMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandTransmissionDirection(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   direction);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandRTAPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandSubaddressPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  subaddressMin,
                            ViString  subaddressMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerCommandWordCountPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  wordCountMin,
                            ViString  wordCountMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerStatusFlags(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViInt32   messageError,
                                                             ViInt32   busy,
                                                             ViInt32   instrumentation,
                                                             ViInt32   subsystem,
                                                             ViInt32   serviceRequest,
                                                             ViInt32   dynamicBusControl,
                                                             ViInt32   broadcastCommand,
                                                             ViInt32   terminal);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerErrorCondition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean synchronizationError,
                            ViBoolean manchesterCodingError,
                            ViBoolean parityError);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553TriggerErrorTiming(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViBoolean minGapState,
                                                             ViReal64  minGap,
                                                             ViBoolean maxResponseState,
                                                             ViReal64  maxResponse);

ViStatus _VI_FUNC rsscope_QueryMIL1553WordCount(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMIL1553Status(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   word,
                                             ViInt32*  status,
                                             ViReal64* start,
                                             ViReal64* stop,
                                             ViInt32*  type,
                                             ViInt32*  info,
                                             ViInt32*  RTAddress);

ViStatus _VI_FUNC rsscope_QueryMIL1553AllData(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   word,
                                              ViInt32   arraySize,
                                              ViInt32   data[],
                                              ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryMIL1553Label(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   word,
                                            ViInt32   bufferSize,
                                            ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchType(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchSyncType(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchDataRTAPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchDataPattern(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   condition,
                                                            ViString  dataMin,
                                                            ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchDataIndex(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   condition,
                                                          ViInt32   indexMin,
                                                          ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandStatusRTAPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandStatusInfoPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  infoMin,
                            ViString  infoMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandTransmissionDirection(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   direction);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandRTAPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  RTAMin,
                            ViString  RTAMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandSubaddressPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  subaddressMin,
                            ViString  subaddressMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchCommandWordCountPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  wordCountMin,
                            ViString  wordCountMax);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchStatusFlags(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   messageError,
                                                            ViInt32   busy,
                                                            ViInt32   instrumentation,
                                                            ViInt32   subsystem,
                                                            ViInt32   serviceRequest,
                                                            ViInt32   dynamicBusControl,
                                                            ViInt32   broadcastCommand,
                                                            ViInt32   terminal);

ViStatus _VI_FUNC rsscope_ConfigureMIL1553SearchErrorCondition(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean synchronizationError,
                            ViBoolean manchesterCodingError,
                            ViBoolean parityError,
                            ViBoolean timing);

ViStatus _VI_FUNC rsscope_QueryMIL1553SearchWordCount(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMIL1553SearchStatus(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   word,
                                                   ViInt32*  status,
                                                   ViReal64* start,
                                                   ViReal64* stop,
                                                   ViInt32*  type,
                                                   ViInt32*  info,
                                                   ViInt32*  RTAddress);

ViStatus _VI_FUNC rsscope_QueryMIL1553SearchAllData(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   word,
                                                    ViInt32   arraySize,
                                                    ViInt32   data[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryMIL1553SearchLabel(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   word,
                                                  ViInt32   bufferSize,
                                                  ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureARINC429Source(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureARINC429Polarity(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureARINC429BitRate(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   bitRateMode,
                                                   ViInt32   bitRateValue);

ViStatus _VI_FUNC rsscope_ConfigureARINC429Threshold(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   preset,
                                                     ViReal64  thresholdHigh,
                                                     ViReal64  thresholdLow);

ViStatus _VI_FUNC rsscope_ConfigureARINC429Timing(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViBoolean minGapState,
                                                  ViInt32   minGap,
                                                  ViBoolean maxGapState,
                                                  ViInt32   maxGap);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerType(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerLabelData(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   SDI,
                                                            ViInt32   SSM);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerLabelPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  labelMin,
                            ViString  labelMax);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerDataPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  dataMin,
                            ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerErrorCondition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean codingError,
                            ViBoolean parityError);

ViStatus _VI_FUNC rsscope_ConfigureARINC429TriggerErrorTiming(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean minGapState,
                            ViInt32   minGap,
                            ViBoolean maxResponseState,
                            ViInt32   maxResponse);

ViStatus _VI_FUNC rsscope_QueryARINC429WordCount(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryARINC429Status(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   word,
                                              ViInt32*  status,
                                              ViReal64* start,
                                              ViReal64* stop,
                                              ViInt32*  pattern,
                                              ViInt32*  SDI,
                                              ViInt32*  SSM);

ViStatus _VI_FUNC rsscope_QueryARINC429AllData(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   word,
                                               ViInt32   arraySize,
                                               ViInt32   data[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryARINC429Label(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   word,
                                             ViInt32   bufferSize,
                                             ViChar    labelName[],
                                             ViInt32*  label);

ViStatus _VI_FUNC rsscope_ConfigureARINC429SearchType(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureARINC429SearchLabelData(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   SDI,
                                                           ViInt32   SSM);

ViStatus _VI_FUNC rsscope_ConfigureARINC429SearchLabelPattern(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  labelMin,
                            ViString  labelMax);

ViStatus _VI_FUNC rsscope_ConfigureARINC429SearchDataPattern(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   condition,
                                                             ViString  dataMin,
                                                             ViString  dataMax);

ViStatus _VI_FUNC rsscope_ConfigureARINC429SearchErrorCondition(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean codingError,
                            ViBoolean parityError,
                            ViBoolean timingError);

ViStatus _VI_FUNC rsscope_QueryARINC429SearchWordCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryARINC429SearchStatus(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   word,
                                                    ViInt32*  status,
                                                    ViReal64* start,
                                                    ViReal64* stop,
                                                    ViInt32*  pattern,
                                                    ViInt32*  SDI,
                                                    ViInt32*  SSM);

ViStatus _VI_FUNC rsscope_QueryARINC429SearchAllData(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   word,
                                                     ViInt32   arraySize,
                                                     ViInt32   data[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryARINC429SearchLabel(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   word,
                                                   ViInt32   bufferSize,
                                                   ViChar    labelName[],
                                                   ViInt32*  label);

ViStatus _VI_FUNC rsscope_ConfigureRFFESource(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   line,
                                              ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureRFFEThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   preset,
                                                 ViInt32   line,
                                                 ViInt32   thresholdType,
                                                 ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureRFFEThresholdsCoupling(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureRFFEGlitchFilter(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViBoolean enable,
                                                    ViReal64  width);

ViStatus _VI_FUNC rsscope_ConfigureRFFETiming(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViBoolean enableMinimumGap,
                                              ViReal64  minimumGapTime,
                                              ViBoolean enableMaximumGap,
                                              ViReal64  maximumGapTime);

ViStatus _VI_FUNC rsscope_ConfigureRFFEReadMode(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   readMode);

ViStatus _VI_FUNC rsscope_ConfigureRFFEVersion(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   version);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerInterruptPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerSlaveAddress(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   condition,
                                                           ViString  minimum,
                                                           ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerAddress(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   condition,
                                                      ViString  minimum,
                                                      ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerByteCount(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerData(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   condition,
                                                   ViString  minimum,
                                                   ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerIndex(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   condition,
                                                    ViInt32   minimum,
                                                    ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerMask(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   condition,
                                                   ViString  minimum,
                                                   ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerErrorConditions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean SSC,
                            ViBoolean length,
                            ViBoolean busPark,
                            ViBoolean parity,
                            ViBoolean noResponse,
                            ViBoolean unknownSequence);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerErrorGap(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViBoolean gap);

ViStatus _VI_FUNC rsscope_ConfigureRFFETriggerErrorVersion(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViBoolean version);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceCount(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceStatus(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   sequence,
                                                  ViInt32*  status,
                                                  ViReal64* start,
                                                  ViReal64* stop,
                                                  ViInt32*  type,
                                                  ViInt32*  slaveAddress,
                                                  ViInt32*  address,
                                                  ViInt32*  byteCount);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceLabel(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   sequence,
                                                 ViInt32   bufferSize,
                                                 ViChar    label[]);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceAllData(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   sequence,
                                                   ViInt32   arraySize,
                                                   ViInt32   data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceData(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   sequence,
                                                ViInt32   byteNumber,
                                                ViInt32*  data,
                                                ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceParity(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   sequence,
                                                  ViInt32*  addressZeroParity,
                                                  ViInt32*  addressOneParity,
                                                  ViInt32*  controlParity);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceByteName(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   sequence,
                                                    ViInt32   byteNumber,
                                                    ViInt32   bufferSize,
                                                    ViChar    name[]);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceBitRate(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   sequence,
                                                   ViReal64* bitRate);

ViStatus _VI_FUNC rsscope_QueryRFFESequenceWriteBitRate(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   sequence,
                                                        ViReal64* writeBitRate);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchSlaveAddress(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   condition,
                                                          ViString  minimum,
                                                          ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchAddress(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   condition,
                                                     ViString  minimum,
                                                     ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchByteCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchIndex(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   condition,
                                                   ViInt32   minimum,
                                                   ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchErrorConditions(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViBoolean SSC,
                                                             ViBoolean length,
                                                             ViBoolean reserved1,
                                                             ViBoolean parity,
                                                             ViBoolean reserved2,
                                                             ViBoolean reserved3);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchInterrupt(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViString  interrupt);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchErrorGapTime(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean gapTime);

ViStatus _VI_FUNC rsscope_ConfigureRFFESearchErrorVersion(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean version);

ViStatus _VI_FUNC rsscope_QueryRFFESearchSequenceCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryRFFESearchSequenceStatus(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   sequence,
                                                        ViInt32*  status,
                                                        ViReal64* start,
                                                        ViReal64* stop,
                                                        ViInt32*  type,
                                                        ViInt32*  slaveAddress,
                                                        ViInt32*  address,
                                                        ViInt32*  byteCount);

ViStatus _VI_FUNC rsscope_QueryRFFESearchSequenceLabel(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   sequence,
                                                       ViInt32   bufferSize,
                                                       ViChar    label[]);

ViStatus _VI_FUNC rsscope_QueryRFFESearchSequenceAllData(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   sequence,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryRFFESearchSequenceData(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   sequence,
                                                      ViInt32   byteNumber,
                                                      ViInt32*  data,
                                                      ViInt32*  statusCode);

ViStatus _VI_FUNC rsscope_ConfigureMDIOSource(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   line,
                                              ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureMDIOThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   preset,
                                                 ViInt32   line,
                                                 ViReal64  thresholdLow,
                                                 ViReal64  thresholdHigh);

ViStatus _VI_FUNC rsscope_ConfigureMDIOThresholdsCoupling(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureMDIOTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMDIOTriggerFramePattern(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   startCode,
                                                           ViInt32   operationCode,
                                                           ViString  physicalAddress,
                                                           ViString  registerAddress,
                                                           ViString  dataPattern);

ViStatus _VI_FUNC rsscope_ConfigureMDIOMaxGapTime(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  maxGapTime);

ViStatus _VI_FUNC rsscope_QueryMDIOWordCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMDIOWordStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   word,
                                              ViInt32   bufferSize,
                                              ViInt32*  status,
                                              ViReal64* start,
                                              ViReal64* stop,
                                              ViChar    startCode[],
                                              ViChar    operationCode[],
                                              ViInt32*  physicalAddress,
                                              ViInt32*  registerAddress,
                                              ViChar    dataPattern[]);

ViStatus _VI_FUNC rsscope_QueryMDIOWordLabel(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   word,
                                             ViInt32   bufferSize,
                                             ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureMDIOSearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMDIOSearchFramePattern(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   startCode,
                                                          ViInt32   operationCode,
                                                          ViString  physicalAddress,
                                                          ViString  registerAddress,
                                                          ViString  dataPattern);

ViStatus _VI_FUNC rsscope_QueryMDIOSearchWordCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMDIOSearchWordStatus(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   word,
                                                    ViInt32   bufferSize,
                                                    ViInt32*  status,
                                                    ViReal64* start,
                                                    ViReal64* stop,
                                                    ViChar    startCode[],
                                                    ViChar    operationCode[],
                                                    ViInt32*  physicalAddress,
                                                    ViInt32*  registerAddress,
                                                    ViChar    dataPattern[]);

ViStatus _VI_FUNC rsscope_QueryMDIOSearchWordLabel(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   word,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[]);

ViStatus _VI_FUNC rsscope_ConfigureEthernetVariant(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   variant);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSource(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureEthernetPolarity(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureEthernetThreshold(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   preset,
                                                     ViReal64  thresholdLow,
                                                     ViReal64  thresholdHigh);

ViStatus _VI_FUNC rsscope_ConfigureEthernetBitRate(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   bitrate);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTrigger(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type,
                                                   ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTriggerError(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViBoolean CRC,
                                                        ViBoolean length,
                                                        ViBoolean preamble);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTriggerDestinationAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTriggerSourceAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTriggerCRC(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   condition,
                                                      ViString  min,
                                                      ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureEthernetTriggerTypeOperator(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_QueryEthernetWordCount(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryEthernetWordBitRate(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   word,
                                                   ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_QueryEthernetWordStatus(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   word,
                                                  ViInt32   bufferSize,
                                                  ViInt32*  status,
                                                  ViReal64* start,
                                                  ViReal64* stop,
                                                  ViChar    destination[],
                                                  ViChar    source[],
                                                  ViInt32*  type,
                                                  ViInt32*  CRC);

ViStatus _VI_FUNC rsscope_QueryEthernetWordLabel(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   word,
                                                 ViInt32   bufferSize,
                                                 ViChar    destinationLabel[],
                                                 ViChar    sourceLabel[]);

ViStatus _VI_FUNC rsscope_QueryEthernetWordData(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   word,
                                                ViInt32   byteNumber,
                                                ViInt32*  data);

ViStatus _VI_FUNC rsscope_QueryEthernetWordAllData(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   word,
                                                   ViInt32   arraySize,
                                                   ViInt32   data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryEthernetWordFrameType(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   word,
                                                     ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryEthernetWordNumberOfWords(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   word,
                                                         ViInt32*  numberOfWords);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchCriteria(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean frameEnabled,
                                                          ViBoolean errorEnabled);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchDestinationAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchSourceAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchTypeLength(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   condition,
                                                            ViString  minimum,
                                                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchFrameCheck(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   condition,
                                                            ViString  minimum,
                                                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchErrorConditions(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean preamble,
                            ViBoolean length);

ViStatus _VI_FUNC rsscope_ConfigureEthernetSearchType(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   ethernetType);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordStatus(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   word,
                                                        ViInt32   bufferSize,
                                                        ViInt32*  status,
                                                        ViReal64* start,
                                                        ViReal64* stop,
                                                        ViChar    destination[],
                                                        ViChar    source[],
                                                        ViInt32*  CRC,
                                                        ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordLabel(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   word,
                                                       ViInt32   bufferSize,
                                                       ViChar    destinationLabel[],
                                                       ViChar    sourceLabel[]);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordData(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   word,
                                                      ViInt32   byteNumber,
                                                      ViInt32*  data);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordAllData(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   word,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryEthernetSearchWordFrameType(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   word,
                                                           ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_ConfigureUSBSource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   protocolType,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureUSBPreset(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   preset);

ViStatus _VI_FUNC rsscope_ConfigureUSBThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   protocolType,
                                                ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerType(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerToken(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   token);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerDataType(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   dataType);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerHandshakeType(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   handshakeType);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerSpecialPID(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   specialPID);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerErrorCondition(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   errorConditionType);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerPIDErrorCheck(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViBoolean PIDErrorCheck);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerEndPointCheck(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViBoolean enabled,
                                                           ViInt32   condition,
                                                           ViString  minimum,
                                                           ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerAddressCheck(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViBoolean enabled,
                                                          ViInt32   condition,
                                                          ViString  minimum,
                                                          ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerPayloadCheck(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViBoolean enabled,
                                                          ViInt32   condition,
                                                          ViInt32   position,
                                                          ViInt32   dataCondition,
                                                          ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerFrameCheck(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViBoolean enabled,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerSCCheck(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViBoolean enabled,
                                                     ViInt32   startComplete);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerPortCheck(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViBoolean enabled,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerSEUCheck(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViBoolean enabled,
                                                      ViInt32   condition,
                                                      ViString  minimum,
                                                      ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBTriggerETCheck(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViBoolean enabled,
                                                     ViInt32   condition,
                                                     ViString  minimum,
                                                     ViString  maximum);

ViStatus _VI_FUNC rsscope_QueryUSBPacketCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryUSBPacketStatus(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   packet,
                                               ViInt32*  status,
                                               ViReal64* start,
                                               ViReal64* stop,
                                               ViInt32*  PID);

ViStatus _VI_FUNC rsscope_QueryUSBPacketValues(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   packet,
                                               ViInt32*  address,
                                               ViInt32*  endpoint,
                                               ViInt32*  CRC,
                                               ViInt32*  ET,
                                               ViInt32*  frame,
                                               ViInt32*  port,
                                               ViInt32*  SC,
                                               ViInt32*  SEU);

ViStatus _VI_FUNC rsscope_QueryUSBPacketAllData(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   packet,
                                                ViInt32   arraySize,
                                                ViInt32   data[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchCriteria(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean startOfPacket,
                                                     ViBoolean token,
                                                     ViBoolean data,
                                                     ViBoolean handshake,
                                                     ViBoolean specialPID,
                                                     ViBoolean errorCondition);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchToken(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   token);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchDataType(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   dataType);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchHandshakeType(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   handshakeType);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchSpecialPID(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   specialPID);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchPIDErrorCheck(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean PIDErrorCheck);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchErrorCondition(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViBoolean PID,
                                                           ViBoolean CRC5,
                                                           ViBoolean CRC16,
                                                           ViBoolean bitstuff,
                                                           ViBoolean glitch);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchEndPointCheck(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean enabled,
                                                          ViInt32   condition,
                                                          ViString  minimum,
                                                          ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchAddressCheck(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean enabled,
                                                         ViInt32   condition,
                                                         ViString  minimum,
                                                         ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchPayloadCheck(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean enabled,
                                                         ViInt32   condition,
                                                         ViInt32   position,
                                                         ViInt32   dataCondition,
                                                         ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchFrameCheck(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViBoolean enabled,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchSCCheck(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViBoolean enabled,
                                                    ViInt32   startComplete);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchPortCheck(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViBoolean enabled,
                                                      ViInt32   condition,
                                                      ViString  minimum,
                                                      ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchSEUCheck(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViBoolean enabled,
                                                     ViInt32   condition,
                                                     ViString  minimum,
                                                     ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBSearchETCheck(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViBoolean enabled,
                                                    ViInt32   condition,
                                                    ViString  minimum,
                                                    ViString  maximum);

ViStatus _VI_FUNC rsscope_QueryUSBSearchPacketCount(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryUSBSearchPacketStatus(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   packet,
                                                     ViInt32*  status,
                                                     ViReal64* start,
                                                     ViReal64* stop,
                                                     ViInt32*  PID);

ViStatus _VI_FUNC rsscope_QueryUSBSearchPacketValues(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   packet,
                                                     ViInt32*  address,
                                                     ViInt32*  endpoint,
                                                     ViInt32*  CRC,
                                                     ViInt32*  ET,
                                                     ViInt32*  frame,
                                                     ViInt32*  port,
                                                     ViInt32*  SC,
                                                     ViInt32*  SEU);

ViStatus _VI_FUNC rsscope_QueryUSBSearchPacketAllData(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   packet,
                                                      ViInt32   arraySize,
                                                      ViInt32   data[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureUSB31(ViSession instrSession,
                                         ViInt32   serialBus,
                                         ViInt32   source,
                                         ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureUSB31ProtocolType(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   protocolType);

ViStatus _VI_FUNC rsscope_ConfigureUSB31Thresholds(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViReal64  low,
                                                   ViReal64  high);

ViStatus _VI_FUNC rsscope_ConfigureUSB31ScrambleMode(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   scrambleMode);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerErrorEnabled(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViString  errorName,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   fieldNumber,
                            ViInt32   packetType,
                            ViBoolean enable);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNameBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNameData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNameIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31TriggerFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameCount(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameStatus(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   frame,
                                                ViInt32*  frameStatus,
                                                ViReal64* startTime,
                                                ViReal64* stopTime,
                                                ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameInfo(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViChar    info[]);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameFieldType(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViChar    type[]);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameFieldStatus(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameFieldStartStop(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViReal64* start,
                                                        ViReal64* stop);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameFieldValue(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   field,
                                                    ViInt32*  value);

ViStatus _VI_FUNC rsscope_QueryUSB31FrameFieldFormatedValue(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   bufferSize,
                                                            ViChar    value[]);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPHighSpeedBitrate(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViReal64  bitrate);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPCTLEEnabled(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViBoolean CTLE);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPCTLEChannelLength(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   channelLength);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPCTLEFrequencies(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViReal64  zeroFrequency,
                                                           ViReal64  poleFrequencyFP1,
                                                           ViReal64  poleFrequencyFP2);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPCTLEDCGain(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  DCGain);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPDFEEnabled(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViBoolean DFE);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPDFEEstimateCoefficientsEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean estimateCoefficients);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPDFECoefficient(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViReal64  coefficient);

ViStatus _VI_FUNC rsscope_ConfigureUSB31DSPDFENumberOfTaps(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   numberOfTaps);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchErrorEnabled(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViString  errorName,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   fieldNumber,
                            ViInt32   packetType,
                            ViBoolean enable);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNameBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNameData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNumericData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNameIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSB31SearchFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameCount(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameStatus(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   frame,
                                                      ViInt32*  frameStatus,
                                                      ViReal64* startTime,
                                                      ViReal64* stopTime,
                                                      ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameInfo(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViChar    info[]);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameFieldType(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViChar    type[]);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameFieldStatus(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   field,
                                                           ViInt32   frame,
                                                           ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameFieldStartStop(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   field,
                            ViInt32   frame,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameFieldValue(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32   field,
                                                          ViInt32*  value);

ViStatus _VI_FUNC rsscope_QueryUSB31SearchFrameFieldFormatedValue(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bufferSize,
                            ViChar    value[]);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDDataSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   dataSource);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDThresholds(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViReal64  dataThreshold,
                                                   ViReal64  hysteresis,
                                                   ViReal64  VRD15,
                                                   ViReal64  VRDUSB,
                                                   ViReal64  VRA);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDShowDecodeDetail(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showDecodeDetail);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerType(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerPacketType(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   packetType);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerErrorEnabled(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViString  errorName,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   fieldNumber,
                            ViInt32   frameName,
                            ViBoolean enable);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerData(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   fieldNumber,
                                                    ViInt32   condition,
                                                    ViString  min,
                                                    ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerIndex(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   fieldNumber,
                                                     ViInt32   condition,
                                                     ViInt32   min,
                                                     ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerBitState(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   fieldNumber,
                                                        ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNameBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNameData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNameIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDTriggerFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameCount(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameStatus(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   frame,
                                                ViInt32*  frameStatus,
                                                ViReal64* startTime,
                                                ViReal64* stopTime,
                                                ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameInfo(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViChar    info[]);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameDataBytes(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   arraySize,
                                                   ViInt32   data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameFieldType(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViChar    type[]);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameFieldStatus(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameFieldStartStop(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViReal64* start,
                                                        ViReal64* stop);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameFieldValue(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   field,
                                                    ViInt32*  value);

ViStatus _VI_FUNC rsscope_QueryUSBPDFrameFieldFormatedValue(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   bufferSize,
                                                            ViChar    value[]);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchType(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchPacketType(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   packetType);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchErrorEnabled(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViString  errorName,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   fieldNumber,
                            ViInt32   frameName,
                            ViBoolean enable);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchData(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   fieldNumber,
                                                   ViInt32   condition,
                                                   ViString  min,
                                                   ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchIndex(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   fieldNumber,
                                                    ViInt32   condition,
                                                    ViInt32   min,
                                                    ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchBitState(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   fieldNumber,
                                                       ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNameBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNameData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNumericData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNameIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureUSBPDSearchFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameCount(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameStatus(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   frame,
                                                      ViInt32*  frameStatus,
                                                      ViReal64* startTime,
                                                      ViReal64* stopTime,
                                                      ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameInfo(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViChar    info[]);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameDataBytes(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameFieldType(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViChar    type[]);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameFieldStatus(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32   field,
                                                           ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameFieldStartStop(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameFieldValue(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32   field,
                                                          ViInt32*  value);

ViStatus _VI_FUNC rsscope_QueryUSBPDSearchFrameFieldFormatedValue(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bufferSize,
                            ViChar    value[]);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZCodingStandard(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   standard);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZBitrate(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean bitrateState,
                                                        ViInt32   bitrate);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZGapTime(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean gapTimeState,
                                                        ViReal64  gapTime);

ViStatus _VI_FUNC rsscope_ConfigureManchesterSettings(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source,
                                                      ViInt32   polarity,
                                                      ViInt32   clockPhase);

ViStatus _VI_FUNC rsscope_ConfigureManchesterThreshold(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   preset,
                                                       ViReal64  thresholdHigh,
                                                       ViReal64  thresholdLow);

ViStatus _VI_FUNC rsscope_ConfigureManchesterThresholdCoupling(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureNRZEnable(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureNRZSource(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   line,
                                             ViInt32   waveformSource);

ViStatus _VI_FUNC rsscope_ConfigureNRZPolarity(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureNRZENAPolarity(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureNRZIdlePolarity(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   line,
                                                   ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureNRZClockPhase(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   clockPhase);

ViStatus _VI_FUNC rsscope_ConfigureNRZThreshold(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   preset,
                                                ViReal64  thresholdClock,
                                                ViReal64  thresholdData);

ViStatus _VI_FUNC rsscope_ConfigureNRZThresholdCoupling(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureNRZThresholdValue(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  enabled);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZFrameCount(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32*  count);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFrameType(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViString  type);

ViStatus _VI_FUNC rsscope_ManchesterNRZAddFrame(ViSession instrSession,
                                                ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_ManchesterNRZFrameClear(ViSession instrSession,
                                                  ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_ManchesterNRZFrameDescription(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   operation,
                                                        ViString  file);

ViStatus _VI_FUNC rsscope_ManchesterNRZExportFramesAsRawBits(ViSession instrSession,
                                                             ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZCellCount(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsscope_ManchesterNRZAddCell(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZCell(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   cell,
                                                     ViString  name,
                                                     ViInt32   bitCount,
                                                     ViString  condition,
                                                     ViInt32   cellFormat,
                                                     ViInt32   bitOrder,
                                                     ViInt32   color,
                                                     ViInt32   resultColumn);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZCellColorCRGB(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   cell,
                            ViInt64   colorRGB);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerType(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerDataPattern(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  dataPattern);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerIndex(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViInt32   condition,
                                                             ViInt32   indexMin,
                                                             ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_ConfigureNRZTriggerWordLength(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   wordLength);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerErrorNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerErrorNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNameBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNameData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNameIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZTriggerFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   minimum,
                            ViInt32   maximum);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultCount(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultStatus(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   result,
                                                         ViInt32   bufferSize,
                                                         ViInt32*  status,
                                                         ViReal64* start,
                                                         ViReal64* stop,
                                                         ViChar    type[]);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultContent(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   result,
                                                          ViInt32   bufferSize,
                                                          ViChar    contentOne[],
                                                          ViChar    contentTwo[],
                                                          ViChar    contentThree[]);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultCellCount(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   result,
                                                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultCellStatus(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   result,
                                                             ViInt32   cell,
                                                             ViInt32   bufferSize,
                                                             ViInt32*  status,
                                                             ViChar    name[],
                                                             ViReal64* value);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZResultCellStartStop(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   result,
                            ViInt32   cell,
                            ViReal64* start,
                            ViReal64* stop);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   errorNumber,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frameNumber,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNameBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNameData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNameIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZSearchFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchFrameCount(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   index,
                                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchFrameStatus(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   index,
                            ViInt32   frame,
                            ViInt32*  frameStatus,
                            ViReal64* frameStart,
                            ViReal64* frameStop,
                            ViInt32   bufferSize,
                            ViChar    frameType[]);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchFrameContent(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   index,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    one[],
                            ViChar    two[],
                            ViChar    three[]);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchCellCount(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   index,
                                                            ViInt32   frame,
                                                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchCellStatus(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   index,
                                                             ViInt32   frame,
                                                             ViInt32   cell,
                                                             ViInt32*  status);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchCellTime(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   index,
                                                           ViInt32   frame,
                                                           ViInt32   cell,
                                                           ViReal64* start,
                                                           ViReal64* stop);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchCellName(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   index,
                                                           ViInt32   frame,
                                                           ViInt32   cell,
                                                           ViInt32   bufferSize,
                                                           ViChar    name[]);

ViStatus _VI_FUNC rsscope_QueryManchesterNRZSearchCellValue(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   index,
                                                            ViInt32   frame,
                                                            ViInt32   cell,
                                                            ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   error,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  error,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFieldEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterBitState(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterDataPattern(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterIndexPattern(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean numeric);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameFieldBitState(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameFieldDataPatternSettings(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   patternCondition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureManchesterNRZFilterFrameFieldIndexPatternSettings(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   patternCondition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSignalType(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   signalType);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSource(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   protocolType,
                                              ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureEBTBFullAutoset(ViSession instrSession,
                                                   ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_ConfigureEBTBThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   signalType,
                                                 ViReal64  thresholdLow,
                                                 ViReal64  thresholdHigh);

ViStatus _VI_FUNC rsscope_ConfigureEBTBBitrate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViReal64  bitrate);

ViStatus _VI_FUNC rsscope_ConfigureEBTBBitrateDetermination(ViSession instrSession,
                                                            ViInt32   serialBus);

ViStatus _VI_FUNC rsscope_ConfigureEBTBEstimatedBitrate(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64* estimatedBitrate);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSWCDRBitrate(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSyncSymbol(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   syncSymbol);

ViStatus _VI_FUNC rsscope_ConfigureEBTBPattern(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   pattern);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSecondPattern(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViBoolean state,
                                                     ViInt32   pattern);

ViStatus _VI_FUNC rsscope_ConfigureEBTBDisplayFormat(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   displayFormat);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerConditionType(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   conditionType);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerDataCharacter(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   dataCharacter);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerDXSymbol(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   DXSymbol);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerDYSymbol(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   DYSymbol);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerPattern(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   symbolFormat,
                                                      ViString  EBPattern,
                                                      ViString  TBPattern);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerSymbol(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   type,
                                                     ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureEBTBTriggerErrorConditions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean disparityError,
                            ViBoolean glitchError,
                            ViBoolean unknownError);

ViStatus _VI_FUNC rsscope_QuerEBTBSymbolCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryEBTBSymbolStatus(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   symbol,
                                                ViInt32*  status,
                                                ViReal64* start,
                                                ViReal64* stop);

ViStatus _VI_FUNC rsscope_QueryEBTBSymbolDataBytes(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   symbol,
                                                   ViInt32   arraySize,
                                                   ViChar    data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryEBTBSymbolParameters(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   symbol,
                                                    ViInt32   arraySize,
                                                    ViChar    byteValue[],
                                                    ViChar    _10bit[],
                                                    ViChar    kDCode[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchError(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViBoolean disparityError,
                                                   ViBoolean glitchingError,
                                                   ViBoolean unknownSymbolError);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchSearchType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   searchType);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchSymbolType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchSymbolFormat(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   format);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchKDCodeSymbol(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   KDCodeSymbol);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchDXY(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   DX,
                                                 ViInt32   DY);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchEightBitPattern(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchTenBitPattern(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViString  pattern);

ViStatus _VI_FUNC rsscope_ConfigureEBTBSearchExpression(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViString  expression);

ViStatus _VI_FUNC rsscope_QueryEBTBSearchSymbolCount(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryEBTBSearchSymbolStatus(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   symbol,
                                                      ViInt32*  status,
                                                      ViReal64* start,
                                                      ViReal64* stop);

ViStatus _VI_FUNC rsscope_QueryEBTBSearchSymbolDataBytes(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   symbol,
                                                         ViInt32   arraySize,
                                                         ViChar    data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureSENTDataSource(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureSENTThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   technology,
                                                 ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureSENTTransmission(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViReal64  clockPeriod,
                                                    ViReal64  clockTolerance,
                                                    ViInt32   dataNibbles,
                                                    ViInt32   serialFormat,
                                                    ViInt32   CRCVersion,
                                                    ViInt32   CRCCalculation,
                                                    ViInt32   pausePulse);

ViStatus _VI_FUNC rsscope_ConfigureSENTFrameLength(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frameLength);

ViStatus _VI_FUNC rsscope_ConfigureSENTResultDisplay(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   resultDisplay);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerTransmissionSequenceType(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerTransmissionSequence(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  status,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerSerialMessageType(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerSerialMessageID(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   type,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerSerialMessageData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTTriggerErrorConditions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean formError,
                            ViBoolean calibrationPulseError,
                            ViBoolean pulsePeriodError,
                            ViBoolean CRCError,
                            ViBoolean irregularFrameLengthError);

ViStatus _VI_FUNC rsscope_QuerySENTFrameCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySENTFrameStatus(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32*  frameStatus,
                                               ViReal64* frameStart,
                                               ViReal64* frameStop,
                                               ViInt32*  frameType,
                                               ViReal64* syncDuration,
                                               ViInt32*  statusCommunicationValue);

ViStatus _VI_FUNC rsscope_QuerySENTFrameID(ViSession instrSession,
                                           ViInt32   serialBus,
                                           ViInt32   frame,
                                           ViInt32*  IDType,
                                           ViInt32*  IDValue);

ViStatus _VI_FUNC rsscope_QuerySENTFrameCSValue(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   frame,
                                                ViInt32*  CSValue);

ViStatus _VI_FUNC rsscope_QuerySENTFramePulsePauseTicks(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  pulsePauseTicks);

ViStatus _VI_FUNC rsscope_QuerySENTFrameLabel(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32   bufferSize,
                                              ViChar    label[]);

ViStatus _VI_FUNC rsscope_QuerySENTFrameDataBytes(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32   arraySize,
                                                  ViInt32   data[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySENTFrameAllSymbolicData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   bufferSize,
                                                        ViChar    result[]);

ViStatus _VI_FUNC rsscope_ExportSENTFrameAllSymbolicDataToFile(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViString  fileName,
                            ViUInt32  timeout);

ViStatus _VI_FUNC rsscope_QuerySENTFrameNibbleData(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   nibble,
                                                   ViInt32*  data,
                                                   ViInt32*  status);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchCalibrationState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchTransmissionSequenceState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchTransmissionSequenceType(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchTransmissionSequence(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  status,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchSerialMessageState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchSerialMessageType(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchSerialMessageID(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   type,
                                                             ViInt32   condition,
                                                             ViString  minimum,
                                                             ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchSerialMessageData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  minimum,
                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchErrorConditionsState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSENTSearchErrorConditions(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViBoolean formError,
                                                             ViBoolean calibrationPulseError,
                                                             ViBoolean pulsePeriodError,
                                                             ViBoolean CRCError,
                                                             ViBoolean irregularFrameLengthError);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameCount(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameStatus(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32*  frameStatus,
                                                     ViReal64* frameStart,
                                                     ViReal64* frameStop,
                                                     ViInt32*  frameType,
                                                     ViReal64* syncDuration,
                                                     ViInt32*  statusCommunicationValue);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameID(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   frame,
                                                 ViInt32*  IDType,
                                                 ViInt32*  IDValue);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameCSValue(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   frame,
                                                      ViInt32*  CSValue);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFramePulsePauseTicks(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32*  pulsePauseTicks);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameLabel(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViChar    label[]);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameDataBytes(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32   arraySize,
                                                        ViInt32   data[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameAllSymbolicData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    result[]);

ViStatus _VI_FUNC rsscope_QuerySENTSearchFrameNibbleData(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   nibble,
                                                         ViInt32*  data,
                                                         ViInt32*  status);

ViStatus _VI_FUNC rsscope_ConfigureDPHYVariant(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   variant);

ViStatus _VI_FUNC rsscope_ConfigureDPHYPhysicalConfiguration(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   physicalConfiguration);

ViStatus _VI_FUNC rsscope_ConfigureDPHYDataLanes(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   dataLanes);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSource(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   lane,
                                              ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureDPHYProbe(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   lane,
                                             ViInt32   probe);

ViStatus _VI_FUNC rsscope_ConfigureDPHYDataRate(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViReal64  dataRate);

ViStatus _VI_FUNC rsscope_ConfigureDPHYDisplayDataVector(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureDPHYThresholdPreset(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   preset);

ViStatus _VI_FUNC rsscope_ConfigureDPHYThresholdCoupling(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureDPHYHighSpeedThreshold(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   lane,
                                                          ViReal64  threshold,
                                                          ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureDPHYLowPowerThreshold(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   lane,
                                                         ViReal64  thresholdLower,
                                                         ViReal64  thresholdUpper);

ViStatus _VI_FUNC rsscope_ConfigureDPHYShowMultipleLanes(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showMultipleLanes);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerVirtualChannel(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViString  virtualChannel);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerDataType(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerWordCount(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerData(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type,
                                                   ViInt32   condition,
                                                   ViString  minimum,
                                                   ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerDataIndex(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   type,
                                                        ViInt32   condition,
                                                        ViInt32   minimum,
                                                        ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYTriggerEscapeMode(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   condition,
                                                         ViString  minimum,
                                                         ViString  maximum);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameStatus(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32*  frameStatus,
                                               ViReal64* frameStart,
                                               ViReal64* frameStop,
                                               ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameChecksum(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32*  checksum);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameDataTypeName(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   bufferSize,
                                                     ViChar    name[]);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameDataType(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32*  dataType);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameErrorCorrectionCode(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32*  errorCorrectionCode);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameNumberOfVirtualChannels(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  numberOfVirtualChannels);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameDataBytes(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32   arraySize,
                                                  ViInt32   data[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryDPHYFrameNumberOfPackets(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  numberOfPackets);

ViStatus _VI_FUNC rsscope_QueryDPHYFramePacketPayload(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   packet,
                                                      ViInt32*  index,
                                                      ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchVirtualChannel(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViString  virtualChannel);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchDataType(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   condition,
                                                      ViString  minimum,
                                                      ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchWordCount(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchDataIndex(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   type,
                                                       ViInt32   condition,
                                                       ViInt32   minimum,
                                                       ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureDPHYSearchEscapeMode(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameCount(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameStatus(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32*  frameStatus,
                                                     ViReal64* frameStart,
                                                     ViReal64* frameStop,
                                                     ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameChecksum(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViInt32*  checksum);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameDataTypeName(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    name[]);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameDataType(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViInt32*  dataType);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameErrorCorrectionCode(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32*  errorCorrectionCode);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameNumberOfVirtualChannels(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32*  numberOfVirtualChannels);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFrameDataBytes(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32   arraySize,
                                                        ViInt32   data[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryDPHYSearchFramePacketPayload(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViInt32   frame,
                                                            ViInt32   packet,
                                                            ViInt32*  index,
                                                            ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureMPHYProtocol(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   protocol);

ViStatus _VI_FUNC rsscope_ConfigureMPHYDataLanes(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   dataLanes);

ViStatus _VI_FUNC rsscope_ConfigureMPHYDataSource(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   dataLane,
                                                  ViInt32   dataSource);

ViStatus _VI_FUNC rsscope_ConfigureMPHYThreshold(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   dataLane,
                                                 ViReal64  threshold);

ViStatus _VI_FUNC rsscope_ConfigureMPHYThresholdCouplingEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYThresholdPreset(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   preset);

ViStatus _VI_FUNC rsscope_ConfigureMPHYScrambledMode(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   scrambledMode);

ViStatus _VI_FUNC rsscope_ConfigureMPHYShowMultipleLanes(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showMultipleLanes);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerLCCType(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   LCCType);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerWord(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   word,
                                                   ViInt32   condition,
                                                   ViString  minimum,
                                                   ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerTCPattern(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViString  TCPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerCREQPattern(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   CREQPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerRREQPattern(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   RREQPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerData(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   condition,
                                                   ViString  minimum,
                                                   ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerIndex(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   condition,
                                                    ViInt32   minimum,
                                                    ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerFSN(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerCRC(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerCredit(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   condition,
                                                     ViString  minimum,
                                                     ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerPACPBegin(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerPACPID(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   condition,
                                                     ViString  minimum,
                                                     ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerErrors(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViBoolean LCC,
                                                     ViBoolean length,
                                                     ViBoolean reserved,
                                                     ViBoolean symbol,
                                                     ViBoolean uniProFrame);

ViStatus _VI_FUNC rsscope_ConfigureMPHYTriggerPRPWidth(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViReal64  width);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   errorNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNameBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNameData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNameIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICTriggerFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameStatus(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32*  frameStatus,
                                               ViReal64* frameStart,
                                               ViReal64* frameStop,
                                               ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameDataBytes(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32   arraySize,
                                                  ViInt32   data[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameInfo(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   frame,
                                             ViInt32   arraySize,
                                             ViChar    info[]);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameCellCount(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameCellStatus(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   cell,
                                                   ViInt32*  frameStatus,
                                                   ViReal64* frameStart,
                                                   ViReal64* frameStop);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameCellType(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32   cell,
                                                 ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryMPHYFrameCellData(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32   cell,
                                                 ViInt32*  data);

ViStatus _VI_FUNC rsscope_QueryMPHYSSICFrameType(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt32*  type);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchLCCType(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   LCCType);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchWord(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   word,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchTCPattern(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViString  TCPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchCREQPattern(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   CREQPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchRREQPattern(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   RREQPattern);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   condition,
                                                  ViString  minimum,
                                                  ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchIndex(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   condition,
                                                   ViInt32   minimum,
                                                   ViInt32   maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchFSN(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   condition,
                                                 ViString  minimum,
                                                 ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchCRC(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   condition,
                                                 ViString  minimum,
                                                 ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchCredit(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   condition,
                                                    ViString  minimum,
                                                    ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchPACPBegin(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchPACPID(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   condition,
                                                    ViString  minimum,
                                                    ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSearchErrors(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViBoolean LCC,
                                                    ViBoolean length,
                                                    ViBoolean reserved,
                                                    ViBoolean symbol,
                                                    ViBoolean uniProFrame);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameCount(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameStatus(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32*  frameStatus,
                                                     ViReal64* frameStart,
                                                     ViReal64* frameStop,
                                                     ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameDataBytes(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32   arraySize,
                                                        ViInt32   data[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameCellCount(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameCellStatus(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   cell,
                                                         ViInt32*  frameStatus,
                                                         ViReal64* frameStart,
                                                         ViReal64* frameStop);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameCellType(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViInt32   cell,
                                                       ViInt32*  type);

ViStatus _VI_FUNC rsscope_QueryMPHYSearchFrameCellData(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViInt32   cell,
                                                       ViInt32*  data);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   errorNumber,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNameBitState(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNumericBitState(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   bitState);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNameData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNameIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureMPHYSSICSearchFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   signal,
                                                   ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireThresholdPreset(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   preset);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireThresholdCoupling(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireThreshold(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   signal,
                                                      ViReal64  threshold,
                                                      ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSyncSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   mode,
                                                         ViInt32   bitPosition);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireMinGap(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViReal64  minGap);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireTriggerType(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireTriggerControlType(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireTriggerTimeCode(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   condition,
                                                            ViString  minimum,
                                                            ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireTriggerData(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  minimum,
                                                        ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireTriggerErrorConditions(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViBoolean parityError,
                            ViBoolean escapeError);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameStatus(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32*  frameStatus,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameDataBytes(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   arraySize,
                                                       ViInt32   data[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameFieldStatus(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32*  frameStatus,
                                                         ViReal64* frameStart,
                                                         ViReal64* frameStop,
                                                         ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameFieldDataBytes(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   arraySize,
                                                            ViInt32   data[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QuerySpaceWireFrameFieldFormattedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   bufferSize,
                            ViChar    formatedValue[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSearchType(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSearchControlType(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSearchTimeCode(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   condition,
                                                           ViString  minimum,
                                                           ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSearchData(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  minimum,
                                                       ViString  maximum);

ViStatus _VI_FUNC rsscope_ConfigureSpaceWireSearchErrorConditions(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean parityError,
                            ViBoolean escapeError);

ViStatus _VI_FUNC rsscope_QuerySpaceWireSearchFrameCount(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32*  count);

ViStatus _VI_FUNC rsscope_QuerySpaceWireSearchFrameStatus(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32*  frameStatus,
                                                          ViReal64* frameStart,
                                                          ViReal64* frameStop,
                                                          ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QuerySpaceWireSearchFrameDataBytes(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   frame,
                                                             ViInt32   arraySize,
                                                             ViInt32   data[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigurePCIe(ViSession instrSession,
                                        ViInt32   serialBus,
                                        ViInt32   generation,
                                        ViInt32   link,
                                        ViBoolean descrambling);

ViStatus _VI_FUNC rsscope_ConfigurePCIeFilterIdle(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViBoolean filterIdlePackets);

ViStatus _VI_FUNC rsscope_ConfigurePCIeLane(ViSession instrSession,
                                            ViInt32   serialBus,
                                            ViInt32   lane,
                                            ViInt32   source,
                                            ViReal64  thresholdLow,
                                            ViReal64  thresholdHigh);

ViStatus _VI_FUNC rsscope_ConfigurePCIeCDR(ViSession instrSession,
                                           ViInt32   serialBus,
                                           ViInt64   nominalBitRate,
                                           ViInt32   initialPhaseSync,
                                           ViInt32   selectedResults);

ViStatus _VI_FUNC rsscope_ConfigurePCIeCDRPLL(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   order,
                                              ViReal64  damping,
                                              ViReal64  bandwidth);

ViStatus _VI_FUNC rsscope_ConfigurePCIeCDRPLLRelativeBandwidth(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViReal64  relativeBandwidth);

ViStatus _VI_FUNC rsscope_ConfigurePCIeShowMultipleLanes(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showMultipleLanes);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerLevel(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  level);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerOSET(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   orderedSetCondition);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerError(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViBoolean CRC16,
                                                    ViBoolean LCRC,
                                                    ViBoolean ECRC,
                                                    ViBoolean invalidSymbol,
                                                    ViBoolean disparityError);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerErrorCondition(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViBoolean length,
                                                             ViBoolean malformError,
                                                             ViBoolean maxEndPrefix,
                                                             ViBoolean prefixOrderError,
                                                             ViBoolean syncBit,
                                                             ViBoolean valueOutOfRange,
                                                             ViBoolean unknownPacket);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPType(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   TLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPAnyType(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViString  sequenceNumber,
                                                         ViInt32   TC,
                                                         ViInt32   ordering,
                                                         ViInt32   snoop,
                                                         ViString  requesterID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPMem(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViInt32   readWrite,
                                                     ViString  requesterID,
                                                     ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPIO(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViInt32   readWrite,
                                                    ViString  requesterID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPCfg(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViInt32   readWrite,
                                                     ViString  requesterID,
                                                     ViInt32   type,
                                                     ViString  deviceID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPMsg(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViString  requesterID,
                                                     ViInt32   routing,
                                                     ViString  messageCode);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPCpl(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViString  requesterID,
                                                     ViInt32   status,
                                                     ViString  completerID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPFetchAdd(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViString  sequenceNumber,
                                                          ViInt32   TC,
                                                          ViInt32   ordering,
                                                          ViInt32   snoop,
                                                          ViString  requesterID,
                                                          ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPSwap(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViString  sequenceNumber,
                                                      ViInt32   TC,
                                                      ViInt32   ordering,
                                                      ViInt32   snoop,
                                                      ViString  requesterID,
                                                      ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerTLPCAS(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViString  requesterID,
                                                     ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPType(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   DLLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPMRType(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   MRDLLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPMRInit(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   phase,
                                                         ViInt32   VHFC,
                                                         ViInt32   mixedType,
                                                         ViInt32   authorized,
                                                         ViInt32   devicePortType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPMRReset(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   a,
                                                          ViInt32   VHGroup);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPMRFC(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   MRDLLP,
                                                       ViInt32   VLNumber,
                                                       ViInt32   VHAbsent,
                                                       ViInt32   TLPType,
                                                       ViInt32   creditType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPAck(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   DLLP,
                                                      ViString  sequence);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPFC(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   DLLP,
                                                     ViInt32   creditType,
                                                     ViInt32   VCID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPPM(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   PMType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeTriggerDLLPVendor(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViString  vendorPattern);

ViStatus _VI_FUNC rsscope_QueryPCIePacketCount(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32*  packetCount);

ViStatus _VI_FUNC rsscope_QueryPCIePacketStatus(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   packet,
                                                ViInt32*  packetStatus,
                                                ViReal64* packetStart,
                                                ViReal64* packetStop,
                                                ViInt32*  packetType);

ViStatus _VI_FUNC rsscope_QueryPCIePacketDataBytes(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   packet,
                                                   ViInt32   arraySize,
                                                   ViInt32   data[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryPCIePacketSequenceNumber(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   packet,
                                                        ViInt32*  sequenceNumber);

ViStatus _VI_FUNC rsscope_QueryPCIePacketTag(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   packet,
                                             ViInt32*  tag);

ViStatus _VI_FUNC rsscope_QueryPCIePacketLength(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViInt32   packet,
                                                ViInt32*  length);

ViStatus _VI_FUNC rsscope_QueryPCIePacketAddress(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   packet,
                                                 ViInt32*  address);

ViStatus _VI_FUNC rsscope_QueryPCIePacketHFC(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   packet,
                                             ViInt32*  HFC);

ViStatus _VI_FUNC rsscope_QueryPCIePacketDFC(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32   packet,
                                             ViInt32*  DFC);

ViStatus _VI_FUNC rsscope_QueryPCIePacketCompletionStatus(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   packet,
                                                          ViInt32*  completionStatus);

ViStatus _VI_FUNC rsscope_QueryPCIePacketRequesterID(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   packet,
                                                     ViInt32*  requesterID);

ViStatus _VI_FUNC rsscope_QueryPCIePacketCompleterID(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   packet,
                                                     ViInt32*  completerID);

ViStatus _VI_FUNC rsscope_QueryPCIePacketDecodedFieldsCount(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   packet,
                                                            ViInt32*  decodedFieldsCount);

ViStatus _VI_FUNC rsscope_QueryPCIePacketField(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   packet,
                                               ViInt32   field,
                                               ViInt32   bufferSize,
                                               ViInt32*  fieldStatus,
                                               ViChar    fieldType[],
                                               ViInt32*  fieldValue);

ViStatus _VI_FUNC rsscope_QueryPCIePacketFormattedValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   packet,
                                                        ViInt32   field,
                                                        ViInt32   bufferSize,
                                                        ViChar    formattedValue[]);

ViStatus _VI_FUNC rsscope_QueryProtocolPCIePacketBitRate(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   packet,
                                                         ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_ConfigurePCIeDSPDFEEnabled(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViBoolean DFE);

ViStatus _VI_FUNC rsscope_ConfigurePCIeDSPDFEEstimateCoefficientsEnabled(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViBoolean estimateCoefficients);

ViStatus _VI_FUNC rsscope_ConfigureCIeDSPDFECoefficient(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  coefficient);

ViStatus _VI_FUNC rsscope_ConfigurePCIeDSPDFENumberOfTaps(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   numberOfTaps);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   searchType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchOrderedSets(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViBoolean TS1,
                                                         ViBoolean TS2,
                                                         ViBoolean fastTrainingSeq,
                                                         ViBoolean electricalIdle,
                                                         ViBoolean electricalIdleExit,
                                                         ViBoolean SKP,
                                                         ViBoolean compliancePattern);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchOrderedSetsStartOfDataSequence(
                            ViSession instrSession,
                            ViString  searchName,
                            ViBoolean startOfDataSequence);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchError(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViBoolean CRC16,
                                                   ViBoolean LCRC,
                                                   ViBoolean ECRC,
                                                   ViBoolean invalidSymbol,
                                                   ViBoolean disparityError);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchErrorCondition(ViSession instrSession,
                                                            ViString  searchName,
                                                            ViBoolean lengthError,
                                                            ViBoolean malformedError,
                                                            ViBoolean maxEndPrefix,
                                                            ViBoolean prefixOrderError,
                                                            ViBoolean syncBit,
                                                            ViBoolean unknownPacket,
                                                            ViBoolean valueOutOfRange);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPType(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   TLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPAnyType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViString  sequenceNumber,
                                                        ViInt32   TC,
                                                        ViInt32   ordering,
                                                        ViInt32   snoop,
                                                        ViString  requesterID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPMem(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViInt32   readWrite,
                                                    ViString  requesterID,
                                                    ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPIO(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViString  sequenceNumber,
                                                   ViInt32   TC,
                                                   ViInt32   ordering,
                                                   ViInt32   snoop,
                                                   ViInt32   readWrite,
                                                   ViString  requesterID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPCfg(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViInt32   readWrite,
                                                    ViString  requesterID,
                                                    ViInt32   type,
                                                    ViString  deviceID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPMsg(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViString  requesterID,
                                                    ViInt32   routing,
                                                    ViString  messageCode);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPCpl(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViString  requesterID,
                                                    ViInt32   status,
                                                    ViString  completerID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPFetchAdd(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViString  sequenceNumber,
                                                         ViInt32   TC,
                                                         ViInt32   ordering,
                                                         ViInt32   snoop,
                                                         ViString  requesterID,
                                                         ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPSwap(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViString  sequenceNumber,
                                                     ViInt32   TC,
                                                     ViInt32   ordering,
                                                     ViInt32   snoop,
                                                     ViString  requesterID,
                                                     ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchTLPCAS(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViString  sequenceNumber,
                                                    ViInt32   TC,
                                                    ViInt32   ordering,
                                                    ViInt32   snoop,
                                                    ViString  requesterID,
                                                    ViInt32   addressType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPType(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   DLLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPMRType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   MRDLLP);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPMRInit(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   phase,
                                                        ViInt32   VHFC,
                                                        ViInt32   mixedType,
                                                        ViInt32   authorized,
                                                        ViInt32   devicePortType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPMRReset(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   a,
                                                         ViInt32   VHGroup);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPMRFC(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   MRDLLP,
                                                      ViInt32   VLNumber,
                                                      ViInt32   VHAbsent,
                                                      ViInt32   TLPType,
                                                      ViInt32   creditType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPAck(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   DLLP,
                                                     ViString  sequence);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPFC(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   DLLP,
                                                    ViInt32   creditType,
                                                    ViInt32   VCID);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPPM(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   PMType);

ViStatus _VI_FUNC rsscope_ConfigurePCIeSearchDLLPVendor(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViString  vendorPattern);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketCount(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32*  searchPCIePacketCount);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketStatus(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   packet,
                                                      ViInt32*  packetStatus,
                                                      ViReal64* packetStart,
                                                      ViReal64* packetStop,
                                                      ViInt32*  packetType);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketDataBytes(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   packet,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketSequenceNumber(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   packet,
                            ViInt32*  sequenceNumber);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketTag(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   packet,
                                                   ViInt32*  tag);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketLength(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   packet,
                                                      ViInt32*  length);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketAddress(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   packet,
                                                       ViInt32*  address);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketHFC(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   packet,
                                                   ViInt32*  HFC);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketDFC(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   packet,
                                                   ViInt32*  DFC);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketCompletionStatus(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   packet,
                            ViInt32*  completionStatus);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketRequesterID(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   packet,
                                                           ViInt32*  requesterID);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketCompleterID(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   packet,
                                                           ViInt32*  completerID);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketDecodedFieldsCount(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   packet,
                            ViInt32*  decodedFieldsCount);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketField(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   packet,
                                                     ViInt32   field,
                                                     ViInt32   bufferSize,
                                                     ViInt32*  fieldStatus,
                                                     ViChar    fieldType[],
                                                     ViInt32*  fieldValue);

ViStatus _VI_FUNC rsscope_QueryPCIeSearchPacketFormattedValue(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   packet,
                            ViInt32   field,
                            ViInt32   bufferSize,
                            ViChar    formattedValue[]);

ViStatus _VI_FUNC rsscope_ConfigureCXPI(ViSession instrSession,
                                        ViInt32   serialBus,
                                        ViInt32   source,
                                        ViInt32   polarity);

ViStatus _VI_FUNC rsscope_ConfigureCXPIThresholds(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViReal64  threshold,
                                                  ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureCXPIDisplayOrder(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   displayOrder);

ViStatus _VI_FUNC rsscope_ConfigureCXPIBitRate(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViBoolean enabled,
                                               ViInt32   bitRateValue);

ViStatus _VI_FUNC rsscope_QueryCXPIMeasuredBitRate(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  measuredBitRate);

ViStatus _VI_FUNC rsscope_ConfigureCXPISpacing(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   IBSMin,
                                               ViInt32   IBSMax,
                                               ViInt32   IFSMin,
                                               ViInt32   IFSMax);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerType(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_ConfigureCXPITrigger(ViSession instrSession,
                                               ViInt32   trigger,
                                               ViString  NM,
                                               ViString  CT);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerFrameID(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   condition,
                                                      ViString  min,
                                                      ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerDLC(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   condition,
                                                  ViString  min,
                                                  ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerDLCExtend(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  min,
                                                        ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerData(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   condition,
                                                   ViString  min,
                                                   ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerIndex(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   condition,
                                                    ViInt32   min,
                                                    ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureCXPITriggerError(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViBoolean CRC,
                                                    ViBoolean DLC,
                                                    ViBoolean IBS,
                                                    ViBoolean IFS,
                                                    ViBoolean length,
                                                    ViBoolean parity,
                                                    ViBoolean UART);

ViStatus _VI_FUNC rsscope_QueryCXPIFrameCount(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryCXPIFrameStatus(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViInt32   frame,
                                               ViInt32*  frameStatus,
                                               ViReal64* frameStart,
                                               ViReal64* frameStop,
                                               ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryCXPIFrameDataBytes(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32   arraySize,
                                                  ViInt32   data[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryCXPIFrameDLCField(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViReal64* DLCField);

ViStatus _VI_FUNC rsscope_QueryCXPIFrameWordStatus(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   word,
                                                   ViInt32*  status,
                                                   ViChar    type[],
                                                   ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchType(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   searchType);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearch(ViSession instrSession,
                                              ViString  searchName,
                                              ViString  NM,
                                              ViString  CT);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchFrameID(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   condition,
                                                     ViString  min,
                                                     ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchDLC(ViSession instrSession,
                                                 ViString  searchName,
                                                 ViInt32   condition,
                                                 ViString  min,
                                                 ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchDLCExtend(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  min,
                                                       ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchData(ViSession instrSession,
                                                  ViString  searchName,
                                                  ViInt32   condition,
                                                  ViString  min,
                                                  ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchIndex(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32   condition,
                                                   ViInt32   min,
                                                   ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureCXPISearchError(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViBoolean CRC,
                                                   ViBoolean DLC,
                                                   ViBoolean IBS,
                                                   ViBoolean IFS,
                                                   ViBoolean length,
                                                   ViBoolean parity,
                                                   ViBoolean UART);

ViStatus _VI_FUNC rsscope_QueryCXPISearchFrameCount(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryCXPISearchFrameStatus(ViSession instrSession,
                                                     ViString  searchName,
                                                     ViInt32   frame,
                                                     ViInt32*  frameStatus,
                                                     ViReal64* frameStart,
                                                     ViReal64* frameStop,
                                                     ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryCXPISearchFrameDLCField(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViReal64* DLCField);

ViStatus _VI_FUNC rsscope_QueryCXPISearchFrameDataBytes(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32   arraySize,
                                                        ViInt32   data[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryCXPISearchFrameWordStatus(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   word,
                                                         ViInt32*  status,
                                                         ViChar    type[],
                                                         ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureDDR(ViSession instrSession,
                                       ViInt32   serialBus,
                                       ViInt32   type,
                                       ViInt32   source,
                                       ViReal64  threshold,
                                       ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_QueryDDRFrameCount(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryDDRFrameStatus(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   frame,
                                              ViInt32*  frameStatus,
                                              ViReal64* frameStart,
                                              ViReal64* frameStop,
                                              ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryDDRFrameNumberOfWords(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  words);

ViStatus _VI_FUNC rsscope_QueryDDRFrameFieldStatus(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  frameStatus,
                                                   ViReal64* frameStart,
                                                   ViReal64* frameStop,
                                                   ViInt32*  value,
                                                   ViInt32   bufferSize,
                                                   ViChar    formattedValue[]);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramDisplay(ViSession instrSession,
                                                        ViInt32   eyeDiagram,
                                                        ViInt32   maxSlicesPerAcquisition,
                                                        ViInt32   stripeDisplayMode);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramPersistence(ViSession instrSession,
                                                            ViInt32   eyeDiagram,
                                                            ViBoolean persistenceState,
                                                            ViBoolean infinitePersistenceState,
                                                            ViReal64  time);

ViStatus _VI_FUNC rsscope_ResetDDREyeDiagramPersistence(ViSession instrSession,
                                                        ViInt32   eyeDiagram);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramEnabled(ViSession instrSession,
                                                        ViInt32   eyeDiagram,
                                                        ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramSource(ViSession instrSession,
                                                       ViInt32   eyeDiagram,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramBitRate(ViSession instrSession,
                                                        ViInt32   eyeDiagram,
                                                        ViInt64   bitRate);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramTimingReference(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   timingReferenceSource,
                            ViInt32   slope,
                            ViInt32   level);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceSignalSource(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   referenceSignalSource);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceCDRType(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   CDRType);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceSoftwareCDR(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   softwareCDR);

ViStatus _VI_FUNC rsscope_QueryEyeDiagramCDRReferenceFiles(ViSession instrSession,
                                                           ViInt32   referenceNumber,
                                                           ViInt32*  algorithm,
                                                           ViReal64* bandwidth,
                                                           ViInt32*  relativeBandwidth,
                                                           ViInt64*  bitRate,
                                                           ViReal64* sampling,
                                                           ViInt32*  analogSource);

ViStatus _VI_FUNC rsscope_EstimateEyeDiagramTimingReferenceClockFrequency(
                            ViSession instrSession,
                            ViInt32   eyeDiagram);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceExplicitClock(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   clockSource,
                            ViInt32   clockLevel,
                            ViReal64  clockFrequency,
                            ViInt32   clockFactor,
                            ViInt32   edgeType);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceClockDelay(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViReal64  clockOffset,
                            ViReal64  samplingTime);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramTimingReferenceSerialBus(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramHorizontalSettings(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   timeSettings,
                            ViReal64  timeRange,
                            ViReal64  timePosition,
                            ViReal64  bitRate,
                            ViReal64  rangeUI,
                            ViReal64  positionUI);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramVerticalSettings(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViReal64  scale,
                            ViReal64  offset,
                            ViReal64  position);

ViStatus _VI_FUNC rsscope_QueryEyeDiagramResultsofEye(ViSession instrSession,
                                                      ViInt32   eyeDiagram,
                                                      ViInt32*  numberOfFilteredBits,
                                                      ViReal64* filteredBitPosition,
                                                      ViInt32*  numberOfSlices,
                                                      ViReal64* lastSlicePosition,
                                                      ViInt32*  numberOfAcquisitions);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramMeasurementMaxPrecision(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViBoolean maxPrecision);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramGate(ViSession instrSession,
                                                     ViInt32   eyeDiagram,
                                                     ViBoolean enabled,
                                                     ViInt32   couplingMode,
                                                     ViInt32   mode,
                                                     ViReal64  start,
                                                     ViReal64  stop,
                                                     ViInt32   cursor,
                                                     ViString  diagram,
                                                     ViString  zoom);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramSignal(ViSession instrSession,
                                                       ViInt32   eyeDiagram,
                                                       ViBoolean enabled,
                                                       ViInt32   source,
                                                       ViInt32   condition,
                                                       ViInt32   verticalReferenceLevel);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramSignalReferenceLevelStop(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   verticalReferenceLevelStop);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterEnabled(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterReset(ViSession instrSession,
                                                            ViInt32   eyeDiagram);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterBitSequenceMode(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterPatternPrefixBit(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   bit,
                            ViInt32   bitValue);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterPatternCenterBit(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   bitValue);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterPatternSuffixBit(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   bit,
                            ViInt32   bitValue);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterPatternShiftBit(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   shift);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterFrameType(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViInt32   frameType);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramFilterLengthErrors(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViBoolean lengthErrorsEnabled);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramMaskTestsSlices(
                            ViSession instrSession,
                            ViInt32*  completed,
                            ViInt32*  hits);

ViStatus _VI_FUNC rsscope_ConfigureDDREyeDiagramMaskTestsViolation(
                            ViSession instrSession,
                            ViInt32   violation,
                            ViInt32*  count,
                            ViReal64* start,
                            ViReal64* stop,
                            ViInt32*  slice);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramMaskTestsZoomCoupling(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViBoolean zoomCouplingEnabled);

ViStatus _VI_FUNC rsscope_ConfigureEyeDiagramMaskTestsZoomDiagram(
                            ViSession instrSession,
                            ViInt32   eyeDiagram,
                            ViString  diagram,
                            ViString  zoom);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchErrorTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  errorName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchErrorTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   errorNumber,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameTypeNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameTypeNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frameNumber,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNameEnabled(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNumericEnabled(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNameData(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNameIndex(
                            ViSession instrSession,
                            ViString  searchName,
                            ViString  frame,
                            ViString  field,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNumericData(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_ConfigureDDRSearchFrameFieldNumericIndex(
                            ViSession instrSession,
                            ViInt32   frame,
                            ViInt32   field,
                            ViString  searchName,
                            ViInt32   condition,
                            ViInt32   min,
                            ViInt32   max);

ViStatus _VI_FUNC rsscope_QueryDDRSearchFrameCount(ViSession instrSession,
                                                   ViString  searchName,
                                                   ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_QueryDDRSearchFrameStatus(ViSession instrSession,
                                                    ViString  searchName,
                                                    ViInt32   frame,
                                                    ViInt32*  frameStatus,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_QueryDDRSearchFrameNumberOfWords(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32*  words);

ViStatus _VI_FUNC rsscope_QueryDDRSearchFrameFieldStatus(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32*  frameStatus,
                                                         ViReal64* frameStart,
                                                         ViReal64* frameStop,
                                                         ViInt32*  value,
                                                         ViInt32   bufferSize,
                                                         ViChar    formattedValue[]);

ViStatus _VI_FUNC rsscope_Configure100BASET1(ViSession instrSession,
                                             ViInt32   serialBus,
                                             ViReal64  attenuation,
                                             ViInt32   polarity,
                                             ViReal64  threshold,
                                             ViInt32   mode,
                                             ViReal64  symbolRate);

ViStatus _VI_FUNC rsscope_Configure100BASET1Source(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   direction,
                                                   ViInt32   positiveSource,
                                                   ViInt32   negativeSource,
                                                   ViInt32   differentialSource);

ViStatus _VI_FUNC rsscope_Configure100BASET1SignalType(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   direction,
                                                       ViInt32   type);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerType(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerDestinationAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerSourceAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerTypeLength(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerCRC(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   condition,
                                                       ViString  min,
                                                       ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerData(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   condition,
                                                        ViString  min,
                                                        ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerIndex(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   condition,
                                                         ViInt32   min,
                                                         ViInt32   max);

ViStatus _VI_FUNC rsscope_Configure100BASET1TriggerError(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViBoolean preamble,
                                                         ViBoolean CRC,
                                                         ViBoolean SFD);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameStatus(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32*  frameStatus,
                                                    ViReal64* frameStart,
                                                    ViReal64* frameStop,
                                                    ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameAddress(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   bufferSize,
                                                     ViChar    destination[],
                                                     ViChar    source[]);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameCRC(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   frame,
                                                 ViInt64*  CRC);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameType(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt32*  type);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameLabel(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   bufferSize,
                                                   ViChar    destination[],
                                                   ViChar    source[]);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameBitRate(ViSession instrSession,
                                                     ViInt32   frame,
                                                     ViInt32   serialBus,
                                                     ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameDataBytes(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   arraySize,
                                                       ViInt32   data[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameNumberOfWords(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt64*  words);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameWordStatus(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt64   word,
                                                        ViInt32   bufferSize,
                                                        ViChar    type[],
                                                        ViInt32*  value);

ViStatus _VI_FUNC rsscope_Query100BASET1FrameWordStringValue(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt64   word,
                                                             ViInt32   bufferSize,
                                                             ViChar    value[]);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchType(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchDestinationAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchSourceAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  min,
                            ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchTypeLength(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   condition,
                                                             ViString  min,
                                                             ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchCRC(ViSession instrSession,
                                                      ViString  searchName,
                                                      ViInt32   condition,
                                                      ViString  min,
                                                      ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchData(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   condition,
                                                       ViString  min,
                                                       ViString  max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchIndex(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   condition,
                                                        ViInt32   min,
                                                        ViInt32   max);

ViStatus _VI_FUNC rsscope_Configure100BASET1SearchError(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViBoolean preamble,
                                                        ViBoolean CRC,
                                                        ViBoolean SFD);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameCount(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameStatus(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32   frame,
                                                          ViInt32*  frameStatus,
                                                          ViReal64* frameStart,
                                                          ViReal64* frameStop,
                                                          ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameAddress(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    destination[],
                                                           ViChar    source[]);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameCRC(ViSession instrSession,
                                                       ViString  searchName,
                                                       ViInt32   frame,
                                                       ViInt32*  CRC);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt32*  type);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameLabel(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32   bufferSize,
                                                         ViChar    destination[],
                                                         ViChar    source[]);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameDataBytes(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   frame,
                                                             ViInt32   arraySize,
                                                             ViInt32   data[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameNumberOfWords(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32*  words);

ViStatus _VI_FUNC rsscope_Query100BASET1SearchFrameWordStatus(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   word,
                            ViInt32   bufferSize,
                            ViChar    type[],
                            ViInt32*  value);

ViStatus _VI_FUNC rsscope_ConfigureProtocol1000BASET1(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViReal64  attenuation,
                                                      ViInt32   polarity,
                                                      ViInt32   mode,
                                                      ViReal64  symbolRate);

ViStatus _VI_FUNC rsscope_ConfigureProtocol1000BASET1ForwardSignal(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   signalType,
                            ViInt32   differentialSource,
                            ViInt32   positiveSource,
                            ViInt32   negativeSource);

ViStatus _VI_FUNC rsscope_ConfigureProtocol1000BASET1ReverseSignal(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   signalType,
                            ViInt32   differentialSource,
                            ViInt32   positiveSource,
                            ViInt32   negativeSource);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerType(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerLevel(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViReal64  level);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerDestinationAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  destinationAddressMin,
                            ViString  destinationAddressMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerSourceAddress(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  sourceAddressMin,
                            ViString  sourceAddressMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerLengthType(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  lengthTypeMin,
                            ViString  lengthTypeMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerFrameCheckCRC(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   condition,
                            ViString  CRCMin,
                            ViString  CRCMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerData(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   condition,
                                                         ViString  dataMin,
                                                         ViString  dataMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerIndex(ViSession instrSession,
                                                          ViInt32   trigger,
                                                          ViInt32   condition,
                                                          ViInt32   indexMin,
                                                          ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1TriggerErrors(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViBoolean RSFEC,
                                                           ViBoolean CRC,
                                                           ViBoolean outOfRange,
                                                           ViBoolean zeroTernarySymbol);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameCount(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameStatus(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  status);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameTime(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViReal64* startTime,
                                                   ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameLengthTypeField(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  lengthTypeField);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameCRC(ViSession instrSession,
                                                  ViInt32   serialBus,
                                                  ViInt32   frame,
                                                  ViInt64*  CRC);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameDataBytes(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   arraySize,
                                                        ViInt32   data[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameAddresses(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   bufferSize,
                                                        ViChar    destination[],
                                                        ViChar    source[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameDestinationSymbols(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    symbols[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameSourceSymbols(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   bufferSize,
                                                            ViChar    symbols[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameBitRate(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt64*  bitRate);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameType(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameNumberOfWords(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt64*  numberOfWords);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameWordType(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt64   word,
                                                       ViInt32   bufferSize,
                                                       ViChar    type[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1FrameWordValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt64   word,
                                                        ViInt32*  value);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchType(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frameType);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchDestinationAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  destinationAddressMin,
                            ViString  destinationAddressMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchSourceAddress(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  sourceAddressMin,
                            ViString  sourceAddressMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchLengthType(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  lengthTypeMin,
                            ViString  lengthTypeMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchFrameCheckCRC(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   condition,
                            ViString  CRCMin,
                            ViString  CRCMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchData(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   condition,
                                                        ViString  dataMin,
                                                        ViString  dataMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchIndex(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   condition,
                                                         ViInt32   indexMin,
                                                         ViInt32   indexMax);

ViStatus _VI_FUNC rsscope_Configure1000BASET1SearchErrors(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViBoolean RSFEC,
                                                          ViBoolean CRC,
                                                          ViBoolean outOfRange,
                                                          ViBoolean zeroTernarySymbol);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameCount(ViSession instrSession,
                                                          ViString  searchName,
                                                          ViInt32*  frameCount);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameStatus(ViSession instrSession,
                                                           ViString  searchName,
                                                           ViInt32   frame,
                                                           ViInt32*  frameStatus);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameTime(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViReal64* startTime,
                                                         ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameAddresses(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    frameDestination[],
                            ViChar    frameSource[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameDestinationSymbols(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    destinationSymbols[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameSourceSymbols(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    sourceSymbols[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameDataBytes(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32   arraySize,
                            ViInt32   data[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameCRC(ViSession instrSession,
                                                        ViString  searchName,
                                                        ViInt32   frame,
                                                        ViInt64*  frameCRC);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameLengthType(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt32*  lengthType);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameType(ViSession instrSession,
                                                         ViString  searchName,
                                                         ViInt32   frame,
                                                         ViInt32*  frameType);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameNumberOfWords(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt64*  numberOfWords);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameWordType(ViSession instrSession,
                                                             ViString  searchName,
                                                             ViInt32   frame,
                                                             ViInt64   word,
                                                             ViInt32   bufferSize,
                                                             ViChar    wordType[]);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameWordValue(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt64   word,
                            ViInt32*  value);

ViStatus _VI_FUNC rsscope_Query1000BASET1SearchFrameWordValueString(
                            ViSession instrSession,
                            ViString  searchName,
                            ViInt32   frame,
                            ViInt64   word,
                            ViInt32   bufferSize,
                            ViChar    valueString[]);

ViStatus _VI_FUNC rsscope_HardcopySetFileName(ViSession instrSession,
                                              ViString  name);

ViStatus _VI_FUNC rsscope_ConfigureHardcopyDevice(ViSession instrSession,
                                                  ViInt32   device,
                                                  ViInt32   destination,
                                                  ViBoolean color,
                                                  ViInt32   pageOrientation);

ViStatus _VI_FUNC rsscope_ConfigureHardcopyWhiteBackground(ViSession instrSession,
                                                           ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureHardcopyInverseColors(ViSession instrSession,
                                                         ViInt32   device,
                                                         ViBoolean inverseColors);

ViStatus _VI_FUNC rsscope_ConfigureHardcopyPrintColorSet(ViSession instrSession,
                                                         ViInt32   device,
                                                         ViInt32   colorSet);

ViStatus _VI_FUNC rsscope_HardcopyPrint(ViSession instrSession);

ViStatus _VI_FUNC rsscope_HardcopyPrintNext(ViSession instrSession);

ViStatus _VI_FUNC rsscope_HardcopyGetPrinterList(ViSession instrSession,
                                                 ViInt32   bufferSize,
                                                 ViChar    printerList[]);

ViStatus _VI_FUNC rsscope_HardcopySetPrinter(ViSession instrSession,
                                             ViInt32   device,
                                             ViString  printerName);

ViStatus _VI_FUNC rsscope_FirmwareShutdown(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureComputerName(ViSession instrSession,
                                                ViString  computerName);

ViStatus _VI_FUNC rsscope_QueryInstrumentInformation(ViSession instrSession,
                                                     ViInt32   bufferSize,
                                                     ViChar    firmwaveVersion[],
                                                     ViChar    materialNumber[],
                                                     ViChar    serialNumber[]);

ViStatus _VI_FUNC rsscope_StartSelftest(ViSession instrSession);

ViStatus _VI_FUNC rsscope_SelftestStatus(ViSession instrSession,
                                         ViInt32*  selftestStatus);

ViStatus _VI_FUNC rsscope_ConfigureExternalApplication(ViSession instrSession,
                                                       ViString  name,
                                                       ViString  parameter,
                                                       ViString  workingDirectory);

ViStatus _VI_FUNC rsscope_ConfigureQuickAction(ViSession instrSession,
                                               ViInt32   mode,
                                               ViString  name,
                                               ViString  parameter,
                                               ViString  workingDirectory);

ViStatus _VI_FUNC rsscope_ExecuteQuickAction(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceState(ViSession instrSession,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceStartMode(ViSession instrSession,
                                                        ViInt32   startMode);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceStopMode(ViSession instrSession,
                                                       ViInt32   stopMode);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceFile(ViSession instrSession,
                                                   ViString  fileName,
                                                   ViInt32   format,
                                                   ViInt32   maximumFileSize);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceFileContent(ViSession instrSession,
                                                          ViBoolean input,
                                                          ViBoolean output,
                                                          ViBoolean error,
                                                          ViBoolean trigger,
                                                          ViBoolean deviceClear,
                                                          ViBoolean statusRegister,
                                                          ViBoolean connection,
                                                          ViBoolean remoteLocalEvents,
                                                          ViBoolean locking);

ViStatus _VI_FUNC rsscope_ConfigureRemoteTraceDiagnostic(ViSession instrSession,
                                                         ViBoolean commandExecutionDuration,
                                                         ViBoolean RPCOutput,
                                                         ViBoolean parserTransitionsOutput,
                                                         ViBoolean functionNamesOutput);

ViStatus _VI_FUNC rsscope_SetAttributeViInt32(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeID,
                                              ViInt32   attributeValue);

ViStatus _VI_FUNC rsscope_SetAttributeViInt64(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeID,
                                              ViInt64   attributeValue);

ViStatus _VI_FUNC rsscope_SetAttributeViReal64(ViSession instrSession,
                                               ViString  repeatedCapability,
                                               ViAttr    attributeID,
                                               ViReal64  attributeValue);

ViStatus _VI_FUNC rsscope_SetAttributeViString(ViSession instrSession,
                                               ViString  repeatedCapability,
                                               ViAttr    attributeID,
                                               ViString  attributeValue);

ViStatus _VI_FUNC rsscope_SetAttributeViBoolean(ViSession instrSession,
                                                ViString  repeatedCapability,
                                                ViAttr    attributeID,
                                                ViBoolean attributeValue);

ViStatus _VI_FUNC rsscope_GetAttributeViInt32(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeID,
                                              ViInt32*  attributeValue);

ViStatus _VI_FUNC rsscope_GetAttributeViInt64(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeID,
                                              ViInt64*  attributeValue);

ViStatus _VI_FUNC rsscope_GetAttributeViReal64(ViSession instrSession,
                                               ViString  repeatedCapability,
                                               ViAttr    attributeID,
                                               ViReal64* attributeValue);

ViStatus _VI_FUNC rsscope_GetAttributeViString(ViSession instrSession,
                                               ViString  repeatedCapability,
                                               ViAttr    attributeID,
                                               ViInt32   bufferSize,
                                               ViChar    attributeValue[]);

ViStatus _VI_FUNC rsscope_GetAttributeViBoolean(ViSession  instrSession,
                                                ViString   repeatedCapability,
                                                ViAttr     attributeID,
                                                ViBoolean* attributeValue);

ViStatus _VI_FUNC rsscope_GetAttributeViStringWithRealLen(ViSession instrSession,
                                                          ViString  repeatedCapability,
                                                          ViAttr    attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    attributeValue[],
                                                          ViInt32*  responseLength);

ViStatus _VI_FUNC rsscope_GetAttributeRawStringWithRealLen(ViSession instrSession,
                                                           ViString  repeatedCapability,
                                                           ViAttr    attributeID,
                                                           ViInt32   bufferSize,
                                                           ViChar    attributeValue[],
                                                           ViInt32*  responseLength);

ViStatus _VI_FUNC rsscope_GetAttributeRepCapName(ViSession instrSession,
                                                 ViUInt32  attributeID,
                                                 ViString  repCapNameID,
                                                 ViInt32   index,
                                                 ViInt32   bufferSize,
                                                 ViChar    repCapName[]);

ViStatus _VI_FUNC rsscope_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                            ViUInt32  attributeID,
                                                            ViInt32   bufferSize,
                                                            ViChar    repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rsscope_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rsscope_ConfigureMathEnabled(ViSession instrSession,
                                               ViInt32   mathNumber,
                                               ViBoolean mathEnabled);

ViStatus _VI_FUNC rsscope_ConfigureMathSetup(ViSession instrSession,
                                             ViInt32   mathNumber,
                                             ViInt32   calculationMethod,
                                             ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMathEnvelopeWaveformSelection(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViInt32   envelopeSelection);

ViStatus _VI_FUNC rsscope_ConfigureMathVerticalRange(ViSession instrSession,
                                                     ViInt32   mathNumber,
                                                     ViReal64  verticalRange);

ViStatus _VI_FUNC rsscope_ConfigureMathVerticalScale(ViSession instrSession,
                                                     ViInt32   mathNumber,
                                                     ViReal64  verticalScale);

ViStatus _VI_FUNC rsscope_ConfigureMathVerticalOffset(ViSession instrSession,
                                                      ViInt32   mathNumber,
                                                      ViReal64  verticalOffset);

ViStatus _VI_FUNC rsscope_MathReset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureMathResetMode(ViSession instrSession,
                                                 ViInt32   resetMode,
                                                 ViReal64  envelopeTimeout,
                                                 ViInt32   acquiredWaveforms);

ViStatus _VI_FUNC rsscope_ConfigureFFTType(ViSession instrSession,
                                           ViInt32   math,
                                           ViInt32   FFTType);

ViStatus _VI_FUNC rsscope_ConfigureFFTFrequencyAxis(ViSession instrSession,
                                                    ViInt32   mathNumber,
                                                    ViInt32   frequencyAxis);

ViStatus _VI_FUNC rsscope_ConfigureFFTFrequencyCenterSpan(ViSession instrSession,
                                                          ViInt32   mathNumber,
                                                          ViReal64  centerFrequency,
                                                          ViReal64  frequencySpan);

ViStatus _VI_FUNC rsscope_ConfigureFFTFrequencySpanFull(ViSession instrSession,
                                                        ViInt32   mathNumber);

ViStatus _VI_FUNC rsscope_ConfigureFFTFrequencyStartStop(ViSession instrSession,
                                                         ViInt32   mathNumber,
                                                         ViReal64  startFrequency,
                                                         ViReal64  stopFrequency);

ViStatus _VI_FUNC rsscope_ConfigureFFTResolutionBandwidth(ViSession instrSession,
                                                          ViInt32   mathNumber,
                                                          ViBoolean RBWAndSpanCouplingEnabled,
                                                          ViInt32   RBWRatio,
                                                          ViReal64  resolutionBandwidth);

ViStatus _VI_FUNC rsscope_QueryFFTAdjustedResolutionBandwidth(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViReal64* adjustedRBW);

ViStatus _VI_FUNC rsscope_ConfigureFFTWindowType(ViSession instrSession,
                                                 ViInt32   mathNumber,
                                                 ViInt32   windowType);

ViStatus _VI_FUNC rsscope_ConfigureFFTFrameSetup(ViSession instrSession,
                                                 ViInt32   mathNumber,
                                                 ViInt32   arithmetic,
                                                 ViInt32   overlapFactor,
                                                 ViInt32   maxFrameCount);

ViStatus _VI_FUNC rsscope_QueryFFTFrameCoverage(ViSession instrSession,
                                                ViInt32   mathNumber,
                                                ViReal64* frameCoverage);

ViStatus _VI_FUNC rsscope_ConfigureFFTUseColorTable(ViSession instrSession,
                                                    ViInt32   mathNumber,
                                                    ViBoolean useColorTable);

ViStatus _VI_FUNC rsscope_ConfigureFFTVerticalMaximum(ViSession instrSession,
                                                      ViInt32   math,
                                                      ViReal64  verticalMaximum);

ViStatus _VI_FUNC rsscope_ConfigureFFTMagnitude(ViSession instrSession,
                                                ViInt32   mathNumber,
                                                ViInt32   magnitudeUnit,
                                                ViReal64  referenceLevel,
                                                ViInt32   magnitudeRange);

ViStatus _VI_FUNC rsscope_ConfigureFFTPhase(ViSession instrSession,
                                            ViInt32   mathNumber,
                                            ViInt32   phaseUnit,
                                            ViBoolean phaseUnwrapEnabled,
                                            ViBoolean suppressionEnabled,
                                            ViReal64  suppressionThreshold);

ViStatus _VI_FUNC rsscope_ConfigureFFTGateState(ViSession instrSession,
                                                ViInt32   mathNumber,
                                                ViBoolean useGate);

ViStatus _VI_FUNC rsscope_ConfigureFFTGateShow(ViSession instrSession,
                                               ViInt32   mathNumber,
                                               ViBoolean showGate);

ViStatus _VI_FUNC rsscope_ConfigureFFTGateDefinitionZoom(ViSession instrSession,
                                                         ViInt32   mathNumber,
                                                         ViBoolean zoomCoupling,
                                                         ViInt32   reserved);

ViStatus _VI_FUNC rsscope_ConfigureFFTGateDefinitionStartStop(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViInt32   mode,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureFFTGateRecordLengthRBWCoupling(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViInt32   coupling);

ViStatus _VI_FUNC rsscope_QueryFFTGateRequiredAcquisitionTime(
                            ViSession instrSession,
                            ViReal64* requiredAcquisitionTime);

ViStatus _VI_FUNC rsscope_ConfigureFFTCoupledSpectrum(ViSession instrSession,
                                                      ViInt32   mathNumber,
                                                      ViInt32   mathNumber2,
                                                      ViBoolean coupledSpectrum);

ViStatus _VI_FUNC rsscope_ConfigureFFTSpectrumEnabled(ViSession instrSession,
                                                      ViInt32   mathNumber,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureFFTSpectrumColorTableMode(ViSession instrSession,
                                                             ViInt32   mathNumber,
                                                             ViInt32   colorTableMode);

ViStatus _VI_FUNC rsscope_ConfigureFFTSpectrumTimeLine(ViSession instrSession,
                                                       ViInt32   mathNumber,
                                                       ViInt32   timeline,
                                                       ViBoolean enabled,
                                                       ViInt64   position);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformSource(ViSession instrSession,
                                                           ViInt32   referenceNumber,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsscope_UpdateReferenceWaveformWithSelectedSource(
                            ViSession instrSession,
                            ViInt32   referenceNumber);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformDisplayState(
                            ViSession instrSession,
                            ViInt32   referenceNumber,
                            ViBoolean displayEnabled);

ViStatus _VI_FUNC rsscope_ClearReferenceWaveform(ViSession instrSession,
                                                 ViInt32   referenceNumber);

ViStatus _VI_FUNC rsscope_ReferenceWaveformFileOperations(ViSession instrSession,
                                                          ViInt32   referenceNumber,
                                                          ViString  waveformName,
                                                          ViInt32   operation);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformVerticalScaling(
                            ViSession instrSession,
                            ViInt32   referenceNumber,
                            ViInt32   verticalCoupling,
                            ViReal64  verticalScale,
                            ViReal64  verticalPosition);

ViStatus _VI_FUNC rsscope_ReferenceWaveformVerticalScalingSetToOriginal(
                            ViSession instrSession,
                            ViInt32   referenceNumber);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformVerticalStretching(
                            ViSession instrSession,
                            ViInt32   referenceNumber,
                            ViBoolean verticalStretchingEnabled,
                            ViReal64  factor,
                            ViReal64  offset);

ViStatus _VI_FUNC rsscope_ResetReferenceWaveformVerticalSettings(
                            ViSession instrSession,
                            ViInt32   referenceNumber);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformHorizontalScaling(
                            ViSession instrSession,
                            ViInt32   referenceNumber,
                            ViInt32   horizontalCoupling);

ViStatus _VI_FUNC rsscope_ConfigureReferenceWaveformHorizontalStretching(
                            ViSession instrSession,
                            ViInt32   referenceNumber,
                            ViBoolean horizontalStretchingEnabled,
                            ViReal64  factor,
                            ViReal64  offset);

ViStatus _VI_FUNC rsscope_ConfigureReferenceMultiwaveformName(
                            ViSession instrSession,
                            ViString  name);

ViStatus _VI_FUNC rsscope_ConfigureReferenceMultiwaveformImport(
                            ViSession instrSession,
                            ViInt32   waveformImport);

ViStatus _VI_FUNC rsscope_OpenReferenceMultiwaveform(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ReadWaveform(ViSession instrSession,
                                       ViInt32   channel,
                                       ViInt32   waveform,
                                       ViInt32   waveformSize,
                                       ViInt32   maximumTime,
                                       ViReal64  waveformArray[],
                                       ViInt32*  actualPoints,
                                       ViReal64* initialX,
                                       ViReal64* xIncrement);

ViStatus _VI_FUNC rsscope_ReadWaveformFloat(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   waveform,
                                            ViInt32   waveformSize,
                                            ViInt32   maximumTime,
                                            ViReal32  waveformArray[],
                                            ViInt32*  actualPoints,
                                            ViReal64* initialX,
                                            ViReal64* xIncrement);

ViStatus _VI_FUNC rsscope_ReadMathWaveform(ViSession instrSession,
                                           ViInt32   mathNumber,
                                           ViInt32   waveformSize,
                                           ViInt32   maximumTime,
                                           ViReal64  waveformArray[],
                                           ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ReadMathWaveformFloat(ViSession instrSession,
                                                ViInt32   mathNumber,
                                                ViInt32   waveformSize,
                                                ViInt32   maximumTime,
                                                ViReal32  waveformArray[],
                                                ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ReadMainWaveformMeasurement(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32   statisticType,
                                                      ViInt32   maximumTime,
                                                      ViInt32   bufferSize,
                                                      ViReal64  measurementResult[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadAmplitudeTimeWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   statisticType,
                            ViInt32   maximumTime,
                            ViInt32   bufferSize,
                            ViReal64  measurementResult[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadStartStopAmplitudeTimeWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   maximumTime,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_ReadEyeJitterWaveformMeasurement(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementFunction,
                                                           ViInt32   statisticType,
                                                           ViInt32   maximumTime,
                                                           ViInt32   bufferSize,
                                                           ViReal64  measurementResult[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadStartStopEyeJitterWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   maximumTime,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_ReadHistogramWaveformMeasurement(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementFunction,
                                                           ViInt32   statisticType,
                                                           ViInt32   maximumTime,
                                                           ViInt32   bufferSize,
                                                           ViReal64  measurementResult[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadStartStopHistogramWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   maximumTime,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_ReadSpectrumWaveformMeasurement(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   measurementFunction,
                                                          ViInt32   statisticType,
                                                          ViInt32   maximumTime,
                                                          ViInt32   bufferSize,
                                                          ViReal64  measurementResult[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadStartStopSpectrumWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   maximumTime,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_ReadJitterWaveformMeasurement(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViInt32   measurementFunction,
                                                        ViInt32   statisticType,
                                                        ViInt32   maximumTime,
                                                        ViInt32   bufferSize,
                                                        ViReal64  measurementResult[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ReadStartStopJitterWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   maximumTime,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_ReadReferenceLevelResult(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViInt32   levelType,
                                                   ViReal64* referenceLevelResult);

ViStatus _VI_FUNC rsscope_ReadReferenceWaveform(ViSession instrSession,
                                                ViInt32   waveformSize,
                                                ViInt32   maximumTime,
                                                ViReal64  waveformArray[],
                                                ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ReadReferenceWaveformFloat(ViSession instrSession,
                                                     ViInt32   waveformSize,
                                                     ViInt32   maximumTime,
                                                     ViReal32  waveformArray[],
                                                     ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_InitiateAcquisition(ViSession instrSession,
                                              ViInt32   action);

ViStatus _VI_FUNC rsscope_IsMeasurementComplete(ViSession  instrSession,
                                                ViBoolean* isMeasurementComplete);

ViStatus _VI_FUNC rsscope_WaitForMeasurementComplete(ViSession instrSession,
                                                     ViInt32   timeout);

ViStatus _VI_FUNC rsscope_IsWaitingForTrigger(ViSession  instrSession,
                                              ViBoolean* isWaitingForTrigger);

ViStatus _VI_FUNC rsscope_SendSoftwareTrigger(ViSession instrSession,
                                              ViInt32   maximumTime);

ViStatus _VI_FUNC rsscope_FetchWaveform(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32   waveform,
                                        ViInt32   waveformSize,
                                        ViReal64  waveformArray[],
                                        ViInt32*  actualPoints,
                                        ViReal64* initialX,
                                        ViReal64* xIncrement);

ViStatus _VI_FUNC rsscope_FetchWaveformFloat(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   waveform,
                                             ViInt32   waveformSize,
                                             ViReal32  waveformArray[],
                                             ViInt32*  actualPoints,
                                             ViReal64* initialX,
                                             ViReal64* xIncrement);

ViStatus _VI_FUNC rsscope_FetchWaveformHeader(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   waveform,
                                              ViInt32   bufferSize,
                                              ViChar    waveformHeader[]);

ViStatus _VI_FUNC rsscope_FetchMathWaveform(ViSession instrSession,
                                            ViInt32   mathNumber,
                                            ViInt32   waveformSize,
                                            ViReal64  waveformArray[],
                                            ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchMathWaveformFloat(ViSession instrSession,
                                                 ViInt32   mathNumber,
                                                 ViInt32   waveformSize,
                                                 ViReal32  waveformArray[],
                                                 ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchMathWaveformHeader(ViSession instrSession,
                                                  ViInt32   mathNumber,
                                                  ViInt32   bufferSize,
                                                  ViChar    mathWaveformHeader[]);

ViStatus _VI_FUNC rsscope_FetchReferenceWaveform(ViSession instrSession,
                                                 ViInt32   waveformSize,
                                                 ViReal64  waveformArray[],
                                                 ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchReferenceWaveformFloat(ViSession instrSession,
                                                      ViInt32   waveformSize,
                                                      ViReal32  waveformArray[],
                                                      ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchReferenceWaveformHeader(ViSession instrSession,
                                                       ViInt32   bufferSize,
                                                       ViChar    referenceWaveformHeader[]);

ViStatus _VI_FUNC rsscope_QueryReferenceWaveformSignalType(ViSession instrSession,
                                                           ViInt32   referenceNumber,
                                                           ViInt32*  signalType);

ViStatus _VI_FUNC rsscope_FetchMainWaveformMeasurement(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViInt32   statisticType,
                                                       ViInt32   bufferSize,
                                                       ViReal64  measurementResult[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchAmplitudeTimeWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViInt32   statisticType,
                            ViInt32   bufferSize,
                            ViReal64  measurementResult[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchStartStopAmplitudeTimeWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_FetchEyeJitterWaveformMeasurement(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32   measurementFunction,
                                                            ViInt32   statisticType,
                                                            ViInt32   bufferSize,
                                                            ViReal64  measurementResult[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchStartStopEyeJitterWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_FetchHistogramWaveformMeasurement(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32   measurementFunction,
                                                            ViInt32   statisticType,
                                                            ViInt32   bufferSize,
                                                            ViReal64  measurementResult[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchStartStopHistogramWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_FetchSpectrumWaveformMeasurement(ViSession instrSession,
                                                           ViInt32   measurement,
                                                           ViInt32   measurementFunction,
                                                           ViInt32   statisticType,
                                                           ViInt32   bufferSize,
                                                           ViReal64  measurementResult[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchSpectrumHarmonicsResultsNumber(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32*  numberOfResults);

ViStatus _VI_FUNC rsscope_FetchStartStopSpectrumWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_FetchJitterWaveformMeasurement(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   measurementFunction,
                                                         ViInt32   statisticType,
                                                         ViInt32   bufferSize,
                                                         ViReal64  measurementResult[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_FetchStartStopJitterWaveformMeasurement(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   measurementFunction,
                            ViReal64* startTime,
                            ViReal64* stopTime);

ViStatus _VI_FUNC rsscope_Abort(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigurePowerAnalysisMode(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigurePowerAnalysisCurrentSource(
                            ViSession instrSession,
                            ViInt32   sourceNumber,
                            ViInt32   channel);

ViStatus _VI_FUNC rsscope_ConfigurePowerAnalysisVoltageSource(
                            ViSession instrSession,
                            ViInt32   sourceNumber,
                            ViInt32   channel);

ViStatus _VI_FUNC rsscope_StartPowerAnalysisDeskew(ViSession instrSession,
                                                   ViInt32   maximumTime);

ViStatus _VI_FUNC rsscope_ResetPowerAnalysisSkew(ViSession instrSession,
                                                 ViBoolean state);

ViStatus _VI_FUNC rsscope_UserDefinedPowerAnalysisSkew(ViSession instrSession,
                                                       ViBoolean state);

ViStatus _VI_FUNC rsscope_PowerAnalysisProbeMode(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsscope_QueryPowerAnalysisAutoDeskewValue(ViSession instrSession,
                                                            ViReal64* deskewValue);

ViStatus _VI_FUNC rsscope_PowerAnalysisAutoDeskewToOffset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportManagement(ViSession instrSession,
                                                        ViInt32   operation,
                                                        ViInt32   measurement,
                                                        ViInt32   index);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportLSend(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViChar    returnedValue[]);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportComment(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViString  comment);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportSelection(ViSession instrSession,
                                                       ViInt32   operation,
                                                       ViInt32   measurement);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportDirectory(ViSession instrSession,
                                                       ViInt32   measurement,
                                                       ViString  directory);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportFileManagement(ViSession instrSession,
                                                            ViInt32   operation,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportDUT(ViSession instrSession,
                                                 ViString  DUTName,
                                                 ViString  user,
                                                 ViString  site,
                                                 ViInt32   temperature,
                                                 ViString  description);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportLayout(ViSession instrSession,
                                                    ViInt32   paperSize,
                                                    ViInt32   font,
                                                    ViInt32   fontSize,
                                                    ViInt32   colorFont,
                                                    ViString  logo,
                                                    ViBoolean invertScreenshotColors);

ViStatus _VI_FUNC rsscope_PowerAnalysisReportContent(ViSession instrSession,
                                                     ViBoolean title,
                                                     ViInt32   measurementSetup,
                                                     ViInt32   settings,
                                                     ViInt32   verticalSetup,
                                                     ViInt32   triggerSetup,
                                                     ViInt32   horizontalSetup,
                                                     ViInt32   measuredSignals,
                                                     ViInt32   results);

ViStatus _VI_FUNC rsscope_GetPowerAnalysisReportCount(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsscope_StartPowerQualityMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerQualityInputFrequency(ViSession instrSession,
                                                     ViInt32   frequency);

ViStatus _VI_FUNC rsscope_PowerQualityCustomFrequency(ViSession instrSession,
                                                      ViReal64  customFrequency);

ViStatus _VI_FUNC rsscope_PowerQualityScaling(ViSession instrSession,
                                              ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerQualityAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerQualityMeasurementVoltageResult(
                            ViSession instrSession,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_QueryPowerQualityMeasurementCurrentResult(
                            ViSession instrSession,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_QueryPowerQualityMeasurementPowerResult(
                            ViSession instrSession,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerCurrentHarmonicsMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerCurrentHarmonicsSettings(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   frequency,
                                                        ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerCurrentHarmonicsEvaluation(ViSession instrSession,
                                                          ViInt32   revisedCurrent,
                                                          ViInt32   voltageResultDisplay);

ViStatus _VI_FUNC rsscope_PowerCurrentHarmonicAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerCurrentHarmonicsUsedStandard(
                            ViSession instrSession,
                            ViInt32   resultNumber,
                            ViInt32*  standard);

ViStatus _VI_FUNC rsscope_QueryPowerCurrentHarmonicsResult(ViSession instrSession,
                                                           ViInt32   type,
                                                           ViInt32   resultNumber,
                                                           ViInt32   harmonic,
                                                           ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerInrushCurrentMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerInrushCurrentSettings(ViSession instrSession,
                                                     ViReal64  maxCurrent,
                                                     ViReal64  trigger);

ViStatus _VI_FUNC rsscope_PowerInrushCurrentGateSettings(ViSession instrSession,
                                                         ViInt32   gate,
                                                         ViReal64  start,
                                                         ViReal64  stop);

ViStatus _VI_FUNC rsscope_PowerInrushCurrentGateValue(ViSession instrSession,
                                                      ViInt32   gate,
                                                      ViReal64  numValue);

ViStatus _VI_FUNC rsscope_PowerInrushCurrentGateManagement(ViSession instrSession,
                                                           ViInt32   operation,
                                                           ViInt32   gateIndex);

ViStatus _VI_FUNC rsscope_PowerInrushCurrentGateAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryInrushCurrentGateCount(ViSession instrSession,
                                                      ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryPowerInrushCurrentMeasurementResult(
                            ViSession instrSession,
                            ViInt32   gateNumber,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerRippleMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerRippleCurrent(ViSession instrSession,
                                             ViBoolean state);

ViStatus _VI_FUNC rsscope_PowerRippleSettings(ViSession instrSession,
                                              ViReal64  frequency,
                                              ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerRippleAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerRippleMeasurementResult(ViSession instrSession,
                                                            ViInt32   statistics,
                                                            ViInt32   measType,
                                                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_QueryPowerRippleMeasureResult(ViSession instrSession,
                                                        ViInt32   statistics,
                                                        ViInt32   rippleType,
                                                        ViInt32   measType,
                                                        ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerSpectrumMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerSpectrumSettings(ViSession instrSession,
                                                ViReal64  frequency,
                                                ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerSpectrumAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerSpectrumMeasurementResult(
                            ViSession instrSession,
                            ViInt32   resultNumber,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_QueryPowerSpectrumHarmonicsCount(ViSession instrSession,
                                                           ViInt32*  harmonicsCount);

ViStatus _VI_FUNC rsscope_StartPowerSlewRateMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerSlewRateSettings(ViSession instrSession,
                                                ViInt32   source,
                                                ViBoolean average,
                                                ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerSlewRateAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerSlewRateGateSettings(ViSession instrSession,
                                                    ViReal64  start,
                                                    ViReal64  stop);

ViStatus _VI_FUNC rsscope_QueryPowerSlewRateMeasurementResult(
                            ViSession instrSession,
                            ViInt32   statistics,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerSafeOperatingAreaMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaSettings(ViSession instrSession,
                                                         ViBoolean maskTest,
                                                         ViInt32   scale);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaSwitch(ViSession instrSession,
                                                       ViInt32   scale);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaLinPointManagement(
                            ViSession instrSession,
                            ViInt32   operation,
                            ViInt32   pointNumber);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaLinPointValue(
                            ViSession instrSession,
                            ViInt32   pointNumber,
                            ViInt32   valueType,
                            ViReal64  pointValue);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaLogPointManagement(
                            ViSession instrSession,
                            ViInt32   operation,
                            ViInt32   pointNumber);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaLogPointValue(
                            ViSession instrSession,
                            ViInt32   pointNumber,
                            ViInt32   valueType,
                            ViReal64  pointValue);

ViStatus _VI_FUNC rsscope_PowerSafeOperatingAreaAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerSafeOperatingAreaLinCount(
                            ViSession instrSession,
                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryPowerSafeOperatingAreaLogCount(
                            ViSession instrSession,
                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_StartPowerModulationMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerModulationSettings(ViSession instrSession,
                                                  ViInt32   source,
                                                  ViInt32   type,
                                                  ViBoolean displayHistogram,
                                                  ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerModulationAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerModulationMeasurementResult(
                            ViSession instrSession,
                            ViInt32   statistics,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerDynamicOnResistanceMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerDynamicOnResistanceSettings(ViSession instrSession,
                                                           ViBoolean average,
                                                           ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerDynamicOnResistanceAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerDynamicOnResistanceGateSettings(
                            ViSession instrSession,
                            ViInt32   gate,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsscope_QueryPowerDynamicOnResistanceMeasurementResult(
                            ViSession instrSession,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerEfficiencyMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerEfficiencyScaling(ViSession instrSession,
                                                 ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerEfficiencyAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerEfficiencyMeasurementResult(
                            ViSession instrSession,
                            ViInt32   resultNumber,
                            ViInt32   statistics,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerSwitchinglossMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerSwitchinglossSettings(ViSession instrSession,
                                                     ViBoolean switchingFrequency,
                                                     ViBoolean turnOn,
                                                     ViBoolean conduction,
                                                     ViBoolean turnOff,
                                                     ViBoolean nonConduction,
                                                     ViBoolean total,
                                                     ViInt32   scaling);

ViStatus _VI_FUNC rsscope_PowerSwitchinglossFrequency(ViSession instrSession,
                                                      ViReal64  switchingFrequency);

ViStatus _VI_FUNC rsscope_PowerSwitchinglossGateSettings(ViSession instrSession,
                                                         ViInt32   period,
                                                         ViReal64  start,
                                                         ViReal64  stop);

ViStatus _VI_FUNC rsscope_PowerSwitchinglossAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerSwitchinglossEnergyResult(
                            ViSession instrSession,
                            ViInt32   statistics,
                            ViInt32   type,
                            ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_QueryPowerSwitchinglossPowerResult(ViSession instrSession,
                                                             ViInt32   statistics,
                                                             ViInt32   type,
                                                             ViReal64* measurementResult);

ViStatus _VI_FUNC rsscope_StartPowerOnOffMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_PowerOnOffInputType(ViSession instrSession,
                                              ViInt32   input);

ViStatus _VI_FUNC rsscope_PowerOnOffSettings(ViSession instrSession,
                                             ViInt32   type,
                                             ViBoolean reserved,
                                             ViReal64  triggerLevel,
                                             ViReal64  steadyStateLevel,
                                             ViReal64  time);

ViStatus _VI_FUNC rsscope_PowerOnOffDCLevel(ViSession instrSession,
                                            ViInt32   type,
                                            ViReal64  triggerLevel);

ViStatus _VI_FUNC rsscope_PowerOnOffAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerOnOffMeasurementResult(ViSession instrSession,
                                                           ViInt32   type,
                                                           ViReal64* result);

ViStatus _VI_FUNC rsscope_StartPowerTransientResponseMeasurement(ViSession instrSession);

ViStatus _VI_FUNC rsscope_TransientResponseInputVoltage(ViSession instrSession,
                                                        ViBoolean inputVoltage);

ViStatus _VI_FUNC rsscope_TransientResponseTrigger(ViSession instrSession,
                                                   ViInt32   source,
                                                   ViReal64  level,
                                                   ViInt32   edgeTriggerSlope);

ViStatus _VI_FUNC rsscope_TransientResponseSettings(ViSession instrSession,
                                                    ViReal64  frequency,
                                                    ViInt32   scaling,
                                                    ViInt32   tubeTolerance,
                                                    ViReal64  signalHigh,
                                                    ViReal64  signalLow);

ViStatus _VI_FUNC rsscope_TransientResponseAddToReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryPowerTransientResponseResult(ViSession instrSession,
                                                            ViInt32   type,
                                                            ViReal64* result);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingEnabled(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingEffectiveBandwidth(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  effectiveBandwidth);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingDelayCompensation(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean compensation);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingRealtimeEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingAddComponent(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   index,
                                                           ViInt32   type);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingRemoveComponent(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component);

ViStatus _VI_FUNC rsscope_QueryDeembeddingComponentCount(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32*  count);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingFile(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViString  fileName,
                                                   ViInt32   action);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingPreset(ViSession instrSession,
                                                     ViInt32   channel);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentType(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   component,
                                                            ViInt32   type,
                                                            ViString  name);

ViStatus _VI_FUNC rsscope_QueryDeembeddingComponentPortCount(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   component,
                                                             ViInt32*  count);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentMode(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   component,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentRemoveProbeLoading(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViBoolean loading);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViInt32   impedanceType,
                            ViReal64  impedance);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentLoadSParameterFile(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViString  fileName);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentIdenticalPaths(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViBoolean identicalPaths);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentInputPorts(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViInt32   port1,
                            ViInt32   port2);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentOutputPorts(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViInt32   port1,
                            ViInt32   port2);

ViStatus _VI_FUNC rsscope_ConfigureDeembeddingComponentLoadSParameterFilePort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   component,
                            ViInt32   port,
                            ViString  fileName);

ViStatus _VI_FUNC rsscope_QueryDeembeddingAttenuation(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64* DC,
                                                      ViReal64* max);

ViStatus _VI_FUNC rsscope_QueryDeembeddingMaxGain(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* max);

ViStatus _VI_FUNC rsscope_ConfigureMSOBusState(ViSession instrSession,
                                               ViInt32   bus,
                                               ViBoolean state);

ViStatus _VI_FUNC rsscope_ConfigureMSOVisualization(ViSession instrSession,
                                                    ViInt32   bus,
                                                    ViBoolean showDigitalSignals,
                                                    ViBoolean showBus,
                                                    ViInt32   busRepresentation);

ViStatus _VI_FUNC rsscope_ConfigureMSOClockedBusState(ViSession instrSession,
                                                      ViInt32   bus,
                                                      ViBoolean enableClockedBus);

ViStatus _VI_FUNC rsscope_ConfigureMSOClockedBus(ViSession instrSession,
                                                 ViInt32   bus,
                                                 ViInt32   clockSource);

ViStatus _VI_FUNC rsscope_ConfigureMSOClockedBusSlope(ViSession instrSession,
                                                      ViInt32   bus,
                                                      ViInt32   clockSlope);

ViStatus _VI_FUNC rsscope_ConfigureMSOAssignChannels(ViSession instrSession,
                                                     ViInt32   bus,
                                                     ViInt32   digitalChannel,
                                                     ViBoolean assignState);

ViStatus _VI_FUNC rsscope_ConfigureMSOSignalSelection(ViSession instrSession,
                                                      ViInt32   digitalChannel,
                                                      ViString  label,
                                                      ViReal64  deskew);

ViStatus _VI_FUNC rsscope_ConfigureMSODigitalChannelDisplay(ViSession instrSession,
                                                            ViInt32   digitalChannel,
                                                            ViBoolean display);

ViStatus _VI_FUNC rsscope_ConfigureMSOBusSignalSelection(ViSession instrSession,
                                                         ViInt32   bus,
                                                         ViInt32   digitalChannel,
                                                         ViString  label,
                                                         ViReal64  deskew);

ViStatus _VI_FUNC rsscope_ConfigureMSODeskew(ViSession instrSession,
                                             ViInt32   bus,
                                             ViReal64  deskew);

ViStatus _VI_FUNC rsscope_ConfigureMSOTechnology(ViSession instrSession,
                                                 ViInt32   digitalChannel,
                                                 ViInt32   technology);

ViStatus _VI_FUNC rsscope_ConfigureMSOTresholdSetup(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64  treshold,
                                                    ViInt32   hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureMSOTresholdAllChannels(ViSession instrSession,
                                                          ViInt32   bus,
                                                          ViInt32   technology,
                                                          ViInt32   channelGroup,
                                                          ViReal64  treshold,
                                                          ViInt32   hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureMSOChannelCoupling(ViSession instrSession,
                                                      ViInt32   bus,
                                                      ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureMSODigitalChannelCoupling(ViSession instrSession,
                                                             ViBoolean coupling);

ViStatus _VI_FUNC rsscope_QueryMSODigitalResolution(ViSession instrSession,
                                                    ViReal64* reolution,
                                                    ViReal64* recordLength);

ViStatus _VI_FUNC rsscope_MSORemoveAllAssignedChannels(ViSession instrSession,
                                                       ViInt32   bus);

ViStatus _VI_FUNC rsscope_ReadSignals(ViSession instrSession,
                                      ViInt32   digitalChannel,
                                      ViUInt32  arraySize,
                                      ViInt32   maximumTime,
                                      ViBoolean signalArray[],
                                      ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ConfigureMSODecodeTableShow(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   decodeTable,
                                                      ViBoolean tableEnabled);

ViStatus _VI_FUNC rsscope_ConfigureMSODataFormat(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   format);

ViStatus _VI_FUNC rsscope_ConfigureMSOTrigger(ViSession instrSession,
                                              ViInt32   triggerType);

ViStatus _VI_FUNC rsscope_ConfigureMSOEdgeTriggerSource(ViSession instrSession,
                                                        ViInt32   triggerSource,
                                                        ViInt32   triggerSlope,
                                                        ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMSOWidthTriggerSource(ViSession instrSession,
                                                         ViInt32   triggerSource,
                                                         ViInt32   widthPolarity,
                                                         ViInt32   widthCondition,
                                                         ViReal64  width,
                                                         ViReal64  widthDelta,
                                                         ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMSOTimeoutTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource,
                                                           ViReal64  timeoutValue,
                                                           ViInt32   timeoutCondition,
                                                           ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMSOData2ClockTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource,
                            ViInt32   clockSource,
                            ViInt32   data2ClockPolarity,
                            ViReal64  holdTime,
                            ViReal64  setupTime);

ViStatus _VI_FUNC rsscope_ConfigureMSOStateTriggerSource(ViSession instrSession,
                                                         ViInt32   triggerSource,
                                                         ViInt32   clockSource,
                                                         ViInt32   clockPolarity,
                                                         ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMSOTriggerChannelState(ViSession instrSession,
                                                          ViInt32   digitalChannel,
                                                          ViInt32   triggerType,
                                                          ViInt32   statusBit);

ViStatus _VI_FUNC rsscope_ConfigureMSOPatternTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource,
                                                           ViInt32   patternMode,
                                                           ViInt32   timeoutCondition,
                                                           ViReal64  timeout,
                                                           ViReal64  patternWidth,
                                                           ViReal64  patternDelta,
                                                           ViInt32   patternCondition,
                                                           ViString  expression);

ViStatus _VI_FUNC rsscope_ConfigureMSOSerialPatternTriggerSource(
                            ViSession instrSession,
                            ViInt32   triggerSource,
                            ViInt32   patternPolarity,
                            ViInt32   clockSource,
                            ViString  pattern,
                            ViString  expression);

ViStatus _VI_FUNC rsscope_QueryMSOBusData(ViSession instrSession,
                                          ViInt32   bus,
                                          ViInt32   arraySize,
                                          ViReal64  results[],
                                          ViInt32*  numberOfResults);

ViStatus _VI_FUNC rsscope_QueryMSOChannelData(ViSession instrSession,
                                              ViInt32   digitalChannel,
                                              ViInt32   arraySize,
                                              ViReal64  results[],
                                              ViInt32*  numberOfResults);

ViStatus _VI_FUNC rsscope_QueryMSOBusDataHeader(ViSession instrSession,
                                                ViInt32   bus,
                                                ViReal64* xStart,
                                                ViReal64* xStop,
                                                ViInt32*  recordLength,
                                                ViInt32*  numberOfValues);

ViStatus _VI_FUNC rsscope_QueryMSOChannelDataHeader(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64* xStart,
                                                    ViReal64* xStop,
                                                    ViInt32*  recordLength,
                                                    ViInt32*  numberOfValues);

ViStatus _VI_FUNC rsscope_QueryMSODecodeTable(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   decodeTable,
                                              ViInt32   bufferSize,
                                              ViInt32*  edgeCount,
                                              ViChar    tableData[],
                                              ViInt32*  returnedCharacters);

ViStatus _VI_FUNC rsscope_ConfigurePulseSourceSetup(ViSession instrSession,
                                                    ViBoolean enabled,
                                                    ViReal64  outputLevel,
                                                    ViInt32   repetitionRate,
                                                    ViInt32   dutyCycle,
                                                    ViInt32   clockMode);

ViStatus _VI_FUNC rsscope_ResetPulseSource(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTMeasurement(ViSession instrSession,
                                                     ViInt32   measurementType,
                                                     ViInt32   configuration);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTSingleEndedChannels(ViSession instrSession,
                                                             ViInt32   referenceChannel,
                                                             ViInt32   outChannel);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTDifferentialChannels(
                            ViSession instrSession,
                            ViInt32   referenceChannel,
                            ViInt32   outChannel,
                            ViInt32   diffOutChannel,
                            ViInt32   diffReferenceChannel);

ViStatus _VI_FUNC rsscope_MeasureTDRTDTWithDefaultValues(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTCalibrationLoad(ViSession instrSession,
                                                         ViString  filename);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTCalibrationSave(ViSession instrSession,
                                                         ViString  filename);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTPulseReferenceChannel(
                            ViSession instrSession,
                            ViInt32   channel);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTShortLength(ViSession instrSession,
                                                     ViReal64  shortLength);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTUseCalibration(ViSession instrSession,
                                                        ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTMeasurementParameters(
                            ViSession instrSession,
                            ViInt32   averaging,
                            ViReal64  bandwidth,
                            ViInt32   domain,
                            ViReal64  permittivity);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTSignal(ViSession instrSession,
                                                ViInt32   signal,
                                                ViBoolean state,
                                                ViReal64  verticalScale,
                                                ViReal64  offset,
                                                ViReal64  position);

ViStatus _VI_FUNC rsscope_FetchTDRTDTSignalWaveformHeader(ViSession instrSession,
                                                          ViInt32   signal,
                                                          ViReal64* xStart,
                                                          ViReal64* xStop,
                                                          ViInt32*  recordLength,
                                                          ViInt32*  valuesPerSample);

ViStatus _VI_FUNC rsscope_FetchTDRTDTSignalCompleteWaveform(ViSession instrSession,
                                                            ViInt32   signal,
                                                            ViUInt32  timeout,
                                                            ViInt32   bufferLength,
                                                            ViReal64  waveformArray[],
                                                            ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_FetchTDRTDTSignalPartialWaveform(ViSession instrSession,
                                                           ViInt32   signal,
                                                           ViUInt32  timeout,
                                                           ViInt32   offset,
                                                           ViInt32   bufferLength,
                                                           ViReal64  waveformArray[],
                                                           ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ConfigureTDRTDTEnabled(ViSession instrSession,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorState(ViSession instrSession,
                                                          ViInt32   generator,
                                                          ViBoolean enable);

ViStatus _VI_FUNC rsscope_WaveformGeneratorPreset(ViSession instrSession,
                                                  ViInt32   generator);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOperationMode(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   operationMode);

ViStatus _VI_FUNC rsscope_WaveformGeneratorCopySettings(ViSession instrSession,
                                                        ViInt32   generator);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFunctionType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   functionType);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorPeriod(ViSession instrSession,
                                                           ViInt32   generator,
                                                           ViReal64  period);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorSymmetry(ViSession instrSession,
                                                             ViInt32   generator,
                                                             ViReal64  symmetry);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorPulseWidth(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  pulseWidth);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorModulationType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   modulationType);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCarrierFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  carrierFrequency);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCarrierPeriod(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  carrierPeriod);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorAMModulation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signal,
                            ViReal64  frequency,
                            ViReal64  depth);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorAMModulationDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorAMModulationSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFMModulation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signal,
                            ViReal64  frequency,
                            ViReal64  frequencyDeviation);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFMModulationDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFMModulationSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorPWMModulation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signal,
                            ViReal64  frequency,
                            ViReal64  depth);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorPWMModulationDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorPWMModulationSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorFSKModulation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency1,
                            ViReal64  frequency2,
                            ViReal64  hopRate);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorSweep(ViSession instrSession,
                                                          ViInt32   generator,
                                                          ViReal64  startFrequency,
                                                          ViReal64  stopFrequency,
                                                          ViReal64  sweepTime);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorArbitrarySource(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorArbitraryRunMode(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   runMode);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorArbitrarySampleRate(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   sampleRate);

ViStatus _VI_FUNC rsscope_QueryWaveformGeneratorArbitrarySamples(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  samples);

ViStatus _VI_FUNC rsscope_WaveformGeneratorArbitraryOpenFile(ViSession instrSession,
                                                             ViInt32   generator,
                                                             ViString  file);

ViStatus _VI_FUNC rsscope_WaveformGeneratorArbitraryMultichannelOpenFile(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViString  file);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorArbitraryMultichannelWaveform(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorArbitraryScopeSource(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   source);

ViStatus _VI_FUNC rsscope_WaveformGeneratorArbitraryScopeOpen(
                            ViSession instrSession,
                            ViInt32   generator);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOutputAmplitude(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  amplitude,
                            ViReal64  offset);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOutputLevel(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  lowLevel,
                            ViReal64  highLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOutputInversion(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean inversion);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOutputUserLoad(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   userLoad);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorOutputDCLevel(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  DCLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorAddNoise(ViSession instrSession,
                                                             ViInt32   generator,
                                                             ViBoolean addNoise);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorNoiseLevelPercent(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  level);

ViStatus _VI_FUNC rsscope_QueryWaveformGeneratorNoiseAbsoluteLevel(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64* absoluteLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorNoiseDCLevel(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  DCLevel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingEnable(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean coupling);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingAll(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean couplingAll);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingOutput(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean couplingOutput);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingNoise(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean noiseCoupling);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingArbitrary(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean arbitraryCoupling);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingAmplitude(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean couplingAmplitude);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingPhaseShift(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  phaseShift);

ViStatus _VI_FUNC rsscope_ConfigureWaveformGeneratorCouplingFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean couplingFrequency);

ViStatus _VI_FUNC rsscope_ConfigurePatternGeneratorState(ViSession instrSession,
                                                         ViBoolean state);

ViStatus _VI_FUNC rsscope_PatternGeneratorPreset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigurePatternGeneratorRunMode(ViSession instrSession,
                                                           ViInt32   runMode);

ViStatus _VI_FUNC rsscope_ExecutePatternGeneratorSingleRun(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigurePatternGeneratorBitRate(ViSession instrSession,
                                                           ViInt32   bitRate);

ViStatus _VI_FUNC rsscope_ConfigurePatternGeneratorHighLevel(ViSession instrSession,
                                                             ViReal64  highLevel);

ViStatus _VI_FUNC rsscope_PatternGeneratorLoadPattern(ViSession instrSession,
                                                      ViString  fileName);

ViStatus _VI_FUNC rsscope_ConfigureGeneratorSynchronization(ViSession instrSession,
                                                            ViInt32   generatorSynchronization);

ViStatus _VI_FUNC rsscope_GeneratorStartAlignment(ViSession instrSession);

ViStatus _VI_FUNC rsscope_GeneratorStartAlignmentWithOPC(ViSession instrSession,
                                                         ViInt32   maximumTime);

ViStatus _VI_FUNC rsscope_GeneratorAbortAlignment(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryGeneratorAlignmentDate(ViSession instrSession,
                                                      ViInt32   bufferSize,
                                                      ViChar    alignmentDate[]);

ViStatus _VI_FUNC rsscope_QueryGeneratorAlignmentTime(ViSession instrSession,
                                                      ViInt32   bufferSize,
                                                      ViChar    alignmentTime[]);

ViStatus _VI_FUNC rsscope_QueryGeneratorAlignmentOverallState(
                            ViSession instrSession,
                            ViInt32*  alignmentOverallState);

ViStatus _VI_FUNC rsscope_ConfigureNumberofFrontends(ViSession instrSession,
                                                     ViInt32   numberOfFrontends);

ViStatus _VI_FUNC rsscope_PresetExternalFrontend(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendMeasurementSetup(
                            ViSession instrSession,
                            ViInt32   measurementSetup);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendChannel(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViInt32   channel);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendConnectionState(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViBoolean connectionEnabled);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendConnectionCurrentState(
                            ViSession  instrSession,
                            ViInt32    frontendPosition,
                            ViBoolean* connectionState);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendType(ViSession instrSession,
                                                    ViInt32   frontendPosition,
                                                    ViInt32   bufferSize,
                                                    ViChar    type[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendConnectionType(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViString  type,
                            ViString  IPAddress,
                            ViString  identifier);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendIdentifier(ViSession instrSession,
                                                          ViInt32   frontendPosition,
                                                          ViInt32   bufferSize,
                                                          ViChar    identity[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendRFInput(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViReal64  RFInput);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendRFLevel(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViInt32   RFLevel);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendReferenceFrequency(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViReal64  referenceFrequency);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendSettings(ViSession instrSession,
                                                        ViInt32   frontendPosition,
                                                        ViReal64* IFOutput,
                                                        ViReal64* RFBandwidth,
                                                        ViReal64* LOInFrequencyCable,
                                                        ViInt32*  externalFrontendGain);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendLOInput(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViInt32   LOInput);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendLOOutputState(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViBoolean LOOutputState);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendAccessories(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViBoolean cableAlignmentEnable,
                            ViString  sParameters);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendRFAttenuation(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViBoolean RFAttenuationAutoMode,
                            ViInt32   RFAttenuation);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendAmplitudeMode(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   amplitudeMode);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendRFAttenuationStepValues(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   bufferSize,
                            ViChar    stepValues[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendConnectionError(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   bufferSize,
                            ViChar    connectionError[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendFrequencyBandConfigAutoMode(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViBoolean autoMode);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendFrequencyBandConfigCount(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32*  count);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendFrequencyBandConfigList(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   bufferSize,
                            ViChar    bandConfigList[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendFrequencyBandConfigSelection(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   frequencyRange);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendFrequencyBandConfigRange(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   frequencyRange,
                            ViInt32   bandConfigID,
                            ViString  parameter,
                            ViInt32   arraySize,
                            ViChar    result[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendIFFrequency(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViReal64* IFFrequencyMax,
                                                           ViReal64* IFFrequencyMin);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendIFFrequencySideband(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   bufferSize,
                            ViChar    sideband[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendLOFrequency(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViReal64* LOFrequency);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendLOOutputFrequency(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViReal64* LOOutputFrequency);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendRFFrequency(ViSession instrSession,
                                                           ViInt32   frontendPosition,
                                                           ViReal64* RFFrequencyMax,
                                                           ViReal64* RFFrequencyMin);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendReferenceFrequencyList(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   bufferSize,
                            ViChar    list[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendIFAttenuation(ViSession instrSession,
                                                             ViInt32   frontendPosition,
                                                             ViInt32*  IFAttenuation);

ViStatus _VI_FUNC rsscope_ConfigureExternalFrontendRFConnector(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   connector);

ViStatus _VI_FUNC rsscope_UpdateExternalFrontend(ViSession instrSession,
                                                 ViInt32   frontendPosition);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendNumberofFrequencyBands(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32*  numberOfFrequencyBands);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendFrequencyBandList(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   multiBand,
                            ViInt32   bufferSize,
                            ViChar    frequencyBandList[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_QueryExternalFrontendFrequencyBandLimits(
                            ViSession instrSession,
                            ViInt32   frontendPosition,
                            ViInt32   multiBand,
                            ViReal64* start,
                            ViReal64* end);

ViStatus _VI_FUNC rsscope_ConfigureIQModeState(ViSession instrSession,
                                               ViBoolean state);

ViStatus _VI_FUNC rsscope_QueryIQWarning(ViSession  instrSession,
                                         ViInt32    channel,
                                         ViInt32    bufferSize,
                                         ViBoolean* enabled,
                                         ViChar     message[]);

ViStatus _VI_FUNC rsscope_ConfigureIQSamplingInputSettings(ViSession instrSession,
                                                           ViReal64  relativeBandwidth,
                                                           ViReal64  sampleRate,
                                                           ViInt32   recordLength);

ViStatus _VI_FUNC rsscope_QueryIQSamplingFilterBandwidth(ViSession instrSession,
                                                         ViInt32*  filterBandwidth);

ViStatus _VI_FUNC rsscope_ConfigureIQSamplingInputType(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   inputType,
                                                       ViInt32   inputMode);

ViStatus _VI_FUNC rsscope_ConfigureIQSamplingRealInput(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64  carrierFrequency,
                                                       ViInt32   sideband);

ViStatus _VI_FUNC rsscope_ConfigureIQSamplingComplexInput(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  carrierFrequency,
                                                          ViInt32   sideband);

ViStatus _VI_FUNC rsscope_QueryIQSamplingInputRate(ViSession instrSession,
                                                   ViInt32*  sampleRate);

ViStatus _VI_FUNC rsscope_QueryIQData(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   arraySize,
                                      ViReal64  i[],
                                      ViReal64  q[],
                                      ViInt32*  numberOfResults);

ViStatus _VI_FUNC rsscope_QueryIQDataHeader(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* xStart,
                                            ViReal64* xStop,
                                            ViInt32*  recordLength,
                                            ViInt32*  valuesPerSample);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAnalysisSpectrogramEnabled(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViBoolean spectrogram);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAnalysisXScaling(ViSession instrSession,
                                                            ViInt32   mathNumber,
                                                            ViInt32   xScaling);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAnalysisCoupledSpectrum(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViInt32   mathNumber2,
                            ViBoolean coupled);

ViStatus _VI_FUNC rsscope_QuerySpectrumAnalysisDataSignalType(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViInt32*  dataSignalType);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAnalysisColorTable(
                            ViSession instrSession,
                            ViInt32   mathNumber,
                            ViBoolean enabled,
                            ViInt32   colorTableMode);

ViStatus _VI_FUNC rsscope_ConfigureSpectrumAnalysisTimeline(ViSession instrSession,
                                                            ViInt32   mathNumber,
                                                            ViInt32   timeline,
                                                            ViBoolean enabled,
                                                            ViInt32   position);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftware(ViSession instrSession,
                                               ViInt32   softwareNumber,
                                               ViReal64  nominalBitRate,
                                               ViInt32   dataEdges,
                                               ViInt32   initialPhaseSync,
                                               ViInt32   selectedResults);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwarePLL(ViSession instrSession,
                                                  ViInt32   softwareNumber,
                                                  ViInt32   order,
                                                  ViReal64  damping,
                                                  ViReal64  bandwidth,
                                                  ViReal64  relativeBandwidth);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwarePLLReverseLockEnabled(
                            ViSession instrSession,
                            ViInt32   softwareNumber,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwareSerialStandard(ViSession instrSession,
                                                             ViInt32   softwareNumber,
                                                             ViInt32   serialStandard);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwareBitRateCorrection(
                            ViSession instrSession,
                            ViInt32   softwareNumber,
                            ViBoolean enabled,
                            ViInt32   source);

ViStatus _VI_FUNC rsscope_CDRSoftwareEstimateBitRateOnce(ViSession instrSession,
                                                         ViInt32   softwareNumber);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwareAlgorithm(ViSession instrSession,
                                                        ViInt32   softwareNumber,
                                                        ViInt32   algorithm);

ViStatus _VI_FUNC rsscope_ConfigureCDRSoftwareSamplingTime(ViSession instrSession,
                                                           ViInt32   softwareNumber,
                                                           ViReal64  samplingTime);

ViStatus _VI_FUNC rsscope_ConfigureCDRHardware(ViSession instrSession,
                                               ViInt32   source,
                                               ViReal64  nominalBitRate,
                                               ViInt32   dataEdges);

ViStatus _VI_FUNC rsscope_ConfigureCDRHardwarePLL(ViSession instrSession,
                                                  ViInt32   order,
                                                  ViReal64  damping,
                                                  ViReal64  bandwidth,
                                                  ViInt32   relativeBandwidth);

ViStatus _VI_FUNC rsscope_ConfigureCDRHardwareSerialStandard(ViSession instrSession,
                                                             ViInt32   serialStandard);

ViStatus _VI_FUNC rsscope_CDRHardwareEstimateBitRateOnce(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureCDRHardwareTriggerUIOffset(
                            ViSession instrSession,
                            ViReal64  UIOffset);

ViStatus _VI_FUNC rsscope_reset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_self_test(ViSession instrSession,
                                    ViInt16*  selfTestResult,
                                    ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rsscope_revision_query(ViSession instrSession,
                                         ViChar    instrumentDriverRevision[],
                                         ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsscope_FetchAllSystemErrors(ViSession instrSession,
                                               ViUInt32  bufferSize,
                                               ViChar    systemErrors[],
                                               ViInt32*  bytesRead);

ViStatus _VI_FUNC rsscope_error_query(ViSession instrSession,
                                      ViInt32*  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rsscope_error_message(ViSession instrSession,
                                        ViStatus  errorCode,
                                        ViChar    errorMessage[]);

ViStatus _VI_FUNC rsscope_ByteOrder(ViSession instrSession,
                                    ViInt32   byteOrder);

ViStatus _VI_FUNC rsscope_SetStatusRegister(ViSession instrSession,
                                            ViInt32   questionableRegister,
                                            ViInt32   enable,
                                            ViInt32   PTransition,
                                            ViInt32   NTransition);

ViStatus _VI_FUNC rsscope_GetStatusRegister(ViSession instrSession,
                                            ViInt32   questionableRegister,
                                            ViInt32   registerPart,
                                            ViInt32*  registerValue);

ViStatus _VI_FUNC rsscope_ConfigureErrorChecking(ViSession instrSession,
                                                 ViBoolean optionChecking,
                                                 ViBoolean rangeChecking,
                                                 ViBoolean statusChecking);

ViStatus _VI_FUNC rsscope_SetOPCTimeout(ViSession instrSession,
                                        ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rsscope_GetOPCTimeout(ViSession instrSession,
                                        ViUInt32* timeout);

ViStatus _VI_FUNC rsscope_SetVISATimeout(ViSession instrSession,
                                         ViUInt32  VISATimeout);

ViStatus _VI_FUNC rsscope_GetVISATimeout(ViSession instrSession,
                                         ViUInt32* VISATimeout);

ViStatus _VI_FUNC rsscope_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsscope_IDQueryResponse(ViSession instrSession,
                                          ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rsscope_QueryDeviceSerialNumber(ViSession instrSession,
                                                  ViUInt32  bufferSize,
                                                  ViChar    deviceID[],
                                                  ViInt32*  bytesRead);

ViStatus _VI_FUNC rsscope_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsscope_QueryOPC(ViSession instrSession,
                                   ViInt32*  OPC);

ViStatus _VI_FUNC rsscope_ScopeModel(ViSession instrSession,
                                     ViInt32*  model);

ViStatus _VI_FUNC rsscope_ScopeSeries(ViSession instrSession,
                                      ViInt32*  series);

ViStatus _VI_FUNC rsscope_ScopeFamily(ViSession instrSession,
                                      ViInt32*  family);

ViStatus _VI_FUNC rsscope_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                      ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsscope_ConfigureMultiThreadLocking(ViSession instrSession,
                                                      ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rsscope_SetSystemDate(ViSession instrSession,
                                        ViInt32   year,
                                        ViInt32   month,
                                        ViInt32   day);

ViStatus _VI_FUNC rsscope_QuerySystemDate(ViSession instrSession,
                                          ViInt32*  year,
                                          ViInt32*  month,
                                          ViInt32*  day);

ViStatus _VI_FUNC rsscope_QuerySystemTime(ViSession instrSession,
                                          ViInt32*  hour,
                                          ViInt32*  minutes,
                                          ViInt32*  seconds);

ViStatus _VI_FUNC rsscope_QueryStatusBitNumber(ViSession instrSession,
                                               ViString  maskTestName,
                                               ViInt32*  status);

ViStatus _VI_FUNC rsscope_OPCSyncWriteEnable(ViSession instrSession,
                                             ViBoolean enable);

ViStatus _VI_FUNC rsscope_OPCSyncQueryEnable(ViSession instrSession,
                                             ViBoolean enable);

ViStatus _VI_FUNC rsscope_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                   ViBoolean useESB,
                                                   ViBoolean CLSBefore,
                                                   ViBoolean useMAV);

ViStatus _VI_FUNC rsscope_GetError(ViSession instrSession,
                                   ViStatus* code,
                                   ViInt32   bufferSize,
                                   ViChar    description[]);

ViStatus _VI_FUNC rsscope_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsscope_WriteInstrData(ViSession instrSession,
                                         ViString  writeBuffer);

ViStatus _VI_FUNC rsscope_ReadInstrData(ViSession instrSession,
                                        ViInt32   numberOfBytesToRead,
                                        ViChar    readBuffer[],
                                        ViUInt32* numBytesRead);

ViStatus _VI_FUNC rsscope_QueryViBoolean(ViSession  instrSession,
                                         ViString   command,
                                         ViBoolean* value);

ViStatus _VI_FUNC rsscope_QueryViInt32(ViSession instrSession,
                                       ViString  command,
                                       ViInt32*  value);

ViStatus _VI_FUNC rsscope_QueryViReal64(ViSession instrSession,
                                        ViString  command,
                                        ViReal64* value);

ViStatus _VI_FUNC rsscope_QueryViString(ViSession instrSession,
                                        ViString  command,
                                        ViInt32   bufferSize,
                                        ViChar    value[]);

ViStatus _VI_FUNC rsscope_SaveInstrumentSettings(ViSession instrSession,
                                                 ViInt32   number);

ViStatus _VI_FUNC rsscope_RecallInstrumentSettings(ViSession instrSession,
                                                   ViInt32   number);

ViStatus _VI_FUNC rsscope_FileManagerOperations(ViSession instrSession,
                                                ViInt32   operation,
                                                ViString  source,
                                                ViString  destination);

ViStatus _VI_FUNC rsscope_ChangeFileAttributes(ViSession instrSession,
                                               ViString  file,
                                               ViString  attributes);

ViStatus _VI_FUNC rsscope_FileCount(ViSession instrSession,
                                    ViString  directory,
                                    ViInt32*  numberOfFilesAndFolders);

ViStatus _VI_FUNC rsscope_FileDirectoryContent(ViSession instrSession,
                                               ViString  directory,
                                               ViInt32   bufferSize,
                                               ViChar    output[]);

ViStatus _VI_FUNC rsscope_FileSubdirectoriesCount(ViSession instrSession,
                                                  ViString  directory,
                                                  ViInt32*  numberOfSubdirectories);

ViStatus _VI_FUNC rsscope_FileSubdirectories(ViSession instrSession,
                                             ViString  directory,
                                             ViInt32   bufferSize,
                                             ViChar    output[]);

ViStatus _VI_FUNC rsscope_FileDrives(ViSession instrSession,
                                     ViInt32   bufferSize,
                                     ViChar    output[]);

ViStatus _VI_FUNC rsscope_ReadToFileFromInstrument(ViSession instrSession,
                                                   ViString  sourceInstrumentFile,
                                                   ViString  destinationPCFile);

ViStatus _VI_FUNC rsscope_WriteFromFileToInstrument(ViSession instrSession,
                                                    ViString  sourcePCFile,
                                                    ViString  destinationInstrumentFile);

ViStatus _VI_FUNC rsscope_DataSetFileOperations(ViSession instrSession,
                                                ViInt32   operation,
                                                ViInt32   stateNumber,
                                                ViString  path);

ViStatus _VI_FUNC rsscope_ConfigureSavesetPreviewImage(ViSession instrSession,
                                                       ViBoolean includeImage);

ViStatus _VI_FUNC rsscope_ConfigureSavesetOneFileUserPreference(
                            ViSession instrSession,
                            ViBoolean status);

ViStatus _VI_FUNC rsscope_OneFileOperations(ViSession instrSession,
                                            ViInt32   operation,
                                            ViString  name);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportChannel(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean exportChannel);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportMultichannel(
                            ViSession instrSession,
                            ViBoolean multichannelExport);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportSource(ViSession instrSession,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeZoom(ViSession instrSession,
                                                           ViString  diagramName,
                                                           ViString  zoomName);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeCursor(ViSession instrSession,
                                                             ViInt32   cursor);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeGate(ViSession instrSession,
                                                           ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeManual(ViSession instrSession,
                                                             ViReal64  start,
                                                             ViReal64  stop);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeComplete(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportScopeDataLogging(
                            ViSession instrSession,
                            ViBoolean dataLogging);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportTimestamps(ViSession instrSession,
                                                            ViBoolean timestamps);

ViStatus _VI_FUNC rsscope_ConfigureWaveformExportFastExport(ViSession instrSession,
                                                            ViBoolean fastExport);

ViStatus _VI_FUNC rsscope_WaveformExportInterleavedXY(ViSession instrSession,
                                                      ViBoolean interleavedXY);

ViStatus _VI_FUNC rsscope_WaveformExportRawValues(ViSession instrSession,
                                                  ViBoolean rawValues);

ViStatus _VI_FUNC rsscope_WaveformExportFile(ViSession instrSession,
                                             ViString  file);

ViStatus _VI_FUNC rsscope_ConfigureWaveformNxSingleAcquisitionDisplayUpdate(
                            ViSession instrSession,
                            ViBoolean displayOff);

ViStatus _VI_FUNC rsscope_ConfigureHistogramExportName(ViSession instrSession,
                                                       ViString  histogramName);

ViStatus _VI_FUNC rsscope_ConfigureHistogramExportIncidence(ViSession instrSession,
                                                            ViInt32   incidence);

ViStatus _VI_FUNC rsscope_HistogramExportFile(ViSession instrSession,
                                              ViString  file);

ViStatus _VI_FUNC rsscope_FetchHistogramExportData(ViSession instrSession,
                                                   ViInt32   arraySize,
                                                   ViReal64  data[],
                                                   ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_NumericResultsSelectItem(ViSession instrSession,
                                                   ViString  item,
                                                   ViBoolean select);

ViStatus _VI_FUNC rsscope_ConfigureNumericResultsParameters(ViSession instrSession,
                                                            ViInt32   delimiter,
                                                            ViBoolean omitUnits);

ViStatus _VI_FUNC rsscope_ConfigureNumericResultsDecimalSymbol(
                            ViSession instrSession,
                            ViInt32   decimal);

ViStatus _VI_FUNC rsscope_SaveNumericResultsBoxes(ViSession instrSession,
                                                  ViString  file);

ViStatus _VI_FUNC rsscope_ConfigureLongTermExportResult(ViSession instrSession,
                                                        ViInt32   measurement);

ViStatus _VI_FUNC rsscope_ConfigureLongTermExportType(ViSession instrSession,
                                                      ViInt32   type);

ViStatus _VI_FUNC rsscope_LongTermExportFile(ViSession instrSession,
                                             ViString  file);

ViStatus _VI_FUNC rsscope_FetchLongTermExportData(ViSession instrSession,
                                                  ViInt32   arraySize,
                                                  ViReal64  data[],
                                                  ViInt32*  actualPoints);

ViStatus _VI_FUNC rsscope_ReportControl(ViSession instrSession,
                                        ViString  language,
                                        ViInt32   paperSize);

ViStatus _VI_FUNC rsscope_ReportComment(ViSession instrSession,
                                        ViString  user,
                                        ViString  comment);

ViStatus _VI_FUNC rsscope_ReportLogo(ViSession instrSession,
                                     ViInt32   logoType,
                                     ViString  logoFile);

ViStatus _VI_FUNC rsscope_ReportFileName(ViSession instrSession,
                                         ViString  fileName);

ViStatus _VI_FUNC rsscope_SaveReport(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureExportEyeSelect(ViSession instrSession,
                                                   ViInt32   eyeSelect);

ViStatus _VI_FUNC rsscope_QueryExportEyeSource(ViSession instrSession,
                                               ViInt32*  exportEyeSource);

ViStatus _VI_FUNC rsscope_ConfigureExportEyePath(ViSession instrSession,
                                                 ViString  eyePath);

ViStatus _VI_FUNC rsscope_SaveExportEye(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ExportEyeData(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViReal64  data[],
                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsscope_ConfigureUserDefinedPresetEnabled(ViSession instrSession,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsscope_ConfigureUserDefinedPresetPathandFileName(
                            ViSession instrSession,
                            ViString  pathName);

ViStatus _VI_FUNC rsscope_OpenUserDefinedPreset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_SaveUserDefinedPreset(ViSession instrSession);

ViStatus _VI_FUNC rsscope_AutonamingFilePattern(ViSession instrSession,
                                                ViString  textInput,
                                                ViBoolean prefix,
                                                ViBoolean userText,
                                                ViBoolean date,
                                                ViBoolean index,
                                                ViBoolean time);

ViStatus _VI_FUNC rsscope_AutonamingDefaultPath(ViSession instrSession,
                                                ViString  defaultPath);

ViStatus _VI_FUNC rsscope_AutonamingResetPath(ViSession instrSession);

ViStatus _VI_FUNC rsscope_AutonamingResetAllSettings(ViSession instrSession);

ViStatus _VI_FUNC rsscope_ConfigureColorTableAssignment(ViSession instrSession,
                                                        ViInt32   source,
                                                        ViBoolean useColorTable,
                                                        ViString  tableName);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevel(ViSession instrSession,
                                                  ViInt32   source,
                                                  ViInt32   referenceLevelMode,
                                                  ViInt32   levelDefinition,
                                                  ViInt32   userLevelSelection);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelAutoSettings(
                            ViSession instrSession,
                            ViInt32   source,
                            ViInt32   signalLevelMode,
                            ViBoolean histogramAveraging,
                            ViInt32   averageCount);

ViStatus _VI_FUNC rsscope_ConfigureReferenceUserSignalLevel(ViSession instrSession,
                                                            ViInt32   source,
                                                            ViReal64  topDistance,
                                                            ViReal64  bottomDistance,
                                                            ViReal64  highSignalLevel,
                                                            ViReal64  lowSignalLevel);

ViStatus _VI_FUNC rsscope_ConfigureUserReferenceLevel(ViSession instrSession,
                                                      ViInt32   source,
                                                      ViReal64  topDistance,
                                                      ViReal64  bottomDistance,
                                                      ViReal64  upperLevel,
                                                      ViReal64  lowerLevel);

ViStatus _VI_FUNC rsscope_ConfigureUserMiddleReferenceLevel(ViSession instrSession,
                                                            ViInt32   source,
                                                            ViReal64  middleLevel);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelRelativeLevels(
                            ViSession instrSession,
                            ViInt32   source,
                            ViInt32   relativeLevels);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelRelativeUserLevels(
                            ViSession instrSession,
                            ViInt32   source,
                            ViInt32   upperLevel,
                            ViInt32   middleLevel,
                            ViInt32   lowerLevel);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelHysteresis(ViSession instrSession,
                                                            ViInt32   source,
                                                            ViReal64  hysteresis);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelTube(ViSession instrSession,
                                                      ViInt32   source,
                                                      ViReal64  topOuter,
                                                      ViReal64  topInner,
                                                      ViReal64  bottomInner,
                                                      ViReal64  bottomOuter);

ViStatus _VI_FUNC rsscope_ConfigureReferenceLevelTubeRelative(
                            ViSession instrSession,
                            ViInt32   source,
                            ViInt32   relativeOuter,
                            ViInt32   relativeInner);

ViStatus _VI_FUNC rsscope_close(ViSession instrSession);

    /****************************************************************************
     *------------------------ Error And Completion Codes ----------------------*
     ****************************************************************************/

#define RSSCOPE_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSSCOPE_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)
#define RSSCOPE_WARN_DATA_NOT_AVAILABLE      (RS_CLASS_WARN_BASE + 0x0003L)

#define RSSCOPE_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSSCOPE_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSSCOPE_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSSCOPE_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSSCOPE_WARNMSG_OVER_RANGE           "Measurement overrange"
#define RSSCOPE_WARNMSG_DATA_NOT_AVAILABLE   "Measurement data not available"

#define RSSCOPE_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSSCOPE_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSSCOPE_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSSCOPE_ERROR_CODES_AND_MSGS \
    {RSSCOPE_WARN_MEASURE_UNCALIBRATED,  RSSCOPE_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSSCOPE_WARN_OVER_RANGE,            RSSCOPE_WARNMSG_OVER_RANGE},\
    {RSSCOPE_WARN_DATA_NOT_AVAILABLE,    RSSCOPE_WARNMSG_DATA_NOT_AVAILABLE},\
    {RSSCOPE_ERROR_MARKER_NOT_ENABLED,   RSSCOPE_ERRMSG_MARKER_NOT_ENABLED},\
    {RSSCOPE_ERROR_NOT_DELTA_MARKER,     RSSCOPE_ERRMSG_NOT_DELTA_MARKER},\
    {RSSCOPE_ERROR_NOT_DELTA_MARKER,     RSSCOPE_ERRMSG_NOT_DELTA_MARKER},\
    {RSSCOPE_ERROR_MAX_TIME_EXCEEDED,    RSSCOPE_ERRMSG_MAX_TIME_EXCEEDED}

     /****************************************************************************
      *---------------------------- End Include File ----------------------------*
      ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSSCOPE_HEADER */

